# All Global changes to build and install go here.
# Per the below section about __spec_install_pre, any rpm
# environment changes that affect %%install need to go
# here before the %%install macro is pre-built.

# Include Fedora files
%global include_fedora 0
# Include RHEL files
%global include_rhel 1

# Disable LTO in userspace packages.
%global _lto_cflags %{nil}

# Option to enable compiling with clang instead of gcc.
%bcond_with toolchain_clang

%if %{with toolchain_clang}
%global toolchain clang
%endif

# Compile the kernel with LTO (only supported when building with clang).
%bcond_with clang_lto

%if %{with clang_lto} && %{without toolchain_clang}
{error:clang_lto requires --with toolchain_clang}
%endif

# Cross compile on copr for arm
# See https://bugzilla.redhat.com/1879599
%if 0%{?_with_cross_arm:1}
%global _target_cpu armv7hl
%global _arch arm
%global _build_arch arm
%global _with_cross    1
%endif

# The kernel's %%install section is special
# Normally the %%install section starts by cleaning up the BUILD_ROOT
# like so:
#
# %%__spec_install_pre %%{___build_pre}\
#     [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf "${RPM_BUILD_ROOT}"\
#     mkdir -p `dirname "$RPM_BUILD_ROOT"`\
#     mkdir "$RPM_BUILD_ROOT"\
# %%{nil}
#
# But because of kernel variants, the %%build section, specifically
# BuildKernel(), moves each variant to its final destination as the
# variant is built.  This violates the expectation of the %%install
# section.  As a result we snapshot the current env variables and
# purposely leave out the removal section.  All global wide changes
# should be added above this line otherwise the %%install section
# will not see them.
%global __spec_install_pre %{___build_pre}

# At the time of this writing (2019-03), RHEL8 packages use w2.xzdio
# compression for rpms (xz, level 2).
# Kernel has several large (hundreds of mbytes) rpms, they take ~5 mins
# to compress by single-threaded xz. Switch to threaded compression,
# and from level 2 to 3 to keep compressed sizes close to "w2" results.
#
# NB: if default compression in /usr/lib/rpm/redhat/macros ever changes,
# this one might need tweaking (e.g. if default changes to w3.xzdio,
# change below to w4T.xzdio):
#
# This is disabled on i686 as it triggers oom errors

%ifnarch i686
%define _binary_payload w3T.xzdio
%endif

Summary: The Linux kernel

# Set debugbuildsenabled to 1 to build separate base and debug kernels
#  (on supported architectures). The kernel-debug-* subpackages will
#  contain the debug kernel.
# Set debugbuildsenabled to 0 to not build a separate debug kernel, but
#  to build the base kernel using the debug configuration. (Specifying
#  the --with-release option overrides this setting.)
%define debugbuildsenabled 1

%if 0%{?fedora}
%define secure_boot_arch x86_64
%else
%define secure_boot_arch x86_64 aarch64 s390x ppc64le
%endif

# Signing for secure boot authentication
%ifarch %{secure_boot_arch}
%global signkernel 1
%else
%global signkernel 0
%endif

# Sign modules on all arches
%global signmodules 1

# Compress modules only for architectures that build modules
%ifarch noarch
%global zipmodules 0
%else
%global zipmodules 1
%endif

%if %{zipmodules}
%global zipsed -e 's/\.ko$/\.ko.xz/'
# for parallel xz processes, replace with 1 to go back to single process
%global zcpu `nproc --all`
%endif

# define buildid .local


%if 0%{?fedora}
%define primary_target fedora
%else
%define primary_target rhel
%endif

# The kernel tarball/base version
%define kversion 5.14

%define rpmversion 5.14.0
%define pkgrelease 162.18.1.rt21.181.el9_1

# This is needed to do merge window version magic
%define patchlevel 14

# allow pkg_release to have configurable %%{?dist} tag
%define specrelease 162.18.1.rt21.181%{?buildid}%{?dist}

%define pkg_release %{specrelease}

# libexec dir is not used by the linker, so the shared object there
# should not be exported to RPM provides
%global __provides_exclude_from ^%{_libexecdir}/kselftests

%define _with_kabidupchk 1
# The following build options are enabled by default, but may become disabled
# by later architecture-specific checks. These can also be disabled by using
# --without <opt> in the rpmbuild command, or by forcing these values to 0.
#
# standard kernel
%define with_up        %{?_without_up:        0} %{?!_without_up:        1}
# kernel PAE (only valid for ARM (lpae))
%define with_pae       %{?_without_pae:       0} %{?!_without_pae:       1}
# kernel-debug
%define with_debug     %{?_without_debug:     0} %{?!_without_debug:     1}
# kernel-zfcpdump (s390 specific kernel for zfcpdump)
%define with_zfcpdump  %{?_without_zfcpdump:  0} %{?!_without_zfcpdump:  1}
# kernel-doc
%define with_doc       %{?_without_doc:       0} %{?!_without_doc:       1}
# realtime
%define with_realtime %{?_without_realtime:   0} %{?!_without_realtime:  1}
# kernel-headers
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
%define with_cross_headers   %{?_without_cross_headers:   0} %{?!_without_cross_headers:   1}
# perf
%define with_perf      %{?_without_perf:      0} %{?!_without_perf:      1}
# tools
%define with_tools     %{?_without_tools:     0} %{?!_without_tools:     1}
# bpf tool
%define with_bpftool   %{?_without_bpftool:   0} %{?!_without_bpftool:   1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# kernel-abi-stablelists
%define with_kernel_abi_stablelists %{?_without_kernel_abi_stablelists: 0} %{?!_without_kernel_abi_stablelists: 1}
# internal samples and selftests
%define with_selftests %{?_without_selftests: 0} %{?!_without_selftests: 1}
#
# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the pae kernel (--with paeonly):
%define with_paeonly   %{?_with_paeonly:      1} %{?!_with_paeonly:      0}
# Only build the debug kernel (--with dbgonly):
%define with_dbgonly   %{?_with_dbgonly:      1} %{?!_with_dbgonly:      0}
# Control whether we perform a compat. check against published ABI.
%define with_kabichk   %{?_without_kabichk:   0} %{?!_without_kabichk:   1}
# Control whether we perform a compat. check against DUP ABI.
%define with_kabidupchk %{?_with_kabidupchk:  1} %{?!_with_kabidupchk:   0}
#
# Control whether to run an extensive DWARF based kABI check.
# Note that this option needs to have baseline setup in SOURCE300.
%define with_kabidwchk %{?_without_kabidwchk: 0} %{?!_without_kabidwchk: 1}
%define with_kabidw_base %{?_with_kabidw_base: 1} %{?!_with_kabidw_base: 0}
#
# Control whether to install the vdso directories.
%define with_vdso_install %{?_without_vdso_install: 0} %{?!_without_vdso_install: 1}
#
# should we do C=1 builds with sparse
%define with_sparse    %{?_with_sparse:       1} %{?!_with_sparse:       0}
#
# Cross compile requested?
%define with_cross    %{?_with_cross:         1} %{?!_with_cross:        0}
#
# build a release kernel on rawhide
%define with_release   %{?_with_release:      1} %{?!_with_release:      0}

# verbose build, i.e. no silent rules and V=1
%define with_verbose %{?_with_verbose:        1} %{?!_with_verbose:      0}

#
# check for mismatched config options
%define with_configchecks %{?_without_configchecks:        0} %{?!_without_configchecks:        1}

#
# gcov support
%define with_gcov %{?_with_gcov:1}%{?!_with_gcov:0}

#
# ipa_clone support
%define with_ipaclones %{?_without_ipaclones: 0} %{?!_without_ipaclones: 1}

# Want to build a vanilla kernel build without any non-upstream patches?
%define with_vanilla %{?_with_vanilla: 1} %{?!_with_vanilla: 0}

%if 0%{?fedora}
# Kernel headers are being split out into a separate package
%define with_headers 0
%define with_cross_headers 0
# no ipa_clone for now
%define with_ipaclones 0
# no stablelist
%define with_kernel_abi_stablelists 0
# Fedora builds these separately
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
# selftests turns on bpftool
%define with_selftests 0
%endif

%if %{with_verbose}
%define make_opts V=1
%else
%define make_opts -s
%endif

%if %{with toolchain_clang}
%global clang_make_opts HOSTCC=clang CC=clang
%if %{with clang_lto}
%global clang_make_opts %{clang_make_opts} LD=ld.lld HOSTLD=ld.lld AR=llvm-ar NM=llvm-nm HOSTAR=llvm-ar HOSTNM=llvm-nm LLVM_IAS=1
%endif
%global make_opts %{make_opts} %{clang_make_opts}
# clang does not support the -fdump-ipa-clones option
%global with_ipaclones 0
%endif

# turn off debug kernel and kabichk for gcov builds
%if %{with_gcov}
%define with_debug 0
%define with_kabichk 0
%define with_kabidupchk 0
%define with_kabidwchk 0
%define with_kabidw_base 0
%define with_kernel_abi_stablelists 0
%endif

# turn off kABI DWARF-based check if we're generating the base dataset
%if %{with_kabidw_base}
%define with_kabidwchk 0
%endif

# kpatch_kcflags are extra compiler flags applied to base kernel
# -fdump-ipa-clones is enabled only for base kernels on selected arches
%if %{with_ipaclones}
%ifarch x86_64 ppc64le
%define kpatch_kcflags -fdump-ipa-clones
%else
%define with_ipaclones 0
%endif
%endif

%if %{with_realtime}
# The preempt RT patch level
#global rttag %%RTTAG%%
# realtimeN
%global rtbuild %%RTBUILD%%
%define with_doc 0
%define with_headers 0
%define with_cross_headers 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_zfcpdump 0
%define with_kabichk  0
%define with_kernel_abi_stablelists 0
%define with_bpf_samples 0
%define with_kabidw_base 0
%define with_ipaclones 0
%endif

%define make_target bzImage
%define image_install_path boot

%define KVERREL %{version}-%{release}.%{_target_cpu}
%define KVERREL_RE %(echo %KVERREL | sed 's/+/[+]/g')
%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%if 0%{!?nopatches:1}
%define nopatches 0
%endif

%if %{with_vanilla}
%define nopatches 1
%endif

%if %{with_release}
%define debugbuildsenabled 1
%endif

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug
# Needed because we override almost everything involving build-ids
# and debuginfo generation. Currently we rely on the old alldebug setting.
%global _build_id_links alldebug

# kernel PAE is only built on ARMv7
%ifnarch armv7hl
%define with_pae 0
%endif

# if requested, only build base kernel
%if %{with_baseonly}
%define with_pae 0
%define with_debug 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# if requested, only build pae kernel
%if %{with_paeonly}
%define with_up 0
%define with_debug 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%define with_up 0
%define with_vdso_install 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_cross 0
%define with_cross_headers 0
%define with_ipaclones 0
%endif

# turn off kABI DUP check and DWARF-based check if kABI check is disabled
%if !%{with_kabichk}
%define with_kabidupchk 0
%define with_kabidwchk 0
%endif

%if %{with_vdso_install}
%define use_vdso 1
%endif

# selftests require bpftool to be built
%if %{with_selftests}
%define with_bpftool 1
%endif

%ifnarch noarch
%define with_kernel_abi_stablelists 0
%endif

# Overrides for generic default options

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%define doc_build_fail true
%endif

%if 0%{?fedora}
# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%define with_debug 0
%endif
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_headers 0
%define with_cross_headers 0
%define with_tools 0
%define with_perf 0
%define with_bpftool 0
%define with_selftests 0
%define with_debug 0
%define all_arch_configs %{name}-%{version}-*.config
%endif

# sparse blows up on ppc
%ifnarch ppc64le
%define with_sparse 0
%endif

# zfcpdump mechanism is s390 only
%ifnarch s390x
%define with_zfcpdump 0
%endif

%if 0%{?fedora}
# This is not for Fedora
%define with_zfcpdump 0
%endif

# Per-arch tweaks

%ifarch i686
%define asmarch x86
%define hdrarch i386
%define all_arch_configs %{name}-%{version}-i?86*.config
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch x86_64
%define asmarch x86
%define all_arch_configs %{name}-%{version}-x86_64*.config
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64le
%define asmarch powerpc
%define hdrarch powerpc
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define use_vdso 0
%define all_arch_configs %{name}-%{version}-ppc64le*.config
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs %{name}-%{version}-s390x.config
%define kernel_image arch/s390/boot/bzImage
%define vmlinux_decompressor arch/s390/boot/compressed/vmlinux
%endif

%ifarch %{arm}
%define all_arch_configs %{name}-%{version}-arm*.config
%define skip_nonpae_vdso 1
%define asmarch arm
%define hdrarch arm
%define make_target bzImage
%define kernel_image arch/arm/boot/zImage
# http://lists.infradead.org/pipermail/linux-arm-kernel/2012-March/091404.html
%define kernel_mflags KALLSYMS_EXTRA_PASS=1
# we only build headers/perf/tools on the base arm arches
# just like we used to only build them on i386 for x86
%ifnarch armv7hl
%define with_headers 0
%define with_cross_headers 0
%endif
# These currently don't compile on armv7
%define with_selftests 0
%endif

%ifarch aarch64
%define all_arch_configs %{name}-%{version}-aarch64*.config
%define asmarch arm64
%define hdrarch arm64
%define make_target Image.gz
%define kernel_image arch/arm64/boot/Image.gz
%endif

# Should make listnewconfig fail if there's config options
# printed out?
%if %{nopatches}
%define with_configchecks 0
%endif

# To temporarily exclude an architecture from being built, add it to
# %%nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We only build kernel-headers on the following...
%if 0%{?fedora}
%define nobuildarches i386
%else
%define nobuildarches i386 i686 %{arm}
%endif

%ifarch %nobuildarches
# disable BuildKernel commands
%define with_up 0
%define with_debug 0
%define with_pae 0
%define with_zfcpdump 0

%define with_debuginfo 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_selftests 0
%define _enable_debug_packages 0
%endif

# Architectures we build tools/cpupower on
%if 0%{?fedora}
%define cpupowerarchs %{ix86} x86_64 ppc64le %{arm} aarch64
%else
%define cpupowerarchs i686 x86_64 ppc64le aarch64
%endif

%if 0%{?use_vdso}

%if 0%{?skip_nonpae_vdso}
%define _use_vdso 0
%else
%define _use_vdso 1
%endif

%else
%define _use_vdso 0
%endif

# If build of debug packages is disabled, we need to know if we want to create
# meta debug packages or not, after we define with_debug for all specific cases
# above. So this must be at the end here, after all cases of with_debug or not.
%define with_debug_meta 0
%if !%{debugbuildsenabled}
%if %{with_debug}
%define with_debug_meta 1
%endif
%define with_debug 0
%endif


#
# Packages that need to be installed before the kernel is, because the %%post
# scripts use them.
#
%define kernel_prereq  coreutils, systemd >= 203-2, /usr/bin/kernel-install
%define initrd_prereq  dracut >= 027


Name: kernel-rt
License: GPLv2 and Redistributable, no modification permitted
URL: https://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
%if %{with_realtime}
ExclusiveArch: x86_64
%else
%if 0%{?fedora}
ExclusiveArch: x86_64 s390x %{arm} aarch64 ppc64le
%else
ExclusiveArch: noarch i386 i686 x86_64 s390x %{arm} aarch64 ppc64le
%endif
%endif
ExclusiveOS: Linux
%ifnarch %{nobuildarches}
Requires: %{name}-core-uname-r = %{KVERREL}
Requires: %{name}-modules-uname-r = %{KVERREL}
%if %{with_realtime}
Requires: realtime-setup
%endif
%endif

Provides: almalinux(kernel-sig-key) = 202303
Conflicts: shim-ia32 <= 15.6-1.el9.alma
Conflicts: shim-x64 <= 15.6-1.el9.alma

#
# List the packages used during the kernel build
#
BuildRequires: kmod, patch, bash, coreutils, tar, git-core, which
BuildRequires: bzip2, xz, findutils, gzip, m4, perl-interpreter, perl-Carp, perl-devel, perl-generators, make, diffutils, gawk
BuildRequires: gcc, binutils, redhat-rpm-config, hmaccalc, bison, flex, gcc-c++
BuildRequires: net-tools, hostname, bc, elfutils-devel
BuildRequires: dwarves
BuildRequires: python3-devel
BuildRequires: gcc-plugin-devel
# glibc-static is required for a consistent build environment (specifically
# CONFIG_CC_CAN_LINK_STATIC=y).
BuildRequires: glibc-static
BuildRequires: kernel-rpm-macros >= 185-9
%ifnarch %{nobuildarches} noarch
BuildRequires: bpftool
%endif
%if %{with_headers}
BuildRequires: rsync
%endif
%if %{with_doc}
BuildRequires: xmlto, asciidoc, python3-sphinx, python3-sphinx_rtd_theme
%endif
%if %{with_sparse}
BuildRequires: sparse
%endif
%if %{with_perf}
BuildRequires: zlib-devel binutils-devel newt-devel perl(ExtUtils::Embed) bison flex xz-devel
BuildRequires: audit-libs-devel
BuildRequires: java-devel
BuildRequires: libbpf-devel >= 0.6.0-1
BuildRequires: libbabeltrace-devel
BuildRequires: libtraceevent-devel
%ifnarch %{arm} s390x
BuildRequires: numactl-devel
%endif
%ifarch aarch64
BuildRequires: opencsd-devel >= 1.0.0
%endif
%endif
%if %{with_tools}
BuildRequires: gettext ncurses-devel
BuildRequires: libcap-devel libcap-ng-devel
%ifnarch s390x
BuildRequires: pciutils-devel
%endif
%ifarch i686 x86_64
BuildRequires: libnl3-devel
%endif
%endif
%if %{with_tools} || %{signmodules} || %{signkernel}
BuildRequires: openssl-devel
%endif
%if %{with_bpftool}
BuildRequires: python3-docutils
BuildRequires: zlib-devel binutils-devel
%endif
%if %{with_selftests}
BuildRequires: clang llvm fuse-devel
%ifnarch %{arm}
BuildRequires: numactl-devel
%endif
BuildRequires: libcap-devel libcap-ng-devel rsync libmnl-devel
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
%if %{with_debuginfo}
BuildRequires: rpm-build, elfutils
BuildConflicts: rpm < 4.13.0.1-19
BuildConflicts: dwarves < 1.13
# Most of these should be enabled after more investigation
%undefine _include_minidebuginfo
%undefine _find_debuginfo_dwz_opts
%undefine _unique_build_ids
%undefine _unique_debug_names
%undefine _unique_debug_srcs
%undefine _debugsource_packages
%undefine _debuginfo_subpackages
%global _find_debuginfo_opts -r
%global _missing_build_ids_terminate_build 1
%global _no_recompute_build_ids 1
%endif
%if %{with_kabidwchk} || %{with_kabidw_base}
BuildRequires: kabi-dw
%endif

%if %{signkernel}%{signmodules}
BuildRequires: openssl
%if %{signkernel}
BuildRequires: system-sb-certs
%ifarch x86_64 aarch64
BuildRequires: nss-tools
BuildRequires: pesign >= 0.10-4
%endif
%endif
%endif

%if %{with_cross}
BuildRequires: binutils-%{_build_arch}-linux-gnu, gcc-%{_build_arch}-linux-gnu
%define cross_opts CROSS_COMPILE=%{_build_arch}-linux-gnu-
%define __strip %{_build_arch}-linux-gnu-strip
%endif

# These below are required to build man pages
%if %{with_perf}
BuildRequires: xmlto
%endif
%if %{with_perf} || %{with_tools}
BuildRequires: asciidoc
%endif

%if %{with toolchain_clang}
BuildRequires: clang
%endif

%if %{with clang_lto}
BuildRequires: llvm
BuildRequires: lld
%endif

# Because this is the kernel, it's hard to get a single upstream URL
# to represent the base without needing to do a bunch of patching. This
# tarball is generated from a src-git tree. If you want to see the
# exact git commit you can run
#
# xzcat -qq ${TARBALL} | git get-tar-commit-id
Source0: linux-5.14.0-162.18.1.rt21.181.el9_1.tar.xz

Source1: Makefile.rhelver

%if %{signkernel}

# Name of the packaged file containing signing key
%ifarch ppc64le
%define signing_key_filename kernel-signing-ppc.cer
%endif
%ifarch s390x
%define signing_key_filename kernel-signing-s390.cer
%endif

%define secureboot_ca_0 %{_datadir}/pki/sb-certs/secureboot-ca-%{_arch}.cer
%define secureboot_key_0 %{_datadir}/pki/sb-certs/secureboot-kernel-%{_arch}.cer

%define pesign_name_0 almalinuxsecurebootca0

# signkernel
%endif

Source20: mod-denylist.sh
Source21: mod-sign.sh
Source22: parallel_xz.sh

%define modsign_cmd %{SOURCE21}

%if 0%{?include_rhel}
Source23: x509.genkey.rhel

Source26: mod-extra.list.rhel

%if !%{with_realtime}
Source24: kernel-rt-aarch64-rhel.config
Source25: kernel-rt-aarch64-debug-rhel.config
Source27: kernel-rt-ppc64le-rhel.config
Source28: kernel-rt-ppc64le-debug-rhel.config
Source29: kernel-rt-s390x-rhel.config
Source30: kernel-rt-s390x-debug-rhel.config
Source31: kernel-rt-s390x-zfcpdump-rhel.config
%endif
Source32: kernel-rt-x86_64-rhel.config
Source33: kernel-rt-x86_64-debug-rhel.config

Source34: filter-x86_64.sh.rhel
Source35: filter-armv7hl.sh.rhel
Source36: filter-i686.sh.rhel
Source37: filter-aarch64.sh.rhel
Source38: filter-ppc64le.sh.rhel
Source39: filter-s390x.sh.rhel
Source40: filter-modules.sh.rhel

Source41: x509.genkey.centos
%endif

%if 0%{?include_fedora}
Source50: x509.genkey.fedora
Source51: mod-extra.list.fedora

%if !%{with_realtime}
Source52: kernel-rt-aarch64-fedora.config
Source53: kernel-rt-aarch64-debug-fedora.config
Source54: kernel-rt-armv7hl-fedora.config
Source55: kernel-rt-armv7hl-debug-fedora.config
Source56: kernel-rt-armv7hl-lpae-fedora.config
Source57: kernel-rt-armv7hl-lpae-debug-fedora.config
Source58: kernel-rt-i686-fedora.config
Source59: kernel-rt-i686-debug-fedora.config
Source60: kernel-rt-ppc64le-fedora.config
Source61: kernel-rt-ppc64le-debug-fedora.config
Source62: kernel-rt-s390x-fedora.config
Source63: kernel-rt-s390x-debug-fedora.config
Source64: kernel-rt-x86_64-fedora.config
Source65: kernel-rt-x86_64-debug-fedora.config
%endif

Source67: filter-x86_64.sh.fedora
Source68: filter-armv7hl.sh.fedora
Source69: filter-i686.sh.fedora
Source70: filter-aarch64.sh.fedora
Source71: filter-ppc64le.sh.fedora
Source72: filter-s390x.sh.fedora
Source73: filter-modules.sh.fedora
%endif

Source75: partial-kgcov-snip.config
Source80: generate_all_configs.sh
Source81: process_configs.sh

Source82: update_scripts.sh

Source84: mod-internal.list

Source100: almalinuxdup1.x509
Source101: almalinuxkpatch1.x509

Source200: check-kabi

%if !%{with_realtime}
Source201: Module.kabi_aarch64
Source202: Module.kabi_ppc64le
Source203: Module.kabi_s390x
Source204: Module.kabi_x86_64

Source210: Module.kabi_dup_aarch64
Source211: Module.kabi_dup_ppc64le
Source212: Module.kabi_dup_s390x
Source213: Module.kabi_dup_x86_64

Source300: kernel-abi-stablelists-%{rpmversion}-%{pkgrelease}.tar.bz2
Source301: kernel-kabi-dw-%{rpmversion}-%{pkgrelease}.tar.bz2
%endif

%if %{with_realtime}
Source400: mod-kvm.list
%endif

# Sources for kernel-tools
Source2000: cpupower.service
Source2001: cpupower.config
Source2002: kvm_stat.logrotate

# Some people enjoy building customized kernels from the dist-git in Fedora and
# use this to override configuration options. One day they may all use the
# source tree, but in the mean time we carry this to support the legacy workflow
Source3000: merge.pl
Source3001: kernel-local

Source4000: README.rst
Source4001: rpminspect.yaml
Source4002: gating.yaml

## Patches needed for building this package

%if !%{nopatches}

Patch1: patch-%{rpmversion}-redhat.patch
%endif

# empty final patch to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch

# END OF PATCH DEFINITIONS

%description
The kernel meta package

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf [-o] <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf(o) \
%if %{-o:0}%{!-o:1}\
Provides: kernel = %{rpmversion}-%{pkg_release}\
Provides: %{name} = %{rpmversion}-%{pkg_release}\
%endif\
Provides: %{name}-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:+%{1}}\
Provides: kernel-drm-nouveau = 16\
Provides: %{name}-uname-r = %{KVERREL}%{?1:+%{1}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): ((linux-firmware >= 20150904-56.git6ebf5d57) if linux-firmware)\
Recommends: linux-firmware\
Requires(preun): systemd >= 200\
Conflicts: xfsprogs < 4.3.0-1\
Conflicts: xorg-x11-drv-vmmouse < 13.0.99\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Obsoletes: glibc-kernheaders < 3.0-46
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package cross-headers
Summary: Header files for the Linux kernel for use by cross-glibc
%description cross-headers
Kernel-cross-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
cross-glibc package.


%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Provides: installonlypkg(kernel)
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{with_perf}
%package -n perf
Summary: Performance monitoring for the Linux kernel
Requires: bzip2
License: GPLv2
%description -n perf
This package contains the perf tool, which enables performance monitoring
of the Linux kernel.

%package -n perf-debuginfo
Summary: Debug information for package perf
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n perf-debuginfo
This package provides debug information for the perf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/perf(\.debug)?|.*%%{_libexecdir}/perf-core/.*|.*%%{_libdir}/libperf-jvmti.so(\.debug)?|XXX' -o perf-debuginfo.list}

%package -n python3-perf
Summary: Python bindings for apps which will manipulate perf events
%description -n python3-perf
The python3-perf package contains a module that permits applications
written in the Python programming language to use the interface
to manipulate perf events.

%package -n python3-perf-debuginfo
Summary: Debug information for package perf python bindings
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n python3-perf-debuginfo
This package provides debug information for the perf python bindings.

# the python_sitearch macro should already be defined from above
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{python3_sitearch}/perf.*so(\.debug)?|XXX' -o python3-perf-debuginfo.list}

# with_perf
%endif

%if %{with_tools}
%package -n kernel-tools
Summary: Assortment of tools for the Linux kernel
License: GPLv2
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils = 1:009-0.6.p1
Obsoletes: cpupowerutils < 1:009-0.6.p1
Provides:  cpufreq-utils = 1:009-0.6.p1
Provides:  cpufrequtils = 1:009-0.6.p1
Obsoletes: cpufreq-utils < 1:009-0.6.p1
Obsoletes: cpufrequtils < 1:009-0.6.p1
Obsoletes: cpuspeed < 1:1.5-16
Requires: kernel-tools-libs = %{version}-%{release}
%endif
%define __requires_exclude ^%{_bindir}/python
%description -n kernel-tools
This package contains the tools/ directory from the kernel source
and the supporting documentation.

%package -n kernel-tools-libs
Summary: Libraries for the kernels-tools
License: GPLv2
%description -n kernel-tools-libs
This package contains the libraries built from the tools/ directory
from the kernel source.

%package -n kernel-tools-libs-devel
Summary: Assortment of tools for the Linux kernel
License: GPLv2
Requires: kernel-tools = %{version}-%{release}
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils-devel = 1:009-0.6.p1
Obsoletes: cpupowerutils-devel < 1:009-0.6.p1
%endif
Requires: kernel-tools-libs = %{version}-%{release}
Provides: kernel-tools-devel
%description -n kernel-tools-libs-devel
This package contains the development files for the tools/ directory from
the kernel source.

%package -n kernel-tools-debuginfo
Summary: Debug information for package kernel-tools
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n kernel-tools-debuginfo
This package provides debug information for package kernel-tools.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/centrino-decode(\.debug)?|.*%%{_bindir}/powernow-k8-decode(\.debug)?|.*%%{_bindir}/cpupower(\.debug)?|.*%%{_libdir}/libcpupower.*|.*%%{_bindir}/turbostat(\.debug)?|.*%%{_bindir}/x86_energy_perf_policy(\.debug)?|.*%%{_bindir}/tmon(\.debug)?|.*%%{_bindir}/lsgpio(\.debug)?|.*%%{_bindir}/gpio-hammer(\.debug)?|.*%%{_bindir}/gpio-event-mon(\.debug)?|.*%%{_bindir}/gpio-watch(\.debug)?|.*%%{_bindir}/iio_event_monitor(\.debug)?|.*%%{_bindir}/iio_generic_buffer(\.debug)?|.*%%{_bindir}/lsiio(\.debug)?|.*%%{_bindir}/intel-speed-select(\.debug)?|.*%%{_bindir}/page_owner_sort(\.debug)?|.*%%{_bindir}/slabinfo(\.debug)?|.*%%{_sbindir}/intel_sdsi(\.debug)?|XXX' -o kernel-tools-debuginfo.list}

# with_tools
%endif

%if !%{with_realtime}
%if %{with_bpftool}

%package -n bpftool
Summary: Inspection and simple manipulation of eBPF programs and maps
License: GPLv2
%description -n bpftool
This package contains the bpftool, which allows inspection and simple
manipulation of eBPF programs and maps.

%package -n bpftool-debuginfo
Summary: Debug information for package bpftool
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n bpftool-debuginfo
This package provides debug information for the bpftool package.

%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_sbindir}/bpftool(\.debug)?|XXX' -o bpftool-debuginfo.list}

# with_bpftool
%endif
%endif

%if %{with_selftests}

%package selftests-internal
Summary: Kernel samples and selftests
License: GPLv2
Requires: binutils, bpftool, iproute-tc, nmap-ncat, python3, fuse-libs
Requires: %{name}-modules-internal = %{version}-%{release}
%if %{with_realtime}
Conflicts: kernel-selftests-internal
%else
Conflicts: kernel-rt-selftests-internal
%endif
%description selftests-internal
Kernel sample programs and selftests.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_libexecdir}/(ksamples|kselftests)/.*|XXX' -o selftests-debuginfo.list}

# with_selftests
%endif

%if %{with_gcov}
%package gcov
Summary: gcov graph and source files for coverage data collection.
%description gcov
kernel-gcov includes the gcov graph and source files for gcov coverage collection.
%endif

%package -n kernel-abi-stablelists
Summary: The AlmaLinux kernel ABI symbol stablelists
AutoReqProv: no
%description -n kernel-abi-stablelists
The kABI package contains information pertaining to the AlmaLinux
kernel ABI, including lists of kernel symbols that are needed by
external Linux kernel modules, and a yum plugin to aid enforcement.

%if %{with_kabidw_base}
%package kernel-kabidw-base-internal
Summary: The baseline dataset for kABI verification using DWARF data
Group: System Environment/Kernel
AutoReqProv: no
%description kernel-kabidw-base-internal
The package contains data describing the current ABI of the AlmaLinux
kernel, suitable for the kabi-dw tool.
%endif

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
# Explanation of the find_debuginfo_opts: We build multiple kernels (debug
# pae etc.) so the regex filters those kernels appropriately. We also
# have to package several binaries as part of kernel-devel but getting
# unique build-ids is tricky for these userspace binaries. We don't really
# care about debugging those so we just filter those out and remove it.
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
%description %{?1:%{1}-}debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} --keep-section '.BTF' -p '.*\/usr\/src\/kernels/.*|XXX' -o ignored-debuginfo.list -p '/.*/%%{KVERREL_RE}%{?1:[+]%{1}}/.*|/.*%%{KVERREL_RE}%{?1:\+%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package [-m] <subpackage> <pretty-name>
#
%define kernel_devel_package(m) \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Provides: %{name}%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}-devel-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}-devel-uname-r = %{KVERREL}%{?1:+%{1}}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
Requires(pre): findutils\
Requires: findutils\
Requires: perl-interpreter\
Requires: openssl-devel\
Requires: elfutils-libelf-devel\
Requires: bison\
Requires: flex\
Requires: make\
Requires: gcc\
%if %{-m:1}%{!-m:0}\
Requires: kernel-devel-uname-r = %{KVERREL}\
%endif\
%description %{?1:%{1}-}devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates an empty kernel-<subpackage>-devel-matched package that
# requires both the core and devel packages locked on the same version.
#	%%kernel_devel_matched_package [-m] <subpackage> <pretty-name>
#
%define kernel_devel_matched_package(m) \
%package %{?1:%{1}-}devel-matched\
Summary: Meta package to install matching core and devel packages for a given %{?2:%{2} }kernel\
Requires: %{name}%{?1:-%{1}}-devel = %{version}-%{release}\
Requires: %{name}%{?1:-%{1}}-core = %{version}-%{release}\
%description %{?1:%{1}-}devel-matched\
This meta package is used to install matching core and devel packages for a given %{?2:%{2} }kernel.\
%{nil}

#
# kernel-<variant>-ipaclones-internal package
#
%define kernel_ipaclones_package() \
%package %{?1:%{1}-}ipaclones-internal\
Summary: *.ipa-clones files generated by -fdump-ipa-clones for kernel%{?1:-%{1}}\
Group: System Environment/Kernel\
AutoReqProv: no\
%description %{?1:%{1}-}ipaclones-internal\
This package provides *.ipa-clones files.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-internal package.
#	%%kernel_modules_internal_package <subpackage> <pretty-name>
#
%define kernel_modules_internal_package() \
%package %{?1:%{1}-}modules-internal\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}%{?1:-%{1}}-modules-internal = %{version}-%{release}%{?1:+%{1}}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-modules-internal-uname-r = %{KVERREL}%{?1:+%{1}}\
Requires: %{name}-uname-r = %{KVERREL}%{?1:+%{1}}\
Requires: %{name}%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{?1:+%{1}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-internal\
This package provides kernel modules for the %{?2:%{2} }kernel package for AlmaLinux internal usage.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-extra package.
#	%%kernel_modules_extra_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_extra_package(m) \
%package %{?1:%{1}-}modules-extra\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Provides: %{name}%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}%{?1:-%{1}}-modules-extra = %{version}-%{release}%{?1:+%{1}}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{?1:+%{1}}\
Requires: %{name}-uname-r = %{KVERREL}%{?1:+%{1}}\
Requires: %{name}%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{?1:+%{1}}\
%if %{-m:1}%{!-m:0}\
Requires: %{name}-modules-extra-uname-r = %{KVERREL}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-extra\
This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules package.
#	%%kernel_modules_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_package(m) \
%package %{?1:%{1}-}modules\
Summary: kernel modules to match the %{?2:%{2}-}core kernel\
Provides: kernel%{?1:-%{1}}-modules-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}-modules-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}-modules = %{version}-%{release}%{?1:+%{1}}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{?1:+%{1}}\
Requires: %{name}-uname-r = %{KVERREL}%{?1:+%{1}}\
%if %{-m:1}%{!-m:0}\
Requires: %{name}-modules-uname-r = %{KVERREL}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules\
This package provides commonly used kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# this macro creates a kernel-<subpackage> meta package.
#	%%kernel_meta_package <subpackage>
#
%define kernel_meta_package() \
%package %{1}\
summary: kernel meta-package for the %{1} kernel\
Requires: %{name}-%{1}-core-uname-r = %{KVERREL}+%{1}\
Requires: %{name}-%{1}-modules-uname-r = %{KVERREL}+%{1}\
%if %{with_realtime}\
Requires: realtime-setup\
%endif\
Provides: installonlypkg(kernel)\
%description %{1}\
The meta-package for the %{1} kernel\
%{nil}

%if %{with_realtime}
#
# this macro creates a kernel-rt-<subpackage>-kvm package
# %%kernel_kvm_package <subpackage>
#
%define kernel_kvm_package() \
%package %{?1:%{1}-}kvm\
Summary: KVM modules for package %{name}%{?1:-%{1}}\
Group: System Environment/Kernel\
Requires: %{name}%{?1:-%{1}} = %{version}-%{release}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-kvm-%{_target_cpu} = %{version}-%{release}\
AutoReq: no\
%description -n %{name}%{?1:-%{1}}-kvm\
This package provides KVM modules for package %{name}%{?1:-%{1}}.\
%{nil}
%endif

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] [-m] [-o] <subpackage>
#
%define kernel_variant_package(n:mo) \
%package %{?1:%{1}-}core\
Summary: %{variant_summary}\
Provides: %{name}-%{?1:%{1}-}core-uname-r = %{KVERREL}%{?1:+%{1}}\
Provides: installonlypkg(kernel)\
%if %{-m:1}%{!-m:0}\
Requires: kernel-core-uname-r = %{KVERREL}\
%endif\
%{expand:%%kernel_reqprovconf %{?1:%{1}} %{-o:%{-o}}}\
%if %{?1:1} %{!?1:0} \
%{expand:%%kernel_meta_package %{?1:%{1}}}\
%endif\
%{expand:%%kernel_devel_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_devel_matched_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_extra_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%if %{-m:0}%{!-m:1}\
%{expand:%%kernel_modules_internal_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %{?1:%{1}}}\
%endif\
%if %{with_realtime} \
%{expand:%%kernel_kvm_package %{?1:%{1}}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%endif \
%{nil}

# Now, each variant package.

%if %{with_pae}
%define variant_summary The Linux kernel compiled for Cortex-A15
%kernel_variant_package lpae
%description lpae-core
This package includes a version of the Linux kernel with support for
Cortex-A15 devices with LPAE and HW virtualisation support
%endif

%if %{with_zfcpdump}
%define variant_summary The Linux kernel compiled for zfcpdump usage
%kernel_variant_package -o zfcpdump
%description zfcpdump-core
The kernel package contains the Linux kernel (vmlinuz) for use by the
zfcpdump infrastructure.
# with_zfcpdump
%endif

%define variant_summary The Linux kernel compiled with extra debugging enabled
%if !%{debugbuildsenabled}
%kernel_variant_package -m debug
%else
%kernel_variant_package debug
%endif
%description debug-core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

# And finally the main -core package

%define variant_summary The Linux kernel
%kernel_variant_package
%description core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.

%if %{with_ipaclones}
%kernel_ipaclones_package
%endif

%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_up}
echo "Cannot build --with baseonly, up build is disabled"
exit 1
%endif
%endif

# more sanity checking; do it quietly
if [ "%{patches}" != "%%{patches}" ] ; then
  for patch in %{patches} ; do
    if [ ! -f $patch ] ; then
      echo "ERROR: Patch  ${patch##/*/}  listed in specfile but is missing"
      exit 1
    fi
  done
fi 2>/dev/null

patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  if ! grep -E "^Patch[0-9]+: $patch\$" %{_specdir}/${RPM_PACKAGE_NAME}.spec ; then
    if [ "${patch:0:8}" != "patch-5." ] ; then
      echo "ERROR: Patch  $patch  not listed as a source patch in specfile"
      exit 1
    fi
  fi 2>/dev/null
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz)  gunzip  < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.xz)  unxz    < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# don't apply patch if it's empty
ApplyOptionalPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  local C=$(wc -l $RPM_SOURCE_DIR/$patch | awk '{print $1}')
  if [ "$C" -gt 9 ]; then
    ApplyPatch $patch ${1+"$@"}
  fi
}

%setup -q -n kernel-5.14.0-162.18.1.rt21.181.el9_1 -c
mv linux-5.14.0-162.18.1.rt21.181.el9_1 linux-%{KVERREL}

cd linux-%{KVERREL}
cp -a %{SOURCE1} .

%if !%{nopatches}

ApplyOptionalPatch patch-%{rpmversion}-redhat.patch
%endif

ApplyOptionalPatch linux-kernel-test.patch

# END OF PATCH APPLICATIONS

# Any further pre-build tree manipulations happen here.

%if %{with_realtime}
# remove the localversion-rt file since it screws around with
# the uname output
if [ -f localversion-rt ]; then
   rm -f localversion-rt
fi
%endif

chmod +x scripts/checkpatch.pl
mv COPYING COPYING-%{version}-%{release}

# This Prevents scripts/setlocalversion from mucking with our version numbers.
touch .scmversion

# Mangle /usr/bin/python shebangs to /usr/bin/python3
# Mangle all Python shebangs to be Python 3 explicitly
# -p preserves timestamps
# -n prevents creating ~backup files
# -i specifies the interpreter for the shebang
# This fixes errors such as
# *** ERROR: ambiguous python shebang in /usr/bin/kvm_stat: #!/usr/bin/python. Change it to python3 (or python2) explicitly.
# We patch all sources below for which we got a report/error.
pathfix.py -i "%{__python3} %{py3_shbang_opts}" -p -n \
	tools/kvm/kvm_stat/kvm_stat \
	scripts/show_delta \
	scripts/diffconfig \
	scripts/bloat-o-meter \
	scripts/jobserver-exec \
	tools \
	Documentation \
	scripts/clang-tools

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

if [ -L configs ]; then
	rm -f configs
fi
mkdir configs
cd configs

# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/kernel-*.config .
cp %{SOURCE80} .
# merge.pl
cp %{SOURCE3000} .
# kernel-local
cp %{SOURCE3001} .
VERSION=%{version} ./generate_all_configs.sh %{primary_target} %{debugbuildsenabled}

# Merge in any user-provided local config option changes
%ifnarch %nobuildarches
for i in %{all_arch_configs}
do
  mv $i $i.tmp
  ./merge.pl %{SOURCE3001} $i.tmp > $i
%if %{with_gcov}
  echo "Merging with gcov options"
  cat %{SOURCE75}
  mv $i $i.tmp
  ./merge.pl %{SOURCE75} $i.tmp > $i
%endif
  rm $i.tmp
done
%endif

%if %{with clang_lto}
for i in *aarch64*.config *x86_64*.config; do
  sed -i 's/# CONFIG_LTO_CLANG_THIN is not set/CONFIG_LTO_CLANG_THIN=y/' $i
  sed -i 's/CONFIG_LTO_NONE=y/# CONFIG_LTO_NONE is not set/' $i
done
%endif

# Add DUP and kpatch certificates to system trusted keys for RHEL
%if 0%{?rhel}
%if %{signkernel}%{signmodules}
openssl x509 -inform der -in %{SOURCE100} -out rheldup3.pem
openssl x509 -inform der -in %{SOURCE101} -out rhelkpatch1.pem
cat rheldup3.pem rhelkpatch1.pem > ../certs/rhel.pem
%if %{signkernel}
%ifarch s390x ppc64le
openssl x509 -inform der -in %{secureboot_ca_0} -out secureboot.pem
cat secureboot.pem >> ../certs/rhel.pem
%endif
%endif
for i in *.config; do
  sed -i 's@CONFIG_SYSTEM_TRUSTED_KEYS=""@CONFIG_SYSTEM_TRUSTED_KEYS="certs/rhel.pem"@' $i
done
%endif
%endif

# Adjust FIPS module name for RHEL
%if 0%{?rhel}
for i in *.config; do
  sed -i 's/CONFIG_CRYPTO_FIPS_NAME=.*/CONFIG_CRYPTO_FIPS_NAME="AlmaLinux %{rhel} - Kernel Cryptographic API"/' $i
done
%endif

cp %{SOURCE81} .
OPTS=""
%if %{with_configchecks}
	OPTS="$OPTS -w -n -c"
%endif
%if %{with clang_lto}
for opt in %{clang_make_opts}; do
  OPTS="$OPTS -m $opt"
done
%endif
./process_configs.sh $OPTS %{name} %{rpmversion}

cp %{SOURCE82} .
RPM_SOURCE_DIR=$RPM_SOURCE_DIR ./update_scripts.sh %{primary_target}

# end of kernel config
%endif

cd ..
# # End of Configs stuff

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -delete >/dev/null

# remove unnecessary SCM files
find . -name .gitignore -delete >/dev/null

cd ..

###
### build
###
%build

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

# Note we need to disable these flags for cross builds because the flags
# from redhat-rpm-config assume that host == target so target arch
# flags cause issues with the host compiler.
%if !%{with_cross}
%define build_hostcflags  %{?build_cflags}
%define build_hostldflags %{?build_ldflags}
%endif

%define make %{__make} %{?cross_opts} %{?make_opts} HOSTCFLAGS="%{?build_hostcflags}" HOSTLDFLAGS="%{?build_hostldflags}"

InitBuildVars() {
    # Initialize the kernel .config file and create some variables that are
    # needed for the actual build process.

    Variant=$1

    # Pick the right kernel config file
    Config=%{name}-%{version}-%{_target_cpu}${Variant:+-${Variant}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Variant:++${Variant}}

    KernelVer=%{version}-%{release}.%{_target_cpu}${Variant:++${Variant}}

    # make sure EXTRAVERSION says what we want it to say
    # Trim the release if this is a CI build, since KERNELVERSION is limited to 64 characters
    ShortRel=$(perl -e "print \"%{release}\" =~ s/\.pr\.[0-9A-Fa-f]{32}//r")
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -${ShortRel}.%{_target_cpu}${Variant:++${Variant}}/" Makefile

    # if pre-rc1 devel kernel, must fix up PATCHLEVEL for our versioning scheme
    # if we are post rc1 this should match anyway so this won't matter
    perl -p -i -e 's/^PATCHLEVEL.*/PATCHLEVEL = %{patchlevel}/' Makefile

    %{make} %{?_smp_mflags} mrproper
    cp configs/$Config .config

    %if %{signkernel}%{signmodules}
    cp $RPM_SOURCE_DIR/x509.genkey certs/.
    %endif

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    KCFLAGS="%{?kcflags}"

    # add kpatch flags for base kernel
    if [ "$Variant" == "" ]; then
        KCFLAGS="$KCFLAGS %{?kpatch_kcflags}"
    fi
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    DoVDSO=$3
    Variant=$4
    InstallName=${5:-vmlinuz}

    DoModules=1
    if [ "$Variant" = "zfcpdump" ]; then
	    DoModules=0
    fi

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    InitBuildVars $Variant

    echo BUILDING A KERNEL FOR ${Variant} %{_target_cpu}...

    %{make} ARCH=$Arch olddefconfig >/dev/null

    # This ensures build-ids are unique to allow parallel debuginfo
    perl -p -i -e "s/^CONFIG_BUILD_SALT.*/CONFIG_BUILD_SALT=\"%{KVERREL}\"/" .config
    %{make} ARCH=$Arch KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" %{?_smp_mflags} $MakeTarget %{?sparse_mflags} %{?kernel_mflags}
    if [ $DoModules -eq 1 ]; then
	%{make} ARCH=$Arch KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" %{?_smp_mflags} modules %{?sparse_mflags} || exit 1
    fi

    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/systemtap
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif

%ifarch %{arm} aarch64
    %{make} ARCH=$Arch dtbs INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    %{make} ARCH=$Arch dtbs_install INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    cp -r $RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/dtb
    find arch/$Arch/boot/dts -name '*.dtb' -type f -delete
%endif

    # Start installing the results
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/config
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/System.map

    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20

    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/lib/modules/$KernelVer/zImage.stub-$KernelVer || :
    fi

    %if %{signkernel}
    if [ "$KernelImage" = vmlinux ]; then
        # We can't strip and sign $KernelImage in place, because
        # we need to preserve original vmlinux for debuginfo.
        # Use a copy for signing.
        $CopyKernel $KernelImage $KernelImage.tosign
        KernelImage=$KernelImage.tosign
        CopyKernel=cp
    fi

    # Sign the image if we're using EFI
    # aarch64 kernels are gziped EFI images
    KernelExtension=${KernelImage##*.}
    if [ "$KernelExtension" == "gz" ]; then
        SignImage=${KernelImage%.*}
    else
        SignImage=$KernelImage
    fi

    %ifarch x86_64 aarch64
    %pesign -s -i $SignImage -o vmlinuz.signed -a %{secureboot_ca_0} -c %{secureboot_key_0} -n %{pesign_name_0}
    %endif
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
	rpm-sign --key "%{pesign_name_0}" --lkmsign $SignImage --output vmlinuz.signed
    elif [ "$DoModules" == "1" -a "%{signmodules}" == "1" ]; then
	chmod +x scripts/sign-file
	./scripts/sign-file -p sha256 certs/signing_key.pem certs/signing_key.x509 $SignImage vmlinuz.signed
    else
	mv $SignImage vmlinuz.signed
    fi
    %endif

    if [ ! -s vmlinuz.signed ]; then
        echo "pesigning failed"
        exit 1
    fi
    mv vmlinuz.signed $SignImage
    if [ "$KernelExtension" == "gz" ]; then
        gzip -f9 $SignImage
    fi
    # signkernel
    %endif

    $CopyKernel $KernelImage \
                $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    cp $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/$InstallName

    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    sha512hmac $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer | sed -e "s,$RPM_BUILD_ROOT,," > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;
    cp $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac $RPM_BUILD_ROOT/lib/modules/$KernelVer/.vmlinuz.hmac

    if [ $DoModules -eq 1 ]; then
	# Override $(mod-fw) because we don't want it to install any firmware
	# we'll get it from the linux-firmware package and we don't want conflicts
	%{make} %{?_smp_mflags} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT %{?_smp_mflags} modules_install KERNELRELEASE=$KernelVer mod-fw=
    fi

%if %{with_gcov}
    # install gcov-needed files to $BUILDROOT/$BUILD/...:
    #   gcov_info->filename is absolute path
    #   gcno references to sources can use absolute paths (e.g. in out-of-tree builds)
    #   sysfs symlink targets (set up at compile time) use absolute paths to BUILD dir
    find . \( -name '*.gcno' -o -name '*.[chS]' \) -exec install -D '{}' "$RPM_BUILD_ROOT/$(pwd)/{}" \;
%endif

    # add an a noop %%defattr statement 'cause rpm doesn't like empty file list files
    echo '%%defattr(-,-,-)' > ../%{name}${Variant:+-${Variant}}-ldsoconf.list
    if [ $DoVDSO -ne 0 ]; then
        %{make} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
        if [ -s ldconfig-kernel.conf ]; then
             install -D -m 444 ldconfig-kernel.conf \
                $RPM_BUILD_ROOT/etc/ld.so.conf.d/%{name}-$KernelVer.conf
	     echo /etc/ld.so.conf.d/%{name}-$KernelVer.conf >> ../%{name}${Variant:+-${Variant}}-ldsoconf.list
        fi

        rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/vdso/.build-id
    fi

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # CONFIG_KERNEL_HEADER_TEST generates some extra files in the process of
    # testing so just delete
    find . -name *.h.s -delete
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ ! -e Module.symvers ]; then
        touch Module.symvers
    fi
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    # NOTENOTE: the name symvers is used by the rpm backend
    # NOTENOTE: to discover and run the /usr/lib/rpm/fileattrs/kabi.attr
    # NOTENOTE: script which dynamically adds exported kernel symbol
    # NOTENOTE: checksums to the rpm metadata provides list.
    # NOTENOTE: if you change the symvers name, update the backend too
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
    cp $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz $RPM_BUILD_ROOT/lib/modules/$KernelVer/symvers.gz

%if %{with_kabichk}
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Variant ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Variant $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
        echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidupchk}
    echo "**** kABI DUP checking is enabled in kernel SPEC file. ****"
    if [ -e $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Variant ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Variant $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
        echo "**** NOTE: Cannot find DUP reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidw_base}
    # Don't build kabi base for debug kernels
    if [ "$Variant" != "zfcpdump" -a "$Variant" != "debug" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf

        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
        tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

        echo "**** GENERATING DWARF-based kABI baseline dataset ****"
        chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
        $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
            "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
            "$(pwd)" \
            "$RPM_BUILD_ROOT/kabidw-base/%{_target_cpu}${Variant:+.${Variant}}" || :

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

%if %{with_kabidwchk}
    if [ "$Variant" != "zfcpdump" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf
        if [ -d "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}" ]; then
            mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
            tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

            echo "**** GENERATING DWARF-based kABI dataset ****"
            chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
                "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
                "$(pwd)" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}.tmp" || :

            echo "**** kABI DWARF-based comparison report ****"
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh compare \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}.tmp" || :
            echo "**** End of kABI DWARF-based comparison report ****"
        else
            echo "**** Baseline dataset for kABI DWARF-BASED comparison report not found ****"
        fi

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/tracing
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/spdxcheck.py

    # Files for 'make scripts' to succeed with kernel-devel.
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/security/selinux/include
    cp -a --parents security/selinux/include/classmap.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents security/selinux/include/initial_sid_to_string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/include/tools
    cp -a --parents tools/include/tools/be_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/tools/le_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    # Files for 'make prepare' to succeed with kernel-devel.
    cp -a --parents tools/include/linux/compiler* $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/linux/types.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/build/Build.include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/build/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/build/fixdep.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/sync-check.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/bpf/resolve_btfids $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    cp --parents security/selinux/include/policycap_names.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents security/selinux/include/policycap.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    cp -a --parents tools/include/asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/linux $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/linux $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/vdso $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/scripts/utilities.mak $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/lib/subcmd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/lib/*.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/*.[ch] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/include/objtool/*.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/lib/bpf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/lib/bpf/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    if [ -f tools/objtool/objtool ]; then
      cp -a tools/objtool/objtool $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -f tools/objtool/fixdep ]; then
      cp -a tools/objtool/fixdep $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    if [ -f arch/%{asmarch}/kernel/module.lds ]; then
      cp -a --parents arch/%{asmarch}/kernel/module.lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts \( -iname "*.o" -o -iname "*.cmd" \) -exec rm -f {} +
%ifarch ppc64le
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
%ifarch aarch64
    # arch/arm64/include/asm/xen references arch/arm
    cp -a --parents arch/arm/include/asm/xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    # arch/arm64/include/asm/opcodes.h references arch/arm
    cp -a --parents arch/arm/include/asm/opcodes.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    # include the machine specific headers for ARM variants, if available.
%ifarch %{arm}
    if [ -d arch/%{asmarch}/mach-${Variant}/include ]; then
      cp -a --parents arch/%{asmarch}/mach-${Variant}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    # include a few files for 'make prepare'
    cp -a --parents arch/arm/tools/gen-mach-types $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/arm/tools/mach-types $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

%endif
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%ifarch i686 x86_64
    # files for 'make prepare' to succeed with kernel-devel
    cp -a --parents arch/x86/entry/syscalls/syscall_32.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscall_64.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_32.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_64.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_common.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/purgatory.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/stack.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/setup-x86_64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/entry64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/ctype.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

    cp -a --parents scripts/syscalltbl.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents scripts/syscallhdr.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

    cp -a --parents tools/arch/x86/include/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/include/uapi/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/objtool/arch/x86/lib $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/lib/ $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/tools/gen-insn-attr-x86.awk $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/objtool/arch/x86/ $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

%endif
    # Clean up intermediate tools files
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools \( -iname "*.o" -o -iname "*.cmd" \) -exec rm -f {} +

    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h

    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

%if %{with_debuginfo}
    eu-readelf -n vmlinux | grep "Build ID" | awk '{print $NF}' > vmlinux.id
    cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    if [ -n "%{vmlinux_decompressor}" ]; then
	    eu-readelf -n  %{vmlinux_decompressor} | grep "Build ID" | awk '{print $NF}' > vmlinux.decompressor.id
	    # Without build-id the build will fail. But for s390 the build-id
	    # wasn't added before 5.11. In case it is missing prefer not
	    # packaging the debuginfo over a build failure.
	    if [ -s vmlinux.decompressor.id ]; then
		    cp vmlinux.decompressor.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.decompressor.id
		    cp %{vmlinux_decompressor} $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer/vmlinux.decompressor
	    fi
    fi
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    grep -F /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
        LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking \
      'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|rt(l_|2x00)(pci|usb)_probe|register_netdevice'
    collect_modules_list block \
      'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm \
      'drm_open|drm_init'
    collect_modules_list modesetting \
      'drm_crtc_init'
%if %{with_realtime}
    collect_modules_list kvm \
      'kvm_init|kvmgt_init'
%endif

    # detect missing or incorrect license tags
    ( find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name '*.ko' | xargs /sbin/modinfo -l | \
        grep -E -v 'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' ) && exit 1

    remove_depmod_files()
    {
        # remove files that will be auto generated by depmod at rpm -i time
        pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/
            rm -f modules.{alias,alias.bin,builtin.alias.bin,builtin.bin} \
                  modules.{dep,dep.bin,devname,softdep,symbols,symbols.bin}
        popd
    }

    remove_depmod_files

    # Identify modules in the kernel-modules-extras package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer $RPM_SOURCE_DIR/mod-extra.list
    # Identify modules in the kernel-modules-extras package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE84} internal
%if %{with_realtime}
    # Identify modules in the kernel-rt-kvm package
    %{SOURCE20} $RPM_BUILD_ROOT lib/modules/$KernelVer %{SOURCE400} kvm
%endif

    #
    # Generate the kernel-core and kernel-modules files lists
    #

    # Copy the System.map file for depmod to use, and create a backup of the
    # full module tree so we can restore it after we're done filtering
    cp System.map $RPM_BUILD_ROOT/.
    pushd $RPM_BUILD_ROOT
    mkdir restore
    cp -r lib/modules/$KernelVer/* restore/.

    # don't include anything going into kernel-modules-extra in the file lists
    xargs rm -rf < mod-extra.list
    # don't include anything going int kernel-modules-internal in the file lists
    xargs rm -rf < mod-internal.list
%if %{with_realtime}
    # don't include anything going into kernel-rt-kvm in the file lists
    xargs rm -rf < mod-kvm.list
%endif

    if [ $DoModules -eq 1 ]; then
	# Find all the module files and filter them out into the core and
	# modules lists.  This actually removes anything going into -modules
	# from the dir.
	find lib/modules/$KernelVer/kernel -name *.ko | sort -n > modules.list
	cp $RPM_SOURCE_DIR/filter-*.sh .
	./filter-modules.sh modules.list %{_target_cpu}
	rm filter-*.sh

	# Run depmod on the resulting module tree and make sure it isn't broken
	depmod -b . -aeF ./System.map $KernelVer &> depmod.out
	if [ -s depmod.out ]; then
	    echo "Depmod failure"
	    cat depmod.out
	    exit 1
	else
	    rm depmod.out
	fi
    else
	# Ensure important files/directories exist to let the packaging succeed
	echo '%%defattr(-,-,-)' > modules.list
	echo '%%defattr(-,-,-)' > k-d.list
	mkdir -p lib/modules/$KernelVer/kernel
	# Add files usually created by make modules, needed to prevent errors
	# thrown by depmod during package installation
	touch lib/modules/$KernelVer/modules.order
	touch lib/modules/$KernelVer/modules.builtin
    fi

    remove_depmod_files

    # Go back and find all of the various directories in the tree.  We use this
    # for the dir lists in kernel-core
    find lib/modules/$KernelVer/kernel -mindepth 1 -type d | sort -n > module-dirs.list

    # Cleanup
    rm System.map
    cp -r restore/* lib/modules/$KernelVer/.
    rm -rf restore
    popd

    # Make sure the files lists start with absolute paths or rpmbuild fails.
    # Also add in the dir entries
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/k-d.list > ../%{name}${Variant:+-${Variant}}-modules.list
    sed -e 's/^lib*/%dir \/lib/' %{?zipsed} $RPM_BUILD_ROOT/module-dirs.list > ../%{name}${Variant:+-${Variant}}-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/modules.list >> ../%{name}${Variant:+-${Variant}}-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-extra.list >> ../%{name}${Variant:+-${Variant}}-modules-extra.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-internal.list >> ../%{name}${Variant:+-${Variant}}-modules-internal.list
%if %{with_realtime}
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/mod-kvm.list >> ../%{name}${Variant:+-${Variant}}-kvm.list
%endif

    # Cleanup
    rm -f $RPM_BUILD_ROOT/k-d.list
    rm -f $RPM_BUILD_ROOT/modules.list
    rm -f $RPM_BUILD_ROOT/module-dirs.list
    rm -f $RPM_BUILD_ROOT/mod-extra.list
    rm -f $RPM_BUILD_ROOT/mod-internal.list
%if %{with_realtime}
    rm -f $RPM_BUILD_ROOT/mod-kvm.list
%endif

%if %{with_cross}
    make -C $RPM_BUILD_ROOT/lib/modules/$KernelVer/build M=scripts clean
    sed -i 's/REBUILD_SCRIPTS_FOR_CROSS:=0/REBUILD_SCRIPTS_FOR_CROSS:=1/' $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile
%endif

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir

    # This is going to create a broken link during the build, but we don't use
    # it after this point.  We need the link to actually point to something
    # when kernel-devel is installed, and a relative link doesn't work across
    # the F17 UsrMove feature.
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

%ifnarch armv7hl
    # Generate vmlinux.h and put it to kernel-devel path
    # zfcpdump build does not have btf anymore
    if [ "$Variant" != "zfcpdump" ]; then
        bpftool btf dump file vmlinux format c > $RPM_BUILD_ROOT/$DevelDir/vmlinux.h
    fi
%endif

    # prune junk from kernel-devel
    find $RPM_BUILD_ROOT/usr/src/kernels -name ".*.cmd" -delete

    # AlmaLinux UEFI Secure Boot CA cert, which can be used to authenticate the kernel
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer
%if %{signkernel}
    install -m 0644 %{secureboot_ca_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
        install -m 0644 %{secureboot_key_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
    fi
    %endif
%endif

%if %{signmodules}
    if [ $DoModules -eq 1 ]; then
        # Save the signing keys so we can sign the modules in __modsign_install_post
        cp certs/signing_key.pem certs/signing_key.pem.sign${Variant:++${Variant}}
        cp certs/signing_key.x509 certs/signing_key.x509.sign${Variant:++${Variant}}
        %ifarch s390x ppc64le
        if [ ! -x /usr/bin/rpm-sign ]; then
            install -m 0644 certs/signing_key.x509.sign${Variant:++${Variant}} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
            openssl x509 -in certs/signing_key.pem.sign${Variant:++${Variant}} -outform der -out $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
            chmod 0644 $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
        fi
        %endif
    fi
%endif

%if %{with_ipaclones}
    MAXPROCS=$(echo %{?_smp_mflags} | sed -n 's/-j\s*\([0-9]\+\)/\1/p')
    if [ -z "$MAXPROCS" ]; then
        MAXPROCS=1
    fi
    if [ "$Variant" == "" ]; then
        mkdir -p $RPM_BUILD_ROOT/$DevelDir-ipaclones
        find . -name '*.ipa-clones' | xargs -i{} -r -n 1 -P $MAXPROCS install -m 644 -D "{}" "$RPM_BUILD_ROOT/$DevelDir-ipaclones/{}"
    fi
%endif

}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot
mkdir -p $RPM_BUILD_ROOT%{_libexecdir}

cd linux-%{KVERREL}


%if %{with_debug}
BuildKernel %make_target %kernel_image %{_use_vdso} debug
%endif

%if %{with_zfcpdump}
BuildKernel %make_target %kernel_image %{_use_vdso} zfcpdump
%endif

%if %{with_pae}
BuildKernel %make_target %kernel_image %{use_vdso} lpae
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image %{_use_vdso}
%endif

%ifnarch noarch i686
%if !%{with_debug} && !%{with_zfcpdump} && !%{with_pae} && !%{with_up}
# If only building the user space tools, then initialize the build environment
# and some variables so that the various userspace tools can be built.
InitBuildVars
%endif
%endif

%ifarch aarch64
%global perf_build_extra_opts CORESIGHT=1
%endif
%global perf_make \
  %{__make} %{?make_opts} EXTRA_CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags} -Wl,-E" %{?cross_opts} -C tools/perf V=1 NO_PERF_READ_VDSO32=1 NO_PERF_READ_VDSOX32=1 WERROR=0 NO_LIBUNWIND=1 HAVE_CPLUS_DEMANGLE=1 NO_GTK2=1 NO_STRLCPY=1 NO_BIONIC=1 LIBBPF_DYNAMIC=1 LIBTRACEEVENT_DYNAMIC=1 %{?perf_build_extra_opts} prefix=%{_prefix} PYTHON=%{__python3}
%if %{with_perf}
# perf
# make sure check-headers.sh is executable
chmod +x tools/perf/check-headers.sh
%{perf_make} DESTDIR=$RPM_BUILD_ROOT all
%endif

%global tools_make \
  %{make} CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" %{?make_opts}

%if %{with_tools}
%ifarch %{cpupowerarchs}
# cpupower
# make sure version-gen.sh is executable.
chmod +x tools/power/cpupower/utils/version-gen.sh
%{tools_make} %{?_smp_mflags} -C tools/power/cpupower CPUFREQ_BENCH=false DEBUG=false
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    %{tools_make} %{?_smp_mflags} centrino-decode powernow-k8-decode
    popd
%endif
%ifarch x86_64
   pushd tools/power/x86/x86_energy_perf_policy/
   %{tools_make}
   popd
   pushd tools/power/x86/turbostat
   %{tools_make}
   popd
   pushd tools/power/x86/intel-speed-select
   %{make} CFLAGS+="-D_GNU_SOURCE -Iinclude -I/usr/include/libnl3"
   popd
   pushd tools/arch/x86/intel_sdsi
   %{tools_make}
   popd
%endif
%endif
pushd tools/thermal/tmon/
%{tools_make}
popd
pushd tools/iio/
%{tools_make}
popd
pushd tools/gpio/
%{tools_make}
popd
# build VM tools
pushd tools/vm/
%{tools_make} slabinfo page_owner_sort
popd
%endif

if [ -f $DevelDir/vmlinux.h ]; then
  RPM_VMLINUX_H=$DevelDir/vmlinux.h
fi

%global bpftool_make \
  %{__make} EXTRA_CFLAGS="${RPM_OPT_FLAGS}" EXTRA_LDFLAGS="%{__global_ldflags}" DESTDIR=$RPM_BUILD_ROOT %{?make_opts} VMLINUX_H="${RPM_VMLINUX_H}" V=1
%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make}
popd
%endif

%if %{with_selftests}
# Unfortunately, samples/bpf/Makefile expects that the headers are installed
# in the source tree. We installed them previously to $RPM_BUILD_ROOT/usr
# but there's no way to tell the Makefile to take them from there.
%{make} %{?_smp_mflags} headers_install

# If we re building only tools without kernel, we need to generate config
# headers and prepare tree for modules building. The modules_prepare target
# will cover both.
if [ ! -f include/generated/autoconf.h ]; then
   %{make} %{?_smp_mflags} modules_prepare
fi

%{make} %{?_smp_mflags} ARCH=$Arch V=1 M=samples/bpf/ VMLINUX_H="${RPM_VMLINUX_H}"

# Prevent bpf selftests to build bpftool repeatedly:
export BPFTOOL=$(pwd)/tools/bpf/bpftool/bpftool

pushd tools/testing/selftests
# We need to install here because we need to call make with ARCH set which
# doesn't seem possible to do in the install section.
%{make} %{?_smp_mflags} ARCH=$Arch V=1 TARGETS="bpf livepatch vm net net/forwarding net/mptcp netfilter tc-testing memfd" SKIP_TARGETS="" FORCE_TARGETS=1 INSTALL_PATH=%{buildroot}%{_libexecdir}/kselftests VMLINUX_H="${RPM_VMLINUX_H}" install

# 'make install' for bpf is broken and upstream refuses to fix it.
# Install the needed files manually.
for dir in bpf bpf/no_alu32 bpf/progs; do
	# In ARK, the rpm build continues even if some of the selftests
	# cannot be built. It's not always possible to build selftests,
	# as upstream sometimes dependens on too new llvm version or has
	# other issues. If something did not get built, just skip it.
	test -d $dir || continue
	mkdir -p %{buildroot}%{_libexecdir}/kselftests/$dir
	find $dir -maxdepth 1 -type f \( -executable -o -name '*.py' -o -name settings -o \
		-name 'btf_dump_test_case_*.c' -o -name '*.ko' -o \
		-name '*.o' -exec sh -c 'readelf -h "{}" | grep -q "^  Machine:.*BPF"' \; \) -print0 | \
	xargs -0 cp -t %{buildroot}%{_libexecdir}/kselftests/$dir || true
done
popd
export -n BPFTOOL
%endif

%if %{with_doc}
# Make the HTML pages.
%{__make} PYTHON=/usr/bin/python3 htmldocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

# In the modsign case, we do 3 things.  1) We check the "variant" and hard
# code the value in the following invocations.  This is somewhat sub-optimal
# but we're doing this inside of an RPM macro and it isn't as easy as it
# could be because of that.  2) We restore the .tmp_versions/ directory from
# the one we saved off in BuildKernel above.  This is to make sure we're
# signing the modules we actually built/installed in that variant.  3) We
# grab the arch and invoke mod-sign.sh command to actually sign the modules.
#
# We have to do all of those things _after_ find-debuginfo runs, otherwise
# that will strip the signature off of the modules.
#
# Don't sign modules for the zfcpdump variant as it is monolithic.

%define __modsign_install_post \
  if [ "%{signmodules}" -eq "1" ]; then \
    if [ "%{with_pae}" -ne "0" ]; then \
       %{modsign_cmd} certs/signing_key.pem.sign+lpae certs/signing_key.x509.sign+lpae $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+lpae/ \
    fi \
    if [ "%{with_debug}" -ne "0" ]; then \
      %{modsign_cmd} certs/signing_key.pem.sign+debug certs/signing_key.x509.sign+debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+debug/ \
    fi \
    if [ "%{with_up}" -ne "0" ]; then \
      %{modsign_cmd} certs/signing_key.pem.sign certs/signing_key.x509.sign $RPM_BUILD_ROOT/lib/modules/%{KVERREL}/ \
    fi \
  fi \
  if [ "%{zipmodules}" -eq "1" ]; then \
    find $RPM_BUILD_ROOT/lib/modules/ -type f -name '*.ko' | xargs -P%{zcpu} -r xz; \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{with_debuginfo}

%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%endif

%endif

# We don't want to package debuginfo for self-tests and samples but
# we have to delete them to avoid an error messages about unpackaged
# files.
# Delete the debuginfo for kernel-devel files
%define __remove_unwanted_dbginfo_install_post \
  if [ "%{with_selftests}" -ne "0" ]; then \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/ksamples; \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/kselftests; \
  fi \
  rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/src; \
%{nil}

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__remove_unwanted_dbginfo_install_post}\
  %{__modsign_install_post}

###
### install
###

%install

cd linux-%{KVERREL}

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{rpmversion}-%{pkgrelease}

# copy the source over
mkdir -p $docdir
tar -h -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir

# with_doc
%endif

# We have to do the headers install before the tools install because the
# kernel headers_install will remove any header files in /usr/include that
# it doesn't install itself.

%if %{with_headers}
# Install kernel headers
%{__make} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) -delete

%endif

%if %{with_cross_headers}
%if 0%{?fedora}
HDR_ARCH_LIST='arm arm64 powerpc s390 x86'
%else
HDR_ARCH_LIST='arm64 powerpc s390 x86'
%endif
mkdir -p $RPM_BUILD_ROOT/usr/tmp-headers

for arch in $HDR_ARCH_LIST; do
	mkdir $RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch}
	%{__make} ARCH=${arch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch} headers_install
done

find $RPM_BUILD_ROOT/usr/tmp-headers \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) -delete

# Copy all the architectures we care about to their respective asm directories
for arch in $HDR_ARCH_LIST ; do
	mkdir -p $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include
	mv $RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch}/include/* $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/
done

rm -rf $RPM_BUILD_ROOT/usr/tmp-headers
%endif

%if %{with_kernel_abi_stablelists}
# kabi directory
INSTALL_KABI_PATH=$RPM_BUILD_ROOT/lib/modules/
mkdir -p $INSTALL_KABI_PATH

# install kabi releases directories
tar xjvf %{SOURCE300} -C $INSTALL_KABI_PATH
# with_kernel_abi_stablelists
%endif

%if %{with_perf}
# perf tool binary and supporting scripts/binaries
%{perf_make} DESTDIR=$RPM_BUILD_ROOT lib=%{_lib} install-bin
# remove the 'trace' symlink.
rm -f %{buildroot}%{_bindir}/trace

# For both of the below, yes, this should be using a macro but right now
# it's hard coded and we don't actually want it anyway right now.
# Whoever wants examples can fix it up!

# remove examples
rm -rf %{buildroot}/usr/lib/perf/examples
rm -rf %{buildroot}/usr/lib/perf/include

# python-perf extension
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-python_ext

# perf man pages (note: implicit rpm magic compresses them later)
mkdir -p %{buildroot}/%{_mandir}/man1
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-man

# remove any tracevent files, eg. its plugins still gets built and installed,
# even if we build against system's libtracevent during perf build (by setting
# LIBTRACEEVENT_DYNAMIC=1 above in perf_make macro). Those files should already
# ship with libtraceevent package.
rm -rf %{buildroot}%{_libdir}/traceevent
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
%{make} -C tools/power/cpupower DESTDIR=$RPM_BUILD_ROOT libdir=%{_libdir} mandir=%{_mandir} CPUFREQ_BENCH=false install
rm -f %{buildroot}%{_libdir}/*.{a,la}
%find_lang cpupower
mv cpupower.lang ../
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    install -m755 centrino-decode %{buildroot}%{_bindir}/centrino-decode
    install -m755 powernow-k8-decode %{buildroot}%{_bindir}/powernow-k8-decode
    popd
%endif
chmod 0755 %{buildroot}%{_libdir}/libcpupower.so*
mkdir -p %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/sysconfig
install -m644 %{SOURCE2000} %{buildroot}%{_unitdir}/cpupower.service
install -m644 %{SOURCE2001} %{buildroot}%{_sysconfdir}/sysconfig/cpupower
%endif
%ifarch x86_64
   mkdir -p %{buildroot}%{_mandir}/man8
   pushd tools/power/x86/x86_energy_perf_policy
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/turbostat
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/intel-speed-select
   %{tools_make} CFLAGS+="-D_GNU_SOURCE -Iinclude -I/usr/include/libnl3" DESTDIR=%{buildroot} install
   popd
   pushd tools/arch/x86/intel_sdsi
   %{tools_make} DESTDIR=%{buildroot} install
   popd
%endif
pushd tools/thermal/tmon
%{tools_make} INSTALL_ROOT=%{buildroot} install
popd
pushd tools/iio
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/gpio
%{tools_make} DESTDIR=%{buildroot} install
popd
install -m644 -D %{SOURCE2002} %{buildroot}%{_sysconfdir}/logrotate.d/kvm_stat
pushd tools/kvm/kvm_stat
%{__make} INSTALL_ROOT=%{buildroot} install-tools
%{__make} INSTALL_ROOT=%{buildroot} install-man
install -m644 -D kvm_stat.service %{buildroot}%{_unitdir}/kvm_stat.service
popd
# install VM tools
pushd tools/vm/
install -m755 slabinfo %{buildroot}%{_bindir}/slabinfo
install -m755 page_owner_sort %{buildroot}%{_bindir}/page_owner_sort
popd
%endif

if [ -f $DevelDir/vmlinux.h ]; then
  RPM_VMLINUX_H=$DevelDir/vmlinux.h
fi

%if !%{with_realtime}
%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make} prefix=%{_prefix} bash_compdir=%{_sysconfdir}/bash_completion.d/ mandir=%{_mandir} install doc-install
popd
%endif
%endif

%if %{with_selftests}
pushd samples
install -d %{buildroot}%{_libexecdir}/ksamples
# install bpf samples
pushd bpf
install -d %{buildroot}%{_libexecdir}/ksamples/bpf
find -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/bpf \;
install -m755 *.sh %{buildroot}%{_libexecdir}/ksamples/bpf
# test_lwt_bpf.sh compiles test_lwt_bpf.c when run; this works only from the
# kernel tree. Just remove it.
rm %{buildroot}%{_libexecdir}/ksamples/bpf/test_lwt_bpf.sh
install -m644 *_kern.o %{buildroot}%{_libexecdir}/ksamples/bpf || true
install -m644 tcp_bpf.readme %{buildroot}%{_libexecdir}/ksamples/bpf
popd
# install pktgen samples
pushd pktgen
install -d %{buildroot}%{_libexecdir}/ksamples/pktgen
find . -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
find . -type f ! -executable -exec install -m644 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
popd
popd
# install vm selftests
pushd tools/testing/selftests/vm
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/vm/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/vm/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/vm/{} \;
popd
# install drivers/net/mlxsw selftests
pushd tools/testing/selftests/drivers/net/mlxsw
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
popd
# install drivers/net/netdevsim selftests
pushd tools/testing/selftests/drivers/net/netdevsim
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
popd
# install net/forwarding selftests
pushd tools/testing/selftests/net/forwarding
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
popd
# install net/mptcp selftests
pushd tools/testing/selftests/net/mptcp
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
popd
# install tc-testing selftests
pushd tools/testing/selftests/tc-testing
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
popd
# install livepatch selftests
pushd tools/testing/selftests/livepatch
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
popd
# install netfilter selftests
pushd tools/testing/selftests/netfilter
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/netfilter/{} \;
popd

# install memfd selftests
pushd tools/testing/selftests/memfd
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
popd
%endif

###
### clean
###

###
### scripts
###

%if %{with_tools}
%post -n kernel-tools-libs
/sbin/ldconfig

%postun -n kernel-tools-libs
/sbin/ldconfig
%endif

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
# Note we don't run hardlink if ostree is in use, as ostree is
# a far more sophisticated hardlink implementation.
# https://github.com/projectatomic/rpm-ostree/commit/58a79056a889be8814aa51f507b2c7a4dccee526
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/bin/hardlink -a ! -e /run/ostree-booted ] \
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:+%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*%{?dist}.*/$f $f > /dev/null\
     done)\
fi\
%if %{with_cross}\
    echo "Building scripts"\
    env --unset=ARCH make -C /usr/src/kernels/%{KVERREL}%{?1:+%{1}} prepare_after_cross\
%endif\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-extra package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_extra_post [<subpackage>]
#
%define kernel_modules_extra_post() \
%{expand:%%post %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-internal package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_internal_post [<subpackage>]
#
%define kernel_modules_internal_post() \
%{expand:%%post %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

%if %{with_realtime}
#
# This macro defines a %%post script for a kernel*-kvm package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_kvm_post [<subpackage>]
#
%define kernel_kvm_post() \
%{expand:%%post %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}
%endif

#
# This macro defines a %%post script for a kernel*-modules package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_post [<subpackage>]
#
%define kernel_modules_post() \
%{expand:%%post %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
if [ ! -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?1:+%{1}} ]; then\
	mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
	touch %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
fi\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%posttrans %{?1:%{1}-}modules}\
if [ -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}} ]; then\
	rm -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
	echo "Running: dracut -f --kver %{KVERREL}%{?1:+%{1}}"\
	dracut -f --kver "%{KVERREL}%{?1:+%{1}}" || exit $?\
fi\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1:%{1}-}core}\
%if 0%{!?fedora:1}\
%if !%{with_realtime}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --add-kernel %{KVERREL}%{?1:+%{1}} || exit $?\
fi\
%endif\
%endif\
rm -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?1:+%{1}}\
/bin/kernel-install add %{KVERREL}%{?1:+%{1}} /lib/modules/%{KVERREL}%{?1:+%{1}}/vmlinuz || exit $?\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_modules_post %{?-v*}}\
%{expand:%%kernel_modules_extra_post %{?-v*}}\
%{expand:%%kernel_modules_internal_post %{?-v*}}\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post %{?-v*:%{-v*}-}core}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
touch %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1:%{1}-}core}\
/bin/kernel-install remove %{KVERREL}%{?1:+%{1}} /lib/modules/%{KVERREL}%{?1:+%{1}}/vmlinuz || exit $?\
%if !%{with_realtime}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --remove-kernel %{KVERREL}%{?1:+%{1}} || exit $?\
fi\
%endif\
%{nil}

%kernel_variant_preun
%kernel_variant_post -r kernel-smp
%if %{with_realtime}
%kernel_kvm_post
%endif

%if %{with_pae}
%kernel_variant_preun lpae
%kernel_variant_post -v lpae -r (kernel|kernel-smp)
%endif

%if %{with_debug}
%kernel_variant_preun debug
%kernel_variant_post -v debug
%if %{with_realtime}
%kernel_kvm_post debug
%endif
%endif

%if %{with_zfcpdump}
%kernel_variant_preun zfcpdump
%kernel_variant_post -v zfcpdump
%endif

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
/usr/include/*
%exclude %{_includedir}/cpufreq.h
%endif

%if %{with_cross_headers}
%files cross-headers
/usr/*-linux-gnu/include/*
%endif

%if %{with_kernel_abi_stablelists}
%files -n kernel-abi-stablelists
/lib/modules/kabi-*
%endif

%if %{with_kabidw_base}
%ifarch x86_64 s390x ppc64 ppc64le aarch64
%files kernel-kabidw-base-internal
%defattr(-,root,root)
/kabidw-base/%{_target_cpu}/*
%endif
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{rpmversion}-%{pkgrelease}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}-%{pkgrelease}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}-%{pkgrelease}
%endif

%if %{with_perf}
%files -n perf
%{_bindir}/perf
%{_libdir}/libperf-jvmti.so
%dir %{_libexecdir}/perf-core
%{_libexecdir}/perf-core/*
%{_datadir}/perf-core/*
%{_mandir}/man[1-8]/perf*
%{_sysconfdir}/bash_completion.d/perf
%doc linux-%{KVERREL}/tools/perf/Documentation/examples.txt
%{_docdir}/perf-tip/tips.txt

%files -n python3-perf
%{python3_sitearch}/*

%if %{with_debuginfo}
%files -f perf-debuginfo.list -n perf-debuginfo

%files -f python3-perf-debuginfo.list -n python3-perf-debuginfo
%endif
# with_perf
%endif

%if %{with_tools}
%ifnarch %{cpupowerarchs}
%files -n kernel-tools
%else
%files -n kernel-tools -f cpupower.lang
%{_bindir}/cpupower
%{_datadir}/bash-completion/completions/cpupower
%ifarch x86_64
%{_bindir}/centrino-decode
%{_bindir}/powernow-k8-decode
%endif
%{_unitdir}/cpupower.service
%{_mandir}/man[1-8]/cpupower*
%config(noreplace) %{_sysconfdir}/sysconfig/cpupower
%ifarch x86_64
%{_bindir}/x86_energy_perf_policy
%{_mandir}/man8/x86_energy_perf_policy*
%{_bindir}/turbostat
%{_mandir}/man8/turbostat*
%{_bindir}/intel-speed-select
%{_sbindir}/intel_sdsi
%endif
# cpupowerarchs
%endif
%{_bindir}/tmon
%{_bindir}/iio_event_monitor
%{_bindir}/iio_generic_buffer
%{_bindir}/lsiio
%{_bindir}/lsgpio
%{_bindir}/gpio-hammer
%{_bindir}/gpio-event-mon
%{_bindir}/gpio-watch
%{_mandir}/man1/kvm_stat*
%{_bindir}/kvm_stat
%{_unitdir}/kvm_stat.service
%config(noreplace) %{_sysconfdir}/logrotate.d/kvm_stat
%{_bindir}/page_owner_sort
%{_bindir}/slabinfo

%if %{with_debuginfo}
%files -f kernel-tools-debuginfo.list -n kernel-tools-debuginfo
%endif

%ifarch %{cpupowerarchs}
%files -n kernel-tools-libs
%{_libdir}/libcpupower.so.0
%{_libdir}/libcpupower.so.0.0.1

%files -n kernel-tools-libs-devel
%{_libdir}/libcpupower.so
%{_includedir}/cpufreq.h
%endif
# with_tools
%endif

%if !%{with_realtime}
%if %{with_bpftool}
%files -n bpftool
%{_sbindir}/bpftool
%{_sysconfdir}/bash_completion.d/bpftool
%{_mandir}/man8/bpftool-cgroup.8.gz
%{_mandir}/man8/bpftool-gen.8.gz
%{_mandir}/man8/bpftool-iter.8.gz
%{_mandir}/man8/bpftool-link.8.gz
%{_mandir}/man8/bpftool-map.8.gz
%{_mandir}/man8/bpftool-prog.8.gz
%{_mandir}/man8/bpftool-perf.8.gz
%{_mandir}/man8/bpftool.8.gz
%{_mandir}/man8/bpftool-net.8.gz
%{_mandir}/man8/bpftool-feature.8.gz
%{_mandir}/man8/bpftool-btf.8.gz
%{_mandir}/man8/bpftool-struct_ops.8.gz

%if %{with_debuginfo}
%files -f bpftool-debuginfo.list -n bpftool-debuginfo
%defattr(-,root,root)
%endif
%endif
%endif

%if %{with_selftests}
%files selftests-internal
%{_libexecdir}/ksamples
%{_libexecdir}/kselftests
%endif

# empty meta-package
%ifnarch %nobuildarches noarch
%files
%endif

%if %{with_gcov}
%ifnarch %nobuildarches noarch
%files gcov
%{_builddir}
%endif
%endif

# This is %%{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <use_vdso> <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{2}\
%{expand:%%files -f %{name}-%{?3:%{3}-}core.list %{?1:-f %{name}-%{?3:%{3}-}ldsoconf.list} %{?3:%{3}-}core}\
%{!?_licensedir:%global license %%doc}\
%license linux-%{KVERREL}/COPYING-%{version}-%{release}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}\
%ghost /%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/.vmlinuz.hmac \
%ghost /%{image_install_path}/.vmlinuz-%{KVERREL}%{?3:+%{3}}.hmac \
%ifarch %{arm} aarch64\
/lib/modules/%{KVERREL}%{?3:+%{3}}/dtb \
%ghost /%{image_install_path}/dtb-%{KVERREL}%{?3:+%{3}} \
%endif\
%attr(0600, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/System.map\
%ghost %attr(0600, root, root) /boot/System.map-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/symvers.gz\
/lib/modules/%{KVERREL}%{?3:+%{3}}/config\
%ghost %attr(0600, root, root) /boot/symvers-%{KVERREL}%{?3:+%{3}}.gz\
%ghost %attr(0600, root, root) /boot/initramfs-%{KVERREL}%{?3:+%{3}}.img\
%ghost %attr(0644, root, root) /boot/config-%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel\
/lib/modules/%{KVERREL}%{?3:+%{3}}/build\
/lib/modules/%{KVERREL}%{?3:+%{3}}/source\
/lib/modules/%{KVERREL}%{?3:+%{3}}/updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/weak-updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/systemtap\
%{_datadir}/doc/kernel-keys/%{KVERREL}%{?3:+%{3}}\
%if %{1}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/vdso\
%endif\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.*\
%{expand:%%files -f %{name}-%{?3:%{3}-}modules.list %{?3:%{3}-}modules}\
%{expand:%%files %{?3:%{3}-}devel}\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?3:+%{3}}\
%{expand:%%files %{?3:%{3}-}devel-matched}\
%{expand:%%files -f %{name}-%{?3:%{3}-}modules-extra.list %{?3:%{3}-}modules-extra}\
%config(noreplace) /etc/modprobe.d/*-blacklist.conf\
%{expand:%%files -f %{name}-%{?3:%{3}-}modules-internal.list %{?3:%{3}-}modules-internal}\
%if %{with_realtime}\
%{expand:%%files -f %{name}-%{?3:%{3}-}kvm.list %{?3:%{3}-}kvm}\
%endif\
%if %{with_debuginfo}\
%ifnarch noarch\
%{expand:%%files -f debuginfo%{?3}.list %{?3:%{3}-}debuginfo}\
%endif\
%endif\
%if %{?3:1} %{!?3:0}\
%{expand:%%files %{3}}\
%endif\
%endif\
%{nil}

%kernel_variant_files %{_use_vdso} %{with_up}
%kernel_variant_files %{_use_vdso} %{with_debug} debug
%if %{with_debug_meta}
%files debug
%files debug-core
%files debug-devel
%files debug-devel-matched
%files debug-modules
%files debug-modules-extra
%endif
%kernel_variant_files %{use_vdso} %{with_pae} lpae
%kernel_variant_files %{_use_vdso} %{with_zfcpdump} zfcpdump

%define kernel_variant_ipaclones(k:) \
%if %{1}\
%if %{with_ipaclones}\
%{expand:%%files %{?2:%{2}-}ipaclones-internal}\
%defattr(-,root,root)\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?2:+%{2}}-ipaclones\
%endif\
%endif\
%{nil}

%kernel_variant_ipaclones %{with_up}

# plz don't put in a version string unless you're going to tag
# and build.
#
#
%changelog
* Thu Feb 09 2023 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.18.1.rt21.181.el9_1]
- [rt] build kernel-rt-5.14.0-162.18.1.rt21.181.el9_1 [2160463]
- powerpc/pseries: Use lparcfg to reconfig VAS windows for DLPAR CPU (Steve Best) [2154305]
- redhat/configs: Change the amd-pstate driver from builtin to loadable (David Arcari) [2151274]
- powerpc/pseries/mobility: set NMI watchdog factor during an LPM (Steve Best) [2140085]
- powerpc/watchdog: introduce a NMI watchdog's factor (Steve Best) [2140085]
- watchdog: export lockup_detector_reconfigure (Steve Best) [2140085]
- powerpc/mobility: wait for memory transfer to complete (Steve Best) [2140085]

* Fri Feb 03 2023 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.17.1.rt21.180.el9_1]
- [rt] build kernel-rt-5.14.0-162.17.1.rt21.180.el9_1 [2160463]
- PCI: hv: Only reuse existing IRTE allocation for Multi-MSI (Emanuele Giuseppe Esposito) [2155459]
- PCI: hv: Fix the definition of vector in hv_compose_msi_msg() (Emanuele Giuseppe Esposito) [2155459]
- PCI: hv: Fix interrupt mapping for multi-MSI (Emanuele Giuseppe Esposito) [2155459]
- PCI: hv: Reuse existing IRTE allocation in compose_msi_msg() (Emanuele Giuseppe Esposito) [2155459]
- PCI: hv: Fix hv_arch_irq_unmask() for multi-MSI (Emanuele Giuseppe Esposito) [2155459]
- PCI: hv: Fix multi-MSI to allow more than one MSI vector (Emanuele Giuseppe Esposito) [2155459]
- proc: proc_skip_spaces() shouldn't think it is working on C strings (Wander Lairson Costa) [2152583] {CVE-2022-4378}
- proc: avoid integer type confusion in get_proc_long (Wander Lairson Costa) [2152583] {CVE-2022-4378}
- blk-mq: run queue no matter whether the request is the last request (Ming Lei) [2162535]
- netfilter: nft_payload: incorrect arithmetics when fetching VLAN header bits (Florian Westphal) [2161727] {CVE-2023-0179}
- nvme-tcp: fix regression that causes sporadic requests to time out (Gopal Tiwari) [2161344]
- netfs: Fix dodgy maths (Xiubo Li) [2161418]
- netfs: Fix missing xas_retry() calls in xarray iteration (Xiubo Li) [2161418]

* Thu Jan 26 2023 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.16.1.rt21.179.el9_1]
- [rt] build kernel-rt-5.14.0-162.16.1.rt21.179.el9_1 [2160463]
- Bluetooth: L2CAP: Fix use-after-free caused by l2cap_reassemble_sdu (Ricardo Robaina) [2152943] {CVE-2022-3564}
- gitlab-ci: use CI templates from production branch (Michael Hofmann)

* Fri Jan 20 2023 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.15.1.rt21.178.el9_1]
- [rt] build kernel-rt-5.14.0-162.15.1.rt21.178.el9_1 [2160463]
- KVM: s390: vsie: Fix the initialization of the epoch extension (epdx) field (Thomas Huth) [2158815]
- x86/fpu: Do not leak fpstate pointer on fork (Rafael Aquini) [2133083]
- Revert "usb: typec: ucsi: add a common function ucsi_unregister_connectors()" (Torez Smith) [2153277]
- i2c: ismt: Fix an out-of-bounds bug in ismt_access() (David Arcari) [2162681] {CVE-2022-2873}

* Thu Jan 12 2023 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.14.1.rt21.177.el9_1]
- [rt] build kernel-rt-5.14.0-162.14.1.rt21.177.el9_1 [2160463]
- NFSD: fix use-after-free in __nfs42_ssc_open() (Benjamin Coddington) [2152817] {CVE-2022-4379}
- PCI: hv: Fix synchronization between channel callback and hv_pci_bus_exit() (Mohammed Gamal) [2155930]
- PCI: hv: Fix synchronization between channel callback and hv_compose_msi_msg() (Mohammed Gamal) [2155930]
- PCI: hv: Use vmbus_requestor to generate transaction IDs for VMbus hardening (Mohammed Gamal) [2155930]
- sched/core: Always flush pending blk_plug (Phil Auld) [2153792]
- [redhat-rt] build: adjust RTBZ for 9.1.0-z2 (Patrick Talbert)

* Thu Jan 05 2023 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.13.1.rt21.176.el9_1]
- [rt] build kernel-rt-5.14.0-162.13.1.rt21.176.el9_1 [2141817]
- scsi: qla2xxx: Fix crash when I/O abort times out (Nilesh Javali) [2152178]
- net: mana: Fix race on per-CQ variable napi work_done (Emanuele Giuseppe Esposito) [2155145]

* Wed Dec 21 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.12.1.rt21.175.el9_1]
- [rt] build kernel-rt-5.14.0-162.12.1.rt21.175.el9_1 [2141817]
- x86/fpu: Drop fpregs lock before inheriting FPU permissions (Valentin Schneider) [2154407]
- hv_netvsc: Fix race between VF offering and VF association message from host (Mohammed Gamal) [2151605]
- PCI: hv: Do not set PCI_COMMAND_MEMORY to reduce VM boot time (Emanuele Giuseppe Esposito) [2150910]

* Mon Dec 12 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.11.1.rt21.174.el9_1]
- [rt] build kernel-rt-5.14.0-162.11.1.rt21.174.el9_1 [2141817]
- drm/i915: fix TLB invalidation for Gen12 video and compute engines (Wander Lairson Costa) [2148165] {CVE-2022-4139}
- memcg: prohibit unconditional exceeding the limit of dying tasks (Chris von Recklinghausen) [2143976]
- mm, oom: do not trigger out_of_memory from the #PF (Waiman Long) [2143976]
- mm, oom: pagefault_out_of_memory: don't force global OOM for dying tasks (Chris von Recklinghausen) [2143976]
- pipe: Fix missing lock in pipe_resize_ring() (Ian Kent) [2141634] {CVE-2022-2959}
- net: usb: ax88179_178a: Fix packet receiving (Jose Ignacio Tornos Martinez) [2120515] {CVE-2022-2964}
- net: usb: ax88179_178a: Fix out-of-bounds accesses in RX fixup (Jose Ignacio Tornos Martinez) [2120515] {CVE-2022-2964}
- NFSD: Protect against send buffer overflow in NFSv3 READ (Scott Mayhew) [2141772] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv2 READ (Scott Mayhew) [2141772] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv3 READDIR (Scott Mayhew) [2141772] {CVE-2022-43945}
- NFSD: Protect against send buffer overflow in NFSv2 READDIR (Scott Mayhew) [2141772] {CVE-2022-43945}
- SUNRPC: Fix svcxdr_init_encode's buflen calculation (Scott Mayhew) [2141772] {CVE-2022-43945}
- SUNRPC: Fix svcxdr_init_decode's end-of-buffer calculation (Scott Mayhew) [2141772] {CVE-2022-43945}

* Mon Dec 05 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.10.1.rt21.173.el9_1]
- [rt] build kernel-rt-5.14.0-162.10.1.rt21.173.el9_1 [2141817]
- ice: Fix crash by keep old cfg when update TCs more than queues (Petr Oros) [2132070]
- ice: Fix tunnel checksum offload with fragmented traffic (Petr Oros) [2132070]
- ice: handle E822 generic device ID in PLDM header (Petr Oros) [2132070]
- ice: ethtool: Prohibit improper channel config for DCB (Petr Oros) [2132070]
- ice: ethtool: advertise 1000M speeds properly (Petr Oros) [2132070]
- ice: Fix switchdev rules book keeping (Petr Oros) [2132070]
- ice: fix access-beyond-end in the switch code (Petr Oros) [2132070]
- eth: ice: silence the GCC 12 array-bounds warning (Petr Oros) [2132070]
- ice: Expose RSS indirection tables for queue groups via ethtool (Petr Oros) [2132070]
- Revert "ice: Hide bus-info in ethtool for PRs in switchdev mode" (Petr Oros) [2132070]
- ice: remove period on argument description in ice_for_each_vf (Petr Oros) [2132070]
- ice: add a function comment for ice_cfg_mac_antispoof (Petr Oros) [2132070]
- ice: fix wording in comment for ice_reset_vf (Petr Oros) [2132070]
- ice: remove return value comment for ice_reset_all_vfs (Petr Oros) [2132070]
- ice: always check VF VSI pointer values (Petr Oros) [2132070]
- ice: add newline to dev_dbg in ice_vf_fdir_dump_info (Petr Oros) [2132070]
- ice: get switch id on switchdev devices (Petr Oros) [2132070]
- ice: return ENOSPC when exceeding ICE_MAX_CHAIN_WORDS (Petr Oros) [2132070]
- ice: introduce common helper for retrieving VSI by vsi_num (Petr Oros) [2132070]
- ice: use min_t() to make code cleaner in ice_gnss (Petr Oros) [2132070]
- ice, xsk: Avoid refilling single Rx descriptors (Petr Oros) [2132070]
- ice, xsk: Diversify return values from xsk_wakeup call paths (Petr Oros) [2132070]
- ice, xsk: Terminate Rx side of NAPI when XSK Rx queue gets full (Petr Oros) [2132070]
- ice, xsk: Decorate ICE_XDP_REDIR with likely() (Petr Oros) [2132070]
- ice: Add mpls+tso support (Petr Oros) [2132070]
- ice: switch: convert packet template match code to rodata (Petr Oros) [2132070]
- ice: switch: use convenience macros to declare dummy pkt templates (Petr Oros) [2132070]
- ice: switch: use a struct to pass packet template params (Petr Oros) [2132070]
- ice: switch: unobscurify bitops loop in ice_fill_adv_dummy_packet() (Petr Oros) [2132070]
- ice: switch: add and use u16[] aliases to ice_adv_lkup_elem::{h, m}_u (Petr Oros) [2132070]
- ice: Support GTP-U and GTP-C offload in switchdev (Petr Oros) [2132070]
- Documentation/admin-guide: Document nomodeset kernel parameter (Karol Herbst) [2145217]
- drm: Move nomodeset kernel parameter to the DRM subsystem (Karol Herbst) [2145217]
- selftests/bpf: Limit unroll_count for pyperf600 test (Frantisek Hrbata) [2144902]
- nvme-fc: fix the fc_appid_store return value (Ewan D. Milne) [2136914]
- ACPI: processor idle: Practically limit "Dummy wait" workaround to old Intel systems (Wei Huang) [2142168]
- CI: Drop c9s CI parts (Veronika Kabatova)
- CI: Use GA builder container (Veronika Kabatova)

* Fri Nov 18 2022 Patrick Talbert <ptalbert@redhat.com> [5.14.0-162.9.1.rt21.172.el9_1]
- [rt] build kernel-rt-5.14.0-162.9.1.rt21.172.el9_1 [2141817]
- CI: Remove deprecated variable (Veronika Kabatova)
- drm: fix duplicated code in drm_connector_register (Karol Herbst) [2134619]
- drm/mgag200: Fix PLL setup for G200_SE_A rev >=4 (Jocelyn Falempe) [2140153]
- scsi: mpi3mr: Schedule IRQ kthreads only on non-RT kernels (Tomas Henzl) [2139213]

* Fri Nov 11 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-162.8.1.rt21.171.el9_1]
- [rt] build kernel-rt-5.14.0-162.8.1.rt21.171.el9_1 [2141817]
- redhat: fix the branch we pull from the documentation tree (Herton R. Krzesinski)
- nvme-tcp: handle number of queue changes (John Meneghini) [2131359]
- nvmet: expose max queues to configfs (John Meneghini) [2131359]
- nvme-fabrics: parse nvme connect Linux error codes (John Meneghini) [2131359]
- vfio/type1: Unpin zero pages (Alex Williamson) [2128514]
- ptrace: Check PTRACE_O_SUSPEND_SECCOMP permission on PTRACE_SEIZE (Oleg Nesterov) [2128033 2121272] {CVE-2022-30594}

* Thu Nov 10 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-162.7.1.rt21.170.el9_1]
- [rt] build kernel-rt-5.14.0-162.7.1.rt21.170.el9_1 [2141817]

* Thu Nov 03 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-162.7.1.rt21.169.el9_1]
- [rt] build kernel-rt-5.14.0-162.7.1.rt21.169.el9_1 [2061574]
- i2c: ismt: prevent memory corruption in ismt_access() (David Arcari) [2125581] {CVE-2022-3077}
- x86/fpu: Prevent FPU state corruption (Oleksandr Natalenko) [2134588]
- iavf: Fix reset error handling (Petr Oros) [2127884]
- iavf: Fix NULL pointer dereference in iavf_get_link_ksettings (Petr Oros) [2127884]
- iavf: Fix missing state logs (Petr Oros) [2127884]

* Mon Oct 03 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-162.6.1.rt21.168.el9_1]
- [rt] build kernel-rt-5.14.0-162.6.1.rt21.168.el9_1 [2061574]
- kabi: add symbol yield to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol xa_find_after to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol xa_find to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol xa_destroy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol x86_spec_ctrl_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol x86_cpu_to_apicid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol wait_for_completion_interruptible to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol wait_for_completion to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vsprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vsnprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vprintk to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vmemmap_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vmalloc_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vmalloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vm_zone_stat to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vm_event_states to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol vfree to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_undefined to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_teardown_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_setup_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_possible_blades to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_get_hubless_system to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_obj_count to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_install_heap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_pci_topology to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_master_nasid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_heapsize to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_get_geoinfo to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_enum_ports to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol uv_bios_enum_objs to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol up_write to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol up_read to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol up to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_reboot_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_nmi_handler to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_netdevice_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_chrdev_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol unregister_blkdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tsc_khz to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol try_wait_for_completion to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol touch_softlockup_watchdog to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol time64_to_tm to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol this_cpu_off to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tasklet_unlock_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tasklet_kill to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol tasklet_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol system_wq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol system_freezing_cnt to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sys_tz to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol synchronize_rcu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strstr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strsep to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strrchr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strnlen to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncpy_from_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strncasecmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strlen to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strlcpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strlcat to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strcpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strcmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol strchr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sscanf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sort to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol snprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sn_region_size to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sn_partition_id to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol smp_call_function_single_async to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol smp_call_function_single to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol smp_call_function_many to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol sme_me_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_strtoull to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_strtoul to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_strtol to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol simple_read_from_buffer to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol set_freezable to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol set_current_groups to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol security_sb_eat_lsm_opts to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol security_free_mnt_opts to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol scsi_command_size_tbl to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol scnprintf to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol schedule_timeout to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol schedule to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rtnl_is_locked to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol revert_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol request_threaded_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol remove_wait_queue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol register_reboot_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol register_netdevice_notifier to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol register_chrdev_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol refcount_warn_saturate to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol recalc_sigpending to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rcu_read_unlock_strict to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rb_next to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol rb_first to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol radix_tree_delete to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol queue_work_on to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol queue_delayed_work_on to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol put_unused_fd to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ptrs_per_p4d to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol printk to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_to_wait_exclusive to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_to_wait_event to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_to_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol prepare_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_valid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_to_xattr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_from_xattr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol posix_acl_alloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol physical_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol phys_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol pgdir_shift to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol percpu_ref_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol percpu_ref_exit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol panic_notifier_list to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol panic to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol page_offset_base to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol override_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol numa_node to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol nr_cpu_ids to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol node_states to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_unlock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mutex_is_locked to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol msleep to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memset to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_free_slab to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_free to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_destroy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_create_node to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_create to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_alloc_slab to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mempool_alloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memparse to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memory_read_from_buffer to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memmove to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memcpy to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol memcmp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mem_section to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol mds_idle_clear to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol lookup_bdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get_ts64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get_real_ts64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get_coarse_real_ts64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ktime_get to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kthread_should_stop to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kstrtoull to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kstrtoll to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kmalloc_order_trace to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kfree to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kernel_sigaction to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kernel_fpu_end to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol kernel_fpu_begin_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol jiffies_64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol jiffies to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol is_vmalloc_addr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol is_uv_system to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol iounmap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol ioremap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol iomem_resource to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol init_wait_entry to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol init_timer_key to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in_group_p to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in_aton to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in6_pton to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol in4_pton to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_start_range_ns to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_forward to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol hrtimer_cancel to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol groups_alloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol get_zeroed_page to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol get_unused_fd_flags to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol free_percpu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol free_pages to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol free_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol fortify_panic to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol flush_workqueue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol finish_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol elfcorehdr_addr to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol efi to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol dump_stack to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol downgrade_write to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_write_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_write to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_read_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_read to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down_interruptible to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol down to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol dmi_get_system_info to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol devmap_managed_key to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol dev_base_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol destroy_workqueue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol delayed_work_timer_fn to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol del_timer_sync to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol default_wake_function to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol csum_partial to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpumask_next to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpufreq_quick_get to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_sibling_map to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_number to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_khz to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_info to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cpu_bit_bitmap to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol congestion_wait to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol complete_and_exit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol complete to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol commit_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol clear_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol capable to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cancel_delayed_work_sync to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cancel_delayed_work to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol call_usermodehelper to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol call_rcu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol cachemode2protval to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol boot_cpu_data to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol blk_stack_limits to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol bitmap_release_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol bitmap_find_free_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol avenrun to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol autoremove_wake_function to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol atomic_notifier_chain_unregister to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol atomic_notifier_chain_register to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol async_synchronize_full_domain to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol async_synchronize_full to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol alloc_workqueue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol alloc_chrdev_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol add_wait_queue_exclusive to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol add_wait_queue to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol add_timer to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol abort_creds to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _totalram_pages to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_unlock_irqrestore to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_unlock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_lock_irqsave to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_write_lock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock_irqrestore to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_unlock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_trylock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_trylock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock_irqsave to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock_irq to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_spin_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_unlock_irqrestore to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_unlock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_lock_irqsave to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _raw_read_lock_bh to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _find_next_bit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _find_first_zero_bit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _find_first_bit to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _ctype to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _copy_to_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol _copy_from_user to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __xa_insert to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rsi to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rdx to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rdi to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rcx to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rbx to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rbp to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_rax to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r8 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r15 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r14 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r13 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r12 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __x86_indirect_thunk_r10 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __warn_printk to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __wake_up to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __vmalloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __uv_hub_info_list to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __uv_cpu_info to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __unregister_chrdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __udelay to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __tasklet_schedule to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __sw_hweight64 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __sw_hweight32 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __stack_chk_fail to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __request_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __release_region to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __register_nmi_handler to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __register_blkdev to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __refrigerator to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __rcu_read_unlock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __rcu_read_lock to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_user_8 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_user_4 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_user_2 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __put_cred to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __preempt_count to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __per_cpu_offset to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __num_online_cpus to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __node_distance to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __ndelay to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __mutex_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __msecs_to_jiffies to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __list_del_entry_valid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __list_add_valid to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __kmalloc to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __init_waitqueue_head to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __init_swait_queue_head to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __init_rwsem to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __hw_addr_init to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __get_user_2 to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __get_free_pages to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __fentry__ to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __cpu_possible_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __cpu_online_mask to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __const_udelay to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __cond_resched to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __check_object_size to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_weight to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_intersects to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_equal to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __bitmap_and to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __alloc_percpu to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __SCT__preempt_schedule to stablelist (Čestmír Kalina) [2120286]
- kabi: add symbol __SCT__might_resched to stablelist (Čestmír Kalina) [2120286]
- kabi: re-enable build-time kabi-checks (Čestmír Kalina) [2120321]
- sfc: fix null pointer dereference in efx_hard_start_xmit (Íñigo Huguet) [2129287]
- sfc: fix TX channel offset when using legacy interrupts (Íñigo Huguet) [2129287]

* Thu Sep 29 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-162.5.1.rt21.167.el9_1]
- [rt] build kernel-rt-5.14.0-162.5.1.rt21.167.el9_1 [2061574]
- redhat: change default dist suffix for RHEL 9.1 (Patrick Talbert)
- netfilter: nf_tables: clean up hook list when offload flags check fails (Florian Westphal) [2121393]
- netfilter: nfnetlink_osf: fix possible bogus match in nf_osf_find() (Florian Westphal) [2121393]
- netfilter: nf_conntrack_irc: Fix forged IP logic (Florian Westphal) [2121393]
- netfilter: nf_conntrack_irc: Tighten matching on DCC message (Florian Westphal) [2121393]
- netfilter: br_netfilter: Drop dst references before setting. (Florian Westphal) [2121393]
- netfilter: flowtable: fix stuck flows on cleanup due to pending work (Florian Westphal) [2121393]
- netfilter: flowtable: add function to invoke garbage collection immediately (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow binding to already bound chain (Florian Westphal) [2121393]
- netfilter: nft_tunnel: restrict it to netdev family (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow updates of implicit chain (Florian Westphal) [2121393]
- netfilter: nft_tproxy: restrict to prerouting hook (Florian Westphal) [2121393]
- netfilter: ebtables: reject blobs that don't provide all entry points (Florian Westphal) [2121393]
- netfilter: nf_tables: check NFT_SET_CONCAT flag if field_count is specified (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow NFT_SET_ELEM_CATCHALL and NFT_SET_ELEM_INTERVAL_END (Florian Westphal) [2121393]
- netfilter: nf_tables: NFTA_SET_ELEM_KEY_END requires concat and interval flags (Florian Westphal) [2121393]
- netfilter: nf_tables: validate NFTA_SET_ELEM_OBJREF based on NFT_SET_OBJECT flag (Florian Westphal) [2121393]
- netfilter: nf_tables: possible module reference underflow in error path (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow NFTA_SET_ELEM_KEY_END with NFT_SET_ELEM_INTERVAL_END flag (Florian Westphal) [2121393]
- netfilter: nf_tables: use READ_ONCE and WRITE_ONCE for shared generation id access (Florian Westphal) [2121393]
- netfilter: nf_tables: fix null deref due to zeroed list head (Florian Westphal) [2121393]
- netfilter: nf_tables: disallow jump to implicit chain from set element (Florian Westphal) [2121393]
- netfilter: nfnetlink: re-enable conntrack expectation events (Florian Westphal) [2121393]

* Tue Sep 27 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-162.4.1.rt21.166.el9]
- [rt] build kernel-rt-5.14.0-162.4.1.rt21.166.el9 [2061574]
- iwlwifi: limit fw version for AC9560 to avoid fw crash (Iñigo Huguet) [2096128]
- configs: enable CONFIG_HP_ILO for aarch64 (Mark Salter) [2126153]

* Mon Sep 19 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-162.3.1.rt21.165.el9]
- [rt] build kernel-rt-5.14.0-162.3.1.rt21.165.el9 [2061574]
- scsi: restore setting of scmd->scsi_done() in EH and reset ioctl paths (Ewan D. Milne) [2120469]
- x86/boot: Don't propagate uninitialized boot_params->cc_blob_address (Terry Bowman) [2124644]
- ice: Allow operation with reduced device MSI-X (Petr Oros) [2107719]

* Thu Sep 15 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-162.2.1.rt21.164.el9]
- [rt] build kernel-rt-5.14.0-162.2.1.rt21.164.el9 [2061574]
- ixgbe: Add locking to prevent panic when setting sriov_numvfs to zero (Ken Cox) [2109871]
- drm/hyperv : Removing the restruction of VRAM allocation with PCI bar size (Vitaly Kuznetsov) [2030922]
- drm/nouveau/kms/nv140-: Disable interlacing (Lyude Paul) [2122068]

* Tue Sep 13 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-162.1.1.rt21.163.el9]
- [rt] build kernel-rt-5.14.0-162.1.1.rt21.163.el9 [2061574]
- drm/amdgpu: Only disable prefer_shadow on hawaii (Lyude Paul) [2120670]
- i40e: Fix kernel crash during module removal (Ivan Vecera) [2070375]
- Revert "net: macsec: update SCI upon MAC address change." (Sabrina Dubroca) [2118139]
- redhat: enable zstream release numbering for rhel 9.1 (Patrick Talbert)
- redhat: add missing CVE reference to latest changelog entries (Patrick Talbert)

* Mon Sep 05 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-162.rt21.162.el9]
- [rt] build kernel-rt-5.14.0-162.rt21.162.el9 [2061574]
- Revert "ixgbevf: Mailbox improvements" (Ken Cox) [2120548]
- Revert "ixgbevf: Add support for new mailbox communication between PF and VF" (Ken Cox) [2120548]
- posix-cpu-timers: Cleanup CPU timers before freeing them during exec (Wander Lairson Costa) [2116970] {CVE-2022-2585}
- fix race between exit_itimers() and /proc/pid/timers (Wander Lairson Costa) [2116970] {CVE-2022-2585}

* Fri Sep 02 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-161.rt21.161.el9]
- [rt] build kernel-rt-5.14.0-161.rt21.161.el9 [2061574]
- x86/ftrace: Use alternative RET encoding (Joe Lawrence) [2121368]
- x86/ibt,ftrace: Make function-graph play nice (Joe Lawrence) [2121368]
- x86/ibt,paravirt: Use text_gen_insn() for paravirt_patch() (Joe Lawrence) [2121368]
- x86/text-patching: Make text_gen_insn() play nice with ANNOTATE_NOENDBR (Joe Lawrence) [2121368]
- redhat: remove GL_DISTGIT_USER, RHDISTGIT and unify dist-git cloning (Frantisek Hrbata)
- random: allow reseeding DRBG with getrandom (Daiki Ueno) [2114854]

* Thu Aug 25 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-160.rt21.160.el9]
- [rt] build kernel-rt-5.14.0-160.rt21.160.el9 [2061574]
- iavf: Fix VLAN_V2 addition/rejection (Ivan Vecera) [2119701]
- gve: Recording rx queue before sending to napi (Jordan Kimbrough) [2022916]
- gve: fix the wrong AdminQ buffer queue index check (Jordan Kimbrough) [2022916]
- gve: Fix GFP flags when allocing pages (Jordan Kimbrough) [2022916]
- gve: Add tx|rx-coalesce-usec for DQO (Jordan Kimbrough) [2022916]
- gve: Add consumed counts to ethtool stats (Jordan Kimbrough) [2022916]
- gve: Implement suspend/resume/shutdown (Jordan Kimbrough) [2022916]
- gve: Add optional metadata descriptor type GVE_TXD_MTD (Jordan Kimbrough) [2022916]
- gve: remove memory barrier around seqno (Jordan Kimbrough) [2022916]
- gve: Update gve_free_queue_page_list signature (Jordan Kimbrough) [2022916]
- gve: Move the irq db indexes out of the ntfy block struct (Jordan Kimbrough) [2022916]
- gve: Correct order of processing device options (Jordan Kimbrough) [2022916]
- gve: fix for null pointer dereference. (Jordan Kimbrough) [2022916]
- gve: fix unmatched u64_stats_update_end() (Jordan Kimbrough) [2022916]
- gve: Fix off by one in gve_tx_timeout() (Jordan Kimbrough) [2022916]
- gve: Add a jumbo-frame device option. (Jordan Kimbrough) [2022916]
- gve: Implement packet continuation for RX. (Jordan Kimbrough) [2022916]
- gve: Add RX context. (Jordan Kimbrough) [2022916]
- gve: Track RX buffer allocation failures (Jordan Kimbrough) [2022916]
- gve: Allow pageflips on larger pages (Jordan Kimbrough) [2022916]
- gve: Add netif_set_xps_queue call (Jordan Kimbrough) [2022916]
- gve: Recover from queue stall due to missed IRQ (Jordan Kimbrough) [2022916]
- gve: Do lazy cleanup in TX path (Jordan Kimbrough) [2022916]
- gve: Add rx buffer pagecnt bias (Jordan Kimbrough) [2022916]
- gve: Switch to use napi_complete_done (Jordan Kimbrough) [2022916]
- gve: report 64bit tx_bytes counter from gve_handle_report_stats() (Jordan Kimbrough) [2022916]
- gve: fix gve_get_stats() (Jordan Kimbrough) [2022916]
- gve: Properly handle errors in gve_assign_qpl (Jordan Kimbrough) [2022916]
- gve: Avoid freeing NULL pointer (Jordan Kimbrough) [2022916]
- gve: Correct available tx qpl check (Jordan Kimbrough) [2022916]
- gve: Use kvcalloc() instead of kvzalloc() (Jordan Kimbrough) [2022916]
- gve: DQO: avoid unused variable warnings (Jordan Kimbrough) [2022916]
- gve: fix the wrong AdminQ buffer overflow check (Jordan Kimbrough) [2022916]
- ath9k: htc: clean up statistics macros (Jose Ignacio Tornos Martinez) [2084601] {CVE-2022-1679}
- ath9k: hif_usb: simplify if-if to if-else (Jose Ignacio Tornos Martinez) [2084601] {CVE-2022-1679}
- ath9k: fix use-after-free in ath9k_hif_usb_rx_cb (Jose Ignacio Tornos Martinez) [2084601] {CVE-2022-1679}
- net: qcom/emac: Fix improper merge resolution in device_get_mac_address (Patrick Talbert) [2108539]
- x86/speculation: Add LFENCE to RSB fill sequence (Waiman Long) [2115088] {CVE-2022-26373}
- x86/speculation: Add RSB VM Exit protections (Waiman Long) [2115088] {CVE-2022-26373}
- tools headers cpufeatures: Sync with the kernel sources (Waiman Long) [2115088]
- x86/bugs: Do not enable IBPB at firmware entry when IBPB is not available (Waiman Long) [2115088]
- lkdtm: Disable return thunks in rodata.c (Waiman Long) [2115088]
- x86/amd: Use IBPB for firmware calls (Waiman Long) [2115088]
- x86/bugs: Warn when "ibrs" mitigation is selected on Enhanced IBRS parts (Waiman Long) [2115088]
- x86/alternative: Report missing return thunk details (Waiman Long) [2115088]
- nvme-fc: restart admin queue if the caller needs to restart queue (Ewan D. Milne) [2104461]
- scsi: csiostor: Uninitialized data in csio_ln_vnp_read_cbfn() (Rahul Lakkireddy) [2109526]
- scsi: csiostor: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Rahul Lakkireddy) [2109526]

* Thu Aug 25 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-159.rt21.159.el9]
- [rt] build kernel-rt-5.14.0-159.rt21.159.el9 [2061574]
- mediatek: mt76: eeprom: fix missing of_node_put() in mt76_find_power_limits_node() (Jose Ignacio Tornos Martinez) [2103595]
- wifi: mac80211: consider EHT element size in assoc request (Jose Ignacio Tornos Martinez) [2103595]
- wifi: mac80211: switch airtime fairness back to deficit round-robin scheduling (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7615: fix throughput regression on DFS channels (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix incorrect testmode ipg on band 1 caused by wmm_idx (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: enlarge maximum VHT MPDU length to 11454 (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: fix aggregation subframes setting to HE max (Jose Ignacio Tornos Martinez) [2103595]
- wifi: mac80211_hwsim: set virtio device ready in probe() (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921s: fix possible sdio deadlock in command fail (Jose Ignacio Tornos Martinez) [2103595]
- wifi: rtw89: 8852a: rfk: fix div 0 exception (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: do not update pm states in case of error (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7615: do not update pm stats in case of error (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: Avoid REO CMD failed prints during firmware recovery (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: Fix incorrect debug_mask mappings (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix missing skb drop on htc_tx_completion error (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921s: fix firmware download random fail (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix IRQ affinity warning on shutdown (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix netdev open race (Jose Ignacio Tornos Martinez) [2103595]
- iwlwifi: fw: init SAR GEO table only if data is present (Jose Ignacio Tornos Martinez) [2103595]
- ath10k: htt_tx: do not interpret Eth frames as WiFi (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: Don't check arvif->is_started before sending management frames (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix twt table_mask to u16 in mt7915_dev (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: reset 11d state in process of recovery (Jose Ignacio Tornos Martinez) [2103595]
- brcmfmac: use ISO3166 country code and 0 rev as fallback on brcmfmac43602 chips (Jose Ignacio Tornos Martinez) [2103595]
- mt76: fix tx status related use-after-free race on station removal (Jose Ignacio Tornos Martinez) [2103595]
- mt76: do not attempt to reorder received 802.3 packets without agg session (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: fix kernel crash at mt7921_pci_remove (Jose Ignacio Tornos Martinez) [2103595]
- mt76: fix antenna config missing in 6G cap (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: report rx mode value in mt7915_mac_fill_rx_rate (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: do not pass data pointer to mt7915_mcu_muru_debug_set (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix possible NULL pointer dereference in mt7915_mac_fill_rx_vector (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix possible uninitialized pointer dereference in mt7986_wmac_gpio_setup (Jose Ignacio Tornos Martinez) [2103595]
- ath10k: enable napi on RX path for usb (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: fix the warning of dev_wake in mhi_pm_disable_transition() (Jose Ignacio Tornos Martinez) [2103595]
- ath11k: acquire ab->base_lock in unassign when finding the peer by addr (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix unbounded shift in mt7915_mcu_beacon_mbss (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7915: fix DBDC default band selection on MT7915D (Jose Ignacio Tornos Martinez) [2103595]
- mt76: mt7921: honor pm user configuration in mt7921_sniffer_interface_iter (Jose Ignacio Tornos Martinez) [2103595]
- crypto: testmgr - disallow plain cbcmac(aes) and ghash in FIPS mode (Vladis Dronov) [2107596]
- crypto: seqiv - flag instantiations as FIPS compliant (Vladis Dronov) [2107596]
- crypto: api - allow algs only in specific constructions in FIPS mode (Vladis Dronov) [2107596]
- i2c: qcom-geni: Fix GPI DMA buffer sync-back (Andrew Halaney) [2105390]
- i2c: qcom-geni: Use the correct return value (Andrew Halaney) [2105390]
- i2c: qcom-geni: Propagate GENI_ABORT_DONE to geni_i2c_abort_xfer() (Andrew Halaney) [2105390]
- i2c: qcom-geni: remove unnecessary conditions (Andrew Halaney) [2105390]
- i2c: qcom-geni: Use dev_err_probe() for GPI DMA error (Andrew Halaney) [2105390]
- i2c: qcom-geni: Add support for GPI DMA (Andrew Halaney) [2105390]
- soc: qcom: geni: Make use of the helper function devm_platform_ioremap_resource() (Andrew Halaney) [2105390]
- soc: qcom: geni: move GENI_IF_DISABLE_RO to common header (Andrew Halaney) [2105390]
- soc: qcom: geni: Add support for gpi dma (Andrew Halaney) [2105390]

* Thu Aug 25 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-158.rt21.158.el9]
- [rt] build kernel-rt-5.14.0-158.rt21.158.el9 [2061574]
- iommu/arm-smmu-qcom: Add SC8280XP support (Eric Chanudet) [2117020]
- dt-bindings: arm-smmu: Add compatible for Qualcomm SC8280XP (Eric Chanudet) [2117020]
- soc: qcom: smem: use correct format characters (Eric Chanudet) [2108804]
- soc: qcom: smem: validate fields of shared structures (Eric Chanudet) [2108804]
- soc: qcom: smem: map only partitions used by local HOST (Eric Chanudet) [2108804]
- soc: qcom: smem: Update max processor count (Eric Chanudet) [2108804]
- dt-bindings: soc: smem: Make indirection optional (Eric Chanudet) [2108804]
- soc: qcom: llcc: Add sc8180x and sc8280xp configurations (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add sc8180x and sc8280xp LLCC compatibles (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add MODULE_DEVICE_TABLE() (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add LLCC compatible for SM8450 (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add LLCC compatible for SM8350 (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add configuration data for SM8450 SoC (Eric Chanudet) [2108329]
- soc: qcom: llcc: Update register offsets for newer LLCC HW (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add missing llcc configuration data (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add write-cache cacheable support (Eric Chanudet) [2108329]
- soc: qcom: llcc: Update the logic for version info extraction (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add support for 16 ways of allocation (Eric Chanudet) [2108329]
- soc: qcom: llcc: Use devm_bitmap_zalloc() when applicable (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Don't mark LLCC interrupt as required (Eric Chanudet) [2108329]
- dt-bindings: arm: msm: Add LLCC for SM6350 (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add configuration data for SM8350 (Eric Chanudet) [2108329]
- soc: qcom: llcc: Disable MMUHWT retention (Eric Chanudet) [2108329]
- soc: qcom: llcc: Add configuration data for SM6350 (Eric Chanudet) [2108329]
- spi: qcom: geni: Simplify DMA setting (Shawn Doherty) [2106892]
- spi: qcom: geni: handle timeout for gpi mode (Shawn Doherty) [2106892]
- spi: qcom: geni: set the error code for gpi transfer (Shawn Doherty) [2106892]
- spi: qcom: geni: remove unused defines (Shawn Doherty) [2106892]
- spi: spi-geni-qcom: fix error handling in spi_geni_grab_gpi_chan() (Shawn Doherty) [2106892]
- spi: spi-geni-qcom: Add support for GPI dma (Shawn Doherty) [2106892]
- soc: qcom: geni: Add support for gpi dma (Shawn Doherty) [2106892]
- soc: qcom: geni: move GENI_IF_DISABLE_RO to common header (Shawn Doherty) [2106892]
- spi: spi-geni-qcom: Remove confusing comment about setting the watermark (Shawn Doherty) [2106892]
- interconnect: qcom: Add SC8280XP interconnect provider (Adrien Thierry) [2105458]
- dt-bindings: interconnect: qcom: Add sc8280xp binding (Adrien Thierry) [2105458]
- soc: qcom: rpmhpd: add sc8280xp & sa8540p rpmh power-domains (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Don't warn about sparse rpmhpd arrays (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add sc8280xp RPMh power-domains (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Add SDX65 power domains (Adrien Thierry) [2105057]
- dt-bindings: power: Add rpm power domain bindings for SDX65 (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add MSM8226 support (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add MSM8226 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Check for null return of devm_kcalloc (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Sort power-domain definitions and lists (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Remove mx/cx relationship on sc7280 (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Rename rpmhpd struct names (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: sm8450: Add the missing .peer for sm8450_cx_ao (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Add SM8450 power domains (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add SM8450 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add support for sm6125 (Adrien Thierry) [2105057]
- dt-bindings: qcom-rpmpd: Add sm6125 power domains (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add QCM2290 support (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add QCM2290 support (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Drop unused res_name from struct rpmpd (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: fix sm8350_mxc's peer domain (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Make power_on actually enable the domain (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add SM6350 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmpd: Add power domains for MSM8953 (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add MSM8953 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Add SM6350 (Adrien Thierry) [2105057]
- drivers: soc: qcom: rpmpd: Add SM6115 RPM Power Domains (Adrien Thierry) [2105057]
- dt-bindings: power: rpmpd: Add SM6115 to rpmpd binding (Adrien Thierry) [2105057]
- soc: qcom: rpmhpd: Use corner in power_off (Adrien Thierry) [2105057]
- scsi: ufs: core: Fix referencing invalid rsp field (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Clean up ufshpb_suspend()/resume() (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add handing of device reset regions in HPB device mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Change sysfs node hpb_stats/rb_* prefix to start with rcmd_* (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Clean up the handler when device resets HPB information (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove enum initialization value (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Merge ufshpb_reset() and ufshpb_reset_host() (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Enable RPM_AUTOSUSPEND for runtime PM (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove redundant wmb() in ufshcd_send_command() (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Add a readl() to make sure ref_clk gets enabled (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Simplify handling of devm_phy_get() (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Fix acquiring the optional reset control line (Eric Chanudet) [2102378]
- dt-bindings: ufs: cdns,ufshc: Add power-domains (Eric Chanudet) [2102378]
- scsi: ufs: Use pm_runtime_resume_and_get() instead of pm_runtime_get_sync() (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove duplicate include in ufshcd (Eric Chanudet) [2102378]
- scsi: ufs: core: Exclude UECxx from SFR dump list (Eric Chanudet) [2102378]
- scsi: ufs: Move the ufs_is_valid_unit_desc_lun() definition (Eric Chanudet) [2102378]
- scsi: ufs: Move the struct ufs_ref_clk definition (Eric Chanudet) [2102378]
- scsi: ufs: Split the ufshcd.h header file (Eric Chanudet) [2102378]
- scsi: ufs: Minimize #include directives (Eric Chanudet) [2102378]
- scsi: ufs: Fix kernel-doc syntax in ufshcd.h (Eric Chanudet) [2102378]
- scsi: ufs: Remove unnecessary ufshcd-crypto.h include directives (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Fix ufs_qcom_resume() (Eric Chanudet) [2102378]
- scsi: ufs: Introduce ufshcd_clkgate_delay_set() (Eric Chanudet) [2102378]
- scsi: ufs: Remove locking from around single register writes (Eric Chanudet) [2102378]
- scsi: ufs: Remove the TRUE and FALSE definitions (Eric Chanudet) [2102378]
- scsi: ufs: Remove paths from source code comments (Eric Chanudet) [2102378]
- scsi: ufs: Use an SPDX license identifier in the Kconfig file (Eric Chanudet) [2102378]
- scsi: ufs: Rename sdev_ufs_device into ufs_device_wlun (Eric Chanudet) [2102378]
- scsi: ufs: Remove the driver version (Eric Chanudet) [2102378]
- scsi: ufs: Make the config_scaling_param calls type safe (Eric Chanudet) [2102378]
- scsi: ufs: Switch to aggregate initialization (Eric Chanudet) [2102378]
- scsi: ufs: Remove unused constants and code (Eric Chanudet) [2102378]
- scsi: ufs: Invert the return value of ufshcd_is_hba_active() (Eric Chanudet) [2102378]
- scsi: ufs: Declare the quirks array const (Eric Chanudet) [2102378]
- scsi: ufs: Rename struct ufs_dev_fix into ufs_dev_quirk (Eric Chanudet) [2102378]
- scsi: ufs: Remove the UFS_FIX() and END_FIX() macros (Eric Chanudet) [2102378]
- scsi: ufs: Use get_unaligned_be16() instead of be16_to_cpup() (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_lrb.sense_buffer (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_lrb.sense_bufflen (Eric Chanudet) [2102378]
- scsi: ufs: Simplify statements that return a boolean (Eric Chanudet) [2102378]
- scsi: ufs: Remove superfluous boolean conversions (Eric Chanudet) [2102378]
- scsi: ufs: Declare ufshcd_wait_for_register() static (Eric Chanudet) [2102378]
- scsi: ufs: Fix a spelling error in a source code comment (Eric Chanudet) [2102378]
- scsi: ufs: core: Increase fDeviceInit poll frequency (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove redundant HPB unmap (Eric Chanudet) [2102378]
- scsi: ufs: ufshcd-pltfrm: Simplify pdev->dev usage (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix a NULL check on list iterator (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Add support for Intel MTL (Eric Chanudet) [2102378]
- scsi: ufs: qcom: Drop custom Android boot parameters (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove unused field in struct ufs_hba (Eric Chanudet) [2102378]
- dt-bindings: ufs: qcom: Add SM6350 compatible string (Eric Chanudet) [2102378]
- scsi: ufs: core: scsi_get_lba() error fix (Eric Chanudet) [2102378]
- dt-bindings: ufs: snps,tc-dwc-g210: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: mediatek,ufs: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: hisilicon,ufs: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: qcom,ufs: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: drop unused/old ufs-qcom PHY bindings (Eric Chanudet) [2102378]
- dt-bindings: ufs: cdns,ufshc: convert to dtschema (Eric Chanudet) [2102378]
- dt-bindings: ufs: samsung,exynos-ufs: use common bindings (Eric Chanudet) [2102378]
- dt-bindings: ufs: add common platform bindings (Eric Chanudet) [2102378]
- scsi: ufs: Fix runtime PM messages never-ending cycle (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove wlun_dev_to_hba() (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix divide by zero in ufshcd_map_queues() (Eric Chanudet) [2102378]
- block: pass a block_device and opf to bio_alloc (Eric Chanudet) [2102378]
- scsi: ufs: Add checking lifetime attribute for WriteBooster (Eric Chanudet) [2102378]
- scsi: ufs: Treat link loss as fatal error (Eric Chanudet) [2102378]
- scsi: ufs: Use generic error code in ufshcd_set_dev_pwr_mode() (Eric Chanudet) [2102378]
- scsi: ufs: ufshcd-pltfrm: Check the return value of devm_kstrdup() (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Fix error checking in ufs_mtk_init_va09_pwr_ctrl() (Eric Chanudet) [2102378]
- scsi: ufs: Modify Tactive time setting conditions (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix deadlock issue in ufshcd_wait_for_doorbell_clr() (Eric Chanudet) [2102378]
- scsi: ufs: dt-bindings: Add SM8450 compatible strings (Eric Chanudet) [2102378]
- scsi: ufs: Implement polling support (Eric Chanudet) [2102378]
- scsi: ufs: Optimize the command queueing code (Eric Chanudet) [2102378]
- scsi: ufs: Stop using the clock scaling lock in the error handler (Eric Chanudet) [2102378]
- scsi: ufs: Fix a kernel crash during shutdown (Eric Chanudet) [2102378]
- scsi: ufs: Improve SCSI abort handling further (Eric Chanudet) [2102378]
- scsi: ufs: Introduce ufshcd_release_scsi_cmd() (Eric Chanudet) [2102378]
- scsi: ufs: Remove the 'update_scaling' local variable (Eric Chanudet) [2102378]
- scsi: ufs: Remove hba->cmd_queue (Eric Chanudet) [2102378]
- scsi: ufs: Fix a deadlock in the error handler (Eric Chanudet) [2102378]
- scsi: ufs: Rework ufshcd_change_queue_depth() (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_any_tag_in_use() (Eric Chanudet) [2102378]
- scsi: ufs: Fix race conditions related to driver data (Eric Chanudet) [2102378]
- scsi: ufs: Remove dead code (Eric Chanudet) [2102378]
- scsi: ufs: Remove the sdev_rpmb member (Eric Chanudet) [2102378]
- scsi: ufs: Remove is_rpmb_wlun() (Eric Chanudet) [2102378]
- scsi: ufs: Rename a function argument (Eric Chanudet) [2102378]
- scsi: Remove superfluous #include <linux/async.h> directives (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Add support for Intel ADL (Eric Chanudet) [2102378]
- scsi: ufs: Let devices remain runtime suspended during system suspend (Eric Chanudet) [2102378]
- block: remove the gendisk argument to blk_execute_rq (Eric Chanudet) [2102378]
- scsi: ufs: Fix double space in SCSI_UFS_HWMON description (Eric Chanudet) [2102378]
- scsi: ufs: Wrap Universal Flash Storage drivers in SCSI_UFSHCD (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Add put_device() after of_find_device_by_node() (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix warning in ufshpb_set_hpb_read_to_upiu() (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix another task management completion race (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix task management completion timeout race (Eric Chanudet) [2102378]
- scsi: ufs: core: Improve SCSI abort handling (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Properly handle max-single-cmd (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove HPB2.0 flows (Eric Chanudet) [2102378]
- dt-bindings: ufs: exynos-ufs: add exynosautov9 compatible (Eric Chanudet) [2102378]
- dt-bindings: ufs: exynos-ufs: add io-coherency property (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Introduce ExynosAuto v9 virtual host (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Multi-host configuration for ExynosAuto v9 (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Support ExynosAuto v9 UFS (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add pre/post_hce_enable drv callbacks (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Factor out priv data init (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add EXYNOS_UFS_OPT_SKIP_CONFIG_PHY_ATTR option (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Support custom version of ufs_hba_variant_ops (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add setup_clocks callback (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Add refclkout_stop control (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Simplify drv_data retrieval (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Change pclk available max value (Eric Chanudet) [2102378]
- scsi: ufs: Add quirk to enable host controller without PH configuration (Eric Chanudet) [2102378]
- scsi: ufs: Add quirk to handle broken UIC command (Eric Chanudet) [2102378]
- scsi: ufs: core: Micro-optimize ufshcd_map_sg() (Eric Chanudet) [2102378]
- scsi: ufs: core: Add a compile-time structure size check (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove three superfluous casts (Eric Chanudet) [2102378]
- scsi: ufs: core: Add debugfs attributes for triggering the UFS EH (Eric Chanudet) [2102378]
- scsi: ufs: core: Make it easier to add new debugfs attributes (Eric Chanudet) [2102378]
- scsi: ufs: core: Export ufshcd_schedule_eh_work() (Eric Chanudet) [2102378]
- scsi: ufs: core: Log error handler activity (Eric Chanudet) [2102378]
- scsi: ufs: core: Improve static type checking (Eric Chanudet) [2102378]
- scsi: ufs: core: Improve source code comments (Eric Chanudet) [2102378]
- scsi: ufs: Revert "Retry aborted SCSI commands instead of completing these successfully" (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Correct timeout value setting registers (Eric Chanudet) [2102378]
- scsi: ufs: ufshcd-pltfrm: Fix memory leak due to probe defer (Eric Chanudet) [2102378]
- scsi: ufs: mediatek: Avoid sched_clock() misuse (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Force a full restore after suspend-to-disk (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Fix wrong location for ref-clk delay (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Fix build error caused by use of sched_clock() (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Introduce default delay for reference clock (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix synchronization between scsi_unjam_host() and ufshcd_queuecommand() (Eric Chanudet) [2102378]
- scsi: ufs: mediatek: Support vops pre suspend to disable auto-hibern8 (Eric Chanudet) [2102378]
- scsi: ufs: core: Do not exit ufshcd_err_handler() unless operational or dead (Eric Chanudet) [2102378]
- scsi: ufs: core: Do not exit ufshcd_reset_and_restore() unless operational or dead (Eric Chanudet) [2102378]
- scsi: ufs: core: Stop clearing UNIT ATTENTIONS (Eric Chanudet) [2102378]
- scsi: ufs: core: Retry START_STOP on UNIT_ATTENTION (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove return statement in void function (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix ufshcd_probe_hba() prototype to match the definition (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix NULL pointer dereference (Eric Chanudet) [2102378]
- scsi: ufs: core: Fix task management completion (Eric Chanudet) [2102378]
- scsi: ufs: ufs-qcom: Enter and exit hibern8 during clock scaling (Eric Chanudet) [2102378]
- scsi: ufs: core: Export hibern8 entry and exit functions (Eric Chanudet) [2102378]
- scsi: ufs: core: SCSI_UFS_HWMON depends on HWMON=y (Eric Chanudet) [2102378]
- scsi: ufs: exynos: Unify naming (Eric Chanudet) [2102378]
- scsi: ufs: Fix illegal offset in UPIU event trace (Eric Chanudet) [2102378]
- scsi: ufs: core: Add temperature notification exception handling (Eric Chanudet) [2102378]
- scsi: ufs: core: Probe for temperature notification support (Eric Chanudet) [2102378]
- scsi: ufs: core: Unbreak the reset handler (Eric Chanudet) [2102378]
- scsi: ufs: core: Revert "scsi: ufs: Synchronize SCSI and UFS error handling" (Eric Chanudet) [2102378]
- dt-bindings: ufs: Add bindings for Samsung ufs host (Eric Chanudet) [2102378]
- scsi: ufs: ufs-mediatek: Change dbg select by check IP version (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Use proper power management API (Eric Chanudet) [2102378]
- scsi: ufs: ufs-qcom: Remove unneeded variable 'err' (Eric Chanudet) [2102378]
- scsi: ufs: ufs-pci: Fix Intel LKF link stability (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove unused parameters (Eric Chanudet) [2102378]
- scsi: ufs: Fix ufshcd_request_sense_async() for Samsung KLUFG8RHDA-B2D1 (Eric Chanudet) [2102378]
- scsi: ufs: ufs-exynos: Fix static checker warning (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix typo in comments (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Fix possible memory leak (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Eric Chanudet) [2102378]
- scsi: ufs: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Do not report victim error in HCM (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Verify that 'num_inflight_map_req' is non-negative (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Use a correct max multi chunk (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Rewind the read timeout on every read (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Remove redundant initialization of variable 'lba' (Eric Chanudet) [2102378]
- scsi: ufshcd: Fix device links when BOOT WLUN fails to probe (Eric Chanudet) [2102378]
- scsi: ufs: Fix unsigned int compared with less than zero (Eric Chanudet) [2102378]
- scsi: ufs: core: Add lu_enable sysfs node (Eric Chanudet) [2102378]
- scsi: ufs: core: Add L2P entry swap quirk for Micron UFS (Eric Chanudet) [2102378]
- scsi: ufs: core: Remove redundant call in ufshcd_add_command_trace() (Eric Chanudet) [2102378]
- scsi: ufs: Add fault injection support (Eric Chanudet) [2102378]
- scsi: ufs: Retry aborted SCSI commands instead of completing these successfully (Eric Chanudet) [2102378]
- scsi: ufs: Synchronize SCSI and UFS error handling (Eric Chanudet) [2102378]
- scsi: ufs: Request sense data asynchronously (Eric Chanudet) [2102378]
- scsi: ufs: Fix the SCSI abort handler (Eric Chanudet) [2102378]
- scsi: ufs: Optimize SCSI command processing (Eric Chanudet) [2102378]
- scsi: ufs: Optimize serialization of setup_xfer_req() calls (Eric Chanudet) [2102378]
- scsi: ufs: Revert "Utilize Transfer Request List Completion Notification Register" (Eric Chanudet) [2102378]
- scsi: ufs: Inline ufshcd_outstanding_req_clear() (Eric Chanudet) [2102378]
- scsi: ufs: Remove several wmb() calls (Eric Chanudet) [2102378]
- scsi: ufs: Improve static type checking for the host controller state (Eric Chanudet) [2102378]
- scsi: ufs: Verify UIC locking requirements at runtime (Eric Chanudet) [2102378]
- scsi: ufs: Remove ufshcd_valid_tag() (Eric Chanudet) [2102378]
- scsi: ufs: Use DECLARE_COMPLETION_ONSTACK() where appropriate (Eric Chanudet) [2102378]
- scsi: ufs: Rename the second ufshcd_probe_hba() argument (Eric Chanudet) [2102378]
- scsi: ufs: Only include power management code if necessary (Eric Chanudet) [2102378]
- scsi: ufs: Reduce power management code duplication (Eric Chanudet) [2102378]
- scsi: ufs: Fix memory corruption by ufshcd_read_desc_param() (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Make host mode parameters configurable (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add support for host control mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Do not send umap_all in host control mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Limit the number of in-flight map requests (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add "cold" regions timer (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add HPB dev reset response (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Region inactivation in host mode (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Make eviction depend on region's reads (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add reads counter (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Transform set_dirty to iterate_rgn (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add host control mode support to rsp_upiu (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Cache HPB Control mode on init (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Add HPB 2.0 support (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Prepare HPB read for cached sub-region (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: L2P map management for HPB read (Eric Chanudet) [2102378]
- scsi: ufs: ufshpb: Introduce Host Performance Buffer feature (Eric Chanudet) [2102378]
- scsi: ufs: Allow async suspend/resume callbacks (Eric Chanudet) [2102378]
- scsi: ufs: core: Use scsi_get_lba() to get LBA (Eric Chanudet) [2102378]
- scsi: ufs: Refactor ufshcd_is_intr_aggr_allowed() (Eric Chanudet) [2102378]
- redhat: config: disable qcom eDP phy driver (Eric Chanudet) [2102384]
- phy: qcom-qmp: rename error labels (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix pipe-clock imbalance on power-on failure (Eric Chanudet) [2102384]
- phy: qcom-qmp: switch to explicit reset helpers (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix reset-controller leak on probe errors (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix struct clk leak on probe errors (Eric Chanudet) [2102384]
- phy: qcom-qmp: fix phy-descriptor kernel-doc typo (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add support for SDX65 QMP PHY (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SDX65 USB PHY binding (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM6350 UFS PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM6350 UFS PHY bindings (Eric Chanudet) [2102384]
- phy: qcom-qmp: add sc8280xp UFS PHY (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: add sc8180x and sc8280xp ufs compatibles (Eric Chanudet) [2102384]
- phy: qcom-snps: Add sc8280xp support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,usb-snps-femto-v2: Add sc8180x and sc8280xp (Eric Chanudet) [2102384]
- phy: qcom: Program SSC only if supported by sink (Eric Chanudet) [2102384]
- phy: qcom: Add support for eDP PHY on sc7280 (Eric Chanudet) [2102384]
- dt-bindings: phy: Add eDP PHY compatible for sc7280 (Eric Chanudet) [2102384]
- dt-bindings: phy: convert Qualcomm USB HS phy to yaml (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Add compatible for MSM8953 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qusb2: Document msm8953 compatible (Eric Chanudet) [2102384]
- drivers: phy: qcom: ipq806x-usb: conver latch function to pool macro (Eric Chanudet) [2102384]
- drivers: phy: qcom: ipq806x-usb: convert to BITFIELD macro (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 PCIe1 PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 PCIe PHY bindings (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 PCIe0 PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 PCIe PHY bindings (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 USB QMP PHYs (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 USB3 PHY (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,usb-snps-femto-v2: Add bindings for SM8450 (Eric Chanudet) [2102384]
- phy: qcom: use struct_size instead of sizeof (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add SM8450 UFS QMP Phy (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM8450 UFS phy compatible (Eric Chanudet) [2102384]
- phy: qcom: Introduce new eDP PHY driver (Eric Chanudet) [2102384]
- dt-bindings: phy: Introduce Qualcomm eDP PHY binding (Eric Chanudet) [2102384]
- phy: qualcomm: ipq806x-usb: Fix kernel-doc style (Eric Chanudet) [2102384]
- phy: qualcomm: usb-hsic: Fix the kernel-doc warn (Eric Chanudet) [2102384]
- phy: qualcomm: qmp: Add missing struct documentation (Eric Chanudet) [2102384]
- phy: qcom-snps: Correct the FSEL_MASK (Eric Chanudet) [2102384]
- phy: qcom-qmp: another fix for the sc8180x PCIe definition (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: IPQ6018 and IPQ8074 PCIe PHY require no supply (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Fix a memory leak on probe (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add QCM2290 USB3 PHY support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add QCM2290 USB3 PHY (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Add missing vdd supply (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qusb2: Add missing vdd-supply (Eric Chanudet) [2102384]
- dt-bindings: arm: qcom: Drop qcom,mtp (Eric Chanudet) [2102384]
- dt-bindings: arm: qcom: Document alcatel,idol347 board (Eric Chanudet) [2102384]
- phy: qcom-qmp: Make use of the helper function devm_add_action_or_reset() (Eric Chanudet) [2102384]
- phy: qcom-qusb2: Add compatible for QCM2290 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qusb2: Add compatible for QCM2290 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Update maintainer email (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add support for SM6115 UFS phy (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add SM6115 UFS PHY bindings (Eric Chanudet) [2102384]
- phy: qmp: Provide unique clock names for DP clocks (Eric Chanudet) [2102384]
- phy: qcom-qmp: add USB3 PHY support for IPQ6018 (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add IPQ6018 USB3 PHY (Eric Chanudet) [2102384]
- phy: qcom: qmp: Add SC8180x USB/DP combo (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp-usb3-dp: Add support for sc8180x (Eric Chanudet) [2102384]
- phy: qualcomm: phy-qcom-usb-hs: repair non-kernel-doc comment (Eric Chanudet) [2102384]
- phy: qcom-qmp: Fix sc8180x PCIe definition (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp-usb3-dp: Add support for SC7280 (Eric Chanudet) [2102384]
- phy: qcom-qmp: Add sc8180x PCIe support (Eric Chanudet) [2102384]
- dt-bindings: phy: qcom,qmp: Add sc8180x PCIe compatible (Eric Chanudet) [2102384]
- clk: qcom: add sc8280xp GCC driver (Adrien Thierry) [2103761]
- dt-bindings: clock: Add Qualcomm SC8280XP GCC bindings (Adrien Thierry) [2103761]
- redhat: config: qcom_scm download off by default (Eric Chanudet) [2101563]
- redhat: config: disable sm8450 by default (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: Add pm6125 compatible (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Add pm6125 compatible (Eric Chanudet) [2101563]
- pinctrl: qcom: Update clock voting as optional (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SC7280 lpass pin configuration (Eric Chanudet) [2101563]
- pinctrl: qcom: Extract chip specific LPASS LPI code (Eric Chanudet) [2101563]
- pinctrl: qcom: Update lpi pin group custiom functions with framework generic functions (Eric Chanudet) [2101563]
- pinctrl: qcom: Update macro name to LPI specific (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add sc7280 lpass lpi pinctrl bindings (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Update lpass lpi file name to SoC specific (Eric Chanudet) [2101563]
- pinctrl: qcom-pmic-gpio: Add support for pmx65 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Add pmx65 support (Eric Chanudet) [2101563]
- pinctrl: qcom: sm6350: fix order of UFS & SDC pins (Eric Chanudet) [2101563]
- pinctrl: qcom: sm8150: Specify PDC map (Eric Chanudet) [2101563]
- dt-bindings: qcom,pdc: Add compatible for SM8150 (Eric Chanudet) [2101563]
- pinctrl: qcom-pmic-gpio: Add support for pm8450 (Eric Chanudet) [2101563]
- pinctrl: qcom: Introduce sc8280xp TLMM driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add sc8280xp TLMM binding (Eric Chanudet) [2101563]
- pinctrl: qcom: cleanup comments (Eric Chanudet) [2101563]
- pinctrl: qcom: qcm2290: Add GPIO wakeirq map (Eric Chanudet) [2101563]
- pinctrl: qcom: print egpio mode in debugfs (Eric Chanudet) [2101563]
- pinctrl: qcom: sm8450: Add egpio support (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-mpp: Add PM8226 compatible (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-mpp: Document PM8226 compatible (Eric Chanudet) [2101563]
- pinctrl: qcom: Return -EINVAL for setting affinity if no IRQ parent (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SM8450 pinctrl driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SM8450 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: spmi-gpio: Add support for PM2250 (Eric Chanudet) [2101563]
- dt-bindings: qcom,pmic-gpio: Add pm2250 compatible string (Eric Chanudet) [2101563]
- pinctrl: qcom: sc7280: Add egpio support (Eric Chanudet) [2101563]
- pinctrl: qcom: Add egpio feature support (Eric Chanudet) [2101563]
- pinctrl: qcom-pmic-gpio: Add support for pm8019 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Add compatible for PM8019 (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SDX65 pincontrol driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SDX65 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom: sm8350: Correct UFS and SDC offsets (Eric Chanudet) [2101563]
- pinctrl: qcom: sdm845: Enable dual edge errata (Eric Chanudet) [2101563]
- pinctrl: qcom: fix unmet dependencies on GPIOLIB for GPIOLIB_IRQCHIP (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-mpp: add support for hierarchical IRQ chip (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-mpp: hardcode IRQ counts (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-mpp: switch to #interrupt-cells (Eric Chanudet) [2101563]
- pinctrl: qcom: ssbi-mpp: add support for hierarchical IRQ chip (Eric Chanudet) [2101563]
- pinctrl: qcom: ssbi-mpp: hardcode IRQ counts (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-mpp: Convert qcom pmic mpp bindings to YAML (Eric Chanudet) [2101563]
- iommu/arm: fix ARM_SMMU_QCOM compilation (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: Add compatible for PM6350 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Add compatible for PM6350 (Eric Chanudet) [2101563]
- qcom_scm: hide Kconfig symbol (Eric Chanudet) [2101563]
- firmware: include drivers/firmware/Kconfig unconditionally (Eric Chanudet) [2101563]
- firmware: qcom_scm: QCOM_SCM should depend on ARCH_QCOM (Eric Chanudet) [2101563]
- firmware: qcom_scm: Allow qcom_scm driver to be loadable as a permenent module (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: add support to enable/disable output (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Add output-{enable,disable} properties (Eric Chanudet) [2101563]
- pinctrl: qcom: Add QCM2290 pinctrl driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add QCM2290 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom: Add SM6350 pinctrl driver (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SM6350 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom: sc7280: Add PM suspend callbacks (Eric Chanudet) [2101563]
- pinctrl: qcom: msm8226: fill in more functions (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: correct parent irqspec translation (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Remove the interrupts property (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom-pmic-gpio: Convert qcom pmic gpio bindings to YAML (Eric Chanudet) [2101563]
- pinctrl: qcom: spmi-gpio: Add pmc8180 & pmc8180c (Eric Chanudet) [2101563]
- drivers: qcom: pinctrl: Add pinctrl driver for sm6115 (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom: Add SM6115 pinctrl bindings (Eric Chanudet) [2101563]
- pinctrl: qcom/pinctrl-spmi-gpio: Add compatible for pmic-gpio on SA8155p-adp (Eric Chanudet) [2101563]
- pinctrl: qcom/pinctrl-spmi-gpio: Arrange compatibles alphabetically (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Add compatible for SA8155p-adp (Eric Chanudet) [2101563]
- dt-bindings: pinctrl: qcom,pmic-gpio: Arrange compatibles alphabetically (Eric Chanudet) [2101563]
- pinctrl: qcom: Add MDM9607 pinctrl driver (Eric Chanudet) [2101563]

* Thu Aug 25 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-157.rt21.157.el9]
- [rt] build kernel-rt-5.14.0-157.rt21.157.el9 [2061574]
- drm/nouveau: recognise GA103 (Karol Herbst) [2115796]
- drm/aperture: Run fbdev removal before internal helpers (Karol Herbst) [2088409]
- drm/i915/ttm: fix 32b build (Karol Herbst) [2088409]
- drm/amd/display: Ensure valid event timestamp for cursor-only commits (Karol Herbst) [2088409]
- drm/amd/pm: Prevent divide by zero (Karol Herbst) [2088409]
- drm/amd/display: Only use depth 36 bpp linebuffers on DCN display engines. (Karol Herbst) [2088409]
- drm/amdkfd: correct the MEC atomic support firmware checking for GC 10.3.7 (Karol Herbst) [2088409]
- drm/amd/display: Ignore First MST Sideband Message Return Error (Karol Herbst) [2088409]
- drm/i915/selftests: fix subtraction overflow bug (Karol Herbst) [2088409]
- drm/i915/gt: Serialize TLB invalidates with GT resets (Karol Herbst) [2088409]
- drm/i915/gt: Serialize GRDOM access between multiple engine resets (Karol Herbst) [2088409]
- drm/i915/ttm: fix sg_table construction (Karol Herbst) [2088409]
- drm/i915/selftests: fix a couple IS_ERR() vs NULL tests (Karol Herbst) [2088409]
- drm/i915/gvt: IS_ERR() vs NULL bug in intel_gvt_update_reg_whitelist() (Karol Herbst) [2088409]
- drm/i915/guc: ADL-N should use the same GuC FW as ADL-S (Karol Herbst) [2088409]
- drm/i915: fix a possible refcount leak in intel_dp_add_mst_connector() (Karol Herbst) [2088409]
- drm/amdgpu/display: disable prefer_shadow for generic fb helpers (Karol Herbst) [2088409]
- drm/amdgpu: keep fbdev buffers pinned during suspend (Karol Herbst) [2088409]
- drm/fourcc: fix integer type usage in uapi header (Karol Herbst) [2088409]
- drm/i915/dgfx: Disable d3cold at gfx root port (Karol Herbst) [2088409]
- drm/i915/gem: add missing else (Karol Herbst) [2088409]
- drm/amdgpu: To flush tlb for MMHUB of RAVEN series (Karol Herbst) [2088409]
- Revert "drm/amdgpu/display: set vblank_disable_immediate for DC" (Karol Herbst) [2088409]
- drm/amdgpu: fix adev variable used in amdgpu_device_gpu_recover() (Karol Herbst) [2088409]
- drm/amd: Revert "drm/amd/display: keep eDP Vdd on when eDP stream is already enabled" (Karol Herbst) [2088409]
- udmabuf: add back sanity check (Karol Herbst) [2088409]
- drm/amd/display: Fix typo in override_lane_settings (Karol Herbst) [2088409]
- amd/display/dc: Fix COLOR_ENCODING and COLOR_RANGE doing nothing for DCN20+ (Karol Herbst) [2088409]
- drm/i915: Implement w/a 22010492432 for adl-s (Karol Herbst) [2088409]
- drm/i915/uc: remove accidental static from a local variable (Karol Herbst) [2088409]
- drm/amd/display: Cap OLED brightness per max frame-average luminance (Karol Herbst) [2088409]
- drm/amdgpu: Fix GTT size reporting in amdgpu_ioctl (Karol Herbst) [2088409]
- drm/i915/reset: Fix error_state_read ptr + offset use (Karol Herbst) [2088409]
- drm/amdkfd: add pinned BOs to kfd_bo_list (Karol Herbst) [2088409]
- drm/amdkfd: Use mmget_not_zero in MMU notifier (Karol Herbst) [2088409]
- drm/amdgpu: Resolve RAS GFX error count issue after cold boot on Arcturus (Karol Herbst) [2088409]
- drm/amd/display: Read Golden Settings Table from VBIOS (Karol Herbst) [2088409]
- Revert "drm/amd/display: Fix DCN3 B0 DP Alt Mapping" (Karol Herbst) [2088409]
- drm/amdgpu: update VCN codec support for Yellow Carp (Karol Herbst) [2088409]
- drm/amd/display: remove stale config guards (Karol Herbst) [2088409]
- drm/amdgpu/jpeg2: Add jpeg vmid update under IB submit (Karol Herbst) [2088409]
- drm/atomic: Force bridge self-refresh-exit on CRTC switch (Karol Herbst) [2088409]
- drm/bridge: analogix_dp: Support PSR-exit to disable transition (Karol Herbst) [2088409]
- drm/amdkfd:Fix fw version for 10.3.6 (Karol Herbst) [2088409]
- drm/amd/pm: use bitmap_{from,to}_arr32 where appropriate (Karol Herbst) [2088409]
- drm/amd/pm: correct the metrics version for SMU 11.0.11/12/13 (Karol Herbst) [2088409]
- drm/amd/pm: Fix missing thermal throttler status (Karol Herbst) [2088409]
- drm/amd/pm: fix a potential gpu_metrics_table memory leak (Karol Herbst) [2088409]
- drm/radeon: fix a possible null pointer dereference (Karol Herbst) [2088409]
- drm/amd/display: Check zero planes for OTG disable W/A on clock change (Karol Herbst) [2088409]
- drm/amd/display: Check if modulo is 0 before dividing. (Karol Herbst) [2088409]
- drm/amdgpu: fix limiting AV1 to the first instance on VCN3 (Karol Herbst) [2088409]
- drm/bridge: ti-sn65dsi83: Handle dsi_lanes == 0 as invalid (Karol Herbst) [2088409]
- drm/amdgpu: Off by one in dm_dmub_outbox1_low_irq() (Karol Herbst) [2088409]
- gma500: fix an incorrect NULL check on list iterator (Karol Herbst) [2088409]
- drm/i915/dsi: fix VBT send packet port selection for ICL+ (Karol Herbst) [2088409]
- drm/bridge: analogix_dp: Grab runtime PM reference for DP-AUX (Karol Herbst) [2088409]
- drm/nouveau/kms/nv50-: atom: fix an incorrect NULL check on list iterator (Karol Herbst) [2088409]
- drm/nouveau/clk: Fix an incorrect NULL check on list iterator (Karol Herbst) [2088409]
- drm/nouveau/subdev/bus: Ratelimit logging for fault errors (Karol Herbst) [2088409]
- drm/amdgpu/cs: make commands with 0 chunks illegal behaviour. (Karol Herbst) [2088409]
- drm/amdgpu: add beige goby PCI ID (Karol Herbst) [2088409]
- drm/i915: Fix CFI violation with show_dynamic_id() (Karol Herbst) [2088409]
- drm/bridge: it6505: Send DPCD SET_POWER to downstream (Karol Herbst) [2088409]
- drm/panel: panel-simple: Fix proper bpc for AM-1280800N3TZQW-T00H (Karol Herbst) [2088409]
- drm/panel: simple: Add missing bus flags for Innolux G070Y2-L01 (Karol Herbst) [2088409]
- drm/bridge: Fix it6505 Kconfig DRM_DP_AUX_BUS dependency (Karol Herbst) [2088409]
- drm/bridge: Fix error handling in analogix_dp_probe (Karol Herbst) [2088409]
- drm/bridge: anx7625: Use uint8 for lane-swing arrays (Karol Herbst) [2088409]
- drm/amd/amdgpu: Remove static from variable in RLCG Reg RW (Karol Herbst) [2088409]
- drm/amd/amdgpu: Fix asm/hypervisor.h build error. (Karol Herbst) [2088409]
- drm/amd/amdgpu: Only reserve vram for firmware with vega9 MS_HYPERV host. (Karol Herbst) [2088409]
- drm: bridge: icn6211: Fix HFP_HSW_HBP_HI and HFP_MIN handling (Karol Herbst) [2088409]
- drm: bridge: icn6211: Fix register layout (Karol Herbst) [2088409]
- drm/bridge: adv7511: clean up CEC adapter when probe fails (Karol Herbst) [2088409]
- drm/bridge: anx7625: add missing destroy_workqueue() in anx7625_i2c_probe() (Karol Herbst) [2088409]
- drm/edid: fix invalid EDID extension block filtering (Karol Herbst) [2088409]
- drm/bridge: it6505: Fix build error (Karol Herbst) [2088409]
- drm: bridge: it66121: Fix the register page length (Karol Herbst) [2088409]
- drm/vmwgfx: Fix an invalid read (Karol Herbst) [2088409]
- drm/ssd130x: Reduce temporary buffer sizes (Karol Herbst) [2088409]
- drm/ssd130x: Fix rectangle updates (Karol Herbst) [2088409]
- drm/format-helper: Fix XRGB888 to monochrome conversion (Karol Herbst) [2088409]
- drm/format-helper: Rename drm_fb_xrgb8888_to_mono_reversed() (Karol Herbst) [2088409]
- drm/solomon: Make DRM_SSD130X depends on MMU (Karol Herbst) [2088409]
- drm: ssd130x: Always apply segment remap setting (Karol Herbst) [2088409]
- drm: ssd130x: Fix COM scan direction register mask (Karol Herbst) [2088409]
- drm/bridge: anx7625: check the return on anx7625_aux_trans (Karol Herbst) [2088409]
- drm/selftests: missing error code in igt_buddy_alloc_smoke() (Karol Herbst) [2088409]
- drm/bridge_connector: enable HPD by default if supported (Karol Herbst) [2088409]
- drm: fix EDID struct for old ARM OABI format (Karol Herbst) [2088409]
- drm/amdgpu: Move mutex_init(&smu->message_lock) to smu_early_init() (Karol Herbst) [2088409]
- drm/amd/pm: update smartshift powerboost calc for smu13 (Karol Herbst) [2088409]
- drm/amd/pm: update smartshift powerboost calc for smu12 (Karol Herbst) [2088409]
- drm/amdgpu/ucode: Remove firmware load type check in amdgpu_ucode_free_bo (Karol Herbst) [2088409]
- drm/amdgpu/psp: move PSP memory alloc from hw_init to sw_init (Karol Herbst) [2088409]
- drm/amd/pm: fix the compile warning (Karol Herbst) [2088409]
- drm/amdkfd: Fix circular lock dependency warning (Karol Herbst) [2088409]
- drm/plane: Move range check for format_count earlier (Karol Herbst) [2088409]
- drm/amdgpu/sdma: Fix incorrect calculations of the wptr of the doorbells (Karol Herbst) [2088409]
- drm/amd/pm: fix double free in si_parse_power_table() (Karol Herbst) [2088409]
- drm/amdgpu/pm: fix the null pointer while the smu is disabled (Karol Herbst) [2088409]
- drm/amd/display: Disabling Z10 on DCN31 (Karol Herbst) [2088409]
- drm/virtio: fix NULL pointer dereference in virtio_gpu_conn_get_modes (Karol Herbst) [2088409]
- drm/vmwgfx: validate the screen formats (Karol Herbst) [2088409]
- drm/selftests: fix a shift-out-of-bounds bug (Karol Herbst) [2088409]
- drm/i915: Fix -Wstringop-overflow warning in call to intel_read_wm_latency() (Karol Herbst) [2088409]

* Wed Aug 24 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-156.rt21.156.el9]
- [rt] build kernel-rt-5.14.0-156.rt21.156.el9 [2061574]
- net/mlx5: fs, fail conflicting actions (Mohammad Kabat) [2049451]
- net/mlx5: Rearm the FW tracer after each tracer event (Mohammad Kabat) [2049451]
- net/mlx5: correct ECE offset in query qp output (Mohammad Kabat) [2049451]
- net/mlx5e: Disable softirq in mlx5e_activate_rq to avoid race condition (Mohammad Kabat) [2049451]
- net/mlx5: CT: Fix header-rewrite re-use for tupels (Mohammad Kabat) [2049451]
- net/mlx5e: TC NIC mode, fix tc chains miss table (Mohammad Kabat) [2049451]
- net/mlx5: Don't use already freed action pointer (Mohammad Kabat) [2049451]
- net/mlx5: fix typo in comment (Mohammad Kabat) [2049451]
- net/mlx5: Allow future addition of IPsec object modifiers (Mohammad Kabat) [2049451]
- IB/mlx5: Fix undefined behavior due to shift overflowing the constant (Mohammad Kabat) [2049451]
- net/mlx5: Drain fw_reset when removing device (Mohammad Kabat) [2049451]
- net/mlx5e: CT: Fix setting flow_source for smfs ct tuples (Mohammad Kabat) [2049451]
- net/mlx5e: CT: Fix support for GRE tuples (Mohammad Kabat) [2049451]
- net/mlx5e: Remove HW-GRO from reported features (Mohammad Kabat) [2049451]
- net/mlx5e: Properly block HW GRO when XDP is enabled (Mohammad Kabat) [2049451]
- net/mlx5e: Properly block LRO when XDP is enabled (Mohammad Kabat) [2049451]
- net/mlx5e: Block rx-gro-hw feature in switchdev mode (Mohammad Kabat) [2049451]
- net/mlx5e: Wrap mlx5e_trap_napi_poll into rcu_read_lock (Mohammad Kabat) [2049451]
- net/mlx5: DR, Ignore modify TTL on RX if device doesn't support it (Mohammad Kabat) [2049451]
- net/mlx5: Initialize flow steering during driver probe (Mohammad Kabat) [2049451]
- net/mlx5: DR, Fix missing flow_source when creating multi-destination FW table (Mohammad Kabat) [2049451]
- net/mlx5: Fix matching on inner TTC (Mohammad Kabat) [2049451]
- net/mlx5: Avoid double clear or set of sync reset requested (Mohammad Kabat) [2049451]
- net/mlx5: Fix deadlock in sync reset flow (Mohammad Kabat) [2049451]
- net/mlx5e: Fix trust state reset in reload (Mohammad Kabat) [2049451]
- net/mlx5e: Avoid checking offload capability in post_parse action (Mohammad Kabat) [2049451]
- net/mlx5e: CT: Fix queued up restore put() executing after relevant ft release (Mohammad Kabat) [2049451]
- net/mlx5e: TC, fix decap fallback to uplink when int port not supported (Mohammad Kabat) [2049451]
- net/mlx5e: TC, Fix ct_clear overwriting ct action metadata (Mohammad Kabat) [2049451]
- net/mlx5e: Lag, Don't skip fib events on current dst (Mohammad Kabat) [2049451]
- net/mlx5e: Lag, Fix fib_info pointer assignment (Mohammad Kabat) [2049451]
- net/mlx5e: Lag, Fix use-after-free in fib event handler (Mohammad Kabat) [2049451]
- net/mlx5e: Fix the calling of update_buffer_lossy() API (Mohammad Kabat) [2049451]
- net/mlx5e: Don't match double-vlan packets if cvlan is not set (Mohammad Kabat) [2049451]
- net/mlx5: Fix slab-out-of-bounds while reading resource dump menu (Mohammad Kabat) [2049451]
- net/mlx5e: Fix wrong source vport matching on tunnel rule (Mohammad Kabat) [2049451 2049589]
- RDMA/mlx5: Add a missing update of cache->last_add (Mohammad Kabat) [2049451]
- RDMA/mlx5: Don't remove cache MRs when a delay is needed (Mohammad Kabat) [2049451]
- net/mlx5e: HTB, remove unused function declaration (Mohammad Kabat) [2049451]
- net/mlx5e: Statify function mlx5_cmd_trigger_completions (Mohammad Kabat) [2049451]
- net/mlx5: Remove unused fill page array API function (Mohammad Kabat) [2049451]
- net/mlx5: Remove unused exported contiguous coherent buffer allocation API (Mohammad Kabat) [2049451]
- net/mlx5: CT: Remove extra rhashtable remove on tuple entries (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove hw_ste from mlx5dr_ste to reduce memory (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove 4 members from mlx5dr_ste_htbl to reduce memory (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove num_of_entries byte_size from struct mlx5_dr_icm_chunk (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove icm_addr from mlx5dr_icm_chunk to reduce memory (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove mr_addr rkey from struct mlx5dr_icm_chunk (Mohammad Kabat) [2049451]
- net/mlx5: DR, Adjust structure member to reduce memory hole (Mohammad Kabat) [2049451]
- net/mlx5e: Drop cqe_bcnt32 from mlx5e_skb_from_cqe_mpwrq_linear (Mohammad Kabat) [2049451]
- net/mlx5e: Drop the len output parameter from mlx5e_xdp_handle (Mohammad Kabat) [2049451]
- net/mlx5e: RX, Test the XDP program existence out of the handler (Mohammad Kabat) [2049451]
- net/mlx5e: Build SKB in place over the first fragment in non-linear legacy RQ (Mohammad Kabat) [2049451]
- net/mlx5e: Add headroom only to the first fragment in legacy RQ (Mohammad Kabat) [2049451]
- net/mlx5e: Validate MTU when building non-linear legacy RQ fragments info (Mohammad Kabat) [2049451]
- net/mlx5e: MPLSoUDP encap, support action vlan pop_eth explicitly (Mohammad Kabat) [2049451]
- net/mlx5e: MPLSoUDP decap, use vlan push_eth instead of pedit (Mohammad Kabat) [2049451]
- RDMA/mlx5: Fix memory leak in error flow for subscribe event routine (Mohammad Kabat) [2049451]
- net/mlx5e: Fix use-after-free in mlx5e_stats_grp_sw_update_stats (Mohammad Kabat) [2049451]
- net/mlx5e: Remove overzealous validations in netlink EEPROM query (Mohammad Kabat) [2049451]
- net/mlx5: Parse module mapping using mlx5_ifc (Mohammad Kabat) [2049451]
- net/mlx5: Query the maximum MCIA register read size from firmware (Mohammad Kabat) [2049451]
- net/mlx5: CT: Create smfs dr matchers dynamically (Mohammad Kabat) [2049451]
- net/mlx5: CT: Add software steering ct flow steering provider (Mohammad Kabat) [2049451]
- net/mlx5: Add smfs lib to export direct steering API to CT (Mohammad Kabat) [2049451]
- net/mlx5: DR, Add helper to get backing dr table from a mlx5 flow table (Mohammad Kabat) [2049451]
- net/mlx5: CT: Introduce a platform for multiple flow steering providers (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the doorbell pgdir (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for UAR (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the EQs (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the EQ table (Mohammad Kabat) [2049451]
- net/mlx5: Node-aware allocation for the IRQ table (Mohammad Kabat) [2049451]
- net/mlx5: Delete useless module.h include (Mohammad Kabat) [2049451]
- net/mlx5: DR, Add support for ConnectX-7 steering (Mohammad Kabat) [2049451]
- net/mlx5: DR, Refactor ste_ctx handling for STE v0/1 (Mohammad Kabat) [2049451]
- net/mlx5: DR, Rename action modify fields to reflect naming in HW spec (Mohammad Kabat) [2049451]
- net/mlx5: DR, Fix handling of different actions on the same STE in STEv1 (Mohammad Kabat) [2049451]
- net/mlx5: DR, Remove unneeded comments (Mohammad Kabat) [2049451]
- net/mlx5: DR, Add support for matching on Internet Header Length (IHL) (Mohammad Kabat) [2049451]
- net/mlx5: DR, Align mlx5dv_dr API vport action with FW behavior (Mohammad Kabat) [2049451]
- net/mlx5: Add debugfs counters for page commands failures (Mohammad Kabat) [2049451]
- net/mlx5: Add pages debugfs (Mohammad Kabat) [2049451]
- net/mlx5: Move debugfs entries to separate struct (Mohammad Kabat) [2049451]
- net/mlx5: Change release_all_pages cap bit location (Mohammad Kabat) [2049451]
- net/mlx5: Remove redundant error on reclaim pages (Mohammad Kabat) [2049451]
- net/mlx5: Remove redundant error on give pages (Mohammad Kabat) [2049451]
- net/mlx5: Remove redundant notify fail on give pages (Mohammad Kabat) [2049451]
- net/mlx5: Add command failures data to debugfs (Mohammad Kabat) [2049451]
- net/mlx5e: TC, Fix use after free in mlx5e_clone_flow_attr_for_post_act() (Mohammad Kabat) [2049451]
- net/mlx5: Support GRE conntrack offload (Mohammad Kabat) [2049451]
- mlx5: add support for page_pool_get_stats (Mohammad Kabat) [2049451]
- net/mlx5: Add migration commands definitions (Mohammad Kabat) [2049451]
- net/mlx5: Introduce migration bits and structures (Mohammad Kabat) [2049451]
- net/mlx5: Expose APIs to get/put the mlx5 core device (Mohammad Kabat) [2049451]
- net/mlx5: Disable SRIOV before PF removal (Mohammad Kabat) [2049451]
- net/mlx5: Reuse exported virtfn index function call (Mohammad Kabat) [2049451]
- net/mlx5: Add clarification on sync reset failure (Mohammad Kabat) [2049451]
- net/mlx5: Add reset_state field to MFRL register (Mohammad Kabat) [2049451]
- RDMA/mlx5: Use new command interface API (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, Refactor error handling and reporting of async commands (Mohammad Kabat) [2049451]
- net/mlx5: Use mlx5_cmd_do() in core create_{cq,dct} (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, Add new api for command execution (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, cmd_check refactoring (Mohammad Kabat) [2049451]
- net/mlx5: cmdif, Return value improvements (Mohammad Kabat) [2049451]
- net/mlx5: Lag, offload active-backup drops to hardware (Mohammad Kabat) [2049451]
- net/mlx5: Lag, record inactive state of bond device (Mohammad Kabat) [2049451]
- net/mlx5: Lag, don't use magic numbers for ports (Mohammad Kabat) [2049451]
- net/mlx5: Lag, use local variable already defined to access E-Switch (Mohammad Kabat) [2049451]
- net/mlx5: E-switch, add drop rule support to ingress ACL (Mohammad Kabat) [2049451]
- net/mlx5: E-switch, remove special uplink ingress ACL handling (Mohammad Kabat) [2049451 2049589]
- net/mlx5: E-Switch, reserve and use same uplink metadata across ports (Mohammad Kabat) [2049451 2049589]
- net/mlx5: Add ability to insert to specific flow group (Mohammad Kabat) [2049451]
- mlx5: remove unused static inlines (Mohammad Kabat) [2049451]
- RDMA/mlx5: Reorder calls to pcie_relaxed_ordering_enabled() (Mohammad Kabat) [2049451]
- RDMA/mlx5: Store ndescs instead of the translation table size (Mohammad Kabat) [2049451]
- RDMA/mlx5: Merge similar flows of allocating MR from the cache (Mohammad Kabat) [2049451]
- RDMA/mlx5: Fix the flow of a miss in the allocation of a cache ODP MR (Mohammad Kabat) [2049451]
- RDMA/mlx5: Remove redundant work in struct mlx5_cache_ent (Mohammad Kabat) [2049451]
- net/mlx5e: TC, Allow sample action with CT (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Make post_act parse CT and sample actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Clean redundant counter flag from tc action parsers (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Use multi table support for CT and sample actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Create new flow attr for multi table actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Add post act offload/unoffload API (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Pass actions param to actions_match_supported() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Move flow hashtable to be per rep (Mohammad Kabat) [2049451]
- net/mlx5e: E-Switch, Add support for tx_port_ts in switchdev mode (Mohammad Kabat) [2049451]
- net/mlx5e: E-Switch, Add PTP counters for uplink representor (Mohammad Kabat) [2049451]
- net/mlx5e: RX, Restrict bulk size for small Striding RQs (Mohammad Kabat) [2049451]
- net/mlx5e: Default to Striding RQ when not conflicting with CQE compression (Mohammad Kabat) [2049451]
- net/mlx5e: Generalize packet merge error message (Mohammad Kabat) [2049451]
- net/mlx5e: Add support for using xdp->data_meta (Mohammad Kabat) [2049451]
- net/mlx5e: Fix spelling mistake "supoported" -> "supported" (Mohammad Kabat) [2049451]
- net/mlx5e: Optimize the common case condition in mlx5e_select_queue (Mohammad Kabat) [2049451]
- net/mlx5e: Optimize modulo in mlx5e_select_queue (Mohammad Kabat) [2049451]
- net/mlx5e: Optimize mlx5e_select_queue (Mohammad Kabat) [2049451]
- net/mlx5e: Use READ_ONCE/WRITE_ONCE for DCBX trust state (Mohammad Kabat) [2049451]
- net/mlx5e: Move repeating code that gets TC prio into a function (Mohammad Kabat) [2049451]
- net/mlx5e: Use select queue parameters to sync with control flow (Mohammad Kabat) [2049451]
- net/mlx5e: Move mlx5e_select_queue to en/selq.c (Mohammad Kabat) [2049451]
- net/mlx5e: Introduce select queue parameters (Mohammad Kabat) [2049451]
- net/mlx5e: Sync txq2sq updates with mlx5e_xmit for HTB queues (Mohammad Kabat) [2049451]
- net/mlx5e: Use a barrier after updating txq2sq (Mohammad Kabat) [2049451]
- net/mlx5e: Disable TX queues before registering the netdev (Mohammad Kabat) [2049451]
- net/mlx5e: Cleanup of start/stop all queues (Mohammad Kabat) [2049451]
- net/mlx5e: Use FW limitation for max MPW WQEBBs (Mohammad Kabat) [2049451]
- net/mlx5e: Read max WQEBBs on the SQ from firmware (Mohammad Kabat) [2049451]
- net/mlx5e: Remove unused tstamp SQ field (Mohammad Kabat) [2049451]
- RDMA/mlx5: Delete useless module.h include (Mohammad Kabat) [2049451]
- RDMA/mlx5: Delete get_num_static_uars function (Mohammad Kabat) [2049451]
- net/mlx5: VLAN push on RX, pop on TX (Mohammad Kabat) [2049451 2049618]
- net/mlx5: Introduce software defined steering capabilities (Mohammad Kabat) [2049451 2049618]
- net/mlx5: Remove unused TIR modify bitmask enums (Mohammad Kabat) [2049451]
- net/mlx5e: CT, Remove redundant flow args from tc ct calls (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Store mapped tunnel id on flow attr (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Test CT and SAMPLE on flow attr (Mohammad Kabat) [2049451 2049589 2049666]
- net/mlx5e: Refactor eswitch attr flags to just attr flags (Mohammad Kabat) [2049451 2049589 2049666]
- net/mlx5e: CT, Don't set flow flag CT for ct clear flow (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Hold sample_attr on stack instead of pointer (Mohammad Kabat) [2049451 2049589 2049666]
- net/mlx5e: TC, Reject rules with multiple CT actions (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Refactor mlx5e_tc_add_flow_mod_hdr() to get flow attr (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Pass attr to tc_act can_offload() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Split pedit offloads verify from alloc_tc_pedit_action() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: TC, Move pedit_headers_action to parse_attr (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Move counter creation call to alloc_flow_attr_counter() (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Pass attr arg for attaching/detaching encaps (Mohammad Kabat) [2049451 2049666]
- net/mlx5e: Move code chunk setting encap dests into its own function (Mohammad Kabat) [2049451 2049666]

* Wed Aug 24 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-155.rt21.155.el9]
- [rt] build kernel-rt-5.14.0-155.rt21.155.el9 [2061574]
- i40e: Fix tunnel checksum offload with fragmented traffic (Ivan Vecera) [2104734]
- wait: Fix __wait_event_hrtimeout for RT/DL tasks (Prarit Bhargava) [2112265]
- raid1: ensure write behind bio has less than BIO_MAX_VECS sectors (Nigel Croxon) [2117034]
- KVM: nVMX: Inject #UD if VMXON is attempted with incompatible CR0/CR4 (Vitaly Kuznetsov) [2118955]
- iavf: Fix deadlock in initialization (Petr Oros) [2106658]
- netfilter: nf_tables: do not allow RULE_ID to refer to another chain (Florian Westphal) [2116357] {CVE-2022-2586}
- netfilter: nf_tables: do not allow CHAIN_ID to refer to another table (Florian Westphal) [2116357] {CVE-2022-2586}
- netfilter: nf_tables: do not allow SET_ID to refer to another table (Florian Westphal) [2116357] {CVE-2022-2586}
- kbuild: expose explicit .symversions targets (Čestmír Kalina) [2066238]
- selftests: mptcp: make sendfile selftest work (Florian Westphal) [2109043]
- netfilter: nf_queue: do not allow packet truncation below transport header offset (Florian Westphal) [2116161] {CVE-2022-36946}
- ASoC: amd: yc: Update DMI table entries for AMD platforms (Jaroslav Kysela) [2114934]
- ASoC: amd: yc: Update DMI table entries (Jaroslav Kysela) [2114934]
- sfc: fix use after free when disabling sriov (Íñigo Huguet) [2097189]
- mm: Fix PASID use-after-free issue (Jerry Snitselaar) [2113044]
- ice: Fix VF not able to send tagged traffic with no VLAN filters (Petr Oros) [2116964]
- ice: Ignore error message when setting same promiscuous mode (Petr Oros) [2116964]
- ice: Fix clearing of promisc mode with bridge over bond (Petr Oros) [2116964]
- ice: Ignore EEXIST when setting promisc mode (Petr Oros) [2116964]
- ice: Fix double VLAN error when entering promisc mode (Petr Oros) [2116964]
- ice: Fix promiscuous mode not turning off (Petr Oros) [2116964]
- ice: Introduce enabling promiscuous mode on multiple VF's (Petr Oros) [2116964]
- ice: do not setup vlan for loopback VSI (Petr Oros) [2116964]
- ice: check (DD | EOF) bits on Rx descriptor rather than (EOP | RS) (Petr Oros) [2116964]
- ice: Fix VSIs unable to share unicast MAC (Petr Oros) [2116964]
- ice: Fix max VLANs available for VF (Petr Oros) [2116964]
- ice: change devlink code to read NVM in blocks (Petr Oros) [2116964]
- be2net: Remove useless DMA-32 fallback configuration (Petr Oros) [2051280]
- ethernet: constify references to netdev->dev_addr in drivers (Petr Oros) [2051280]
- ethernet: Remove redundant 'flush_workqueue()' calls (Petr Oros) [2051280]
- be2net: Use irq_update_affinity_hint() (Petr Oros) [2051280]

* Wed Aug 24 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-154.rt21.154.el9]
- [rt] build kernel-rt-5.14.0-154.rt21.154.el9 [2061574]
- Revert "x86/sev: Expose sev_es_ghcb_hv_call() for use by HyperV" (John Allen) [2081424]
- virt: sev-guest: Pass the appropriate argument type to iounmap() (John Allen) [2081424]
- x86/boot: Fix the setup data types max limit (John Allen) [2081424]
- x86/compressed/64: Add identity mappings for setup_data entries (John Allen) [2081424]
- x86/Hyper-V: Add SEV negotiate protocol support in Isolation VM (John Allen) [2081424]
- x86/sev: Mark the code returning to user space as syscall gap (John Allen) [2081424]
- x86/sev: Annotate stack change in the #VC handler (John Allen) [2081424]
- x86/sev: Remove duplicated assignment to variable info (John Allen) [2081424]
- x86/sev: Fix address space sparse warning (John Allen) [2081424]
- x86/sev: Get the AP jump table address from secrets page (John Allen) [2081424]
- x86/sev: Add missing __init annotations to SEV init routines (John Allen) [2081424]
- virt: sevguest: Rename the sevguest dir and files to sev-guest (John Allen) [2081424]
- virt: sevguest: Change driver name to reflect generic SEV support (John Allen) [2081424]
- x86/boot: Put globals that are accessed early into the .data section (John Allen) [2081424]
- virt: sevguest: Fix bool function returning negative value (John Allen) [2081424]
- virt: sevguest: Fix return value check in alloc_shared_pages() (John Allen) [2081424]
- x86/sev: Unroll string mmio with CC_ATTR_GUEST_UNROLL_STRING_IO (John Allen) [2081424]
- x86/sev-es: Replace open-coded hlt-loop with sev_es_terminate() (John Allen) [2081424]
- virt: sevguest: Add documentation for SEV-SNP CPUID Enforcement (John Allen) [2081424]
- virt: sevguest: Add support to get extended report (John Allen) [2081424]
- virt: sevguest: Add support to derive key (John Allen) [2081424]
- redhat/configs: enable CONFIG_SEV_GUEST (John Allen) [2081424]
- virt: Add SEV-SNP guest driver (John Allen) [2081424]
- x86/sev: Register SEV-SNP guest request platform device (John Allen) [2081424]
- x86/sev: Provide support for SNP guest request NAEs (John Allen) [2081424]
- x86/sev: Add a sev= cmdline option (John Allen) [2081424]
- x86/sev: Use firmware-validated CPUID for SEV-SNP guests (John Allen) [2081424]
- x86/sev: Add SEV-SNP feature detection/setup (John Allen) [2081424]
- x86/compressed/64: Add identity mapping for Confidential Computing blob (John Allen) [2081424]
- x86/compressed: Export and rename add_identity_map() (John Allen) [2081424]
- x86/compressed: Use firmware-validated CPUID leaves for SEV-SNP guests (John Allen) [2081424]
- x86/compressed: Add SEV-SNP feature detection/setup (John Allen) [2081424]
- x86/boot: Add a pointer to Confidential Computing blob in bootparams (John Allen) [2081424]
- x86/compressed/64: Add support for SEV-SNP CPUID table in #VC handlers (John Allen) [2081424]
- x86/sev: Move MSR-based VMGEXITs for CPUID to helper (John Allen) [2081424]
- KVM: x86: Move lookup of indexed CPUID leafs to helper (John Allen) [2081424]
- x86/boot: Add Confidential Computing type to setup_data (John Allen) [2081424]
- x86/compressed/acpi: Move EFI kexec handling into common code (John Allen) [2081424]
- x86/compressed/acpi: Move EFI vendor table lookup to helper (John Allen) [2081424]
- x86/compressed/acpi: Move EFI config table lookup to helper (John Allen) [2081424]
- x86/compressed/acpi: Move EFI system table lookup to helper (John Allen) [2081424]
- x86/compressed/acpi: Move EFI detection to helper (John Allen) [2081424]
- x86/head/64: Re-enable stack protection (John Allen) [2081424]
- x86/sev: Use SEV-SNP AP creation to start secondary CPUs (John Allen) [2081424]
- x86/mm: Validate memory when changing the C-bit (John Allen) [2081424]
- x86/kernel: Validate ROM memory before accessing when SEV-SNP is active (John Allen) [2081424]
- x86/kernel: Mark the .bss..decrypted section as shared in the RMP table (John Allen) [2081424]
- x86/sev: Add helper for validating pages in early enc attribute changes (John Allen) [2081424]
- x86/sev: Register GHCB memory when SEV-SNP is active (John Allen) [2081424]
- x86/compressed: Register GHCB memory when SEV-SNP is active (John Allen) [2081424]
- x86/compressed: Add helper for validating pages in the decompression stage (John Allen) [2081424]
- x86/sev: Check the VMPL level (John Allen) [2081424]
- x86/sev: Add a helper for the PVALIDATE instruction (John Allen) [2081424]
- x86/sev: Check SEV-SNP features support (John Allen) [2081424]
- x86/sev: Save the negotiated GHCB version (John Allen) [2081424]
- x86/sev: Define the Linux-specific guest termination reasons (John Allen) [2081424]
- x86/mm: Extend cc_attr to include AMD SEV-SNP (John Allen) [2081424]
- x86/sev: Detect/setup SEV/SME features earlier in boot (John Allen) [2081424]
- x86/compressed/64: Detect/setup SEV/SME features earlier during boot (John Allen) [2081424]
- x86/boot: Use MSR read/write helpers instead of inline assembly (John Allen) [2081424]
- x86/boot: Introduce helpers for MSR reads/writes (John Allen) [2081424]
- KVM: SVM: Update the SEV-ES save area mapping (John Allen) [2081424]
- KVM: SVM: Create a separate mapping for the GHCB save area (John Allen) [2081424]
- KVM: SVM: Create a separate mapping for the SEV-ES save area (John Allen) [2081424]
- KVM: SVM: Define sev_features and vmpl field in the VMSA (John Allen) [2081424]
- x86/mm/cpa: Generalize __set_memory_enc_pgtable() (John Allen) [2081424]
- x86/coco: Add API to handle encryption mask (John Allen) [2081424]
- x86/cc: Move arch/x86/{kernel/cc_platform.c => coco/core.c} (John Allen) [2081424]
- x86/sev: Move common memory encryption code to mem_encrypt.c (John Allen) [2081424]
- x86/sev: Rename mem_encrypt.c to mem_encrypt_amd.c (John Allen) [2081424]
- x86/sev: Remove do_early_exception() forward declarations (John Allen) [2081424]
- x86/head64: Carve out the guest encryption postprocessing into a helper (John Allen) [2081424]
- x86/sev: Get rid of excessive use of defines (John Allen) [2081424]
- x86/sev: Shorten GHCB terminate macro names (John Allen) [2081424]
- x86/sev: Make the #VC exception stacks part of the default stacks storage (John Allen) [2081424]
- tools headers UAPI: Synch KVM's svm.h header with the kernel (John Allen) [2081424]

* Tue Aug 23 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-153.rt21.153.el9]
- [rt] build kernel-rt-5.14.0-153.rt21.153.el9 [2061574]
- selftests: netfilter: add test case for nf trace infrastructure (Florian Westphal) [2112751]
- netfilter: nf_tables: fix crash when nf_trace is enabled (Florian Westphal) [2112751]
- netfilter: nf_log: incorrect offset to network header (Phil Sutter) [2067133]
- netfilter: nf_log_syslog: Consolidate entry checks (Phil Sutter) [2067133]
- netfilter: nf_log_syslog: Don't ignore unknown protocols (Phil Sutter) [2067133]
- netfilter: nf_log_syslog: Merge MAC header dumpers (Phil Sutter) [2067133]
- net/mlx4_en: use kzalloc (Mohammad Kabat) [2049443]
- net/mlx4: Delete useless moduleparam include (Mohammad Kabat) [2049443]
- RDMA/mlx4: remove redundant assignment to variable nreq (Mohammad Kabat) [2049443]
- RDMA/mlx4: Delete useless module.h include (Mohammad Kabat) [2049443]
- RDMA/mlx4: Don't continue event handler after memory allocation failure (Mohammad Kabat) [2049443]
- net/mlx4: Use irq_update_affinity_hint() (Mohammad Kabat) [2049443]
- RDMA/mlx4: Use bitmap_alloc() when applicable (Mohammad Kabat) [2049443]
- net/mlx4_en: Fix an use-after-free bug in mlx4_en_try_alloc_resources() (Mohammad Kabat) [2049443]
- net/mlx4_en: Update reported link modes for 1/10G (Mohammad Kabat) [2049443]
- RDMA/mlx4: Do not fail the registration on port stats (Mohammad Kabat) [2049443]
- net: convert users of bitmap_foo() to linkmode_foo() (Mohammad Kabat) [2049443]
- RDMA/mlx4: Return missed an error if device doesn't support steering (Mohammad Kabat) [2049443]
- ethernet: Remove redundant 'flush_workqueue()' calls (Mohammad Kabat) [2049443]
- mlx4: constify args for const dev_addr (Mohammad Kabat) [2049443]
- mlx4: remove custom dev_addr clearing (Mohammad Kabat) [2049443]
- mlx4: replace mlx4_u64_to_mac() with u64_to_ether_addr() (Mohammad Kabat) [2049443]
- mlx4: replace mlx4_mac_to_u64() with ether_addr_to_u64() (Mohammad Kabat) [2049443]
- net/mlx4_en: avoid one cache line miss to ring doorbell (Mohammad Kabat) [2049443]
- net/mlx4_en: Add XDP_REDIRECT statistics (Mohammad Kabat) [2049443]
- net/mlx4: Use array_size() helper in copy_to_user() (Mohammad Kabat) [2049443]
- net: mlx4: Add support for XDP_REDIRECT (Mohammad Kabat) [2049443]
- net/mlx4_en: Don't allow aRFS for encapsulated packets (Mohammad Kabat) [2049443]
- net/mlx4_en: Resolve bad operstate value (Mohammad Kabat) [2049443]
- net/mellanox: switch from 'pci_' to 'dma_' API (Mohammad Kabat) [2049443]
- net/mlx4: Use ARRAY_SIZE to get an array's size (Mohammad Kabat) [2049443]
- net/mlx4: make the array states static const, makes object smaller (Mohammad Kabat) [2049443]
- redhat: Use redhatsecureboot701 for ppc64le (Patrick Talbert) [2109211]
- device property: Advertise fwnode and device property count API calls (Al Stone) [2102893]
- device property: Fix recent breakage of fwnode_get_next_parent_dev() (Al Stone) [2102893]
- device property: Use multi-connection matchers for single case (Al Stone) [2102893]
- device property: Drop 'test' prefix in parameters of fwnode_is_ancestor_of() (Al Stone) [2102893]
- device property: Introduce fwnode_for_each_parent_node() (Al Stone) [2102893]
- device property: Allow error pointer to be passed to fwnode APIs (Al Stone) [2102893]
- device property: Add irq_get to fwnode operation (Al Stone) [2102893]
- device property: Add iomap to fwnode operations (Al Stone) [2102893]
- device property: Convert device_{dma_supported,get_dma_attr} to fwnode (Al Stone) [2102893]
- ARM: tegra: paz00: Handle device properties with software node API (Al Stone) [2102893]

* Tue Aug 23 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-152.rt21.152.el9]
- [rt] build kernel-rt-5.14.0-152.rt21.152.el9 [2061574]
- net/mlx5e: SHAMPO, reduce TIR indication (Mohammad Kabat) [2049450]
- net/mlx5e: Lag, Only handle events from highest priority multipath entry (Mohammad Kabat) [2049450]
- net/mlx5: Fix offloading with ESWITCH_IPV4_TTL_MODIFY_ENABLE (Mohammad Kabat) [2049450]
- net/mlx5: Fix a race on command flush flow (Mohammad Kabat) [2049450]
- net/mlx5: Fix size field in bufferx_reg struct (Mohammad Kabat) [2049450]
- net/mlx5e: Fix VF min/max rate parameters interchange mistake (Mohammad Kabat) [2049450]
- net/mlx5e: Add missing increment of count (Mohammad Kabat) [2049450]
- net/mlx5e: MPLSoUDP decap, fix check for unsupported matches (Mohammad Kabat) [2049450]
- net/mlx5e: Fix MPLSoUDP encap to use MPLS action information (Mohammad Kabat) [2049450]
- net/mlx5e: Add feature check for set fec counters (Mohammad Kabat) [2049450 2049713]
- net/mlx5e: TC, Skip redundant ct clear actions (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with forward and drop actions (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with drop and modify hdr action (Mohammad Kabat) [2049450]
- net/mlx5e: kTLS, Use CHECKSUM_UNNECESSARY for device-offloaded packets (Mohammad Kabat) [2049450]
- net/mlx5e: Fix wrong return value on ioctl EEPROM query failure (Mohammad Kabat) [2049450]
- net/mlx5: Fix possible deadlock on rule deletion (Mohammad Kabat) [2049450]
- net/mlx5: Fix tc max supported prio for nic mode (Mohammad Kabat) [2049450]
- net/mlx5: Fix wrong limitation of metadata match on ecpf (Mohammad Kabat) [2049450]
- net/mlx5: Update log_max_qp value to be 17 at most (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix the threshold that defines when pool sync is initiated (Mohammad Kabat) [2049450]
- net/mlx5: DR, Don't allow match on IP w/o matching on full ethertype/ip_version (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix slab-out-of-bounds in mlx5_cmd_dr_create_fte (Mohammad Kabat) [2049450]
- net/mlx5: DR, Cache STE shadow memory (Mohammad Kabat) [2049450]
- net/mlx5e: Avoid field-overflowing memcpy() (Mohammad Kabat) [2049450]
- net/mlx5e: Use struct_group() for memcpy() region (Mohammad Kabat) [2049450]
- net/mlx5e: Avoid implicit modify hdr for decap drop rule (Mohammad Kabat) [2049450]
- net/mlx5e: IPsec: Fix tunnel mode crypto offload for non TCP/UDP traffic (Mohammad Kabat) [2049450]
- net/mlx5e: IPsec: Fix crypto offload for non TCP/UDP encapsulated traffic (Mohammad Kabat) [2049450]
- net/mlx5e: Don't treat small ceil values as unlimited in HTB offload (Mohammad Kabat) [2049450]
- net/mlx5: E-Switch, Fix uninitialized variable modact (Mohammad Kabat) [2049450]
- net/mlx5e: Fix handling of wrong devices during bond netevent (Mohammad Kabat) [2049450]
- net/mlx5e: Fix broken SKB allocation in HW-GRO (Mohammad Kabat) [2049450]
- net/mlx5e: Fix wrong calculation of header index in HW_GRO (Mohammad Kabat) [2049450]
- net/mlx5: Bridge, Fix devlink deadlock on net namespace deletion (Mohammad Kabat) [2049450]
- net/mlx5: Fix offloading with ESWITCH_IPV4_TTL_MODIFY_ENABLE (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with forward and drop actions (Mohammad Kabat) [2049450]
- net/mlx5: Use del_timer_sync in fw reset flow of halting poll (Mohammad Kabat) [2049450]
- net/mlx5e: Fix module EEPROM query (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Reject rules with drop and modify hdr action (Mohammad Kabat) [2049450]
- net/mlx5: Bridge, ensure dev_name is null-terminated (Mohammad Kabat) [2049450]
- net/mlx5: Bridge, take rtnl lock in init error handler (Mohammad Kabat) [2049450]
- mlx5: Don't accidentally set RTO_ONLINK before mlx5e_route_lookup_ipv4_get() (Mohammad Kabat) [2049450]
- net/mlx5e: Fix build error in fec_set_block_stats() (Mohammad Kabat) [2049450]
- Revert "net/mlx5: Add retry mechanism to the command entry index allocation" (Mohammad Kabat) [2049450]
- net/mlx5: Set command entry semaphore up once got index free (Mohammad Kabat) [2049450]
- net/mlx5e: Sync VXLAN udp ports during uplink representor profile change (Mohammad Kabat) [2049450]
- net/mlx5: Fix access to sf_dev_table on allocation failure (Mohammad Kabat) [2049450]
- net/mlx5e: Fix matching on modified inner ip_ecn bits (Mohammad Kabat) [2049450]
- Revert "net/mlx5e: Block offload of outer header csum for GRE tunnel" (Mohammad Kabat) [2049450]
- Revert "net/mlx5e: Block offload of outer header csum for UDP tunnels" (Mohammad Kabat) [2049450]
- net/mlx5e: Don't block routes with nexthop objects in SW (Mohammad Kabat) [2049450 2049888]
- net/mlx5e: Fix wrong usage of fib_info_nh when routes with nexthop objects are used (Mohammad Kabat) [2049450 2049888]
- net/mlx5e: Fix nullptr on deleting mirroring rule (Mohammad Kabat) [2049450]
- net/mlx5e: Fix page DMA map/unmap attributes (Mohammad Kabat) [2049450]
- net/mlx5e: Add recovery flow in case of error CQE (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Remove redundant error logging (Mohammad Kabat) [2049450]
- net/mlx5e: Refactor set_pflag_cqe_based_moder (Mohammad Kabat) [2049450]
- net/mlx5e: Move HW-GRO and CQE compression check to fix features flow (Mohammad Kabat) [2049450]
- net/mlx5e: Fix feature check per profile (Mohammad Kabat) [2049450]
- net/mlx5e: Unblock setting vid 0 for VF in case PF isn't eswitch manager (Mohammad Kabat) [2049450]
- net/mlx5e: Expose FEC counters via ethtool (Mohammad Kabat) [2049450 2049713]
- net/mlx5: Update log_max_qp value to FW max capability (Mohammad Kabat) [2049450]
- net/mlx5: SF, Use all available cpu for setting cpu affinity (Mohammad Kabat) [2049450]
- net/mlx5: Introduce API for bulk request and release of IRQs (Mohammad Kabat) [2049450]
- net/mlx5: Split irq_pool_affinity logic to new file (Mohammad Kabat) [2049450]
- net/mlx5: Move affinity assignment into irq_request (Mohammad Kabat) [2049450]
- net/mlx5: Introduce control IRQ request API (Mohammad Kabat) [2049450]
- net/mlx5: mlx5e_hv_vhca_stats_create return type to void (Mohammad Kabat) [2049450]
- RDMA/mlx5: Print wc status on CQE error and dump needed (Mohammad Kabat) [2049450]
- net: fixup build after bpf header changes (Mohammad Kabat) [2049450]
- net/mlx5: CT: Set flow source hint from provided tuple device (Mohammad Kabat) [2049450]
- net/mlx5: Set SMFS as a default steering mode if device supports it (Mohammad Kabat) [2049450]
- net/mlx5: DR, Ignore modify TTL if device doesn't support it (Mohammad Kabat) [2049450]
- net/mlx5: DR, Improve steering for empty or RX/TX-only matchers (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add support for matching on geneve_tlv_option_0_exist field (Mohammad Kabat) [2049450]
- net/mlx5: DR, Support matching on tunnel headers 0 and 1 (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add misc5 to match_param structs (Mohammad Kabat) [2049450]
- net/mlx5: Add misc5 flow table match parameters (Mohammad Kabat) [2049450]
- net/mlx5: DR, Warn on failure to destroy objects due to refcount (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add support for UPLINK destination type (Mohammad Kabat) [2049450]
- net/mlx5: DR, Add support for dumping steering info (Mohammad Kabat) [2049450 2049888]
- net/mlx5: DR, Add missing reserved fields to dr_match_param (Mohammad Kabat) [2049450 2049888]
- net/mlx5: DR, Add check for flex parser ID value (Mohammad Kabat) [2049450]
- net/mlx5: DR, Rename list field in matcher struct to list_node (Mohammad Kabat) [2049450 2049888]
- net/mlx5: DR, Remove unused struct member in matcher (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix lower case macro prefix "mlx5_" to "MLX5_" (Mohammad Kabat) [2049450]
- net/mlx5: DR, Fix error flow in creating matcher (Mohammad Kabat) [2049450]
- net/mlx5e: Use auxiliary_device driver data helpers (Mohammad Kabat) [2049450]
- net/mlx5e: Take packet_merge params directly from the RX res struct (Mohammad Kabat) [2049450]
- net/mlx5e: Allocate per-channel stats dynamically at first usage (Mohammad Kabat) [2049450]
- net/mlx5e: Use dynamic per-channel allocations in stats (Mohammad Kabat) [2049450]
- net/mlx5e: Allow profile-specific limitation on max num of channels (Mohammad Kabat) [2049450]
- net/mlx5e: Save memory by using dynamic allocation in netdev priv (Mohammad Kabat) [2049450]
- net/mlx5e: Add profile indications for PTP and QOS HTB features (Mohammad Kabat) [2049450]
- net/mlx5e: Use bitmap field for profile features (Mohammad Kabat) [2049450]
- net/mlx5: Remove the repeated declaration (Mohammad Kabat) [2049450]
- net/mlx5: Let user configure max_macs generic param (Mohammad Kabat) [2049450]
- net/mlx5: Let user configure event_eq_size param (Mohammad Kabat) [2049450]
- net/mlx5: Let user configure io_eq_size param (Mohammad Kabat) [2049450]
- net/mlx5: Introduce log_max_current_uc_list_wr_supported bit (Mohammad Kabat) [2049450]
- net/mlx5e: Move goto action checks into tc_action goto post parse op (Mohammad Kabat) [2049450]
- net/mlx5e: Move vlan action chunk into tc action vlan post parse op (Mohammad Kabat) [2049450]
- net/mlx5e: Add post_parse() op to tc action infrastructure (Mohammad Kabat) [2049450]
- net/mlx5e: Move sample attr allocation to tc_action sample parse op (Mohammad Kabat) [2049450]
- net/mlx5e: TC action parsing loop (Mohammad Kabat) [2049450]
- net/mlx5e: Add redirect ingress to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add sample and ptype to tc_action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add ct to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add mirred/redirect to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add mpls push/pop to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add vlan push/pop/mangle to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add pedit to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add csum to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add tunnel encap/decap to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add goto to tc action infra (Mohammad Kabat) [2049450]
- net/mlx5e: Add tc action infrastructure (Mohammad Kabat) [2049450]
- RDMA/mlx5: Use memset_after() to zero struct mlx5_ib_mr (Mohammad Kabat) [2049450]
- RDMA/mlx5: Add support to multiple priorities for FDB rules (Mohammad Kabat) [2049450]
- net/mlx5: Create more priorities for FDB bypass namespace (Mohammad Kabat) [2049450]
- net/mlx5: Refactor mlx5_get_flow_namespace (Mohammad Kabat) [2049450]
- net/mlx5: Separate FDB namespace (Mohammad Kabat) [2049450]
- net/mlx5: Use irq_set_affinity_and_hint() (Mohammad Kabat) [2049450]
- net/mlx5: Dynamically resize flow counters query buffer (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Set flow attr ip_version earlier (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Move common flow_action checks into function (Mohammad Kabat) [2049450]
- net/mlx5e: Remove redundant actions arg from vlan push/pop funcs (Mohammad Kabat) [2049450]
- net/mlx5e: Remove redundant actions arg from validate_goto_chain() (Mohammad Kabat) [2049450]
- net/mlx5e: TC, Remove redundant action stack var (Mohammad Kabat) [2049450]
- net/mlx5e: Hide function mlx5e_num_channels_changed (Mohammad Kabat) [2049450]
- net/mlx5e: SHAMPO, clean MLX5E_MAX_KLM_PER_WQE macro (Mohammad Kabat) [2049450]
- net/mlx5: Print more info on pci error handlers (Mohammad Kabat) [2049450]
- net/mlx5: SF, silence an uninitialized variable warning (Mohammad Kabat) [2049450]
- net/mlx5: Fix error return code in esw_qos_create() (Mohammad Kabat) [2049450]
- mlx5: fix mlx5i_grp_sw_update_stats() stack usage (Mohammad Kabat) [2049450]
- mlx5: fix psample_sample_packet link error (Mohammad Kabat) [2049450]
- net/mlx5: E-switch, Create QoS on demand (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, Enable vport QoS on demand (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, move offloads mode callbacks to offloads file (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, Reuse mlx5_eswitch_set_vport_mac (Mohammad Kabat) [2049450 2049844]
- net/mlx5: E-switch, Remove vport enabled check (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: Specify out ifindex when looking up decap route (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: TC, Move comment about mod header flag to correct place (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: TC, Move kfree() calls after destroying all resources (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: TC, Destroy nic flow counter if exists (Mohammad Kabat) [2049450 2049844]
- net/mlx5: TC, using swap() instead of tmp variable (Mohammad Kabat) [2049450 2049844]
- net/mlx5: CT: Allow static allocation of mod headers (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: Refactor mod header management API (Mohammad Kabat) [2049450 2049844]
- net/mlx5: Avoid printing health buffer when firmware is unavailable (Mohammad Kabat) [2049450 2049833 2049844]
- net/mlx5: Fix format-security build warnings (Mohammad Kabat) [2049450 2049844]
- net/mlx5e: Support ethtool cq mode (Mohammad Kabat) [2049450 2049844]
- Revert "RDMA/mlx5: Fix releasing unallocated memory in dereg MR flow" (Mohammad Kabat) [2049449]
- net/mlx5e: Fix wrong features assignment in case of error (Mohammad Kabat) [2049449]
- net/mlx5e: TC, Fix memory leak with rules with internal port (Mohammad Kabat) [2049449]
- net/mlx5: Fix some error handling paths in 'mlx5e_tc_add_fdb_flow()' (Mohammad Kabat) [2049449]
- net/mlx5e: Delete forward rule for ct or sample action (Mohammad Kabat) [2049449]
- net/mlx5e: Fix ICOSQ recovery flow for XSK (Mohammad Kabat) [2049449]
- net/mlx5e: Fix interoperability between XSK and ICOSQ recovery flow (Mohammad Kabat) [2049449]
- net/mlx5e: Fix skb memory leak when TC classifier action offloads are disabled (Mohammad Kabat) [2049449]
- net/mlx5e: Wrap the tx reporter dump callback to extract the sq (Mohammad Kabat) [2049449]
- net/mlx5: Fix tc max supported prio for nic mode (Mohammad Kabat) [2049449]
- net/mlx5: Fix SF health recovery flow (Mohammad Kabat) [2049449]
- net/mlx5: Fix error print in case of IRQ request failed (Mohammad Kabat) [2049449]
- net/mlx5: Use first online CPU instead of hard coded CPU (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix querying eswitch manager vport for ECPF (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix NULL vs IS_ERR checking in dr_domain_init_resources (Mohammad Kabat) [2049449]
- net/mlx5e: SHAMPO, Fix constant expression result (Mohammad Kabat) [2049449]
- net/mlx5: Fix access to a non-supported register (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Fix too early queueing of log timestamp work (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Fix use after free in mlx5_health_wait_pci_up (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Use indirect table only if all destinations support it (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Check group pointer before reading bw_share value (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, fix single FDB creation on BlueField (Mohammad Kabat) [2049449]
- net/mlx5: E-switch, Respect BW share of the new group (Mohammad Kabat) [2049449]
- net/mlx5: Lag, Fix recreation of VF LAG (Mohammad Kabat) [2049449]
- net/mlx5: Move MODIFY_RQT command to ignore list in internal error state (Mohammad Kabat) [2049449]
- net/mlx5e: Sync TIR params updates against concurrent create/modify (Mohammad Kabat) [2049449]
- net/mlx5e: Fix missing IPsec statistics on uplink representor (Mohammad Kabat) [2049449]
- net/mlx5e: IPsec: Fix Software parser inner l3 type setting in case of encapsulation (Mohammad Kabat) [2049449]
- RDMA/mlx5: Fix releasing unallocated memory in dereg MR flow (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, return error if encap isn't supported (Mohammad Kabat) [2049449]
- net/mlx5: Lag, update tracker when state change event received (Mohammad Kabat) [2049449]
- net/mlx5e: CT, Fix multiple allocations and memleak of mod acts (Mohammad Kabat) [2049449]
- net/mlx5: Fix flow counters SF bulk query len (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, rebuild lag only when needed (Mohammad Kabat) [2049449]
- net/mlx5: Update error handler for UCTX and UMEM (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix check for unsupported fields in match param (Mohammad Kabat) [2049449]
- net/mlx5: DR, Handle eswitch manager and uplink vports separately (Mohammad Kabat) [2049449]
- net/mlx5e: nullify cq->dbg pointer in mlx5_debug_cq_remove() (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Fix resetting of encap mode when entering switchdev (Mohammad Kabat) [2049449]
- net/mlx5e: Wait for concurrent flow deletion during neigh/fib events (Mohammad Kabat) [2049449]
- net/mlx5e: kTLS, Fix crash in RX resync flow (Mohammad Kabat) [2049449]
- net/mlx5: Lag, fix a potential Oops with mlx5_lag_create_definer() (Mohammad Kabat) [2049449]
- net/mlx5: Support internal port as decap route device (Mohammad Kabat) [2049449]
- net/mlx5e: Term table handling of internal port rules (Mohammad Kabat) [2049449]
- net/mlx5e: Add indirect tc offload of ovs internal port (Mohammad Kabat) [2049449]
- net/mlx5e: Offload internal port as encap route device (Mohammad Kabat) [2049449]
- net/mlx5e: Offload tc rules that redirect to ovs internal port (Mohammad Kabat) [2049449]
- net/mlx5e: Accept action skbedit in the tc actions list (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Add ovs internal port mapping to metadata support (Mohammad Kabat) [2049449]
- net/mlx5e: Use generic name for the forwarding dev pointer (Mohammad Kabat) [2049449]
- net/mlx5e: Refactor rx handler of represetor device (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add check for unsupported fields in match param (Mohammad Kabat) [2049449]
- net/mlx5: Allow skipping counter refresh on creation (Mohammad Kabat) [2049449]
- net/mlx5e: IPsec: Refactor checksum code in tx data path (Mohammad Kabat) [2049449]
- net/mlx5: CT: Remove warning of ignore_flow_level support for VFs (Mohammad Kabat) [2049449]
- net/mlx5: Add esw assignment back in mlx5e_tc_sample_unoffload() (Mohammad Kabat) [2049449]
- net/mlx5: Lag, Make mlx5_lag_is_multipath() be static inline (Mohammad Kabat) [2049449]
- net/mlx5e: Prevent HW-GRO and CQE-COMPRESS features operate together (Mohammad Kabat) [2049449]
- net/mlx5e: Add HW-GRO offload (Mohammad Kabat) [2049449]
- net/mlx5e: Add HW_GRO statistics (Mohammad Kabat) [2049449]
- net/mlx5e: HW_GRO cqe handler implementation (Mohammad Kabat) [2049449]
- net/mlx5e: Add data path for SHAMPO feature (Mohammad Kabat) [2049449]
- net/mlx5e: Add handle SHAMPO cqe support (Mohammad Kabat) [2049449]
- net/mlx5e: Add control path for SHAMPO feature (Mohammad Kabat) [2049449]
- net/mlx5e: Add support to klm_umr_wqe (Mohammad Kabat) [2049449]
- net/mlx5e: Rename TIR lro functions to TIR packet merge functions (Mohammad Kabat) [2049449]
- net/mlx5: Add SHAMPO caps, HW bits and enumerations (Mohammad Kabat) [2049449]
- net/mlx5e: Rename lro_timeout to packet_merge_timeout (Mohammad Kabat) [2049449]
- net/mlx5: remove the recent devlink params (Mohammad Kabat) [2049449]
- net/mlx5: SF_DEV Add SF device trace points (Mohammad Kabat) [2049449]
- net/mlx5: SF, Add SF trace points (Mohammad Kabat) [2049449]
- net/mlx5: Let user configure max_macs param (Mohammad Kabat) [2049449]
- net/mlx5: Let user configure event_eq_size param (Mohammad Kabat) [2049449]
- net/mlx5: Let user configure io_eq_size param (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, support replacing existing FDB entry (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, extract code to lookup and del/notify entry (Mohammad Kabat) [2049449]
- net/mlx5: Add periodic update of host time to firmware (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Print health buffer by log level (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Extend health buffer dump (Mohammad Kabat) [2049449 2049833]
- net/mlx5: Reduce flow counters bulk query buffer size for SFs (Mohammad Kabat) [2049449]
- net/mlx5: Fix unused function warning of mlx5i_flow_type_mask (Mohammad Kabat) [2049449]
- net/mlx5: Remove unnecessary checks for slow path flag (Mohammad Kabat) [2049449]
- net/mlx5e: don't write directly to netdev->dev_addr (Mohammad Kabat) [2049449]
- RDMA/mlx5: Use dev_addr_mod() (Mohammad Kabat) [2049449]
- RDMA/mlx5: fix build error with INFINIBAND_USER_ACCESS=n (Mohammad Kabat) [2049449]
- RDMA/mlx5: Attach ndescs to mlx5_ib_mkey (Mohammad Kabat) [2049449]
- RDMA/mlx5: Move struct mlx5_core_mkey to mlx5_ib (Mohammad Kabat) [2049449]
- RDMA/mlx5: Replace struct mlx5_core_mkey by u32 key (Mohammad Kabat) [2049449]
- RDMA/mlx5: Remove pd from struct mlx5_core_mkey (Mohammad Kabat) [2049449]
- RDMA/mlx5: Remove size from struct mlx5_core_mkey (Mohammad Kabat) [2049449]
- RDMA/mlx5: Remove iova from struct mlx5_core_mkey (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Increase supported number of forward destinations to 32 (Mohammad Kabat) [2049449]
- net/mlx5: E-Switch, Use dynamic alloc for dest array (Mohammad Kabat) [2049449]
- net/mlx5: Lag, use steering to select the affinity port in LAG (Mohammad Kabat) [2049449]
- net/mlx5: Lag, add support to create/destroy/modify port selection (Mohammad Kabat) [2049449]
- net/mlx5: Lag, add support to create TTC tables for LAG port selection (Mohammad Kabat) [2049449]
- net/mlx5: Lag, add support to create definers for LAG (Mohammad Kabat) [2049449]
- net/mlx5: Lag, set match mask according to the traffic type bitmap (Mohammad Kabat) [2049449]
- net/mlx5: Lag, set LAG traffic type mapping (Mohammad Kabat) [2049449]
- net/mlx5: Lag, move lag files into directory (Mohammad Kabat) [2049449]
- net/mlx5: Introduce new uplink destination type (Mohammad Kabat) [2049449]
- net/mlx5: Add support to create match definer (Mohammad Kabat) [2049449]
- net/mlx5: Introduce port selection namespace (Mohammad Kabat) [2049449]
- net/mlx5: Support partial TTC rules (Mohammad Kabat) [2049449]
- mlx5: prevent 64bit divide (Mohammad Kabat) [2049449]
- net/mlx5: Use system_image_guid to determine bonding (Mohammad Kabat) [2049449]
- net/mlx5: Use native_port_num as 1st option of device index (Mohammad Kabat) [2049449]
- net/mlx5: Introduce new device index wrapper (Mohammad Kabat) [2049449]
- net/mlx5: Check return status first when querying system_image_guid (Mohammad Kabat) [2049449]
- net/mlx5: DR, Prefer kcalloc over open coded arithmetic (Mohammad Kabat) [2049449]
- net/mlx5e: Add extack msgs related to TC for better debug (Mohammad Kabat) [2049449]
- net/mlx5: CT: Fix missing cleanup of ct nat table on init failure (Mohammad Kabat) [2049449]
- net/mlx5: Disable roce at HCA level (Mohammad Kabat) [2049449]
- net/mlx5i: Enable Rx steering for IPoIB via ethtool (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, provide flow source hints (Mohammad Kabat) [2049449]
- net/mlx5: Read timeout values from DTOR (Mohammad Kabat) [2049449]
- net/mlx5: Read timeout values from init segment (Mohammad Kabat) [2049449]
- net/mlx5: Add layout to support default timeouts register (Mohammad Kabat) [2049449]
- ethernet: constify references to netdev->dev_addr in drivers (Mohammad Kabat) [2049449]
- RDMA/mlx5: Add optional counter support in get_hw_stats callback (Mohammad Kabat) [2049449]
- RDMA/mlx5: Add modify_op_stat() support (Mohammad Kabat) [2049449]
- RDMA/mlx5: Add steering support in optional flow counters (Mohammad Kabat) [2049449]
- RDMA/mlx5: Support optional counters in hw_stats initialization (Mohammad Kabat) [2049449]
- ethernet: Remove redundant 'flush_workqueue()' calls (Mohammad Kabat) [2049449]
- net/mlx5: Add priorities for counters in RDMA namespaces (Mohammad Kabat) [2049449]
- net/mlx5: Add ifc bits to support optional counters (Mohammad Kabat) [2049449]
- net/mlx5: Enable single IRQ for PCI Function (Mohammad Kabat) [2049449]
- net/mlx5: Shift control IRQ to the last index (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, pop VLAN on egress table miss (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, mark reg_c1 when pushing VLAN (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, extract VLAN pop code to dedicated functions (Mohammad Kabat) [2049449]
- net/mlx5: Bridge, refactor eswitch instance usage (Mohammad Kabat) [2049449]
- net/mlx5e: Support accept action (Mohammad Kabat) [2049449]
- net/mlx5e: Specify out ifindex when looking up encap route (Mohammad Kabat) [2049449]
- net/mlx5e: Reserve a value from TC tunnel options mapping (Mohammad Kabat) [2049449]
- net/mlx5e: Move parse fdb check into actions_match_supported_fdb() (Mohammad Kabat) [2049449]
- net/mlx5e: Split actions_match_supported() into a sub function (Mohammad Kabat) [2049449]
- net/mlx5e: Move mod hdr allocation to a single place (Mohammad Kabat) [2049449]
- net/mlx5e: TC, Refactor sample offload error flow (Mohammad Kabat) [2049449]
- net/mlx5e: Add TX max rate support for MQPRIO channel mode (Mohammad Kabat) [2049449]
- net/mlx5e: Specify SQ stats struct for mlx5e_open_txqsq() (Mohammad Kabat) [2049449]
- RDMA/mlx5: Avoid taking MRs from larger MR cache pools when a pool is empty (Mohammad Kabat) [2049449]
- IB/mlx5: Flow through a more detailed return code from get_prefetchable_mr() (Mohammad Kabat) [2049449]
- net/mlx5e: Use array_size() helper (Mohammad Kabat) [2049449]
- net/mlx5: Use struct_size() helper in kvzalloc() (Mohammad Kabat) [2049449]
- net/mlx5: Use kvcalloc() instead of kvzalloc() (Mohammad Kabat) [2049449]
- net/mlx5: Tolerate failures in debug features while driver load (Mohammad Kabat) [2049449]
- net/mlx5: Warn for devlink reload when there are VFs alive (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add missing string for action type SAMPLER (Mohammad Kabat) [2049449]
- net/mlx5: DR, init_next_match only if needed (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix typo 'offeset' to 'offset' (Mohammad Kabat) [2049449]
- net/mlx5: DR, Increase supported num of actions to 32 (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add support for SF vports (Mohammad Kabat) [2049449]
- net/mlx5: DR, Support csum recalculation flow table on SFs (Mohammad Kabat) [2049449]
- net/mlx5: DR, Align error messages for failure to obtain vport caps (Mohammad Kabat) [2049449]
- net/mlx5: DR, Add missing query for vport 0 (Mohammad Kabat) [2049449]
- net/mlx5: DR, Replace local WIRE_PORT macro with the existing MLX5_VPORT_UPLINK (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix vport number data type to u16 (Mohammad Kabat) [2049449]
- IB/mlx5: Enable UAR to have DevX UID (Mohammad Kabat) [2049449]
- net/mlx5: Add uid field to UAR allocation structures (Mohammad Kabat) [2049449]
- net/mlx5e: check return value of rhashtable_init (Mohammad Kabat) [2049449]
- net/mlx5e: Enable TC offload for ingress MACVLAN (Mohammad Kabat) [2049449]
- net/mlx5e: Enable TC offload for egress MACVLAN (Mohammad Kabat) [2049449]
- net/mlx5e: loopback test is not supported in switchdev mode (Mohammad Kabat) [2049449]
- net/mlx5e: Use NL_SET_ERR_MSG_MOD() for errors parsing tunnel attributes (Mohammad Kabat) [2049449]
- net/mlx5e: Use tc sample stubs instead of ifdefs in source file (Mohammad Kabat) [2049449]
- net/mlx5e: Remove redundant priv arg from parse_pedit_to_reformat() (Mohammad Kabat) [2049449]
- net/mlx5e: Check action fwd/drop flag exists also for nic flows (Mohammad Kabat) [2049449]
- net/mlx5e: Set action fwd flag when parsing tc action goto (Mohammad Kabat) [2049449]
- net/mlx5e: Remove incorrect addition of action fwd flag (Mohammad Kabat) [2049449]
- net/mlx5e: Use correct return type (Mohammad Kabat) [2049449]
- net/mlx5e: Add error flow for ethtool -X command (Mohammad Kabat) [2049449]
- net/mlx5: DR, Fix code indentation in dr_ste_v1 (Mohammad Kabat) [2049449]
- net/mlx5e: IPsec: Fix work queue entry ethernet segment checksum flags (Mohammad Kabat) [2049447]
- net/mlx5e: IPsec: Fix a misuse of the software parser's fields (Mohammad Kabat) [2049447]
- net/mlx5e: Fix vlan data lost during suspend flow (Mohammad Kabat) [2049447]
- net/mlx5: E-switch, Return correct error code on group creation failure (Mohammad Kabat) [2049447]
- net/mlx5: Lag, change multipath and bonding to be mutually exclusive (Mohammad Kabat) [2049447]
- RDMA/mlx5: Initialize the ODP xarray when creating an ODP MR (Mohammad Kabat) [2049447]
- net/mlx5e: Fix division by 0 in mlx5e_select_queue for representors (Mohammad Kabat) [2049447]
- net/mlx5e: Mutually exclude RX-FCS and RX-port-timestamp (Mohammad Kabat) [2049447]
- net/mlx5e: Switchdev representors are not vlan challenged (Mohammad Kabat) [2049447]
- net/mlx5e: Fix memory leak in mlx5_core_destroy_cq() error path (Mohammad Kabat) [2049447]
- net/mlx5e: Allow only complete TXQs partition in MQPRIO channel mode (Mohammad Kabat) [2049447]
- net/mlx5: Fix cleanup of bridge delayed work (Mohammad Kabat) [2049447]
- RDMA/mlx5: Set user priority for DCT (Mohammad Kabat) [2049447]
- net/mlx5e: Mutually exclude setting of TX-port-TS and MQPRIO in channel mode (Mohammad Kabat) [2049447]
- net/mlx5e: Fix the presented RQ index in PTP stats (Mohammad Kabat) [2049447]
- net/mlx5: Fix setting number of EQs of SFs (Mohammad Kabat) [2049447]
- net/mlx5: Fix length of irq_index in chars (Mohammad Kabat) [2049447]
- net/mlx5: Avoid generating event after PPS out in Real time mode (Mohammad Kabat) [2049447]
- net/mlx5: Force round second at 1PPS out start time (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, Fix double allocation of acl flow counter (Mohammad Kabat) [2049447]
- net/mlx5e: Improve MQPRIO resiliency (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Keep the value for maximum number of channels in-sync (Mohammad Kabat) [2049447]
- net/mlx5e: IPSEC RX, enable checksum complete (Mohammad Kabat) [2049447]
- net/{mlx5|nfp|bnxt}: Remove unnecessary RTNL lock assert (Mohammad Kabat) [2049447]
- RDMA/mlx5: Fix xlt_chunk_align calculation (Mohammad Kabat) [2049447]
- net/mlx5e: Fix condition when retrieving PTP-rqn (Mohammad Kabat) [2049447]
- net/mlx5e: Fix mutual exclusion between CQE compression and HW TS (Mohammad Kabat) [2049447]
- net/mlx5: Fix potential sleeping in atomic context (Mohammad Kabat) [2049447]
- net/mlx5: FWTrace, cancel work on alloc pd error flow (Mohammad Kabat) [2049447]
- net/mlx5: Lag, don't update lag if lag isn't supported (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, fix uninitialized variable usage (Mohammad Kabat) [2049447]
- RDMA/mlx5: Relax DCS QP creation checks (Mohammad Kabat) [2049447]
- net/mlx5: DR, Add support for update FTE (Mohammad Kabat) [2049447]
- net/mlx5: DR, Improve rule tracking memory consumption (Mohammad Kabat) [2049447]
- net/mlx5: DR, Remove rehash ctrl struct from dr_htbl (Mohammad Kabat) [2049447]
- net/mlx5: DR, Remove HW specific STE type from nic domain (Mohammad Kabat) [2049447]
- net/mlx5: DR, Merge DR_STE_SIZE enums (Mohammad Kabat) [2049447]
- net/mlx5: DR, Skip source port matching on FDB RX domain (Mohammad Kabat) [2049447]
- net/mlx5: DR, Add ignore_flow_level support for multi-dest flow tables (Mohammad Kabat) [2049447]
- net/mlx5: DR, Use FW API when updating FW-owned flow table (Mohammad Kabat) [2049447]
- net/mlx5: DR, replace uintN_t with kernel-style types (Mohammad Kabat) [2049447]
- net/mlx5: DR, Support IPv6 matching on flow label for STEv0 (Mohammad Kabat) [2049447]
- net/mlx5: DR, Reduce print level for FT chaining level check (Mohammad Kabat) [2049447]
- net/mlx5: DR, Warn and ignore SW steering rule insertion on QP err (Mohammad Kabat) [2049447]
- net/mlx5: DR, Improve error flow in actions_build_ste_arr (Mohammad Kabat) [2049447]
- net/mlx5: DR, Enable QP retransmission (Mohammad Kabat) [2049447]
- net/mlx5: DR, Enable VLAN pop on TX and VLAN push on RX (Mohammad Kabat) [2049447]
- net/mlx5: DR, Split modify VLAN state to separate pop/push states (Mohammad Kabat) [2049447]
- net/mlx5: DR, Added support for REMOVE_HEADER packet reformat (Mohammad Kabat) [2049447]
- net/mlx5: DR, fix a potential use-after-free bug (Mohammad Kabat) [2049447]
- net/mlx5e: Use correct eswitch for stack devices with lag (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, Set vhca id valid flag when creating indir fwd group (Mohammad Kabat) [2049447]
- net/mlx5e: Fix possible use-after-free deleting fdb rule (Mohammad Kabat) [2049447]
- net/mlx5: Remove all auxiliary devices at the unregister event (Mohammad Kabat) [2049447]
- net/mlx5: Lag, fix multipath lag activation (Mohammad Kabat) [2049447]
- net/mellanox: switch from 'pci_' to 'dma_' API (Mohammad Kabat) [2049447]
- net/mlx5: E-switch, Add QoS tracepoints (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Allow to add vports to rate groups (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Allow setting share/max tx rate limits of rate groups (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Introduce rate limiting groups API (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Enable devlink port tx_{share|max} rate control (Mohammad Kabat) [2049447 2049610]
- net/mlx5: E-switch, Move QoS related code to dedicated file (Mohammad Kabat) [2049447 2049610]
- net/mlx5e: TC, Support sample offload action for tunneled traffic (Mohammad Kabat) [2049447]
- net/mlx5e: TC, Restore tunnel info for sample offload (Mohammad Kabat) [2049447]
- net/mlx5e: TC, Remove CONFIG_NET_TC_SKB_EXT dependency when restoring tunnel (Mohammad Kabat) [2049447]
- net/mlx5e: Refactor ct to use post action infrastructure (Mohammad Kabat) [2049447]
- net/mlx5e: Introduce post action infrastructure (Mohammad Kabat) [2049447]
- net/mlx5e: CT, Use xarray to manage fte ids (Mohammad Kabat) [2049447]
- net/mlx5e: Move sample attribute to flow attribute (Mohammad Kabat) [2049447]
- net/mlx5e: Move esw/sample to en/tc/sample (Mohammad Kabat) [2049447]
- net/mlx5e: Remove mlx5e dependency from E-Switch sample (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, support LAG (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, allow merged eswitch connectivity (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, extract FDB delete notification to function (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, identify port by vport_num+esw_owner_vhca_id pair (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, obtain core device from eswitch instead of priv (Mohammad Kabat) [2049447]
- net/mlx5: Bridge, release bridge in same function where it is taken (Mohammad Kabat) [2049447]
- net/mlx5e: Support MQPRIO channel mode (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Handle errors of netdev_set_num_tc() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Maintain MQPRIO mode parameter (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Abstract MQPRIO params (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Support flow classification into RSS contexts (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Support multiple RSS contexts (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Dynamically allocate TIRs in RSS contexts (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Convert RSS to a dedicated object (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Introduce abstraction of RSS context (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Introduce TIR create/destroy API in rx_res (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Do not try enable RSS when resetting indir table (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Make use of netdev_warn() (Mohammad Kabat) [2049447]
- net/mlx5: Fix variable type to match 64bit (Mohammad Kabat) [2049447]
- net/mlx5: Initialize numa node for all core devices (Mohammad Kabat) [2049447]
- net/mlx5: Allocate individual capability (Mohammad Kabat) [2049447]
- net/mlx5: Reorganize current and maximal capabilities to be per-type (Mohammad Kabat) [2049447]
- net/mlx5: SF, use recent sysfs api (Mohammad Kabat) [2049447]
- net/mlx5: Refcount mlx5_irq with integer (Mohammad Kabat) [2049447]
- net/mlx5: Change SF missing dedicated MSI-X err message to dbg (Mohammad Kabat) [2049447]
- net/mlx5: Align mlx5_irq structure (Mohammad Kabat) [2049447]
- net/mlx5: Delete impossible dev->state checks (Mohammad Kabat) [2049447]
- net/mlx5: Fix inner TTC table creation (Mohammad Kabat) [2049447]
- net/mlx5: Fix typo in comments (Mohammad Kabat) [2049447]
- net/mlx5: Lag, Create shared FDB when in switchdev mode (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, add logic to enable shared FDB (Mohammad Kabat) [2049447]
- net/mlx5: Lag, move lag destruction to a workqueue (Mohammad Kabat) [2049447]
- net/mlx5: Lag, properly lock eswitch if needed (Mohammad Kabat) [2049447]
- net/mlx5: Add send to vport rules on paired device (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, Add event callback for representors (Mohammad Kabat) [2049447]
- net/mlx5e: Use shared mappings for restoring from metadata (Mohammad Kabat) [2049447]
- net/mlx5e: Add an option to create a shared mapping (Mohammad Kabat) [2049447]
- net/mlx5: E-Switch, set flow source for send to uplink rule (Mohammad Kabat) [2049447]
- RDMA/mlx5: Add shared FDB support (Mohammad Kabat) [2049447]
- {net, RDMA}/mlx5: Extend send to vport rules (Mohammad Kabat) [2049447]
- RDMA/mlx5: Fill port info based on the relevant eswitch (Mohammad Kabat) [2049447]
- net/mlx5: Lag, add initial logic for shared FDB (Mohammad Kabat) [2049447]
- net/mlx5: Return mdev from eswitch (Mohammad Kabat) [2049447]
- RDMA/mlx5: Delete not-available udata check (Mohammad Kabat) [2049447]
- RDMA/mlx5: Drop in-driver verbs object creations (Mohammad Kabat) [2049447]
- RDMA/mlx5: Delete device resource mutex that didn't protect anything (Mohammad Kabat) [2049447]
- RDMA/mlx5: Cancel pkey work before destroying device resources (Mohammad Kabat) [2049447]
- net/mlx5: Fix missing return value in mlx5_devlink_eswitch_inline_mode_set() (Mohammad Kabat) [2049447]
- net/mlx5e: Return -EOPNOTSUPP if more relevant when parsing tc actions (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant assignment of counter to null (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant parse_attr arg (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant cap check for flow counter (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant filter_dev arg from parse_tc_fdb_actions() (Mohammad Kabat) [2049447]
- net/mlx5e: Remove redundant tc act includes (Mohammad Kabat) [2049447]
- net/mlx5: Embed mlx5_ttc_table (Mohammad Kabat) [2049447 2049891]
- net/mlx5: Move TTC logic to fs_ttc (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Decouple TTC logic from mlx5e (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Rename some related TTC args and functions (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Rename traffic type enums (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Allocate the array of channels according to the real max_nch (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Hide all implementation details of mlx5e_rx_res (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Introduce mlx5e_channels API to get RQNs (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Use a new initializer to build uniform indir table (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Use the new TIR API for kTLS (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Move management of indir traffic types to rx_res (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Convert TIR to a dedicated object (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Create struct mlx5e_rss_params_hash (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Remove mdev from mlx5e_build_indir_tir_ctx_common() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Remove lro_param from mlx5e_build_indir_tir_ctx_common() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Remove mlx5e_priv usage from mlx5e_build_*tir_ctx*() (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Use mlx5e_rqt_get_rqtn to access RQT hardware id (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Take RQT out of TIR and group RX resources (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Move RX resources to a separate struct (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Move mlx5e_build_rss_params() call to init_rx (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Convert RQT to a dedicated object (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Check if inner FT is supported outside of create/destroy functions (Mohammad Kabat) [2049447 2049891]
- net/mlx5: Take TIR destruction out of the TIR list lock (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Block LRO if firmware asks for tunneled LRO (Mohammad Kabat) [2049447 2049891]
- net/mlx5e: Prohibit inner indir TIRs in IPoIB (Mohammad Kabat) [2049447 2049891]
- IB/mlx5: Rename is_apu_thread_cq function to is_apu_cq (Mohammad Kabat) [2049447]
- RDMA/mlx5: Add DCS offload support (Mohammad Kabat) [2049447]
- RDMA/mlx5: Separate DCI QP creation logic (Mohammad Kabat) [2049447]
- net/mlx5: Add DCS caps & fields support (Mohammad Kabat) [2049447]

* Mon Aug 22 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-151.rt21.151.el9]
- [rt] build kernel-rt-5.14.0-151.rt21.151.el9 [2061574]
- crypto: ccp - Fix device IRQ counting by using platform_irq_count() (Al Stone) [2071840]
- amd-xgbe: Use platform_irq_count() (Al Stone) [2071840]
- MAINTAINERS: adjust file entry for of_net.c after (Al Stone) [2071840]
- rhel: CONFIG_OPEN_DICE is not set (Al Stone) [2071840]
- of/irq: fix typo in comment (Al Stone) [2071840]
- powerpc/powermac: constify device_node in of_irq_parse_oldworld() (Al Stone) [2071840]
- of/fdt: Ignore disabled memory nodes (Al Stone) [2071840]
- of: overlay: do not free changeset when of_overlay_apply returns error (Al Stone) [2071840]
- of: overlay: unittest: add tests for overlay notifiers (Al Stone) [2071840]
- of: overlay: add entry to of_overlay_action_name[] (Al Stone) [2071840]
- of: overlay: rework overlay apply and remove kfree()s (Al Stone) [2071840]
- of: overlay: rename variables to be consistent (Al Stone) [2071840]
- of: overlay: do not break notify on NOTIFY_{OK|STOP} (Al Stone) [2071840]
- mtd: phram: Allow probing via reserved-memory (Al Stone) [2071840]
- of: Create platform devices for OF framebuffers (Al Stone) [2071840]
- of: of_property_read_string return -ENODATA when !length (Al Stone) [2071840]
- of/irq: Use interrupts-extended to find parent (Al Stone) [2071840]
- device property: Convert device_{dma_supported,get_dma_attr} to fwnode (Al Stone) [2071840]
- of/platform: Drop static setup of IRQ resource from DT core (Al Stone) [2071840]
- cma: factor out minimum alignment requirement (Al Stone) [2071840]
- Revert "of: base: Introduce of_alias_get_alias_list() to check alias IDs" (Al Stone) [2071840]
- of: unittest: print pass messages at PR_INFO level (Al Stone) [2071840]
- misc: open-dice: Add driver to expose DICE data to userspace (Al Stone) [2071840]
- of: unittest: update text of expected warnings (Al Stone) [2071840]
- of: Check 'of_node_reused' flag on of_match_device() (Al Stone) [2071840]
- of: property: define of_property_read_u{8,16,32,64}_array() unconditionally (Al Stone) [2071840]
- of: base: make small of_parse_phandle() variants static inline (Al Stone) [2071840]
- mm: kmemleak: alloc gray object for reserved region with direct map (Al Stone) [2071840]
- of: unittest: remove unneeded semicolon (Al Stone) [2071840]
- of: base: Improve argument length mismatch error (Al Stone) [2071840]
- of: base: Fix phandle argument length mismatch error message (Al Stone) [2071840]
- of: unittest: re-implement overlay tracking (Al Stone) [2071840]
- of: unittest: change references to obsolete overlay id (Al Stone) [2071840]
- of: Move simple-framebuffer device handling from simplefb to of (Al Stone) [2071840]
- of: unittest: 64 bit dma address test requires arch support (Al Stone) [2071840]
- of: unittest: fix warning on PowerPC frame size warning (Al Stone) [2071840]
- of/irq: Add a quirk for controllers with their own definition of interrupt-map (Al Stone) [2071840]
- of: base: Skip CPU nodes with "fail"/"fail-..." status (Al Stone) [2071840]
- of: property: fw_devlink: Fixup behaviour when 'node_not_dev' is set (Al Stone) [2071840]
- of/irq: Don't ignore interrupt-controller when interrupt-map failed (Al Stone) [2071840]
- of: Support using 'mask' in making device bus id (Al Stone) [2071840]
- memblock: use memblock_free for freeing virtual pointers (Al Stone) [2071840]
- memblock: rename memblock_free to memblock_phys_free (Al Stone) [2071840]
- xen/x86: free_p2m_page: use memblock_free_ptr() to free a virtual pointer (Al Stone) [2071840]
- memblock: drop memblock_free_early_nid() and memblock_free_early() (Al Stone) [2071840]
- of/irq: Allow matching of an interrupt-map local to an interrupt controller (Al Stone) [2071840]
- of: unittest: document intentional interrupt-map provider build warning (Al Stone) [2071840]
- of: unittest: fix EXPECT text for gpio hog errors (Al Stone) [2071840]
- of/unittest: Disable new dtc node_name_vs_property_name and interrupt_map warnings (Al Stone) [2071840]
- x86/of: Kill unused early_init_dt_scan_chosen_arch() (Al Stone) [2071840]
- of/unittest: Add of_node_put() before return (Al Stone) [2071840]
- of: make of_node_check_flag() device_node parameter const (Al Stone) [2071840]
- of: kobj: make of_node_is_(initialized|attached) parameters const (Al Stone) [2071840]
- of: Add of_get_cpu_hwid() to read hardware ID from CPU nodes (Al Stone) [2071840]
- ARM: 9119/1: amba: Properly handle device probe without IRQ domain (Al Stone) [2071840]
- ARM: 9120/1: Revert "amba: make use of -1 IRQs warn" (Al Stone) [2071840]
- soc: qcom: smem: Support reserved-memory description (Al Stone) [2071840]
- net: of: fix stub of_net helpers for CONFIG_NET=n (Al Stone) [2071840]
- of: net: add a helper for loading netdev->dev_addr (Al Stone) [2071840]
- of: net: move of_net under net/ (Al Stone) [2071840]
- of: remove duplicate declarations of __of_*_sysfs() functions (Al Stone) [2071840]
- fbdev: simplefb: fix Kconfig dependencies (Al Stone) [2071840]
- of, numa: Fetch empty NUMA node ID from distance map (Al Stone) [2071840]
- of: restricted dma: Fix condition for rmem init (Al Stone) [2071840]
- of: property: Disable fw_devlink DT support for X86 (Al Stone) [2071840]
- of: Don't allow __of_attached_node_sysfs() without CONFIG_SYSFS (Al Stone) [2071840]
- of: restricted dma: Don't fail device probe on rmem init failure (Al Stone) [2071840]
- of: Move of_dma_set_restricted_buffer() into device.c (Al Stone) [2071840]
- of: property: fw_devlink: Add support for "leds" and "backlight" (Al Stone) [2071840]
- of: property: fw_devlink: Add support for "resets" and "pwms" (Al Stone) [2071840]
- gpiolib: constify passed device_node pointer (Al Stone) [2071840]
- of: unify of_count_phandle_with_args() arguments with !CONFIG_OF (Al Stone) [2071840]
- of: Return success from of_dma_set_restricted_buffer() when !OF_ADDRESS (Al Stone) [2071840]
- of: kexec: Remove FDT_PROP_* definitions (Al Stone) [2071840]
- of: base: remove unnecessary for loop (Al Stone) [2071840]
- of: Add plumbing for restricted DMA pool (Al Stone) [2071840]
- of: Add stub for of_add_property() (Al Stone) [2071840]

* Sat Aug 20 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-150.rt21.150.el9]
- [rt] build kernel-rt-5.14.0-150.rt21.150.el9 [2061574]
- CI: Switch to c9s container image on quay.io (Michael Hofmann)
- KVM: x86: nSVM: implement nested LBR virtualization (Emanuele Giuseppe Esposito) [2079722]
- KVM: x86: nSVM: correctly virtualize LBR msrs when L2 is running (Emanuele Giuseppe Esposito) [2079722]
- kvm: x86: SVM: use vmcb* instead of svm->vmcb where it makes sense (Emanuele Giuseppe Esposito) [2079722]
- KVM: x86: nSVM: implement nested VMLOAD/VMSAVE (Emanuele Giuseppe Esposito) [2079722]
- nfs: only issue commit in DIO codepath if we have uncommitted data (Jeffrey Layton) [2028370]
- nfs: always check dreq->error after a commit (Jeffrey Layton) [2028370]
- nfs: add new nfs_direct_req tracepoint events (Jeffrey Layton) [2028370]
- nfsd: eliminate the NFSD_FILE_BREAK_* flags (Jeffrey Layton) [2107360]
- NFSD: Clean up the show_nf_flags() macro (Jeffrey Layton) [2107360]
- vmxnet3: do not reschedule napi for rx processing (Kamal Heib) [2115062]
- Revert "ACPI: APEI: explicit init of HEST and GHES in apci_init()" (Mark Langsdorf) [2115261]
- Revert "ACPI: APEI: rename ghes_init() with an "acpi_" prefix" (Mark Langsdorf) [2115261]
- KVM: selftests: Disable rseq_test for all architectures (Gavin Shan) [2116654]
- mm: Fix CVE-2022-2590 by reverting "mm/shmem: unconditionally set pte dirty in mfill_atomic_install_pte" (David Hildenbrand) [2116179] {CVE-2022-2590}
- scsi: megaraid: Clear READ queue map's nr_queues (Tomas Henzl) [2103830]
- SUNRPC release the transport of a relocated task with an assigned transport (Scott Mayhew) [2069732]
- SUNRPC don't resend a task on an offlined transport (Scott Mayhew) [2069732]
- Documentation: Describe net.ipv4.tcp_reflect_tos. (Guillaume Nault) [2070198]
- drm/amd/display: Fix new dmub notification enabling in DM (Mika Penttilä) [2107633]
- sfc: fix kernel panic when creating VF (Íñigo Huguet) [2104536]
- netdevsim: don't overwrite read only ethtool parms (Petr Oros) [2112332]
- netdevsim: fix uninit value in nsim_drv_configure_vfs() (Petr Oros) [2112332]
- netdevsim: rename 'driver' entry points (Petr Oros) [2112332]
- netdevsim: move max vf config to dev (Petr Oros) [2112332]
- netdevsim: move details of vf config to dev (Petr Oros) [2112332]
- netdevsim: move vfconfig to nsim_dev (Petr Oros) [2112332]
- netdevsim: take rtnl_lock when assigning num_vfs (Petr Oros) [2112332]
- netdevsim: remove max_vfs dentry (Petr Oros) [2112332]
- netdevsim: make array res_ids static const, makes object smaller (Petr Oros) [2112332]
- CI: Add automotive checks (Veronika Kabatova)
- fs: dlm: fix build with CONFIG_IPV6 disabled (Alexander Aring) [2026474]
- fs: dlm: don't call kernel_getpeername() in error_report() (Alexander Aring) [2026474]
- fs: dlm: use sk->sk_socket instead of con->sock (Alexander Aring) [2026474]

* Sat Aug 20 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-149.rt21.149.el9]
- [rt] build kernel-rt-5.14.0-149.rt21.149.el9 [2061574]
- netfilter: h323: merge nat hook pointers into one (Florian Westphal) [2111270]
- netfilter: nf_conntrack: use rcu accessors where needed (Florian Westphal) [2111270]
- netfilter: nf_conntrack: add missing __rcu annotations (Florian Westphal) [2111270]
- netfilter: conntrack: use correct format characters (Florian Westphal) [2111270]
- netfilter: conntrack: use fallthrough to cleanup (Florian Westphal) [2111270]
- netfilter: ctnetlink: fix up for "netfilter: conntrack: remove unconfirmed list" (Florian Westphal) [2111270]
- netfilter: cttimeout: fix slab-out-of-bounds read typo in cttimeout_net_exit (Florian Westphal) [2111270]
- netfilter: cttimeout: fix slab-out-of-bounds read in cttimeout_net_exit (Florian Westphal) [2111270]
- netfilter: nfnetlink: fix warn in nfnetlink_unbind (Florian Westphal) [2111270]
- netfilter: conntrack: remove pr_debug callsites from tcp tracker (Florian Westphal) [2111270]
- netfilter: prefer extension check to pointer check (Florian Westphal) [2111270]
- netfilter: conntrack: add nf_conntrack_events autodetect mode (Florian Westphal) [2111270]
- netfilter: conntrack: un-inline nf_ct_ecache_ext_add (Florian Westphal) [2111270]
- netfilter: conntrack: add nf_ct_iter_data object for nf_ct_iterate_cleanup*() (Florian Westphal) [2111270]
- netfilter: nfnetlink: allow to detect if ctnetlink listeners exist (Florian Westphal) [2111270]
- netfilter: conntrack: avoid unconditional local_bh_disable (Florian Westphal) [2111270]
- netfilter: conntrack: remove unconfirmed list (Florian Westphal) [2111270]
- netfilter: conntrack: remove __nf_ct_unconfirmed_destroy (Florian Westphal) [2111270]
- netfilter: cttimeout: decouple unlink and free on netns destruction (Florian Westphal) [2111270]
- netfilter: extensions: introduce extension genid count (Florian Westphal) [2111270]
- netfilter: remove nf_ct_unconfirmed_destroy helper (Florian Westphal) [2111270]
- netfilter: cttimeout: decouple unlink and free on netns destruction (Florian Westphal) [2111270]
- netfilter: conntrack: remove the percpu dying list (Florian Westphal) [2111270]
- netfilter: conntrack: include ecache dying list in dumps (Florian Westphal) [2111270]
- netfilter: ecache: use dedicated list for event redelivery (Florian Westphal) [2111270]
- netfilter: conntrack: split inner loop of list dumping to own function (Florian Westphal) [2111270]
- netfilter: ctnetlink: remove useless type conversion to bool (Florian Westphal) [2111270]
- netfilter: ecache: move to separate structure (Florian Westphal) [2111270]
- netfilter: ctnetlink: use dump structure instead of raw args (Florian Westphal) [2111270]
- netfilter: cttimeout: use option structure (Florian Westphal) [2111270]
- netfilter: ecache: don't use nf_conn spinlock (Florian Westphal) [2111270]
- netfilter: ecache: remove nf_exp_event_notifier structure (Florian Westphal) [2111270]
- netfilter: ecache: prepare for event notifier merge (Florian Westphal) [2111270]
- netfilter: ecache: add common helper for nf_conntrack_eventmask_report (Florian Westphal) [2111270]
- netfilter: ecache: remove another indent level (Florian Westphal) [2111270]
- netfilter: ecache: remove one indent level (Florian Westphal) [2111270]
- netfilter: conntrack: pptp: use single option structure (Florian Westphal) [2111270]
- netfilter: conntrack: don't refresh sctp entries in closed state (Florian Westphal) [2111270]
- netfilter: conntrack: revisit gc autotuning (Florian Westphal) [2111270]
- netfilter: nf_conntrack_netbios_ns: fix helper module alias (Florian Westphal) [2111270]
- netfilter: conntrack: Remove useless assignment statements (Florian Westphal) [2111270]
- netfilter: conntrack: Use memset_startat() to zero struct nf_conn (Florian Westphal) [2111270]
- netfilter: ctnetlink: missing counters and timestamp in nfnetlink_{log,queue} (Florian Westphal) [2111270]
- netfilter: ctnetlink: allow to filter dump by status bits (Florian Westphal) [2111270]
- netfilter: ctnetlink: add and use a helper for mark parsing (Florian Westphal) [2111270]
- netfilter: ctnetlink: remove expired entries first (Florian Westphal) [2111270]
- net: align static siphash keys (Florian Westphal) [2111270]

* Fri Aug 19 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-148.rt21.148.el9]
- [rt] build kernel-rt-5.14.0-148.rt21.148.el9 [2061574]
- arm64/sve: update sve_state variable (Scott Weaver) [2104174]
- lockdown: also lock down previous kgdb use (Lenny Szubowicz) [2104751] {CVE-2022-21499}
- perf build: Stop using __weak bpf_object__next_map() to handle older libbpf versions (Michael Petlan) [2102240]
- perf build: Stop using __weak bpf_object__next_program() to handle older libbpf versions (Michael Petlan) [2102240]
- scsi: qla2xxx: Fix erroneous mailbox timeout after PCI error injection (Nilesh Javali) [2106623]
- vhost-vdpa: call vhost_vdpa_cleanup during the release (Eugenio Pérez) [1939367]
- vdpasim: Off by one in vdpasim_set_group_asid() (Eugenio Pérez) [1939367]
- vdpasim: allow to enable a vq repeatedly (Eugenio Pérez) [1939367]
- vdpasim: control virtqueue support (Eugenio Pérez) [1939367]
- vdpa_sim: filter destination mac address (Eugenio Pérez) [1939367]
- vdpa_sim: factor out buffer completion logic (Eugenio Pérez) [1939367]
- vdpa_sim: advertise VIRTIO_NET_F_MTU (Eugenio Pérez) [1939367]
- vhost-vdpa: support ASID based IOTLB API (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce uAPI to set group ASID (Eugenio Pérez) [1939367]
- vhost-vdpa: uAPI to get virtqueue group id (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce uAPI to get the number of address spaces (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce uAPI to get the number of virtqueue groups (Eugenio Pérez) [1939367]
- vhost-vdpa: introduce asid based IOTLB (Eugenio Pérez) [1939367]
- vhost: support ASID in IOTLB API (Eugenio Pérez) [1939367]
- vhost_iotlb: split out IOTLB initialization (Eugenio Pérez) [1939367]
- vdpa: introduce config operations for associating ASID to a virtqueue group (Eugenio Pérez) [1939367]
- vdpa: multiple address spaces support (Eugenio Pérez) [1939367]
- vdpa: introduce virtqueue groups (Eugenio Pérez) [1939367]
- vhost-vdpa: switch to use vhost-vdpa specific IOTLB (Eugenio Pérez) [1939367]
- vhost-vdpa: passing iotlb to IOMMU mapping helpers (Eugenio Pérez) [1939367]
- virtio-vdpa: don't set callback if virtio doesn't need it (Eugenio Pérez) [1939367]
- vhost: move the backend feature bits to vhost_types.h (Eugenio Pérez) [1939367]
- fs: dlm: change posix lock sigint handling (Alexander Aring) [2088518]
- fs: dlm: use dlm_plock_info for do_unlock_close (Alexander Aring) [2088518]
- fs: dlm: change plock interrupted message to debug again (Alexander Aring) [2088518]
- fs: dlm: add pid to debug log (Alexander Aring) [2088518]
- fs: dlm: plock use list_first_entry (Alexander Aring) [2088518]
- dlm: replace usage of found with dedicated list iterator variable (Alexander Aring) [2088518]
- dlm: move global to static inits (Alexander Aring) [2088518]
- dlm: remove unnecessary INIT_LIST_HEAD() (Alexander Aring) [2088518]
- dlm: improve plock logging if interrupted (Alexander Aring) [2088518]
- dlm: rearrange async condition return (Alexander Aring) [2088518]
- dlm: cleanup plock_op vs plock_xop (Alexander Aring) [2088518]
- dlm: replace sanity checks with WARN_ON (Alexander Aring) [2088518]
- fs: dlm: make dlm_callback_resume quite (Alexander Aring) [2009423]

* Thu Aug 18 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-147.rt21.147.el9]
- [rt] build kernel-rt-5.14.0-147.rt21.147.el9 [2061574]
- RedHat: ASoC: SOF: Intel: do not enable IMR boot when resuming by default (Jaroslav Kysela) [2065578]
- ASoC: SOF: make ctx_store and ctx_restore as optional (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Prevent double freeing of ipc_control_data via load_bytes (Jaroslav Kysela) [2065578]
- ASoC: imx-hdmi: Fix refcount leak in imx_hdmi_probe (Jaroslav Kysela) [2065578]
- ASoC: mediatek: Fix error handling in mt8173_max98090_dev_probe (Jaroslav Kysela) [2065578]
- ASoC: amd: Add support for enabling DMIC on acp6x via _DSD (Jaroslav Kysela) [2065578]
- soundwire: intel: prevent pm_runtime resume prior to system suspend (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirk for Fiero SC-01 (fw v1.0.0) (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirk for Fiero SC-01 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirks for MacroSilicon MS2100/MS2106 devices (Jaroslav Kysela) [2065578]
- ASoC: cs47l15: Fix event generation for low power mux control (Jaroslav Kysela) [2065578]
- ASoC: cs35l41: Add ASP TX3/4 source to register patch (Jaroslav Kysela) [2065578]
- ASoC: dapm: Initialise kcontrol data for mux/demux controls (Jaroslav Kysela) [2065578]
- ASoC: rt711-sdca: fix kernel NULL pointer dereference when IO error (Jaroslav Kysela) [2065578]
- ASoC: cs35l41: Correct some control names (Jaroslav Kysela) [2065578]
- ASoC: wm5110: Fix DRE control (Jaroslav Kysela) [2065578]
- ASoC: wm_adsp: Fix event for preloader (Jaroslav Kysela) [2065578]
- ASoC: Intel: bytcr_wm5102: Fix GPIO related probe-ordering problem (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda-loader: Clarify the cl_dsp_init() flow (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda-loader: Make sure that the fw load sequence is followed (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda-dsp: Expose hda_dsp_core_power_up() (Jaroslav Kysela) [2065578]
- ASoC: codecs: rt700/rt711/rt711-sdca: initialize workqueues in probe (Jaroslav Kysela) [2065578]
- ASoC: rt7*-sdw: harden jack_detect_handler (Jaroslav Kysela) [2065578]
- ASoC: rt711: fix calibrate mutex initialization (Jaroslav Kysela) [2065578]
- ASoC: Intel: sof_sdw: handle errors on card registration (Jaroslav Kysela) [2065578]
- ASoC: rt711-sdca-sdw: fix calibrate mutex initialization (Jaroslav Kysela) [2065578]
- ASoC: Realtek/Maxim SoundWire codecs: disable pm_runtime on remove (Jaroslav Kysela) [2065578]
- ASoC: ops: Fix off by one in range control validation (Jaroslav Kysela) [2065578]
- ASoC: Intel: Skylake: Correct the handling of fmt_config flexible array (Jaroslav Kysela) [2065578]
- ASoC: Intel: Skylake: Correct the ssp rate discovery in skl_get_ssp_clks() (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Enable the headset-mic on a Xiaomi's laptop (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc221 (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: fix mute/micmute LEDs for HP machines (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc671 (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Fix headset mic for Acer SF313-51 (Jaroslav Kysela) [2065578]
- ALSA: hda/conexant: Apply quirk for another HP ProDesk 600 G3 model (Jaroslav Kysela) [2065578]
- ALSA: hda - Add fixup for Dell Latitidue E5430 (Jaroslav Kysela) [2065578]
- ASoC: SOF: Intel: hda: Fix compressed stream position tracking (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Move and correct size checks in sof_ipc3_control_load_bytes() (Jaroslav Kysela) [2065578]
- ASoC: codecs: rt700/rt711/rt711-sdca: resume bus/codec in .set_jack_detect (Jaroslav Kysela) [2065578]
- ASoC: rt711-sdca: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065578]
- ASoC: rt711: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065578]
- ALSA: cs46xx: Fix missing snd_card_free() call at probe error (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for Clevo L140PU (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Workarounds for Behringer UMC 204/404 HD (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for Clevo NS50PU (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for Clevo PD70PNT (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Apply fixup for Lenovo Yoga Duet 7 properly (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - ALC897 headset MIC no sound (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add mute LED quirk for HP Omen laptop (Jaroslav Kysela) [2065578]
- ALSA: hda/conexant: Fix missing beep setup (Jaroslav Kysela) [2065578]
- ALSA: hda: Fix discovery of i915 graphics PCI device (Jaroslav Kysela) [2065578]
- ALSA: hda/via: Fix missing beep setup (Jaroslav Kysela) [2065578]
- ALSA: memalloc: Drop x86-specific hack for WC allocations (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Add HW8326 support (Jaroslav Kysela) [2065578]
- ALSA: hda: MTL: add HD Audio PCI ID and HDMI codec vendor ID (Jaroslav Kysela) [2065578]
- ASoC: es8328: Fix event generation for deemphasis control (Jaroslav Kysela) [2065578]
- ASoC: cs42l51: Correct minimum value for SX volume control (Jaroslav Kysela) [2065578]
- ASoC: cs42l56: Correct typo in minimum level for SX volume controls (Jaroslav Kysela) [2065578]
- ASoC: cs42l52: Correct TLV for Bypass Volume (Jaroslav Kysela) [2065578]
- ASoC: cs53l30: Correct number of volume levels on SX controls (Jaroslav Kysela) [2065578]
- ASoC: cs35l36: Update digital volume TLV (Jaroslav Kysela) [2065578]
- ASoC: cs42l52: Fix TLV scales for mixer controls (Jaroslav Kysela) [2065578]
- ASoC: Intel: cirrus-common: fix incorrect channel mapping (Jaroslav Kysela) [2065578]
- ASoC: qcom: lpass-platform: Update VMA access permissions in mmap callback (Jaroslav Kysela) [2065578]
- ASoC: nau8822: Add operation for internal PLL off and on (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Add quirk for HP Dev One (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Fix for quirk to enable speaker output on the Lenovo Yoga DuetITL 2021 (Jaroslav Kysela) [2065578]
- ALSA: hda/conexant - Fix loopback issue with CX20632 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Set up (implicit) sync for Saffire 6 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Skip generic sync EP parse for secondary EP (Jaroslav Kysela) [2065578]
- ASoC: rt5640: Do not manipulate pin "Platform Clock" if the "Platform Clock" is not in the DAPM (Jaroslav Kysela) [2065578]
- ASoC: SOF: amd: Fixed Build error (Jaroslav Kysela) [2065578]
- ASoC: rt5514: Fix event generation for "DSP Voice Wake Up" control (Jaroslav Kysela) [2065578]
- ASoC: max98090: Move check for invalid values before casting in max98090_put_enab_tlv() (Jaroslav Kysela) [2065578]
- ALSA: pcm: Check for null pointer of pointer substream before dereferencing it (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Set scontrol->priv to NULL after freeing it (Jaroslav Kysela) [2065578]
- ASoC: cs35l41: Fix an out-of-bounds access in otp_packed_element_t (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Move generic implicit fb quirk entries into quirks.c (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add quirk bits for enabling/disabling generic implicit fb (Jaroslav Kysela) [2065578]
- ASoC: amd: Add driver data to acp6x machine driver (Jaroslav Kysela) [2065578]
- ASoC: rt1015p: remove dependency on GPIOLIB (Jaroslav Kysela) [2065578]
- ASoC: max98357a: remove dependency on GPIOLIB (Jaroslav Kysela) [2065578]
- ASoC: rt5645: Fix errorenous cleanup order (Jaroslav Kysela) [2065578]
- ASoC: SOF: amd: add missing platform_device_unregister in acp_pci_rn_probe (Jaroslav Kysela) [2065578]
- ASoC: Intel: sof_ssp_amp: fix no DMIC BE Link on Chromebooks (Jaroslav Kysela) [2065578]
- ASoC: tscs454: Add endianness flag in snd_soc_component_driver (Jaroslav Kysela) [2065578]
- ASoC: SOF: ipc3-topology: Correct get_control_data for non bytes payload (Jaroslav Kysela) [2065578]
- ASoC: dapm: Don't fold register value changes into notifications (Jaroslav Kysela) [2065578]
- ASoC: Intel: bytcr_rt5640: Add quirk for the HP Pro Tablet 408 (Jaroslav Kysela) [2065578]
- ALSA: jack: Access input_dev under mutex (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Cancel pending work at closing a MIDI substream (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Fix microphone noise on ASUS TUF B550M-PLUS (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek: Enable 4-speaker output for Dell XPS 15 9520 laptop (Jaroslav Kysela) [2065578]
- ALSA: hda/realtek - Add new type for ALC245 (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Optimize TEAC clock quirk (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Configure sync endpoints before data (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Add missing ep_idx in fixed EP quirks (Jaroslav Kysela) [2065578]
- ALSA: usb-audio: Workaround for clock setup on TEAC devices (Jaroslav Kysela) [2065578]
- ALSA: ctxfi: Add SB046x PCI ID (Jaroslav Kysela) [2065578]
- ALSA: update kernel configuration for 9.1 (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Define PLL clock inputs (Jaroslav Kysela) [2065572]
- ASoC: tlv320adc3xxx: New codec bindings (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Add the binding include file for the HDA header support (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: rename q6afe.h to q6dsp-lpass-ports.h (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: lpass: add binding headers for digital codecs (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: lpass: add binding headers for digital codecs (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: Document Microchip's PDMC (Jaroslav Kysela) [2065572]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2065572]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2065572]
- ALSA: spi: Add check for clk_enable() (Jaroslav Kysela) [2065572]
- ALSA: sparc: no need to initialise statics to 0 (Jaroslav Kysela) [2065572]
- sound: core: Remove redundant variable and return the last statement (Jaroslav Kysela) [2065572]
- sound: core: remove initialise static variables to 0 (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Add cs35l51/53 IDs (Jaroslav Kysela) [2065572]
- ALSA: ppc: beep: fix clang -Wimplicit-fallthrough (Jaroslav Kysela) [2065572]
- sound/oss/dmasound: fix 'dmasound_setup' defined but not used (Jaroslav Kysela) [2065572]
- sound/oss/dmasound: fix build when drivers are mixed =y/=m (Jaroslav Kysela) [2065572]
- ALSA: mips: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: Add RaptorLake PCI IDs (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: update AlderLake PCI IDs (Jaroslav Kysela) [2065572]
- ALSA: intel-dspconfig: add ES8336 support for CNL (Jaroslav Kysela) [2065572]
- ALSA: intel-dsp-config: add more ACPI HIDs for ES83x6 devices (Jaroslav Kysela) [2065572]
- ALSA: hda/i915 - avoid hung task timeout in i915 wait (Jaroslav Kysela) [2065572]
- ALSA: hda/i915: Fix one too many pci_dev_put() (Jaroslav Kysela) [2065572]
- ALSA: hda/i915 - skip acomp init if no matching display (Jaroslav Kysela) [2065572]
- ASoC: SOF: tokens: add token for Mediatek AFE (Jaroslav Kysela) [2065572]
- ALSA: uapi: use C90 comment style instead of C99 style (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: Add new IPC command to free trace DMA (Jaroslav Kysela) [2065572]
- ASoC: SOF: fix 32 signed bit overflow (Jaroslav Kysela) [2065572]
- ASoC: SOF: add _D3_PERSISTENT flag to fw_ready message (Jaroslav Kysela) [2065572]
- ipc: debug: Add shared memory heap to memory scan (Jaroslav Kysela) [2065572]
- ASoC: soc-acpi: add information on I2S/TDM link mask (Jaroslav Kysela) [2065572]
- ASoC: soc-acpi: fix kernel-doc descriptor (Jaroslav Kysela) [2065572]
- ALSA: pcm: comment about relation between msbits hw parameter and [S|U]32 formats (Jaroslav Kysela) [2065572]
- ALSA: hda: Add helper macros for DSP capable devices (Jaroslav Kysela) [2065572]
- ALSA: cleanup double word in comment (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Add support for hibernate memory retention mode (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Correct DSP power down (Jaroslav Kysela) [2065572]
- mfd: arizona-spi: Add Android board ACPI table handling (Jaroslav Kysela) [2065572]
- mfd: arizona: Add missing statics to the of_match_tables (Jaroslav Kysela) [2065572]
- mfd: arizona-spi: Split Windows ACPI init code into its own function (Jaroslav Kysela) [2065572]
- Documentation: sound: fix typo in control-names.rst (Jaroslav Kysela) [2065572]
- ALSA: wavefront: Proper check of get_user() error (Jaroslav Kysela) [2065572]
- ALSA: sc6000: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: galaxy: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cs4236: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2065572]
- ALSA: gus: Fix memory leaks at memory allocator error paths (Jaroslav Kysela) [2065572]
- ALSA: gus: Fix erroneous memory allocation (Jaroslav Kysela) [2065572]
- ALSA: sound/isa/gus: check the return value of kstrdup() (Jaroslav Kysela) [2065572]
- ALSA: fireworks: fix wrong return count shorter than expected by 4 bytes (Jaroslav Kysela) [2065572]
- ALSA: firewire-lib: fix uninitialized flag for AV/C deferred transaction (Jaroslav Kysela) [2065572]
- soundwire: qcom: use __maybe_unused for swrm_runtime_resume() (Jaroslav Kysela) [2065572]
- soundwire: qcom: constify static struct qcom_swrm_data global variables (Jaroslav Kysela) [2065572]
- soundwire: qcom: add in-band wake up interrupt support (Jaroslav Kysela) [2065572]
- soundwire: qcom: add runtime pm support (Jaroslav Kysela) [2065572]
- soundwire: stream: make enable/disable/deprepare idempotent (Jaroslav Kysela) [2065572]
- soundwire: stream: sdw_stream_add_ functions can be called multiple times (Jaroslav Kysela) [2065572]
- soundwire: stream: introduce sdw_slave_rt_find() helper (Jaroslav Kysela) [2065572]
- soundwire: stream: separate alloc and config within sdw_stream_add_xxx() (Jaroslav Kysela) [2065572]
- soundwire: stream: move list addition to sdw_slave_alloc_rt() (Jaroslav Kysela) [2065572]
- soundwire: stream: rename and move master/slave_rt_free routines (Jaroslav Kysela) [2065572]
- soundwire: stream: group sdw_stream_ functions (Jaroslav Kysela) [2065572]
- soundwire: stream: split sdw_alloc_slave_rt() in alloc and config (Jaroslav Kysela) [2065572]
- soundwire: stream: move sdw_alloc_slave_rt() before 'master' helpers (Jaroslav Kysela) [2065572]
- soundwire: stream: split sdw_alloc_master_rt() in alloc and config (Jaroslav Kysela) [2065572]
- soundwire: stream: simplify sdw_alloc_master_rt() (Jaroslav Kysela) [2065572]
- soundwire: stream: group sdw_port and sdw_master/slave_port functions (Jaroslav Kysela) [2065572]
- soundwire: stream: add 'slave' prefix for port range checks (Jaroslav Kysela) [2065572]
- soundwire: stream: split alloc and config in two functions (Jaroslav Kysela) [2065572]
- soundwire: stream: split port allocation and configuration loops (Jaroslav Kysela) [2065572]
- soundwire: stream: add alloc/config/free helpers for ports (Jaroslav Kysela) [2065572]
- soundwire: stream: simplify check on port range (Jaroslav Kysela) [2065572]
- soundwire: stream: add slave runtime to list earlier (Jaroslav Kysela) [2065572]
- soundwire: stream: remove unused parameter in sdw_stream_add_slave (Jaroslav Kysela) [2065572]
- soundwire: intel: fix wrong register name in intel_shim_wake (Jaroslav Kysela) [2065572]
- soundwire: bus: add dev_warn() messages to track UNATTACHED devices (Jaroslav Kysela) [2065572]
- soundwire: intel: remove PDM support (Jaroslav Kysela) [2065572]
- soundwire: intel: remove unnecessary init (Jaroslav Kysela) [2065572]
- soundwire: intel: improve suspend flows (Jaroslav Kysela) [2065572]
- soundwire: intel: Use auxiliary_device driver data helpers (Jaroslav Kysela) [2065572]
- soundwire: qcom: remove redundant version number read (Jaroslav Kysela) [2065572]
- ALSA: intel_hdmi: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: x86: Use standard mmap helper for Intel HDMI LPE audio (Jaroslav Kysela) [2065572]
- ALSA: intel_hdmi: Fix reference to PCM buffer address (Jaroslav Kysela) [2065572]
- ALSA: intel_hdmi: Check for error num after setting mask (Jaroslav Kysela) [2065572]
- ALSA: intel-nhlt: add helper to detect SSP link mask (Jaroslav Kysela) [2065572]
- ALSA: hda: Add snd_hdac_ext_bus_link_at() helper (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: reorder the config table (Jaroslav Kysela) [2065572]
- ALSA: hda: intel-dsp-config: add JasperLake support (Jaroslav Kysela) [2065572]
- ALSA: HDA: hdac_ext_stream: use consistent prefixes for variables (Jaroslav Kysela) [2065572]
- ALSA: hda: Simplify DMIC-in-NHLT check (Jaroslav Kysela) [2065572]
- ALSA: hda: Fill gaps in NHLT endpoint-interface (Jaroslav Kysela) [2065572]
- ASoC: SOF: Fix NULL pointer exception in sof_pci_probe callback (Jaroslav Kysela) [2065572]
- ASoC: ops: Validate input values in snd_soc_put_volsw_range() (Jaroslav Kysela) [2065572]
- ASoC: dmaengine: Restore NULL prepare_slave_config() callback (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: set prepare_slave_config (Jaroslav Kysela) [2065572]
- ASoC: max98090: Generate notifications on changes for custom control (Jaroslav Kysela) [2065572]
- ASoC: max98090: Reject invalid values in custom control put() (Jaroslav Kysela) [2065572]
- ASoC: rt9120: Correct the reg 0x09 size to one byte (Jaroslav Kysela) [2065572]
- ASoC: meson: axg-card: Fix nonatomic links (Jaroslav Kysela) [2065572]
- ASoC: meson: axg-tdm-interface: Fix formatters in trigger" (Jaroslav Kysela) [2065572]
- ASoC: soc-ops: fix error handling (Jaroslav Kysela) [2065572]
- ASoC: meson: Fix event generation for G12A tohdmi mux (Jaroslav Kysela) [2065572]
- ASoC: meson: Fix event generation for AUI CODEC mux (Jaroslav Kysela) [2065572]
- ASoC: meson: Fix event generation for AUI ACODEC mux (Jaroslav Kysela) [2065572]
- ASoC: da7219: Fix change notifications for tone generator frequency (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: fix sysclk shutdown (Jaroslav Kysela) [2065572]
- ASoC: wm8958: Fix change notifications for DSP controls (Jaroslav Kysela) [2065572]
- ASoC: codecs: Fix an error handling path in (rx|tx|va)_macro_probe() (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: Add a quirk for Huawei Matebook D15 (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add a quirk for headset at mic1 port (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: support a separate gpio to control headphone (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: simplify speaker gpio naming (Jaroslav Kysela) [2065572]
- ASoC: wm8731: Disable the regulator when probing fails (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: correct device endpoints for max98373 (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: do not switch off SIDO Buck when codec is in use (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Fix memory leak in sof_control_load() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: cleanup dailinks on widget unload (Jaroslav Kysela) [2065572]
- ASoC: rt711/5682: check if bus is active before deferred jack detection (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: Add support for max98360a speaker amp on SSP2 (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: fix 1:1 bclk:mclk ratio support (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Avoid NULL deref in asoc_simple_set_tdm() (Jaroslav Kysela) [2065572]
- ASoC: meson: aiu: fix duplicate debugfs directory error (Jaroslav Kysela) [2065572]
- ASoC: soc-core: add debugfs_prefix member to snd_soc_component_driver (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-digital: Check failure for devm_snd_soc_register_component (Jaroslav Kysela) [2065572]
- ASoC: rk817: Use devm_clk_get() in rk817_platform_probe (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix a shift-out-of-bounds warning found by UBSAN (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Add one more variable in the debug log (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Update handling of test key registers (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Correct handling of some registers in the cache (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Create shared function for boost configuration (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Create shared function for setting channels (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Create shared function for errata patches (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Move power initializations to reg_sequence (Jaroslav Kysela) [2065572]
- ASoC: rt5682: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2065572]
- ASoC: soc-dapm: fix two incorrect uses of list iterator (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: use GFP_KERNEL when the code is sleepable (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Fix memory leak of scontrol->name (Jaroslav Kysela) [2065572]
- codecs: rt5682s: fix an incorrect NULL check on list iterator (Jaroslav Kysela) [2065572]
- ASoC: topology: Correct error handling in soc_tplg_dapm_widget_create() (Jaroslav Kysela) [2065572]
- ASoC: atmel: Remove system clock tree configuration for at91sam9g20ek (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Fix build error without SND_SOC_SOF_PCI_DEV (Jaroslav Kysela) [2065572]
- ASoC: rockchip: i2s_tdm: Fixup config for SND_SOC_DAIFMT_DSP_A/B (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Fix jack_event() always return 0 (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt6358: add missing EXPORT_SYMBOLs (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: print the correct property name (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a new dai_get_clk topology IPC op (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add ops for setting up and tearing down pipelines (Jaroslav Kysela) [2065572]
- ASoC: SOF: expose sof_route_setup() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add dai_link_fixup PCM op for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add trigger PCM op for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Define hw_params PCM op for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC3 PCM hw_free op (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: expose the sof_pcm_setup_connected_widgets() function (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC-specific PCM ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add bytes_ext control IPC ops for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add bytes_get/put control IPC ops for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add enum_get/put control ops for IPC3 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add switch get/put IPC3 ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add volume_get/put IPC3 ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add IPC3 topology control ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC ops for kcontrol IO (Jaroslav Kysela) [2065572]
- ASoC: SOF: Make sof_suspend/resume IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: Make sof_widget_setup/free IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: set up scheduler widget before all other widgets in the pipeline (Jaroslav Kysela) [2065572]
- ASoC: fsl_spdif: Add new registers included on i.MX8ULP (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Use kmemdup() to replace kzalloc + memcpy (Jaroslav Kysela) [2065572]
- ASoC: ak4642: Use of_device_get_match_data() (Jaroslav Kysela) [2065572]
- ASoC: codecs: Fix misplaced lpass_macro_pds_exit call (Jaroslav Kysela) [2065572]
- ASoC: sti: Fix deadlock via snd_pcm_stop_xrun() call (Jaroslav Kysela) [2065572]
- ASoC: amd: Fix reference to PCM buffer address (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: Add missing of_node_put() in wcd934x_codec_parse_data (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: Fix error handling in mt8195_mt6359_rt1019_rt5682_dev_probe (Jaroslav Kysela) [2065572]
- ASoC: rt1308-sdw: get calibration params after power on (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-analog: Fix error handling in pm8916_wcd_analog_spmi_probe (Jaroslav Kysela) [2065572]
- ASoC: ti: Fix spelling mistake "cant" -> "can't" (Jaroslav Kysela) [2065572]
- ASoC: mediatek: Fix error handling in mt8183_da7219_max98357_dev_probe (Jaroslav Kysela) [2065572]
- ASoC: atmel: Fix error handling in sam9x5_wm8731_driver_probe (Jaroslav Kysela) [2065572]
- ASoC: rockchip: Fix PM usage reference of rockchip_i2s_tdm_resume (Jaroslav Kysela) [2065572]
- ASoC: samsung: i2s: check the return value of kstrdup() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove snd_sof_complete_pipeline() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make widget binding IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make control parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make DAI widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make route setup IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make effect widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make siggen widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make asrc widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make src widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make mux/demux widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make mixer widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make pga widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make buffer widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Make scheduler widget parsing IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC3 ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add helper function for processing tuple arrays (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: Introduce IPC ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce struct snd_sof_dai_link (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: Fix `-Wpointer-bool-conversion` warning (Jaroslav Kysela) [2065572]
- ASoC: soc-compress: Change the check for codec_dai (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Code loading over HDA (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Code loading over CLDMA (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Implement CLDMA transfer (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: General code loading flow (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Dynamic firmware resources management (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Declare module configuration types (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Firmware resources management utilities (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add basefw runtime-parameter requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add ROM requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add power management requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add module management requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add pipeline management requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Add code loading requests (Jaroslav Kysela) [2065572]
- ASoC: Intel: avs: Inter process communication (Jaroslav Kysela) [2065572]
- ASoC: Intel: Introduce AVS driver (Jaroslav Kysela) [2065572]
- ASoC: Export DAI register and widget ctor and dctor functions (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-digital: Fix missing clk_disable_unprepare() in msm8916_wcd_digital_probe (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Don't reset clock of active DAI (Jaroslav Kysela) [2065572]
- ASoC: mchp-spdifrx: fix typo (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add reset controller (Jaroslav Kysela) [2065572]
- ASoC: SOF: Remove ipc_pcm_params() ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx: Convert to use the generic set_stream_data_offset ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Convert to use the generic set_stream_data_offset ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-ipc: Add hda_set_stream_data_offset() (Jaroslav Kysela) [2065572]
- ASoC: SOF: stream-ipc: Add sof_set_stream_data_offset() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Mark snd_sof_dsp_ops.ipc_pcm_params() callback optional (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce optional callback to configure stream data offset (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: Remove sof_pcm_dsp_params() wrapper (Jaroslav Kysela) [2065572]
- ASoC: SOF: Make pcm_hw_params snd_sof_dsp_ops callback IPC neutral (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-priv: Remove stale snd_sof_ipc_stream_pcm_params() declaration (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: Add entry for rt711-sdca-sdw in ADL match table (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: add topology overwrite for Taniks (Jaroslav Kysela) [2065572]
- ASoC: SOF: trace: Use proper DMA direction for the trace data buffer (Jaroslav Kysela) [2065572]
- ASoC: SOF: compress: fix null check after dereference (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: enable DMI L1 for playback streams (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: Fix spelling mistake "microchopnes" -> "microphones" (Jaroslav Kysela) [2065572]
- ASoC: imx-es8328: Fix error return code in imx_es8328_probe() (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: Remove unnecessary print function dev_err() (Jaroslav Kysela) [2065572]
- ASoC: fsl_spdif: Disable TX clock when stop (Jaroslav Kysela) [2065572]
- ASoC: qcom: fix Kconfig for SC7280 (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc-msg-injector: Use devm_kzalloc() for the rx_buffer (Jaroslav Kysela) [2065572]
- ASoC: fsl_spdif: keep all TxClk sources by txclk array (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Remove unneeded semicolon (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Remove unneeded semicolon (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: fix randconfig issue (Jaroslav Kysela) [2065572]
- ASoC: fsl_rpmsg: Remove SET_SYSTEM_SLEEP_PM_OPS callback (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcht_es8316: move comment to the right place (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add cfg-dmics component for UCM support (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: extend machine driver to support ES8326 codec (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add support for JD inverted quirk (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: move comment to the right place (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: log all quirks (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: use NHLT information to set dmic and SSP (Jaroslav Kysela) [2065572]
- ASoC: Intel: Revert "ASoC: Intel: sof_es8336: add quirk for Huawei D15 2021" (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: get codec device with ACPI instead of bus search (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: make gpio optional (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: add ESSX8336 support on Cannon Lake machines (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: add more ACPI HIDs for ES83x6 devices (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: quirk topology filename dynamically (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: report SSP link mask to machine driver (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: retrieve DMIC number for I2S boards (Jaroslav Kysela) [2065572]
- ASoC: SOF: move definition of snd_sof_ipc to header file (Jaroslav Kysela) [2065572]
- ASoC: SOF: make struct snd_sof_dai IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Rename arguments in sof_parse_tokens() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Rename arguments in sof_parse_token_sets() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Modify signature for token parsing functions (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a tuples array to struct snd_sof_widget (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: make sof_route_load() IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: SOF: make struct snd_sof_widget IPC agnostic (Jaroslav Kysela) [2065572]
- ASoC: mxs: Fix error handling in mxs_sgtl5000_probe (Jaroslav Kysela) [2065572]
- ASoC: atmel: mchp-pdmc: add PDMC driver (Jaroslav Kysela) [2065572]
- ASoC: dmaengine: do not use a NULL prepare_slave_config() callback (Jaroslav Kysela) [2065572]
- ASoC: rk817: Fix missing clk_disable_unprepare() in rk817_platform_probe (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8192-mt6359: Fix error handling in mt8192_mt6359_dev_probe (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add missing of_node_put() in imx8m_probe (Jaroslav Kysela) [2065572]
- ASoC: rockchip: i2s: Fix missing clk_disable_unprepare() in rockchip_i2s_probe (Jaroslav Kysela) [2065572]
- ASoC: amd: acp3x: Fix signedness bug in acp3x (Jaroslav Kysela) [2065572]
- ASoC: amd: acp5x-pcm-dma: Fix signedness bug (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8183: support wb bt audio (Jaroslav Kysela) [2065572]
- ASoC: Intel: catpt: use asoc_substream_to_rtd() (Jaroslav Kysela) [2065572]
- ASoC: atmel: Fix error handling in snd_proto_probe (Jaroslav Kysela) [2065572]
- ASoC: SOF: change comp_dai to a pointer in struct snd_sof_dai (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: expose some get_token ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Modify the get_token op for string tokens (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Drop the size parameter from struct sof_topology_token (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove redundant code in sof_link_afe_load() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove redundant code (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-audio: removed unused function (Jaroslav Kysela) [2065572]
- ASoC: SOF: set swidget's core for scheduler widget (Jaroslav Kysela) [2065572]
- ASoC: SOF: simplify snd_sof_device_remove() (Jaroslav Kysela) [2065572]
- ASoC: SOF: remove snd_sof_pipeline_find() (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: fix signedness bug in acp5x_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Expand firmware loading search options (Jaroslav Kysela) [2065572]
- ASoC: fsi: Add check for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: qcom: select correct WCD938X config for SC7280 (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Remove unnecessary param (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: Stabilize the combo jack detection (Jaroslav Kysela) [2065572]
- ASoC: wm8350: Handle error for wm8350_register_irq (Jaroslav Kysela) [2065572]
- ASoC: atmel: Add missing of_node_put() in at91sam9g20ek_audio_probe (Jaroslav Kysela) [2065572]
- ASoC: amd: pcm-dma: Fix signedness bug in acp3x_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: amd: pcm-dma: Fix signedness bug in acp_pdm_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Fix signedness bug in renoir_audio_probe() (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_sdw: fix quirks for 2022 HP Spectre x360 13" (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: add GPIOLIB dependency where missed (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: remove explicit dependency on GPIOLIB when DMIC is used" (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: implement 1:1 bclk:mclk ratio support (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: use DIV_ROUND_CLOSEST() to calculate divider (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: Use better variable names (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: store full version instead of major/minor (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: simplify register poking in fsl_sai_set_bclk (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: simplify irq return value (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: Drop unnecessary defines (Jaroslav Kysela) [2065572]
- ASoC: codecs: Add Awinic AW8738 audio amplifier driver (Jaroslav Kysela) [2065572]
- ASoC: audio_graph_card2: Add support for variable slot widths (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: clarify operator precedence (Jaroslav Kysela) [2065572]
- ASoC: SOF: debug: clarify operator precedence (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Increase ACP_HW_SEM_RETRY_COUNT value (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Move group register configuration to acp-loader (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Use semaphore register to synchronize ipc's irq (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Flush cache after ATU_BASE_ADDR_GRP register update (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Do not set ipc_pcm_params ops as it is optional (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: acp-pcm: Take buffer information directly from runtime (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: pci-tgl: add RPL-S support (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix DSP mbox start command and global enable order (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix max number of TX channels (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix GPIO2 configuration (Jaroslav Kysela) [2065572]
- ASoC: bt-sco: fix bt-sco-pcm-wb dai widget don't connect to the endpoint (Jaroslav Kysela) [2065572]
- ASoC: hdac_hda: Avoid unexpected match when pcm_name is "Analog" (Jaroslav Kysela) [2065572]
- ASoC: qcom: Fix error code in lpass_platform_copy() (Jaroslav Kysela) [2065572]
- ASoC: soc-compress: prevent the potentially use of null pointer (Jaroslav Kysela) [2065572]
- ASoC: soc-generic-dmaengine-pcm: set period_bytes_min based on maxburst (Jaroslav Kysela) [2065572]
- ASoC: dwc-i2s: Handle errors for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: amd: use asoc_substream_to_rtd() (Jaroslav Kysela) [2065572]
- ASoC: atmel_ssc_dai: Handle errors for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: mxs-saif: Handle errors for clk_enable (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi: add entries in ADL match table (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_ssp_amp: rename driver and support cs35l41 amplifier (Jaroslav Kysela) [2065572]
- ASoC: Intel: cirrus-common: support cs35l41 amplifier (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt1308: move rt1308 code to common module (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: create sof-realtek-common module (Jaroslav Kysela) [2065572]
- ASoC: Intel: add RT1308 I2S machine driver and HDMI-in capture via I2S support. (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: fix spelling in comments (Jaroslav Kysela) [2065572]
- ASoC: soc-acpi: remove sof_fw_filename (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa881x: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: es7241: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98927: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98926: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98925: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max9867: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max9860: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max9850: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98390: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98371: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98095: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: max98088: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: uda134x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: ml26124: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm512x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm186x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm1681: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: pcm3060: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: fsl: Drop unused argument from imx_pcm_dma_init() (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: Remove unnecessary print function dev_err() (Jaroslav Kysela) [2065572]
- ASoC: ti: davinci-i2s: Add check for clk_enable() (Jaroslav Kysela) [2065572]
- ASoC: mc13783: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: isabelle: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: amd: vangogh: fix uninitialized symbol warning in machine driver (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: remove warnings and errors pointed out by checkpatch pl (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: update DAI link name (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: fix for pm resume callback sequence (Jaroslav Kysela) [2065572]
- ASoC: es8328: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: inno_rk3036: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: es8316: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: wl1273: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: es7134: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: twl4030: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: uda1334: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: uda1380: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: si476x: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: sti-sas: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: amd: pcm-dma: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: tscs454: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: tscs42xx: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: lm49453: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2065572]
- ASoC: codecs: Add power domains support in digital macro codecs (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd-mbhc: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: add simple clk stop support (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: va-macro: add runtime pm support (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: setup soundwire clks correctly (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: setup soundwire clks correctly (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa-macro: setup soundwire clks correctly (Jaroslav Kysela) [2065572]
- ASoC: codecs: wsa-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: codecs: tx-macro: move clk provider to managed variants (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: move clk provider to managed variants (Jaroslav Kysela) [2065572]
- ASoC: codecs: va-macro: move to individual clks from bulk (Jaroslav Kysela) [2065572]
- ASoC: qcom: lpass-platform: Update warning print to control excess logging (Jaroslav Kysela) [2065572]
- ASoC: acp: check the return value of devm_kzalloc() in acp_legacy_dai_links_create() (Jaroslav Kysela) [2065572]
- ASoC: rt5663: check the return value of devm_kzalloc() in rt5663_parse_dp() (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-priv: Drop duplicate sof_compressed_ops declaration (Jaroslav Kysela) [2065572]
- ASoC: amd: Use platform_get_irq_byname() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: Make use of the helper component_compare/release_of (Jaroslav Kysela) [2065572]
- ASoC: SOF: Declare sof_compress_ops in sof-priv.h (Jaroslav Kysela) [2065572]
- ASoC: qcom: lpass-sc7280: Add platform driver for lpass audio (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add lpass CPU driver for codec dma control (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add support for codec dma driver (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add regmap config support for codec dma driver (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add register definition for codec rddma and wrdma (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add helper function to get dma control and lpaif handle (Jaroslav Kysela) [2065572]
- ASoC: qcom: lpass: Add dma fields for codec dma lpass interface (Jaroslav Kysela) [2065572]
- ASoC: qcom: Move lpass_pcm_data structure to lpass header (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Fix NULL ptr dereference when ENOMEM (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add DMIC machine driver ops (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-legacy: Add legacy card support for new machines (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Change card name for Guybrush Machine (Jaroslav Kysela) [2065572]
- ASoC: tlv320adc3xxx: Fix buggy return value (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: Add compress_ops for SOF platform component driver (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: Fix the wrong jack type detected (Jaroslav Kysela) [2065572]
- ASoC: Intel: soc-acpi-byt: Add new WM5102 ACPI HID (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: update acp init and deinit sequence (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: apply sample bits pcm constraint (Jaroslav Kysela) [2065572]
- ASoC: amd: vg: update platform clock control sequence (Jaroslav Kysela) [2065572]
- ASoC: nau8821: enable no_capture_mute flag (Jaroslav Kysela) [2065572]
- ASoC: amd: vangogh: refactor i2s master mode clock sequence code (Jaroslav Kysela) [2065572]
- ASoC: sc7280: Really depends on SOUNDWIRE (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: fix return value of wcd934x_rx_hph_mode_put (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: fix kcontrol max values (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: fix kcontrol max values (Jaroslav Kysela) [2065572]
- ASoC: codecs: wc938x: fix accessing array out of bounds for enum type (Jaroslav Kysela) [2065572]
- ASoC: codecs: va-macro: fix accessing array out of bounds for enum type (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: fix accessing array out of bounds for enum type (Jaroslav Kysela) [2065572]
- ASoC: codecs: rx-macro: fix accessing compander for aux (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: enable apll tuner (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Add topology overwrite for Felwinter (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_es8336: add quirk for Huawei D15 2021 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Replace zero-length array with flexible-array member (Jaroslav Kysela) [2065572]
- ASoC: intel: skylake: Set max DMA segment size (Jaroslav Kysela) [2065572]
- ASoC: SOF: hda: Set max DMA segment size (Jaroslav Kysela) [2065572]
- ASoC: SOF: core: unregister clients and machine drivers in .shutdown (Jaroslav Kysela) [2065572]
- ASoC: codec: wcd938x: Update CTIA/OMTP switch control (Jaroslav Kysela) [2065572]
- ASoC: cs4265: Fix the duplicated control name (Jaroslav Kysela) [2065572]
- ASoC: ops: Shift tested values in snd_soc_put_volsw() by +min (Jaroslav Kysela) [2065572]
- ASoC: soc-core: skip zero num_dai component in searching dai name (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: make const array rates static (Jaroslav Kysela) [2065572]
- ASoC: SOF: Makefile: Fix randconfig sof-client build when SND_SOC_SOF=y (Jaroslav Kysela) [2065572]
- ASoC: codec: wcd938x: Add switch control for selecting CTIA/OMTP Headset (Jaroslav Kysela) [2065572]
- ASoC: codec: wm8960: complete discharge on BIAS OFF->STANDBY (Jaroslav Kysela) [2065572]
- ASoC: wm8731: Delete empty remove() function (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: remove numeric PCM3168A_NUM_SUPPLIES (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: refactor format handling (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: refactor hw_params routine (Jaroslav Kysela) [2065572]
- ASoC: pcm3168a: cleanup unintuitive mask usage (Jaroslav Kysela) [2065572]
- ASoC: SOF: compr: Mark snd_compress_ops static (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcr_wm5102: use GFP_KERNEL (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Add trace caps to speaker protection FW (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Make compressed buffers optional (Jaroslav Kysela) [2065572]
- ASoC: tlv320adc3xxx: Add IIR filter configuration (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Correct control read size when parsing compressed buffer (Jaroslav Kysela) [2065572]
- ASoC: SOF: Convert the generic probe support to SOF client (Jaroslav Kysela) [2065572]
- ASoC: SOF: Convert the generic IPC message injector into SOF client (Jaroslav Kysela) [2065572]
- ASoC: SOF: Convert the generic IPC flood test into SOF client (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-client: Add support for clients not managed by pm framework (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce IPC SOF client support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Split up utils.c into sof-utils and iomem-utils (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Read and pass the whole message to handlers for IPC events (Jaroslav Kysela) [2065572]
- ASoC: SOF: Move the definition of enum sof_dsp_power_states to global header (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop unused DSP power states: D3_HOT and D3_COLD (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Remove the sysclk and sysclk_src checking (Jaroslav Kysela) [2065572]
- ASoC: qcom: SC7280: Add machine driver (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add macro for lpass DAI id's max limit (Jaroslav Kysela) [2065572]
- ASoC: qcom: Actually clear DMA interrupt register for HDMI (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hdac_ext_stream: consistent prefixes for variables/members (Jaroslav Kysela) [2065572]
- ASoC: fsl_sai: Enable combine mode soft (Jaroslav Kysela) [2065572]
- ASoC: SOF: compr: Add compress ops implementation (Jaroslav Kysela) [2065572]
- ASoC: SOF: dma-trace: Pass pointer to params_ext struct in trace_init() (Jaroslav Kysela) [2065572]
- ASoC: SOF: intel: hda-trace: Pass the dma buffer pointer to hda_dsp_trace_prepare (Jaroslav Kysela) [2065572]
- ASoC: simple-mux: Depend on gpiolib rather than selecting it (Jaroslav Kysela) [2065572]
- ASoC: zl38060: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: max9759: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: simple-amplifier: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: rt9120: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: dmic: Remove spurious gpiolib select (Jaroslav Kysela) [2065572]
- ASoC: rt5682: do not block workqueue if card is unbound (Jaroslav Kysela) [2065572]
- ASoC: rt5668: do not block workqueue if card is unbound (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: do not block workqueue if card is unbound (Jaroslav Kysela) [2065572]
- ASoC: tas2770: Insert post reset delay (Jaroslav Kysela) [2065572]
- ASoC: madera: Add dependencies on MFD (Jaroslav Kysela) [2065572]
- ASoC: samsung: Explicitly include gpiolib header (Jaroslav Kysela) [2065572]
- ASoC: wm8962: Allow switching between analog and digital inputs (Jaroslav Kysela) [2065572]
- ASoC: sun4i-i2s: Add support for the R329/D1 variant (Jaroslav Kysela) [2065572]
- ASoC: sun4i-i2s: Update registers for more channels (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Set gpio_spkr_en to None for max speaker amplifer in machine driver (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_xr_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw_range() (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Fix stereo change notifications in snd_soc_put_volsw() (Jaroslav Kysela) [2065572]
- ASoC: max98927: add missing header file (Jaroslav Kysela) [2065572]
- ASoC: ops: Check for negative values before reading them (Jaroslav Kysela) [2065572]
- ASoC: cs42l51: Improve error handling in cs42l51_remove() (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Do not allocate buffer for msg_data (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Drop header parameter from sof_ipc_tx_message_unlocked() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: cnl: Use pm_gate->hdr.cmd in cnl_compact_ipc_compress() (Jaroslav Kysela) [2065572]
- ASoC: amd: renoir: Add check for acp configuration flags (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: acp-legacy: Add DMIC dai link support for Renoir (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add ACP init()/deinit() callback for Renoir. (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add generic PCI driver module for ACP device (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add PDM controller based dmic dai for Renoir (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Add generic support for PDM controller on ACP (Jaroslav Kysela) [2065572]
- ASoC: rk3399_gru_sound: Wire up DP jack detection (Jaroslav Kysela) [2065572]
- ASoC: rt5682: Fix deadlock on resume (Jaroslav Kysela) [2065572]
- ASoC: hdmi-codec: Fix OOB memory accesses (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: Move debugfs removal out of spinlock (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: Fix DPCM lockdep warning due to nested stream locks (Jaroslav Kysela) [2065572]
- ASoC: SOF: trace: Simplify count adjustment in trace_read (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: Remove link assignment limitation (Jaroslav Kysela) [2065572]
- ASoC: tegra: Update AHUB driver for Tegra234 (Jaroslav Kysela) [2065572]
- ASoC: fsl: Add missing error handling in pcm030_fabric_probe (Jaroslav Kysela) [2065572]
- ASoC: qdsp6: q6apm-dai: only stop graphs that are started (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: fix return value of mixer put function (Jaroslav Kysela) [2065572]
- ASoC: codecs: lpass-rx-macro: fix sidetone register offsets (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: fix incorrect used of portid (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Remove duplicate macros (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Add rz_ssi_set_substream() helper function (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Use a do-while loop in rz_ssi_pio_recv() (Jaroslav Kysela) [2065572]
- ASoC: ops: Reject out of bounds values in snd_soc_put_xr_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw_sx() (Jaroslav Kysela) [2065572]
- ASoC: ops: Reject out of bounds values in snd_soc_put_volsw() (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Add new system-clock-fixed flag (Jaroslav Kysela) [2065572]
- ASoC: simple-card-utils: Set sysclk on all components (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_i2s: Handle sysclk setting (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_i2s: create drvdata structure (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_formatter_pcm: Handle sysclk setting (Jaroslav Kysela) [2065572]
- ASoC: codecs: Check for error pointer after calling devm_regmap_init_mmio (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: add 512FS MCLK clock configuration (Jaroslav Kysela) [2065572]
- ASoC: amd: sof-mach: Add support for RT5682S and RT1019 card (Jaroslav Kysela) [2065572]
- ASoC: soc-generic-dmaengine-pcm: separate max_buffer_size assignment (Jaroslav Kysela) [2065572]
- ASoC: samsung: remove unneeded ret variable (Jaroslav Kysela) [2065572]
- ASoC: codecs: remove redundant ret variable (Jaroslav Kysela) [2065572]
- ASoC: Rename tlv320aic31xx-micbias.h as tlv320aic31xx.h (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Remove BCLK default value for tlv320aic31xx card (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Add optional dt property for setting mclk-id (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: Add support for platform without amplifier (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: add support for systems without i915 audio (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: Compare sdw adr directly (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: match sdw version on link_slaves_found (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Make return type of rz_ssi_stream_is_valid() to bool (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Drop ssi parameter from rz_ssi_stream_init() (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Make the data structures available before registering the handlers (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Drop calling rz_ssi_pio_recv() recursively (Jaroslav Kysela) [2065572]
- ASoC: add support for TAS5805M digital amplifier (Jaroslav Kysela) [2065572]
- ASoC: topology: Optimize soc_tplg_dapm_graph_elems_load behavior (Jaroslav Kysela) [2065572]
- ASoC: topology: Allow TLV control to be either read or write (Jaroslav Kysela) [2065572]
- ASoC: topology: Remove superfluous error prints (Jaroslav Kysela) [2065572]
- ASoC: SOF: add flag to disable IMR restore to sof_debug (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-loader: add IMR restore support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-loader: add SSP helper (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: use inclusive language for SSP clocks (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-mach: Fix Left and Right rt1019 amp devices (Jaroslav Kysela) [2065572]
- ASoC: mediatek: fix unmet dependency on GPIOLIB for SND_SOC_DMIC (Jaroslav Kysela) [2065572]
- ASoC: max9759: fix underflow in speaker_gain_control_put() (Jaroslav Kysela) [2065572]
- ASoC: cpcap: Check for NULL pointer after calling of_get_child_by_name (Jaroslav Kysela) [2065572]
- ASoC: simple-card: fix probe failure on platform component (Jaroslav Kysela) [2065572]
- ASoC: xilinx: xlnx_formatter_pcm: Make buffer bytes multiple of period bytes (Jaroslav Kysela) [2065572]
- ASoC: wcd9335: Keep a RX port value for each SLIM RX mux (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: acp-mach: Change default RT1019 amp dev id (Jaroslav Kysela) [2065572]
- ASoC: topology: Fix typo (Jaroslav Kysela) [2065572]
- ASoC: fsl_asrc: refine the check of available clock divider (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcr_rt5640: Add support for external GPIO jack-detect (Jaroslav Kysela) [2065572]
- ASoC: Intel: bytcr_rt5640: Support retrieving the codec IRQ from the AMCR0F28 ACPI dev (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Add support for boards with an external jack-detect GPIO (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Allow snd_soc_component_set_jack() to override the codec IRQ (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Change jack_work to a delayed_work (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Fix possible NULL pointer deref on resume (Jaroslav Kysela) [2065572]
- ASoC: imx-card: improve the sound quality for low rate (Jaroslav Kysela) [2065572]
- ASoC: imx-card: Fix mclk calculation issue for akcodec (Jaroslav Kysela) [2065572]
- ASoC: imx-card: Need special setting for ak4497 on i.MX8MQ (Jaroslav Kysela) [2065572]
- ASoC: ak4375: Fix unused function error (Jaroslav Kysela) [2065572]
- ASoC: cs4265: Add a remove() function (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Add support for "toggle" preloaders (Jaroslav Kysela) [2065572]
- ASoC: fsl_mqs: fix MODULE_ALIAS (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Move cs35l41_otp_unpack to shared code (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add playback support to PCM1_BE dai_link (Jaroslav Kysela) [2065572]
- ASoC: rt5682: Register wclk with its parent_hws instead of parent_data (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: update control for RT5682 series (Jaroslav Kysela) [2065572]
- ASoC: samsung: idma: Check of ioremap return value (Jaroslav Kysela) [2065572]
- ASoC: mediatek: use of_device_get_match_data() (Jaroslav Kysela) [2065572]
- ASoC: cs4265: Fix part number ID error message (Jaroslav Kysela) [2065572]
- ALSA/ASoC: hda: move/rename snd_hdac_ext_stop_streams to hdac_stream.c (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Power on/off the speaker enable gpio pin based on DAPM callback. (Jaroslav Kysela) [2065572]
- ASoC: remove unneeded variable (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: release device_node after snd_soc_register_card (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8173: reduce log verbosity in probe() (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8183: fix device_node leak (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8173: fix device_node leak (Jaroslav Kysela) [2065572]
- ASoC: Intel/SOF: use set_stream() instead of set_tdm_slots() for HDAudio (Jaroslav Kysela) [2065572]
- ASoC/SoundWire: dai: expand 'stream' concept beyond SoundWire (Jaroslav Kysela) [2065572]
- ASoC/soundwire: intel: simplify callbacks for params/hw_free (Jaroslav Kysela) [2065572]
- ASOC: SOF: Intel: use snd_soc_dai_get_widget() (Jaroslav Kysela) [2065572]
- ASoC: msm8916-wcd-analog: Use separate outputs for HPH_L/HPH_R (Jaroslav Kysela) [2065572]
- ASoC: qcom: common: Parse "pin-switches" and "widgets" from DT (Jaroslav Kysela) [2065572]
- ASoC: core: Add snd_soc_of_parse_pin_switches() from simple-card-utils (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8192-mt6359: fix device_node leak (Jaroslav Kysela) [2065572]
- ASoC: codec: tlv320adc3xxx: Fix missing clk_disable_unprepare() on error in adc3xxx_i2c_probe() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: Use DEBUG log level for optional prints (Jaroslav Kysela) [2065572]
- ASoC: SOF: debug: Use DEBUG log level for optional prints (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add clarifying comments for sof_core_debug and DSP dump flags (Jaroslav Kysela) [2065572]
- ASoC: SOF: Rename snd_sof_get_status() and add kernel log level parameter (Jaroslav Kysela) [2065572]
- ASoC: SOF: dsp_arch_ops: add kernel log level parameter for oops and stack (Jaroslav Kysela) [2065572]
- ASoC: SOF: ops: Always print DSP Panic message but use different message (Jaroslav Kysela) [2065572]
- ASoc: SOF: core: Update the FW boot state transition diagram (Jaroslav Kysela) [2065572]
- ASoC: SOF: pm: Force DSP off on suspend in BOOT_FAILED state also (Jaroslav Kysela) [2065572]
- ASoC: SOF: Set SOF_FW_BOOT_FAILED in case we have failure during boot (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Only allow sending of an IPC in SOF_FW_BOOT_COMPLETE state (Jaroslav Kysela) [2065572]
- ASoC: SOF: Rename 'enum snd_sof_fw_state' to 'enum sof_fw_state' (Jaroslav Kysela) [2065572]
- ASoC: SOF: Move the definition of enum snd_sof_fw_state to global header (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce new firmware state: SOF_FW_BOOT_READY_OK (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce new firmware state: SOF_FW_CRASHED (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a 'message' parameter to snd_sof_dsp_dbg_dump() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add 'non_recoverable' parameter to snd_sof_dsp_panic() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Use sof_debug_check_flag() instead of sof_core_debug directly (Jaroslav Kysela) [2065572]
- ASoC: SOF: core: Add simple wrapper to check flags in sof_core_debug (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-loader: Avoid re-defining the HDA_FW_BOOT_ATTEMPTS (Jaroslav Kysela) [2065572]
- ASoC: SOF: ops: Use dev_warn() if the panic offsets differ (Jaroslav Kysela) [2065572]
- ASoC: codecs: ak4375: Change invert controls to a stereo switch (Jaroslav Kysela) [2065572]
- ASoC: Add AK4375 support (Jaroslav Kysela) [2065572]
- ASoC: bcm: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: xlnx: Use platform_get_irq() to get the interrupt (Jaroslav Kysela) [2065572]
- ASoC: amd: acp: Remove duplicate dependency in Kconfig (Jaroslav Kysela) [2065572]
- ASoC: qdsp6: fix a use after free bug in open() (Jaroslav Kysela) [2065572]
- ASoC: SOF: AMD: simplify return status handling (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-config: Update sof_tplg_filename for SOF machines (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-config: Enable SOF audio for Google chrome boards. (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195-mt6359: reduce log verbosity in probe() (Jaroslav Kysela) [2065572]
- ASoC: codec: tlv320adc3xxx: New codec driver (Jaroslav Kysela) [2065572]
- ASoC: sunxi: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: stm: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: samsung: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: rockchip: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: qcom: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: mxs: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: meson: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: img: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: generic: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: fsl: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: ti: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: ateml: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: tlv320aic31xx: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: ssm2305: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: simple-mux: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: simple-amplifier: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: sgtl5000: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: pcm3168a: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: max9860: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: max9759: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: es7241: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: codecs: ak4118: Use dev_err_probe() helper (Jaroslav Kysela) [2065572]
- ASoC: sh: rz-ssi: Check return value of pm_runtime_resume_and_get() (Jaroslav Kysela) [2065572]
- ASoC: Intel: catpt: Streamline locals declaration for PCM-functions (Jaroslav Kysela) [2065572]
- ASoC: Intel: catpt: Reduce size of catpt_component_open() (Jaroslav Kysela) [2065572]
- ASoC: tegra20: i2s: Filter out unsupported rates (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Filter out unsupported rates (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Support system suspend (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Reset hardware (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Use more resource-managed helpers (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Improve driver's code (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Support device-tree (Jaroslav Kysela) [2065572]
- ASoC: tegra20: spdif: Set FIFO trigger level (Jaroslav Kysela) [2065572]
- ASoC: SOF: Kconfig: Make the SOF_DEVELOPER_SUPPORT depend on SND_SOC_SOF (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Add null pointer check for substream->runtime (Jaroslav Kysela) [2065572]
- ASoC: SOF: avoid casting "const" attribute away (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: remove support for RESUME in platform trigger (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: remove support for RESUME trigger (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: remove support for RESUME trigger (Jaroslav Kysela) [2065572]
- ASoC: tegra20-spdif: stop setting slave_id (Jaroslav Kysela) [2065572]
- ASoC: AMD: fix depend/select mistake on SND_AMD_ACP_CONFIG (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: read back control data from DSP (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop ctrl_type parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: SOF: control: Do not handle control notification with component type (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-audio: Drop the `cmd` member from struct snd_sof_control (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop ctrl_cmd parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Set control_data->cmd alongside scontrol->cmd (Jaroslav Kysela) [2065572]
- ASoC: SOF: Drop ipc_cmd parameter for snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: SOF: ipc: Rename send parameter in snd_sof_ipc_set_get_comp_data() (Jaroslav Kysela) [2065572]
- ASoC: rt5663: Handle device_property_read_u32_array error codes (Jaroslav Kysela) [2065572]
- ASoC: SOF: OF: Avoid reverse module dependency (Jaroslav Kysela) [2065572]
- ASoC: qdsp6: Fix an IS_ERR() vs NULL bug (Jaroslav Kysela) [2065572]
- ASoC: qcom: Distinguish headset codec by codec_dai->name (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: fix BE handling of PAUSE_RELEASE (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: test refcount before triggering (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: serialize BE triggers (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: Fix and cleanup DPCM locking (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: align BE 'atomicity' with that of the FE (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: use GFP_ATOMIC for dpcm structure (Jaroslav Kysela) [2065572]
- ASoC: mediatek: assign correct type to argument (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-probes: Constify sof_probe_compr_ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Remove pm_runtime_put_autosuspend() for SOF OF device (Jaroslav Kysela) [2065572]
- ASoC: qcom: apq8016_sbc: Allow routing audio through QDSP6 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: add comment on JasperLake support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-dai: remove unused fields (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: add quirks for HDAudio DMA position information (Jaroslav Kysela) [2065572]
- ASoC: SOF: hda-stream: only enable DPIB if needed (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-ctrl: apply symmetry for DPIB (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda-stream: limit PROCEN workaround (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: ICL: move ICL-specific ops to icl.c (Jaroslav Kysela) [2065572]
- ASoC: test-component: fix null pointer dereference. (Jaroslav Kysela) [2065572]
- ASoC: amd: Convert to new style DAI format definitions (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: silence uninitialized variable warning (Jaroslav Kysela) [2065572]
- ASoC: AMD: acp-config: fix missing dependency on SND_SOC_ACPI (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_rt5682: Move rt1015 speaker amp to common file (Jaroslav Kysela) [2065572]
- ASoC: rt5682s: add delay time to fix pop sound issue (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: add 'static' qualifiers for max98390 routes (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add sof support on mt8195-mt6359-rt1019-rt5682 (Jaroslav Kysela) [2065572]
- ASoC: amd: acp6x-pdm-dma: Constify static snd_soc_dai_ops (Jaroslav Kysela) [2065572]
- ASoC: ti: davinci-mcasp: Remove unnecessary conditional (Jaroslav Kysela) [2065572]
- ASoC: ti: davinci-mcasp: Get rid of duplicate of_node assignment (Jaroslav Kysela) [2065572]
- ASoC: zl38060: Setup parent device and get rid of unnecessary of_node assignment (Jaroslav Kysela) [2065572]
- ASoC: test-component: fix null pointer dereference. (Jaroslav Kysela) [2065572]
- sound/soc: remove useless bool conversion to bool variable (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: add headset codec rt5682s support (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Add missing Kconfig option for tlv320aic31xx (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: support reserved memory assignment (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Fix the wrong state of the JD in the HDA header (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd934x: remove redundant ret variable (Jaroslav Kysela) [2065572]
- ASoC: tegra: Add master volume/mute control support (Jaroslav Kysela) [2065572]
- ASoC: Intel: Skylake: Use NHLT API to search for blob (Jaroslav Kysela) [2065572]
- ASoC: Intel: boards: add max98390 2/4 speakers support (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: make several arrays static const (Jaroslav Kysela) [2065572]
- ASoC: intel: boards: bytcht*: Constify static snd_soc_ops (Jaroslav Kysela) [2065572]
- ASoC: Intel: hda_dsp_common: don't multiline PCM topology warning (Jaroslav Kysela) [2065572]
- ASoC: mediatek: mt8195: Constify static snd_soc_ops (Jaroslav Kysela) [2065572]
- ASoC: sunxi: sun4i-spdif: Implement IEC958 control (Jaroslav Kysela) [2065572]
- ASoC: qcom: Add support for ALC5682I-VS codec (Jaroslav Kysela) [2065572]
- ASoC: sun8i-codec: Add AIF, ADC, and DAC volume controls (Jaroslav Kysela) [2065572]
- ASoC: soc-pcm: tidyup soc_pcm_pointer()'s delay update method (Jaroslav Kysela) [2065572]
- ASoC: intel: sst-mfld-platform-pcm: add .delay support (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-pcm-dma: add .delay support (Jaroslav Kysela) [2065572]
- ASoC: soc-component: add snd_soc_pcm_component_delay() (Jaroslav Kysela) [2065572]
- ASoC: soc-dai: update snd_soc_dai_delay() to snd_soc_pcm_dai_delay() (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Use %%pR/%%pa to print resources/physical addresses (Jaroslav Kysela) [2065572]
- ASoC: codecs/jz4770: Add missing gain control after DAC/ADC mixer (Jaroslav Kysela) [2065572]
- ASoC: imx-hdmi: add put_device() after of_find_device_by_node() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: send DAI_CONFIG IPC during pause (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: dai: Expand DAI_CONFIG IPC flags (Jaroslav Kysela) [2065572]
- ASoC: SOF: align the hw_free sequence with stop (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: move the check for prepared flag (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add a helper for freeing PCM stream (Jaroslav Kysela) [2065572]
- ASoC: SOF: call platform hw_free for paused streams during suspend (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: invoke platform hw_free for STOP/SUSPEND triggers (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: reset stream before coupling host and link DMA's (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: Add a helper function for stream reset (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: clear stream before freeing the DAI widget (Jaroslav Kysela) [2065572]
- ASoC: rt5640: Add the HDA header support (Jaroslav Kysela) [2065572]
- ASoC: codecs: wcd938x: add SND_SOC_WCD938_SDW to codec list instead (Jaroslav Kysela) [2065572]
- ASoC: uniphier: drop selecting non-existing SND_SOC_UNIPHIER_AIO_DMA (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add missing of_node_put() in platform_parse_resource() (Jaroslav Kysela) [2065572]
- ASoC: mediatek: remove unnecessary CONFIG_PM (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: don't use list_for_each_entry_reverse() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: add .ack support for HDaudio platforms (Jaroslav Kysela) [2065572]
- ASoC: SOF: pcm: add .ack callback support (Jaroslav Kysela) [2065572]
- ASoC: fsl-asoc-card: Support fsl,imx-audio-tlv320aic31xx codec (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Handle BCLK set as PLL input configuration (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Add divs for bclk as clk_in (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Add support for pll_r coefficient (Jaroslav Kysela) [2065572]
- ASoC: tlv320aic31xx: Fix typo in BCLK clock name (Jaroslav Kysela) [2065572]
- ASoC: SOF: sof-pci-dev: use community key on all Up boards (Jaroslav Kysela) [2065572]
- ASoC: stm32: spdifrx: add pm_runtime support (Jaroslav Kysela) [2065572]
- ASoC: stm32: dfsdm: add pm_runtime support for audio (Jaroslav Kysela) [2065572]
- ASoC: stm32: i2s: add pm_runtime support (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: free DAI widget during stop and suspend (Jaroslav Kysela) [2065572]
- ASoC: SOF: add support for dynamic pipelines with multi-core (Jaroslav Kysela) [2065572]
- ASoC: SOF: hda: don't use the core op for power up/power down (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: remove sof_load_pipeline_ipc() (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: CNL/ICL/APL: set core_get/core_put ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: TGL: set core_get/put ops (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add ops for core_get and core_put (Jaroslav Kysela) [2065572]
- ASoC: SOF: Introduce num_cores and ref count per core (Jaroslav Kysela) [2065572]
- ASoC: SOF: Intel: hda: expose get_chip_info() (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8m: Implement reset callback (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8m: Implement DSP start (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8m: Add runtime PM / System PM support (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx8: Add runtime PM / System PM support (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx: Add code to manage DSP related clocks (Jaroslav Kysela) [2065572]
- ASoC: codecs: MBHC: Remove useless condition check (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add DSP system PM callback for mt8195 (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add mt8195 dsp clock support (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add dai driver dsp ops callback for mt8195 (Jaroslav Kysela) [2065572]
- ASoC: SOF: Add mt8195 device descriptor (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add fw loader and mt8195 dsp ops to load firmware (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add support for Mediatek AFE DAI (Jaroslav Kysela) [2065572]
- ASoC: SOF: mediatek: Add mt8195 hardware support (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Fix overrun of unterminated control name string (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Clear core reset for cache (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Move lockdep asserts to avoid potential null pointer (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Allow creation of event controls (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add offset to cs_dsp read/write (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Clarify some kernel doc comments (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Perform NULL check in cs_dsp_coeff_write/read_ctrl (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add support for rev 2 coefficient files (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Print messages from bin files (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add pre_run callback (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add version checks on coefficient loading (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: Add lockdep asserts to interface functions (Jaroslav Kysela) [2065572]
- firmware: cs_dsp: tidy includes in cs_dsp.c and cs_dsp.h (Jaroslav Kysela) [2065572]
- ASoC: wm_adsp: Remove the wmfw_add_ctl helper function (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add support for SOF firmware authentication (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add trace logger support (Jaroslav Kysela) [2065572]
- ASoC: SOF: topology: Add support for AMD ACP DAIs (Jaroslav Kysela) [2065572]
- ASoC: amd: acp-config: Remove legacy acpi based machine struct (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add Renoir PCI driver interface (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add machine driver dsp ops for Renoir platform (Jaroslav Kysela) [2065572]
- ASoC: amd: Add module to determine ACP configuration (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add PCM stream callback for Renoir dai's (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add dai driver dsp ops callback for Renoir (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add IPC support for ACP IP block (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add fw loader and renoir dsp ops to load firmware (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add helper callbacks for ACP's DMA configuration (Jaroslav Kysela) [2065572]
- ASoC: SOF: amd: Add Renoir ACP HW support (Jaroslav Kysela) [2065572]
- ASoC: stm32: sai: increase channels_max limit (Jaroslav Kysela) [2065572]
- ASoC: SOF: debug: Add support for IPC message injection (Jaroslav Kysela) [2065572]
- ASoC: SOF: intel: Use the generic helper to get the reply (Jaroslav Kysela) [2065572]
- ASoC: SOF: imx: Use the generic helper to get the reply (Jaroslav Kysela) [2065572]
- ASoC: SOF: utils: Add generic function to get the reply for a tx message (Jaroslav Kysela) [2065572]
- ASoC: SOF: i.MX: simplify Kconfig (Jaroslav Kysela) [2065572]
- ASoC: qcom: sdm845: only setup slim ports once (Jaroslav Kysela) [2065572]
- ASoC: codecs: MBHC: Add support for special headset (Jaroslav Kysela) [2065572]
- ASoC: SOF: core: Unregister machine driver before IPC and debugfs (Jaroslav Kysela) [2065572]
- ASoC: adau1701: Replace legacy gpio interface for gpiod (Jaroslav Kysela) [2065572]
- ASoC: Intel: add sof-nau8825 machine driver (Jaroslav Kysela) [2065572]
- ASoC: codecs: Axe some dead code in 'wcd_mbhc_adc_hs_rem_irq()' (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: add link adr order check (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: remove get_next_be_id (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: remove sof_sdw_mic_codec_mockup_init (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: remove SOF_RT715_DAI_ID_FIX quirk (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: move DMIC link id overwrite to create_sdw_dailink (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: Use a fixed DAI link id for AMP (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: rename be_index/link_id to link_index (Jaroslav Kysela) [2065572]
- ASoC: Intel: sof_sdw: add SKU for Dell Latitude 9520 (Jaroslav Kysela) [2065572]
- ASoC: intel: sof_sdw: return the original error number (Jaroslav Kysela) [2065572]
- ASoC: SOF: trace: send DMA_TRACE_FREE IPC during release (Jaroslav Kysela) [2065572]
- ASoC: SOF: IPC: update ipc_log_header() (Jaroslav Kysela) [2065572]
- ASoC: codecs: tfa989x: Add support for tfa9897 optional rcv-gpios (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Restore Rane SL-1 quirk (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Don't get sample rate for MCT Trigger 5 USB-to-HDMI (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Clear MIDI port active flag after draining (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: add mapping for MSI MAG X570S Torpedo MAX. (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Limit max buffer and period sizes per time (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Increase max buffer size (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Cap upper limits of buffer/period bytes for implicit fb (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Fix undefined behavior due to shift overflowing the constant (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Add mute TLV for playback volumes on RODE NT-USB (Jaroslav Kysela) [2065572]
- ALSA: scarlett2: Add support for the internal "standalone" switch (Jaroslav Kysela) [2065572]
- ALSA: scarlett2: Split scarlett2_config_items[] into 3 sections (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: add mapping for new Corsair Virtuoso SE (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Don't abort resume upon errors (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: revert to IMPLICIT_FB_FIXED_DEV for M-Audio FastTrack Ultra (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: remove redundant assignment to variable c (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: Correct quirk for VF0770 (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: initialize variables that could ignore errors (Jaroslav Kysela) [2065572]
- ALSA: usb-audio: scarlett2: Use struct_size() helper in scarlett2_usb() (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for HP machine (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for TongFang devices with pop noise (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for the Framework Laptop (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Dell Latitude 7520 (Jaroslav Kysela) [2065572]
- ALSA: hda - fix unused Realtek function when PM is not enabled (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Yoga Duet 7 13ITL6 speakers (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Enable mute/micmute LEDs support for HP Laptops (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix mute led issue on thinkpad with cs35l41 s-codec (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo NP70PNP (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Enable mute/micmute LEDs and limit mic boost on EliteBook 845/865 G9 (Jaroslav Kysela) [2065572]
- ALSA: hda/hdmi: add HDMI codec VID for Raptorlake-P (Jaroslav Kysela) [2065572]
- ALSA: hda/hdmi: fix warning about PCM count when used with SOF (Jaroslav Kysela) [2065572]
- ALSA: nm256: Don't call card private_free at probe error path (Jaroslav Kysela) [2065572]
- ALSA: rme9652: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: hdspm: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: hdsp: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: oxygen: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: lx6464es: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cmipci: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: aw2: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: als300: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: lola: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: bt87x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: sis7019: Fix the missing error handling (Jaroslav Kysela) [2065572]
- ALSA: via82xx: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: sonicvibes: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: rme96: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: rme32: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: riptide: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: maestro3: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: korg1212: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: intel8x0: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ice1724: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: fm801: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: es1968: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: es1938: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ens137x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: emu10k1x: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cs5535audio: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: cs4281: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ca0106: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: azt3328: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: au88x0: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: atiixp: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: als4000: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ali5451: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: ad1889: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: echoaudio: Fix the missing snd_card_free() call at probe error (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: add quirk for Lenovo Thinkpad X12 speakers (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo PD50PNT (Jaroslav Kysela) [2065572]
- ALSA: hda: Avoid unsol event during RPM suspending (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix audio regression on Mi Notebook Pro 2020 (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Add new Dolphin HW variants (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Disable HSBIAS_SENSE_EN for Cyborg (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Support new Warlock MLK Variants (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Fix Full Scale Volume setting for all variants (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Re-order quirk table into ascending order (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Fix Warlock to use mono mic configuration (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Enable headset mic on Lenovo P360 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add mute and micmut LED support for Zbook Fury 17 G9 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add alc256-samsung-headphone fixup (Jaroslav Kysela) [2065572]
- ALSA: pci: fix reading of swapped values from pcmreg in AC97 codec (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix LED on Zbook Studio G9 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for HP machines (Jaroslav Kysela) [2065572]
- ALSA: cmipci: Restore aux vol on suspend/resume (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for ASUS GA402 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek - Fix headset mic problem for a HP machine with alc671 (Jaroslav Kysela) [2065572]
- ALSA: hda: Add AlderLake-PS variant PCI ID (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo NP50PNJ (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Clevo NP70PNJ (Jaroslav Kysela) [2065572]
- ALSA: lola: add a check for the return of vmalloc() (Jaroslav Kysela) [2065572]
- ALSA: echoaudio: remove redundant assignment to variable bytes (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Make use of the helper component_compare_dev_name (Jaroslav Kysela) [2065572]
- ALSA: hda/tegra: Update scratch reg. communication (Jaroslav Kysela) [2065572]
- ALSA: hda/tegra: Hardcode GCAP ISS value on T234 (Jaroslav Kysela) [2065572]
- ALSA: hda/tegra: Add Tegra234 hda driver support (Jaroslav Kysela) [2065572]
- ALSA: hda: Expose codec cleanup and power-save functions (Jaroslav Kysela) [2065572]
- ALSA: hda: Update and expose codec register procedures (Jaroslav Kysela) [2065572]
- ALSA: hda: Update and expose snd_hda_codec_device_init() (Jaroslav Kysela) [2065572]
- ALSA: hda/hdmi: add keep-alive support for ADL-P and DG2 (Jaroslav Kysela) [2065572]
- ALSA: hda: Set max DMA segment size (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix deadlock by COEF mutex (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix missing codec probe on Shenker Dock 15 (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix regression on forced probe mask option (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for Legion Y9000X 2019 (Jaroslav Kysela) [2065572]
- ALSA: hda: Add PCI and HDMI IDs for Intel Raptor Lake (Jaroslav Kysela) [2065572]
- ALSA: ca0106: Rename register macro names (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix driver index handling at re-binding (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add support for HP Laptops (Jaroslav Kysela) [2065572]
- ALSA: hda: Skip codec shutdown in case the codec is not registered (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add quirk for ASUS GU603 (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix silent output on Gigabyte X570 Aorus Xtreme after reboot from Windows (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Fix silent output on Gigabyte X570S Aorus Master (newer chipset) (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add missing fixup-model entry for Gigabyte X570 ALC1220 quirks (Jaroslav Kysela) [2065572]
- ALSA: hda: realtek: Fix race at concurrent COEF updates (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix signedness of sscanf() arguments (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix UAF of leds class devs at unbinding (Jaroslav Kysela) [2065572]
- ALSA: hda/cs8409: Add new Warlock SKUs to patch_cs8409 (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Make cs35l41_hda_remove() return void (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Tidyup code (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Make use of the helper function dev_err_probe() (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Add missing default cases (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Move cs35l41* calls to its own symbol namespace (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Add calls to newly added test key function (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Avoid overwriting register patch (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: fix speakers and micmute on HP 855 G8 (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: fix double free on error in probe() (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix dependencies of CS35L41 on SPI/I2C buses (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Convert tables to shared source code (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix undefined reference to core functions (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: Fix link problem (Jaroslav Kysela) [2065572]
- ASoC: cs35l41: DSP Support (Jaroslav Kysela) [2065572]
- ALSA: hda: Fix dependency on ASoC cs35l41 codec (Jaroslav Kysela) [2065572]
- ALSA: hda: ALC287: Add Lenovo IdeaPad Slim 9i 14ITL5 speaker quirk (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add CS35L41 support for Thinkpad laptops (Jaroslav Kysela) [2065572]
- ALSA: hda/realtek: Add support for Legion 7 16ACHg6 laptop (Jaroslav Kysela) [2065572]
- ALSA: hda: cs35l41: Add support for CS35L41 in HDA systems (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: cs42l42: Convert binding to yaml (Jaroslav Kysela) [2065572]
- ASoC: dt-bindings: cs42l42: Correct description of ts-inv (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Add warnings about DETECT_MODE and PLL_START (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Handle system suspend (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Change jack_detect_mutex to a lock of all IRQ handling (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Report full jack status when plug is detected (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Remove redundant pll_divout member (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Simplify reporting of jack unplug (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Remove redundant writes to RS_PLUG/RS_UNPLUG masks (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Remove redundant writes to DETECT_MODE (Jaroslav Kysela) [2065572]
- ASoC: cs42l42: Add control for audio slow-start switch (Jaroslav Kysela) [2065572]
- ALSA: mixart: Add sanity check for timer notify streams (Jaroslav Kysela) [2065572]
- ALSA: mixart: Reduce size of mixart_timer_notify (Jaroslav Kysela) [2065572]
- ALSA: mtpav: Don't call card private_free at probe error path (Jaroslav Kysela) [2065572]
- ALSA: virmidi: Remove duplicated code (Jaroslav Kysela) [2065572]
- ALSA: memalloc: Add fallback SG-buffer allocations for x86 (Jaroslav Kysela) [2065572]
- ALSA: core: Add snd_card_free_on_error() helper (Jaroslav Kysela) [2065572]
- ALSA: pcm: Test for "silence" field in struct "pcm_format_data" (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix potential AB/BA lock with buffer_mutex and mmap_lock (Jaroslav Kysela) [2065572]
- ALSA: pcm: Add stream lock during PCM reset ioctl operations (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent prealloc proc writes (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent prepare and hw_params/hw_free calls (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent read/write and buffer changes (Jaroslav Kysela) [2065572]
- ALSA: pcm: Fix races among concurrent hw_params and hw_free calls (Jaroslav Kysela) [2065572]
- ALSA: oss: Release temporary buffers upon errors (Jaroslav Kysela) [2065572]
- ALSA: oss: Fix PCM OSS buffer allocation overflow (Jaroslav Kysela) [2065572]
- ALSA: core: Fix typo in 'PCM Timer Interface' help (Jaroslav Kysela) [2065572]
- ALSA: seq: oss: fix typo (Jaroslav Kysela) [2065572]
- ALSA: seq: oss: use kzalloc (Jaroslav Kysela) [2065572]
- ALSA: memalloc: invalidate SG pages before sync (Jaroslav Kysela) [2065572]
- ALSA: memalloc: Fix dma_need_sync() checks (Jaroslav Kysela) [2065572]
- ALSA: core: Simplify snd_power_ref_and_wait() with the standard macro (Jaroslav Kysela) [2065572]
- ALSA: seq: virmidi: Add a drain operation (Jaroslav Kysela) [2065572]
- ASoC: dai_dma: remove slave_id field (Jaroslav Kysela) [2065572]
- ALSA: seq: Set upper limit of processed events (Jaroslav Kysela) [2065572]
- ALSA: oss: remove useless NULL check before kfree (Jaroslav Kysela) [2065572]
- ALSA: pcm: introduce INFO_NO_REWINDS flag (Jaroslav Kysela) [2065572]
- ALSA: pcm: unconditionally check if appl_ptr is in 0..boundary range (Jaroslav Kysela) [2065572]

* Tue Aug 16 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-146.rt21.146.el9]
- [rt] build kernel-rt-5.14.0-146.rt21.146.el9 [2061574]
- cpufreq: fix memory leak in sun50i_cpufreq_nvmem_probe (Mark Langsdorf) [2072976]
- cpufreq: powernow-k8: Re-order the init checks (Mark Langsdorf) [2072976]
- cpufreq: amd-pstate: Add more tracepoint for AMD P-State module (Mark Langsdorf) [2072976]
- cpufreq: CPPC: Fix performance/frequency conversion (Mark Langsdorf) [2072976]
- cpufreq: unify show() and store() naming and use __ATTR_XX (Mark Langsdorf) [2072976]
- cpufreq: longhaul: Replace acpi_bus_get_device() (Mark Langsdorf) [2072976]
- cpufreq: Move to_gov_attr_set() to cpufreq.h (Mark Langsdorf) [2072976]
- cpufreq: use default_groups in kobj_type (Mark Langsdorf) [2072976]
- cpufreq: Fix initialization of min and max frequency QoS requests (Mark Langsdorf) [2072976]
- cpufreq: Fix a comment in cpufreq_policy_free (Mark Langsdorf) [2072976]
- cpufreq: Fix get_cpu_device() failure in add_cpu_dev_symlink() (Mark Langsdorf) [2072976]
- cpufreq: Use CPUFREQ_RELATION_E in DVFS governors (Mark Langsdorf) [2072976]
- cpufreq: Introducing CPUFREQ_RELATION_E (Mark Langsdorf) [2072976]
- cpufreq: Add an interface to mark inefficient frequencies (Mark Langsdorf) [2072976]
- cpufreq: Make policy min/max hard requirements (Mark Langsdorf) [2072976]
- PM: EM: Allow skipping inefficient states (Mark Langsdorf) [2072976]
- PM: EM: Extend em_perf_domain with a flag field (Mark Langsdorf) [2072976]
- PM: EM: Mark inefficient states (Mark Langsdorf) [2072976]
- PM: EM: Fix inefficient states detection (Mark Langsdorf) [2072976]
- PM: EM: Increase energy calculation precision (Mark Langsdorf) [2072976]
- cpufreq: tegra186/tegra194: Handle errors in BPMP response (Mark Langsdorf) [2072976]
- cpufreq: remove useless INIT_LIST_HEAD() (Mark Langsdorf) [2072976]
- cpufreq: s3c244x: add fallthrough comments for switch (Mark Langsdorf) [2072976]
- cpufreq: vexpress: Drop unused variable (Mark Langsdorf) [2072976]
- qede: Reduce verbosity of ptp tx timestamp (Manish Chopra) [2080656]
- redhat/configs: Enable Marvell OcteonTX2 crypto device (Vladis Dronov) [2042239]
- hwrng: cn10k - Enable compile testing (Vladis Dronov) [2042239]
- hwrng: cn10k - Make check_rng_health() return an error code (Vladis Dronov) [2042239]
- hwrng: cn10k - Optimize cn10k_rng_read() (Vladis Dronov) [2042239]
- hwrng: cn10k - Add random number generator support (Vladis Dronov) [2042239]
- hwrng: cavium - fix NULL but dereferenced coccicheck error (Vladis Dronov) [2042261]
- hwrng: cavium - HW_RANDOM_CAVIUM should depend on ARCH_THUNDER (Vladis Dronov) [2042261]
- hwrng: cavium - Check health status while reading random data (Vladis Dronov) [2042261]
- crypto: octeontx2 - fix potential null pointer access (Vladis Dronov) [2041740]
- crypto: octeontx2 - add firmware version in devlink info (Vladis Dronov) [2041740]
- crypto: octeontx2 - simplify the return expression of otx2_cpt_aead_cbc_aes_sha_setkey() (Vladis Dronov) [2041740]
- crypto: octeontx2 - fix missing unlock (Vladis Dronov) [2041740]
- crypto: octeontx2 - add synchronization between mailbox accesses (Vladis Dronov) [2041740]
- crypto: octeontx2 - remove CONFIG_DM_CRYPT check (Vladis Dronov) [2041740]
- crypto: octeontx2 - increase CPT HW instruction queue length (Vladis Dronov) [2041740]
- crypto: octeontx2 - disable DMA black hole on an DMA fault (Vladis Dronov) [2041740]
- crypto: octeontx2 - CN10K CPT to RNM workaround (Vladis Dronov) [2041740]
- crypto: octeontx2 - Avoid stack variable overflow (Vladis Dronov) [2041740]
- crypto: octeontx2 - prevent underflow in get_cores_bmap() (Vladis Dronov) [2041740]
- crypto: octeontx2 - out of bounds access in otx2_cpt_dl_custom_egrp_delete() (Vladis Dronov) [2041740]
- crypto: octeontx2 - Use swap() instead of swap_engines() (Vladis Dronov) [2041740]
- crypto: octeontx2 - parameters for custom engine groups (Vladis Dronov) [2041740]
- crypto: octeontx2 - add apis for custom engine groups (Vladis Dronov) [2041740]
- crypto: octeontx2 - uninitialized variable in kvf_limits_store() (Vladis Dronov) [2041740]
- crypto: octeontx2 - use swap() to make code cleaner (Vladis Dronov) [2041740]
- crypto: octeontx2 - set assoclen in aead_do_fallback() (Vladis Dronov) [2041740]

* Wed Aug 10 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-145.rt21.145.el9]
- [rt] build kernel-rt-5.14.0-145.rt21.145.el9 [2061574]
- KVM: x86: do not report preemption if the steal time cache is stale (Vitaly Kuznetsov) [2115238]
- KVM: x86: revalidate steal time cache if MSR value changes (Vitaly Kuznetsov) [2115238]
- KVM: nVMX: Always enable TSC scaling for L2 when it was enabled for L1 (Vitaly Kuznetsov) [2115238]
- KVM: x86: Fully initialize 'struct kvm_lapic_irq' in kvm_pv_kick_cpu_op() (Vitaly Kuznetsov) [2115238]
- KVM: SEV: Init target VMCBs in sev_migrate_from (Vitaly Kuznetsov) [2115238]
- KVM: SVM: fix tsc scaling cache logic (Vitaly Kuznetsov) [2115238]
- KVM: x86/mmu: Check every prev_roots in __kvm_mmu_free_obsolete_roots() (Vitaly Kuznetsov) [2115238]
- KVM: LAPIC: Drop pending LAPIC timer injection when canceling the timer (Vitaly Kuznetsov) [2115238]
- KVM: x86: avoid calling x86 emulator without a decoded instruction (Vitaly Kuznetsov) [2115238]
- KVM: SVM: Use kzalloc for sev ioctl interfaces to prevent kernel data leak (Vitaly Kuznetsov) [2115238]
- KVM: x86: avoid loading a vCPU after .vm_destroy was called (Vitaly Kuznetsov) [2115238]
- KVM: nVMX: Clear IDT vectoring on nested VM-Exit for double/triple fault (Vitaly Kuznetsov) [2115238]
- KVM: nVMX: Leave most VM-Exit info fields unmodified on failed VM-Entry (Vitaly Kuznetsov) [2115238]
- KVM: x86: Drop WARNs that assert a triple fault never "escapes" from L2 (Vitaly Kuznetsov) [2115238]
- virtio-ring: fix DMA metadata flags (Cindy Lu) [2000425]
- RDMA/cxgb4: Set queue pair state when being queried (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use non-atomic bitmap functions when possible (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use bitmap_set() when applicable (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use bitmap_zalloc() when applicable (Rahul Lakkireddy) [2109523]
- RDMA/cxgb4: Use helper function to set GUIDs (Rahul Lakkireddy) [2109523]
- cxgb4: Use the bitmap API to allocate bitmaps (Rahul Lakkireddy) [2109520]
- cxgb4: Fix typo in string (Rahul Lakkireddy) [2109520]
- cxgb4/cxgb4vf: Fix typo in comments (Rahul Lakkireddy) [2109520]
- cxgb4vf: remove unexpected word "the" (Rahul Lakkireddy) [2109520]
- net: chelsio: cxgb4: Avoid potential negative array offset (Rahul Lakkireddy) [2109520]
- libcxgb: Don't accidentally set RTO_ONLINK in cxgb_find_route() (Rahul Lakkireddy) [2109520]
- cxgb4vf: Remove useless DMA-32 fallback configuration (Rahul Lakkireddy) [2109520]
- cxgb4: Remove useless DMA-32 fallback configuration (Rahul Lakkireddy) [2109520]
- cxgb4: allow reading unrecognized port module eeprom (Rahul Lakkireddy) [2109520]
- net: chelsio: cxgb4vf: Fix an error code in cxgb4vf_pci_probe() (Rahul Lakkireddy) [2109520]
- cxgb4: Use struct_group() for memcpy() region (Rahul Lakkireddy) [2109520]
- cxgb4: fix eeprom len when diagnostics not implemented (Rahul Lakkireddy) [2109520]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Rahul Lakkireddy) [2109520]
- net: chelsio: cxgb4vf: Make use of the helper function dev_err_probe() (Rahul Lakkireddy) [2109520]
- cxgb4: improve printing NIC information (Rahul Lakkireddy) [2109520]
- net: chelsio: switch from 'pci_' to 'dma_' API (Rahul Lakkireddy) [2109520]
- cxgb4: make the array match_all_mac static, makes object smaller (Rahul Lakkireddy) [2109520]
- scsi: mpt3sas: Stop fw fault watchdog work item during system shutdown (Tomas Henzl) [2112378]
- redhat: nvme/tcp mistakenly uses blk_mq_tag_to_rq(nvme_tcp_tagset(queue)) (John Meneghini) [2112031]
- bnxt_en: Fix bnxt_refclk_read() (Ken Cox) [2111502]
- bnxt_en: fix livepatch query (Ken Cox) [2111502]
- bnxt_en: Fix bnxt_reinit_after_abort() code path (Ken Cox) [2111502]
- bnxt_en: reclaim max resources if sriov enable fails (Ken Cox) [2111502]
- eth: bnxt: make ulp_id unsigned to make GCC 12 happy (Ken Cox) [2111502]
- igc: Reinstate IGC_REMOVED logic and implement it properly (Corinna Vinschen) [2037987]
- intel/igc:fix repeated words in comments (Corinna Vinschen) [2037987]
- intel: remove unused macros (Corinna Vinschen) [2037987]
- igc: Change type of the 'igc_check_downshift' method (Corinna Vinschen) [2037987]
- igc: Remove unused phy_type enum (Corinna Vinschen) [2037987]
- igc: Remove igc_set_spd_dplx method (Corinna Vinschen) [2037987]
- igc: Fix suspending when PTM is active (Corinna Vinschen) [2037987]
- igc: Fix BUG: scheduling while atomic (Corinna Vinschen) [2037987]
- igc: Fix infinite loop in release_swfw_sync (Corinna Vinschen) [2037987]
- igc: igc_write_phy_reg_gpy: drop premature return (Corinna Vinschen) [2037987]
- igc: igc_read_phy_reg_gpy: drop premature return (Corinna Vinschen) [2037987]
- igc: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Corinna Vinschen) [2037987]
- igc: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037987]
- igc: switch to napi_build_skb() (Corinna Vinschen) [2037987]
- igc: Remove obsolete define (Corinna Vinschen) [2037987]
- igc: Remove obsolete mask (Corinna Vinschen) [2037987]
- igc: Remove obsolete nvm type (Corinna Vinschen) [2037987]
- igc: Remove unused phy type (Corinna Vinschen) [2037987]
- igc: Remove unused _I_PHY_ID define (Corinna Vinschen) [2037987]

* Tue Aug 09 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-144.rt21.144.el9]
- [rt] build kernel-rt-5.14.0-144.rt21.144.el9 [2061574]
- dm raid: fix address sanitizer warning in raid_resume (Benjamin Marzinski) [2115117]
- dm raid: fix address sanitizer warning in raid_status (Benjamin Marzinski) [2115117]
- dm: return early from dm_pr_call() if DM device is suspended (Benjamin Marzinski) [2115117]
- dm thin: fix use-after-free crash in dm_sm_register_threshold_callback (Benjamin Marzinski) [2115117]
- dm writecache: count number of blocks discarded, not number of discard bios (Benjamin Marzinski) [2115117]
- dm writecache: count number of blocks written, not number of write bios (Benjamin Marzinski) [2115117]
- dm writecache: count number of blocks read, not number of read bios (Benjamin Marzinski) [2115117]
- dm writecache: return void from functions (Benjamin Marzinski) [2115117]
- dm kcopyd: use __GFP_HIGHMEM when allocating pages (Benjamin Marzinski) [2115117]
- dm writecache: set a default MAX_WRITEBACK_JOBS (Benjamin Marzinski) [2115117]
- dm raid: fix KASAN warning in raid5_add_disks (Benjamin Marzinski) [2115117]
- dm raid: fix KASAN warning in raid5_remove_disk (Benjamin Marzinski) [2115117]
- NFS: Fix initialisation of nfs_client cl_flags field (Scott Mayhew) [2114872]
- ipmi: When handling send message responses, don't process the message (Tony Camuso) [2102319]
- net: ena: Do not waste napi skb cache (Michal Schmidt) [2097646]
- opp: Don't print an error if required-opps is missing (Mark Salter) [2112431]
- scsi: smartpqi: Update version to 2.1.18-045 (Don Brace) [2101544]
- scsi: smartpqi: Update copyright to current year (Don Brace) [2101544]
- scsi: smartpqi: Add ctrl ready timeout module parameter (Don Brace) [2101544]
- scsi: smartpqi: Update deleting a LUN via sysfs (Don Brace) [2101544]
- scsi: smartpqi: Add module param to disable managed ints (Don Brace) [2101544]
- scsi: smartpqi: Fix RAID map race condition (Don Brace) [2101544]
- scsi: smartpqi: Fix DMA direction for RAID requests (Don Brace) [2101544]
- scsi: smartpqi: Stop logging spurious PQI reset failures (Don Brace) [2101544]
- scsi: smartpqi: Add PCI IDs for Lenovo controllers (Don Brace) [2101544]
- scsi: smartpqi: Add PCI ID for Adaptec SmartHBA 2100-8i (Don Brace) [2101544]
- scsi: smartpqi: Fix PCI control linkdown system hang (Don Brace) [2101544]
- scsi: smartpqi: Add driver support for multi-LUN devices (Don Brace) [2101544]
- scsi: smartpqi: Close write read holes (Don Brace) [2101544]
- scsi: smartpqi: Add PCI IDs for ramaxel controllers (Don Brace) [2101544]
- scsi: smartpqi: Add controller fw version to console log (Don Brace) [2101544]
- scsi: smartpqi: Shorten drive visibility after removal (Don Brace) [2101544]
- scsi: smartpqi: Fix typo in comment (Don Brace) [2101544]
- xfs: fix maxlevels comparisons in the btree staging code (Andrey Albershteyn) [2106569]
- xfs: use kmem_cache_free() for kmem_cache objects (Andrey Albershteyn) [2106569]
- xfs: fix incorrect unit conversion in scrub tracepoint (Andrey Albershteyn) [2106569]
- xfs: reserve quota for dir expansion when linking/unlinking files (Andrey Albershteyn) [2106569]
- xfs: fix xfs_ifree() error handling to not leak perag ref (Andrey Albershteyn) [2106569]
- xfs: reorder iunlink remove operation in xfs_ifree (Andrey Albershteyn) [2106569]
- xfs: don't generate selinux audit messages for capability testing (Andrey Albershteyn) [2106569]
- scsi: qla2xxx: Fix imbalance vha->vref_count (Nilesh Javali) [2109000]
- ext4: make sure ext4_append() always allocates new block (Lukas Czerner) [2070213]
- ext4: check if directory block is within i_size (Lukas Czerner) [2070213]

* Fri Aug 05 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-143.rt21.143.el9]
- [rt] build kernel-rt-5.14.0-143.rt21.143.el9 [2061574]
- sched, cpuset: Fix dl_cpu_busy() panic due to empty cs->cpus_allowed (Waiman Long) [2104946]
- intel_idle: Fix false positive RCU splats due to incorrect hardirqs state (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- tools headers cpufeatures: Sync with the kernel sources (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- um: Add missing apply_returns() (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: emulate: do not adjust size of fastop and setcc subroutines (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm: fix FASTOP_SIZE when return thunks are enabled (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- efi/x86: use naked RET on mixed mode call wrapper (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Remove apostrophe typo (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Use DECLARE_PER_CPU for x86_spec_ctrl_current (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Remove UNTRAIN_RET from native_irq_return_ldt (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Mark retbleed_strings static (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/asm/32: Fix ANNOTATE_UNRET_SAFE use on 32-bit (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/static_call: Serialize __static_call_fixup() properly (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Disable RRSBA behavior (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kexec: Disable RET on kexec (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Do not enable IBPB-on-entry when IBPB is not supported (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Move PUSH_AND_CLEAR_REGS() back into error_entry (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add Cannon lake to RETBleed affected CPU list (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- redhat/configs: Add new mitigation configs for RetBleed CVEs (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retbleed: Add fine grained Kconfig knobs (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpu/amd: Enumerate BTC_NO (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/common: Stamp out the stepping madness (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Prevent RSB underflow before vmenter (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fill RSB on vmexit for IBRS (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Fix IBRS handling after vmexit (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Prevent guest RSB poisoning attacks with eIBRS (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Convert launched argument to flags (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- KVM: VMX: Flatten __vmx_vcpu_run() (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: Re-add UNWIND_HINT_{SAVE_RESTORE} (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Remove x86_spec_ctrl_mask (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Use cached host SPEC_CTRL value for guest entry/exit (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fix SPEC_CTRL write on SMT state change (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fix firmware entry SPEC_CTRL handling (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Fix RSB filling with CONFIG_RETPOLINE=n (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpu/amd: Add Spectral Chicken (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Do IBPB fallback check only once (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add retbleed=ibpb (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/xen: Add UNTRAIN_RET (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/xen: Rename SYS* entry points (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: Update Retpoline validation (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- intel_idle: Disable IBRS during long idle (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Report Intel retbleed vulnerability (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Split spectre_v2_select_mitigation() and spectre_v2_user_select_mitigation() (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/speculation: Add spectre_v2=ibrs option to support Kernel IBRS (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Optimize SPEC_CTRL MSR writes (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Add kernel IBRS implementation (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Keep a per-CPU IA32_SPEC_CTRL value (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Enable STIBP for JMP2RET (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Add AMD retbleed= boot parameter (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bugs: Report AMD retbleed vulnerability (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: skip non-text sections when adding return-thunk sites (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Add magic AMD return-thunk (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- objtool: Treat .text.__x86.* as noinstr (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Avoid very early RET (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Use return-thunk in asm code (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/sev: Avoid using __x86_return_thunk (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/vsyscall_emu/64: Don't use RET in vsyscall emulation (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm: Fix SETcc emulation for return thunks (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/bpf: Use alternative RET encoding (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/ftrace: Use alternative RET encoding (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86,static_call: Use alternative RET encoding (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86,objtool: Create .return_sites (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86: Undo return-thunk damage (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Use -mfunction-return (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Swizzle retpoline thunk (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/retpoline: Cleanup some #ifdefery (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/cpufeatures: Move RETPOLINE flags to word 11 (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/kvm/vmx: Make noinstr clean (Waiman Long) [2090232] {CVE-2022-23816 CVE-2022-23825 CVE-2022-29900 CVE-2022-29901}
- x86/entry: Fix register corruption in compat syscall (Waiman Long) [2090232]
- x86/entry: Remove skip_r11rcx (Waiman Long) [2090232]
- x86/entry: Use PUSH_AND_CLEAR_REGS for compat (Waiman Long) [2090232]
- x86/entry: Simplify entry_INT80_compat() (Waiman Long) [2090232]
- x86/entry: Don't call error_entry() for XENPV (Waiman Long) [2090232]
- x86/entry: Move CLD to the start of the idtentry macro (Waiman Long) [2090232]
- x86/entry: Move PUSH_AND_CLEAR_REGS out of error_entry() (Waiman Long) [2090232]
- x86/entry: Switch the stack after error_entry() returns (Waiman Long) [2090232]
- x86/traps: Use pt_regs directly in fixup_bad_iret() (Waiman Long) [2090232]
- x86/retpoline: Add ANNOTATE_NOENDBR for retpolines (Waiman Long) [2090232]
- x86/static_call: Add ANNOTATE_NOENDBR to static call trampoline (Waiman Long) [2090232]
- objtool: Fix SLS validation for kcov tail-call replacement (Waiman Long) [2090232]
- x86,static_call: Fix __static_call_return0 for i386 (Waiman Long) [2090232]
- crypto: x86/poly1305 - Fixup SLS (Waiman Long) [2090232]
- kvm/emulate: Fix SETcc emulation for ENDBR (Waiman Long) [2090232]
- x86/ibt: Annotate text references (Waiman Long) [2090232]
- x86/alternative: Simplify int3_selftest_ip (Waiman Long) [2090232]
- x86/ibt,kvm: Add ENDBR to fastops (Waiman Long) [2090232]
- x86/ibt,entry: Sprinkle ENDBR dust (Waiman Long) [2090232]
- x86/ibt,xen: Sprinkle the ENDBR (Waiman Long) [2090232]
- x86/entry: Cleanup PARAVIRT (Waiman Long) [2090232]
- x86/ibt: Add ANNOTATE_NOENDBR (Waiman Long) [2090232]
- redhat/configs: Disable CONFIG_X86_KERNEL_IBT (Waiman Long) [2090232]
- x86/ibt: Base IBT bits (Waiman Long) [2090232]
- objtool,efi: Update __efi64_thunk annotation (Waiman Long) [2090232]
- objtool: Fix truncated string warning (Waiman Long) [2090232]
- redhat/configs: Disable CONFIG_SLS (Waiman Long) [2090232]
- x86: Add straight-line-speculation mitigation (Waiman Long) [2090232]
- x86/alternative: Relax text_poke_bp() constraint (Waiman Long) [2090232]
- objtool: Add straight-line-speculation validation (Waiman Long) [2090232]
- x86: Prepare inline-asm for straight-line-speculation (Waiman Long) [2090232]
- x86: Prepare asm files for straight-line-speculation (Waiman Long) [2090232]
- x86/mce: Reduce number of machine checks taken during recovery (Waiman Long) [2090232]
- x86/lib/atomic64_386_32: Rename things (Waiman Long) [2090232]
- x86: Use -mindirect-branch-cs-prefix for RETPOLINE builds (Waiman Long) [2090232]
- x86: Move RETPOLINE*_CFLAGS to arch Makefile (Waiman Long) [2090232]
- x86/xen: Add xenpv_restore_regs_and_return_to_usermode() (Waiman Long) [2090232]
- x86/entry: Use the correct fence macro after swapgs in kernel CR3 (Waiman Long) [2090232]
- x86/entry: Add a fence for kernel entry SWAPGS in paranoid_entry() (Waiman Long) [2090232]
- objtool: Fix pv_ops noinstr validation (Waiman Long) [2090232]
- static_call,x86: Robustify trampoline patching (Waiman Long) [2090232]
- x86/xen: switch initial pvops IRQ functions to dummy ones (Waiman Long) [2090232]
- bpf,x86: Respect X86_FEATURE_RETPOLINE* (Waiman Long) [2090232]
- x86/alternative: Add debug prints to apply_retpolines() (Waiman Long) [2090232]
- x86/alternative: Try inline spectre_v2=retpoline,amd (Waiman Long) [2090232]
- x86/alternative: Handle Jcc __x86_indirect_thunk_\reg (Waiman Long) [2090232]
- x86/alternative: Implement .retpoline_sites support (Waiman Long) [2090232]
- x86/retpoline: Create a retpoline thunk array (Waiman Long) [2090232]
- x86/retpoline: Move the retpoline thunk declarations to nospec-branch.h (Waiman Long) [2090232]
- x86/asm: Fixup odd GEN-for-each-reg.h usage (Waiman Long) [2090232]
- x86/asm: Fix register order (Waiman Long) [2090232]
- x86/retpoline: Remove unused replacement symbols (Waiman Long) [2090232]
- objtool,x86: Replace alternatives with .retpoline_sites (Waiman Long) [2090232]
- objtool: Shrink struct instruction (Waiman Long) [2090232]
- objtool: Explicitly avoid self modifying code in .altinstr_replacement (Waiman Long) [2090232]
- objtool: Classify symbols (Waiman Long) [2090232]
- objtool: Remove reloc symbol type checks in get_alt_entry() (Waiman Long) [2090232]
- objtool: print out the symbol type when complaining about it (Waiman Long) [2090232]
- objtool: Teach get_alt_entry() about more relocation types (Waiman Long) [2090232]
- kbuild: reuse $(cmd_objtool) for cmd_cc_lto_link_modules (Waiman Long) [2090232]
- kbuild: detect objtool update without using .SECONDEXPANSION (Waiman Long) [2090232]
- kbuild: factor out OBJECT_FILES_NON_STANDARD check into a macro (Waiman Long) [2090232]
- kbuild: store the objtool command in *.cmd files (Waiman Long) [2090232]
- kbuild: rename __objtool_obj and reuse it for cmd_cc_lto_link_modules (Waiman Long) [2090232]
- kbuild: move objtool_args back to scripts/Makefile.build (Waiman Long) [2090232]
- x86/mce: Drop copyin special case for #MC (Waiman Long) [2090232]
- objtool: Support pv_opsindirect calls for noinstr (Waiman Long) [2090232]
- x86/xen: Rework the xen_{cpu,irq,mmu}_opsarrays (Waiman Long) [2090232]
- objtool: Handle __sanitize_cov*() tail calls (Waiman Long) [2090232]
- objtool: Introduce CFI hash (Waiman Long) [2090232]
- kbuild: clean up objtool_args slightly (Waiman Long) [2090232]
- kbuild: remove stale *.symversions (Waiman Long) [2090232]
- kbuild: remove unused quiet_cmd_update_lto_symversions (Waiman Long) [2090232]
- kbuild: Fix TRIM_UNUSED_KSYMS with LTO_CLANG (Waiman Long) [2090232]
- Makefile: remove stale cc-option checks (Waiman Long) [2090232]
- x86/build: Remove stale cc-option checks (Waiman Long) [2090232]
- xen: assume XENFEAT_mmu_pt_update_preserve_ad being set for pv guests (Waiman Long) [2090232]
- dmaengine: idxd: Fixup upstream merge conflict resolution (Jerry Snitselaar) [2100482]
- dmaengine: idxd: skip clearing device context when device is read-only (Jerry Snitselaar) [2100482]
- dmaengine: idxd: add RO check for wq max_transfer_size write (Jerry Snitselaar) [2100482]
- dmaengine: idxd: add RO check for wq max_batch_size write (Jerry Snitselaar) [2100482]
- dmaengine: idxd: fix device cleanup on disable (Jerry Snitselaar) [2100482]
- Revert "dmaengine: idxd: Separate user and kernel pasid enabling" (Jerry Snitselaar) [2100482]

* Thu Aug 04 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-142.rt21.142.el9]
- [rt] build kernel-rt-5.14.0-142.rt21.142.el9 [2061574]
- sit: do not call ipip6_dev_free() from sit_init_net() (Hangbin Liu) [2089080]
- net: ping6: Fix memleak in ipv6_renew_options(). (Ivan Vecera) [2112338]
- dma-direct: use the correct size for dma_set_encrypted() (Jerry Snitselaar) [2105609]
- dma-debug: make things less spammy under memory pressure (Jerry Snitselaar) [2105609]
- dma-iommu: Check that swiotlb is active before trying to use it (Jerry Snitselaar) [2105609]
- Documentation: add a description for net.core.high_order_alloc_disable (Antoine Tenart) [2068582]
- Input: bcm5974 - set missing URB_NO_TRANSFER_DMA_MAP urb flag (Benjamin Tissoires) [2070873]
- Input: add Marine Navigation Keycodes (Benjamin Tissoires) [2070873]
- Revert "Input: clear BTN_RIGHT/MIDDLE on buttonpads" (Benjamin Tissoires) [2070873]
- Input: synaptics - enable InterTouch on ThinkPad T14/P14s Gen 1 AMD (Benjamin Tissoires) [2070873]
- Input: add bounds checking to input_set_capability() (Benjamin Tissoires) [2070873]
- Input: add input_copy_abs() function (Benjamin Tissoires) [2070873]
- Input: set EV_ABS in dev->evbit even if input_alloc_absinfo() fails (Benjamin Tissoires) [2070873]
- Input: aiptek - properly check endpoint type (Benjamin Tissoires) [2070873]
- Input: elan_i2c - fix regulator enable count imbalance after suspend/resume (Benjamin Tissoires) [2070873]
- Input: elan_i2c - move regulator_[en|dis]able() out of elan_[en|dis]able_power() (Benjamin Tissoires) [2070873]
- Input: psmouse - set up dependency between PS/2 and SMBus companions (Benjamin Tissoires) [2070873]
- Input: clear BTN_RIGHT/MIDDLE on buttonpads (Benjamin Tissoires) [2070873]
- Input: gpio-keys - avoid clearing twice some memory (Benjamin Tissoires) [2070873]
- Input: byd - fix typo in a comment (Benjamin Tissoires) [2070873]
- Input: ff-core - correct magnitude setting for rumble compatibility (Benjamin Tissoires) [2070873]
- Input: wacom_i2c - clean up the query device fields (Benjamin Tissoires) [2070873]
- Input: appletouch - initialize work before device registration (Benjamin Tissoires) [2070873]
- Input: elants_i2c - do not check Remark ID on eKTH3900/eKTH5312 (Benjamin Tissoires) [2070873]
- Input: i8042 - enable deferred probe quirk for ASUS UM325UA (Benjamin Tissoires) [2070873]
- Input: elantech - fix stack out of bound access in elantech_change_report_id() (Benjamin Tissoires) [2070873]
- Input: i8042 - add deferred probe support (Benjamin Tissoires) [2070873]
- Input: wacom_i2c - use macros for the bit masks (Benjamin Tissoires) [2070873]
- Input: elantench - fix misreporting trackpoint coordinates (Benjamin Tissoires) [2070873]
- Input: synaptics-rmi4 - Fix device hierarchy (Benjamin Tissoires) [2070873]
- Input: remove unused header <linux/input/cy8ctmg110_pdata.h> (Benjamin Tissoires) [2070873]
- Input: elants_i2c - make use of devm_add_action_or_reset() (Benjamin Tissoires) [2070873]
- Input: touchscreen - avoid bitwise vs logical OR warning (Benjamin Tissoires) [2070873]
- Input: elan_i2c - reduce the resume time for controller in Whitebox (Benjamin Tissoires) [2070873]
- Input: Fix spelling mistake in Kconfig "useable" -> "usable" (Benjamin Tissoires) [2070873]
- Input: Fix spelling mistake in Kconfig "Modul" -> "Module" (Benjamin Tissoires) [2070873]
- Input: remove dead CSR Prima2 PWRC driver (Benjamin Tissoires) [2070873]
- Input: parkbd - switch to use module_parport_driver() (Benjamin Tissoires) [2070873]
- Revert "Input: serio - make write method mandatory" (Benjamin Tissoires) [2070873]
- Input: serio - make write method mandatory (Benjamin Tissoires) [2070873]
- Input: ixp4xx-beeper - delete driver (Benjamin Tissoires) [2070873]
- HID: elan: Fix potential double free in elan_input_configured (Benjamin Tissoires) [2070873]
- HID: hid-led: fix maximum brightness for Dream Cheeky (Benjamin Tissoires) [2070873]
- HID: bigben: fix slab-out-of-bounds Write in bigben_probe (Benjamin Tissoires) [2070873]
- HID: multitouch: add quirks to enable Lenovo X12 trackpoint (Benjamin Tissoires) [2070873]
- HID: multitouch: Add support for Google Whiskers Touchpad (Benjamin Tissoires) [2070873]
- HID: Add driver for Razer Blackwidow keyboards (Benjamin Tissoires) [2070873]
- HID: add SiGma Micro driver (Benjamin Tissoires) [2070873]
- HID: google: modify HID device groups of eel (Benjamin Tissoires) [2070873]
- HID: google: Add support for vivaldi to hid-hammer (Benjamin Tissoires) [2070873]
- HID: google: extract Vivaldi hid feature mapping for use in hid-hammer (Benjamin Tissoires) [2070873]
- Input: extract ChromeOS vivaldi physmap show function (Benjamin Tissoires) [2070873]
- HID: google: switch to devm when registering keyboard backlight LED (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: Use dma_alloc_coherent for firmware update (Benjamin Tissoires) [2070873]
- HID: input: accommodate priorities for slotted devices (Benjamin Tissoires) [2070873]
- HID: input: remove the need for HID_QUIRK_INVERT (Benjamin Tissoires) [2070873]
- HID: input: enforce Invert usage to be processed before InRange (Benjamin Tissoires) [2070873]
- HID: core: for input reports, process the usages by priority list (Benjamin Tissoires) [2070873]
- HID: compute an ordered list of input fields to process (Benjamin Tissoires) [2070873]
- HID: input: move up out-of-range processing of input values (Benjamin Tissoires) [2070873]
- HID: input: rework spaghetti code with switch statements (Benjamin Tissoires) [2070873]
- HID: input: tag touchscreens as such if the physical is not there (Benjamin Tissoires) [2070873]
- HID: core: split data fetching from processing in hid_input_field() (Benjamin Tissoires) [2070873]
- HID: core: de-duplicate some code in hid_input_field() (Benjamin Tissoires) [2070873]
- HID: core: statically allocate read buffers (Benjamin Tissoires) [2070873]
- HID: uclogic: Support multiple frame input devices (Benjamin Tissoires) [2070873]
- HID: uclogic: Define report IDs before their descriptors (Benjamin Tissoires) [2070873]
- HID: uclogic: Put version first in rdesc namespace (Benjamin Tissoires) [2070873]
- HID: uclogic: Use "frame" instead of "buttonpad" (Benjamin Tissoires) [2070873]
- HID: uclogic: Use different constants for frame report IDs (Benjamin Tissoires) [2070873]
- HID: uclogic: Specify total report size to buttonpad macro (Benjamin Tissoires) [2070873]
- HID: uclogic: Switch to matching subreport bytes (Benjamin Tissoires) [2070873]
- HID: uclogic: Replace pen_frame_flag with subreport_list (Benjamin Tissoires) [2070873]
- HID: uclogic: Remove pen usage masking (Benjamin Tissoires) [2070873]
- HID: apple: properly reflect LEDS dependency (Benjamin Tissoires) [2070873]
- HID: apple: Add fn mapping for MacBook Pros with Touch Bar (Benjamin Tissoires) [2070873]
- HID: apple: Add necessary IDs and configuration for T2 Macs. (Benjamin Tissoires) [2070873]
- HID: apple: Add support for keyboard backlight on certain T2 Macs. (Benjamin Tissoires) [2070873]
- HID: apple: Report Magic Keyboard 2021 with fingerprint reader battery over USB (Benjamin Tissoires) [2070873]
- HID: apple: Report Magic Keyboard 2021 battery over USB (Benjamin Tissoires) [2070873]
- HID: apple: Magic Keyboard 2015 FN key mapping (Benjamin Tissoires) [2070873]
- HID: apple: Magic Keyboard first generation FN key mapping (Benjamin Tissoires) [2070873]
- HID: apple: Refactor key translation setup (Benjamin Tissoires) [2070873]
- HID: uclogic: Handle virtual frame reports (Benjamin Tissoires) [2070873]
- HID: uclogic: Skip non-input raw events earlier (Benjamin Tissoires) [2070873]
- HID: uclogic: Access pen/frame params directly in raw_event handling (Benjamin Tissoires) [2070873]
- HID: uclogic: Split pen and frame raw event handling (Benjamin Tissoires) [2070873]
- HID: uclogic: Support Huion 13th frame button (Benjamin Tissoires) [2070873]
- HID: uclogic: Rename Huion HS64 PID to Huion Tablet 2 (Benjamin Tissoires) [2070873]
- HID: uclogic: Support Huion tilt reporting (Benjamin Tissoires) [2070873]
- HID: i2c-hid: remove unneeded semicolon (Benjamin Tissoires) [2070873]
- HID: i2c-hid: note that I2C xfer buffers are DMA-safe (Benjamin Tissoires) [2070873]
- HID: i2c-hid: no longer need raw access to HID descriptor structure (Benjamin Tissoires) [2070873]
- HID: i2c-hid: use helpers to do endian conversion in i2c_hid_get_input() (Benjamin Tissoires) [2070873]
- HID: i2c-hid: rework i2c_hid_get_report() to use i2c_hid_xfer() (Benjamin Tissoires) [2070873]
- HID: i2c-hid: convert i2c_hid_execute_reset() to use i2c_hid_xfer() (Benjamin Tissoires) [2070873]
- HID: i2c-hid: create a helper for SET_POWER command (Benjamin Tissoires) [2070873]
- HID: i2c-hid: define i2c_hid_read_register() and use it (Benjamin Tissoires) [2070873]
- HID: i2c-hid: explicitly code setting and sending reports (Benjamin Tissoires) [2070873]
- HID: i2c-hid: refactor reset command (Benjamin Tissoires) [2070873]
- HID: i2c-hid: use "struct i2c_hid" as argument in most calls (Benjamin Tissoires) [2070873]
- HID: i2c-hid: fix GET/SET_REPORT for unnumbered reports (Benjamin Tissoires) [2070873]
- HID: i2c-hid: fix handling numbered reports with IDs of 15 and above (Benjamin Tissoires) [2070873]
- HID: google: Use struct_size() helper in kzalloc() (Benjamin Tissoires) [2070873]
- HID: Add new Letsketch tablet driver (Benjamin Tissoires) [2070873]
- HID: elo: Revert USB reference counting (Benjamin Tissoires) [2070873]
- HID: elo: fix memory leak in elo_probe (Benjamin Tissoires) [2070873]
- HID: add mapping for KEY_ALL_APPLICATIONS (Benjamin Tissoires) [2070873]
- HID: add mapping for KEY_DICTATE (Benjamin Tissoires) [2070873]
- HID: nintendo: check the return value of alloc_workqueue() (Benjamin Tissoires) [2070873]
- HID: vivaldi: fix sysfs attributes leak (Benjamin Tissoires) [2070873]
- HID: hid-thrustmaster: fix OOB read in thrustmaster_interrupts (Benjamin Tissoires) [2070873]
- HID: Add support for open wheel and no attachment to T300 (Benjamin Tissoires) [2070873]
- HID: logitech-dj: add new lightspeed receiver id (Benjamin Tissoires) [2070873]
- HID:Add support for UGTABLET WP5540 (Benjamin Tissoires) [2070873]
- HID: i2c-hid: goodix: Fix a lockdep splat (Benjamin Tissoires) [2070873]
- HID: apple: Set the tilde quirk flag on the Wellspring 5 and later (Benjamin Tissoires) [2070873]
- HID: wacom: Avoid using stale array indicies to read contact count (Benjamin Tissoires) [2070873]
- HID: wacom: Ignore the confidence flag when a touch is removed (Benjamin Tissoires) [2070873]
- HID: wacom: Reset expected and received contact counts at the same time (Benjamin Tissoires) [2070873]
- HID: uhid: Use READ_ONCE()/WRITE_ONCE() for ->running (Benjamin Tissoires) [2070873]
- HID: uhid: Fix worker destroying device without any protection (Benjamin Tissoires) [2070873]
- HID: vivaldi: Minor cleanups (Benjamin Tissoires) [2070873]
- HID: vivaldi: fix handling devices not using numbered reports (Benjamin Tissoires) [2070873]
- HID: Ignore battery for Elan touchscreen on HP Envy X360 15t-dr100 (Benjamin Tissoires) [2070873]
- HID: magicmouse: Fix an error handling path in magicmouse_probe() (Benjamin Tissoires) [2070873]
- HID: address kernel-doc warnings (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: ishtp-fw-loader: Fix a kernel-doc formatting issue (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: ipc: Specify no cache snooping on TGL and ADL (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_frame_init_v1_buttonpad (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_huion_init (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_get_str_desc (Benjamin Tissoires) [2070873]
- HID: hid-uclogic-params: Invalid parameter check in uclogic_params_init (Benjamin Tissoires) [2070873]
- HID: apple: Add Magic Keyboard 2021 with fingerprint reader FN key mapping (Benjamin Tissoires) [2070873]
- HID: apple: Add 2021 magic keyboard FN key mapping (Benjamin Tissoires) [2070873]
- HID: magicmouse: set Magic Trackpad 2021 name (Benjamin Tissoires) [2070873]
- HID: magicmouse: set device name when it has been personalized (Benjamin Tissoires) [2070873]
- HID: apple: Add 2021 Magic Keyboard with number pad (Benjamin Tissoires) [2070873]
- HID: apple: Add 2021 Magic Keyboard with fingerprint reader (Benjamin Tissoires) [2070873]
- HID: i2c-hid-of: Expose the touchscreen-inverted properties (Benjamin Tissoires) [2070873]
- HID: quirks: Allow inverting the absolute X/Y values (Benjamin Tissoires) [2070873]
- HID: hidraw: Replace hidraw device table mutex with a rwsem (Benjamin Tissoires) [2070873]
- HID: thrustmaster use swap() to make code cleaner (Benjamin Tissoires) [2070873]
- HID: debug: Add USI usages (Benjamin Tissoires) [2070873]
- HID: input: Make hidinput_find_field() static (Benjamin Tissoires) [2070873]
- HID: Add hid usages for USI style pens (Benjamin Tissoires) [2070873]
- HID: hid-input: Add suffix also for HID_DG_PEN (Benjamin Tissoires) [2070873]
- HID: Add map_msc() to avoid boilerplate code (Benjamin Tissoires) [2070873]
- HID: do not inline some hid_hw_ functions (Benjamin Tissoires) [2070873]
- HID: add suspend/resume helpers (Benjamin Tissoires) [2070873]
- HID: apple: Report Magic Keyboard battery over USB (Benjamin Tissoires) [2070873]
- HID: apple: Use BIT to define quirks (Benjamin Tissoires) [2070873]
- HID: apple: Do not reset quirks when the Fn key is not found (Benjamin Tissoires) [2070873]
- HID: magicmouse: Report battery level over USB (Benjamin Tissoires) [2070873]
- HID: i2c-hid: Report wakeup events (Benjamin Tissoires) [2070873]
- HID: potential dereference of null pointer (Benjamin Tissoires) [2070873]
- HID: holtek: fix mouse probing (Benjamin Tissoires) [2070873]
- HID: Ignore battery for Elan touchscreen on Asus UX550VE (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: ipc: only enable IRQ wakeup when requested (Benjamin Tissoires) [2070873]
- HID: google: add eel USB id (Benjamin Tissoires) [2070873]
- HID: add USB_HID dependancy to hid-prodikeys (Benjamin Tissoires) [2070873]
- HID: add USB_HID dependancy to hid-chicony (Benjamin Tissoires) [2070873]
- HID: bigbenff: prevent null pointer dereference (Benjamin Tissoires) [2070873]
- HID: sony: fix error path in probe (Benjamin Tissoires) [2070873]
- HID: add USB_HID dependancy on some USB HID drivers (Benjamin Tissoires) [2070873]
- HID: check for valid USB device for many HID drivers (Benjamin Tissoires) [2070873]
- HID: wacom: fix problems when device is not a valid USB device (Benjamin Tissoires) [2070873]
- HID: add hid_is_usb() function to make it simpler for USB detection (Benjamin Tissoires) [2070873]
- HID: quirks: Add quirk for the Microsoft Surface 3 type-cover (Benjamin Tissoires) [2070873]
- HID: multitouch: Fix Iiyama ProLite T1931SAW (0eef:0001 again!) (Benjamin Tissoires) [2070873]
- HID: nintendo: eliminate dead datastructures in !CONFIG_NINTENDO_FF case (Benjamin Tissoires) [2070873]
- HID: magicmouse: prevent division by 0 on scroll (Benjamin Tissoires) [2070873]
- HID: thrustmaster: fix sparse warnings (Benjamin Tissoires) [2070873]
- HID: Ignore battery for Elan touchscreen on HP Envy X360 15-eu0xxx (Benjamin Tissoires) [2070873]
- HID: input: set usage type to key on keycode remap (Benjamin Tissoires) [2070873]
- HID: input: Fix parsing of HID_CP_CONSUMER_CONTROL fields (Benjamin Tissoires) [2070873]
- HID: ft260: fix i2c probing for hwmon devices (Benjamin Tissoires) [2070873]
- Revert "HID: hid-asus.c: Maps key 0x35 (display off) to KEY_SCREENLOCK" (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: fix module device-id handling (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: hid-client: only load for matching devices (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: fw-loader: only load for matching devices (Benjamin Tissoires) [2070873]
- HID: intel-ish-hid: use constants for modaliases (Benjamin Tissoires) [2070873]
- HID: wacom: Use "Confidence" flag to prevent reporting invalid contacts (Benjamin Tissoires) [2070873]
- HID: nintendo: unlock on error in joycon_leds_create() (Benjamin Tissoires) [2070873]
- HID: nintendo: fix -Werror build (Benjamin Tissoires) [2070873]
- HID: playstation: require multicolor LED functionality (Benjamin Tissoires) [2070873]
- HID: u2fzero: properly handle timeouts in usb_submit_urb (Benjamin Tissoires) [2070873]
- HID: u2fzero: clarify error check and length calculations (Benjamin Tissoires) [2070873]
- HID: u2fzero: Support NitroKey U2F revision of the device (Benjamin Tissoires) [2070873]
- HID: wacom: Make use of the helper function devm_add_action_or_reset() (Benjamin Tissoires) [2070873]
- HID: wacom: Shrink critical section in `wacom_add_shared_data` (Benjamin Tissoires) [2070873]
- HID: nintendo: prevent needless queueing of the rumble worker (Benjamin Tissoires) [2070873]
- HID: nintendo: ratelimit subcommands and rumble (Benjamin Tissoires) [2070873]
- HID: nintendo: improve rumble performance and stability (Benjamin Tissoires) [2070873]
- HID: nintendo: add IMU support (Benjamin Tissoires) [2070873]
- HID: nintendo: add support for reading user calibration (Benjamin Tissoires) [2070873]
- HID: nintendo: add support for charging grip (Benjamin Tissoires) [2070873]
- HID: nintendo: set controller uniq to MAC (Benjamin Tissoires) [2070873]
- HID: nintendo: reduce device removal subcommand errors (Benjamin Tissoires) [2070873]
- HID: nintendo: patch hw version for userspace HID mappings (Benjamin Tissoires) [2070873]
- HID: nintendo: send subcommands after receiving input report (Benjamin Tissoires) [2070873]
- HID: nintendo: improve subcommand reliability (Benjamin Tissoires) [2070873]
- HID: nintendo: add rumble support (Benjamin Tissoires) [2070873]
- HID: nintendo: add home led support (Benjamin Tissoires) [2070873]
- HID: nintendo: add power supply support (Benjamin Tissoires) [2070873]
- HID: nintendo: add player led support (Benjamin Tissoires) [2070873]
- HID: nintendo: add nintendo switch controller driver (Benjamin Tissoires) [2070873]
- HID: playstation: fix return from dualsense_player_led_set_brightness() (Benjamin Tissoires) [2070873]
- HID: playstation: expose DualSense player LEDs through LED class. (Benjamin Tissoires) [2070873]
- leds: add new LED_FUNCTION_PLAYER for player LEDs for game controllers. (Benjamin Tissoires) [2070873]
- Documentation: leds: standartizing LED names (Benjamin Tissoires) [2070873]
- HID: playstation: expose DualSense lightbar through a multi-color LED. (Benjamin Tissoires) [2070873]
- HID: surface-hid: Allow driver matching for target ID 1 devices (Benjamin Tissoires) [2070873]
- HID: surface-hid: Use correct event registry for managing HID events (Benjamin Tissoires) [2070873]
- HID: hid-asus.c: Maps key 0x35 (display off) to KEY_SCREENLOCK (Benjamin Tissoires) [2070873]
- HID: apple: Bring back flag for Apple tilde key quirk (Benjamin Tissoires) [2070873]
- HID: apple: Add support for the 2021 Magic Keyboard (Benjamin Tissoires) [2070873]
- HID: apple: Rename MAGIC_KEYBOARD_ANSI to MAGIC_KEYBOARD_2015 (Benjamin Tissoires) [2070873]
- HID: multitouch: disable sticky fingers for UPERFECT Y (Benjamin Tissoires) [2070873]
- HID: cougar: Make use of the helper function devm_add_action_or_reset() (Benjamin Tissoires) [2070873]
- HID: roccat: Use struct_group() to zero kone_mouse_event (Benjamin Tissoires) [2070873]
- HID: cp2112: Use struct_group() for memcpy() region (Benjamin Tissoires) [2070873]
- HID: Add support for side buttons of Xiaomi Mi Dual Mode Wireless Mouse Silent (Benjamin Tissoires) [2070873]
- HID: hid-debug: clean up snprintf() checks in hid_resolv_usage() (Benjamin Tissoires) [2070873]
- HID: apple: Eliminate obsolete IR receiver quirks (Benjamin Tissoires) [2070873]
- HID: core: add TransducerSerialNumber2 (Benjamin Tissoires) [2070873]
- HID: u2fzero: ignore incomplete packets without data (Benjamin Tissoires) [2070873]
- HID: wacom: Add new Intuos BT (CTL-4100WL/CTL-6100WL) device IDs (Benjamin Tissoires) [2070873]
- HID: apple: Fix logical maximum and usage maximum of Magic Keyboard JIS (Benjamin Tissoires) [2070873]
- HID: betop: fix slab-out-of-bounds Write in betop_probe (Benjamin Tissoires) [2070873]
- HID: usbhid: Simplify code in hid_submit_ctrl() (Benjamin Tissoires) [2070873]
- HID: usbhid: Fix warning caused by 0-length input reports (Benjamin Tissoires) [2070873]
- HID: usbhid: Fix flood of "control queue full" messages (Benjamin Tissoires) [2070873]
- HID: sony: Fix more ShanWan clone gamepads to not rumble when plugged in. (Benjamin Tissoires) [2070873]
- HID: sony: support for the ghlive ps4 dongles (Benjamin Tissoires) [2070873]
- HID: thrustmaster: clean up Makefile and adapt quirks (Benjamin Tissoires) [2070873]
- HID: i2c-hid: Fix Elan touchpad regression (Benjamin Tissoires) [2070873]
- HID: asus: Prevent Claymore sending suspend event (Benjamin Tissoires) [2070873]
- HID: logitech-hidpp: battery: provide CAPACITY property for newer devices (Benjamin Tissoires) [2070873]
- HID: thrustmaster: Fix memory leak in thrustmaster_interrupts() (Benjamin Tissoires) [2070873]
- HID: thrustmaster: Fix memory leak in remove (Benjamin Tissoires) [2070873]
- HID: thrustmaster: Fix memory leaks in probe (Benjamin Tissoires) [2070873]
- HID: elo: update the reference count of the usb device structure (Benjamin Tissoires) [2070873]
- HID: logitech-hidpp: Use 'atomic_inc_return' instead of hand-writing it (Benjamin Tissoires) [2070873]
- HID: apple: Add missing scan code event for keys handled by hid-apple (Benjamin Tissoires) [2070873]
- HID: cmedia: add support for HS-100B mute button (Benjamin Tissoires) [2070873]
- HID: i2c-hid: goodix: Use the devm variant of regulator_register_notifier() (Benjamin Tissoires) [2070873]
- HID: wacom: Refactor touch input mute checks into a common function (Benjamin Tissoires) [2070873]
- HID: wacom: Avoid sending empty sync events (Benjamin Tissoires) [2070873]
- HID: wacom: Short-circuit processing of touch when it is disabled (Benjamin Tissoires) [2070873]
- HID: wacom: set initial hardware touch switch state to 'off' (Benjamin Tissoires) [2070873]
- HID: usbhid: free raw_report buffers in usbhid_stop (Benjamin Tissoires) [2070873]
- HID: i2c-hid: goodix: Tie the reset line to true state of the regulator (Benjamin Tissoires) [2070873]
- HID: magicmouse: high-resolution scroll threshold (Benjamin Tissoires) [2070873]
- HID: magicmouse: enable high-resolution scroll (Benjamin Tissoires) [2070873]
- HID: input: do not report stylus battery state as "full" (Benjamin Tissoires) [2070873]
- HID: amd_sfh: Modify the hid name (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Modify the bus name (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add support for sensor discovery (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Remove useless DMA-32 fallback configuration (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add interrupt handler to process interrupts (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add functionality to clear interrupts (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Disable the interrupt for all command (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Correct the structure field name (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Handle amd_sfh work buffer in PM ops (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add illuminance mask to limit ALS max value (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Increase sensor command timeout (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Update Copyright details (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: switch from 'pci_' to 'dev_' API (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Use dma_set_mask_and_coherent() (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Fix potential NULL pointer dereference (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: switch from 'pci_' to 'dma_' API (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Fix potential NULL pointer dereference (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add dyndbg prints for debugging (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add support for PM suspend and resume (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Move hid probe after sensor is enabled (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Add command response to check command status (Benjamin Tissoires) [2054930 2070873]
- HID: amd_sfh: Fix period data field to enable sensor (Benjamin Tissoires) [2054930 2070873]

* Wed Aug 03 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-141.rt21.141.el9]
- [rt] build kernel-rt-5.14.0-141.rt21.141.el9 [2061574]
- Documentation: Add an explanation of NFSv4 client identifiers (Dave Wysochanski) [2112933]
- powerpc/bpf: Fix use of user_pt_regs in uapi (Desnes A. Nunes do Rosario) [2113065]
- Documentation: filesystems: proc: update meminfo section (David Hildenbrand) [2075394]
- mm: make slab and vmalloc allocators __GFP_NOLOCKDEP aware (Waiman Long) [2109001]
- mm/munlock: protect the per-CPU pagevec by a local_lock_t (Waiman Long) [2109671]
- mm/migration: add trace events for base page and HugeTLB migrations (Waiman Long) [2109671]
- powercap: intel_rapl: add support for ALDERLAKE_N (David Arcari) [2096965]
- ACPI: VIOT: Fix ACS setup (Eric Auger) [2101431]
- iommu/vt-d: Fix PCI bus rescan device hot add (Jerry Snitselaar) [2101592]
- iommu/vt-d: Fix RID2PASID setup/teardown failure (Jerry Snitselaar) [2101592]
- scsi: qla2xxx: Fix excessive I/O error messages by default (Nilesh Javali) [2083241]
- ACPI: CPPC: Only probe for _CPC if CPPC v2 is acked (Mark Langsdorf) [2067297]
- ACPI: CPPC: Change default error code and clean up debug messages in probe (Mark Langsdorf) [2067297]
- ACPI: CPPC: Avoid out of bounds access when parsing _CPC data (Mark Langsdorf) [2067297]
- ACPI: tables: Make LAPIC_ADDR_OVR address readable in message (Mark Langsdorf) [2067297]
- ACPI: IPMI: replace usage of found with dedicated list iterator variable (Mark Langsdorf) [2067297]
- ACPI, APEI: Use the correct variable for sizeof() (Mark Langsdorf) [2067297]
- clocksource: acpi_pm: fix return value of __setup handler (Mark Langsdorf) [2067297]
- ACPI / x86: Add support for LPS0 callback handler (Mark Langsdorf) [2067297]
- ACPI: bus: Avoid using CPPC if not supported by firmware (Mark Langsdorf) [2067297]
- Revert "ACPI: Pass the same capabilities to the _OSC regardless of the query flag" (Mark Langsdorf) [2067297]
- ACPI: video: Force backlight native for Clevo NL5xRU and NL5xNU (Mark Langsdorf) [2067297]
- PM: hibernate: Honour ACPI hardware signature by default for virtual guests (Mark Langsdorf) [2067297]
- ACPI: NFIT: Remove block aperture support (Mark Langsdorf) [2067297]
- x86, ACPI: rename init_freq_invariance_cppc() to arch_init_invariance_cppc() (Mark Langsdorf) [2067297]
- ACPI/APEI: Limit printable size of BERT table data (Mark Langsdorf) [2067297]
- ACPI: APEI: fix return value of __setup handlers (Mark Langsdorf) [2067297]
- ACPI / x86: Add skip i2c clients quirk for Lenovo Yoga Tablet 1050F/L (Mark Langsdorf) [2067297]
- ACPI / x86: Add skip i2c clients quirk for Nextbook Ares 8 (Mark Langsdorf) [2067297]
- ACPICA: Avoid walking the ACPI Namespace if it is not there (Mark Langsdorf) [2067297]
- ACPI: APEI: rename ghes_init() with an "acpi_" prefix (Mark Langsdorf) [2067297]
- ACPI: APEI: explicit init of HEST and GHES in apci_init() (Mark Langsdorf) [2067297]
- ACPI: processor idle: Check for architectural support for LPI (Mark Langsdorf) [2067297]
- ACPI: LPSS: Provide an SSP type to the driver (Mark Langsdorf) [2067297]
- ACPI: LPSS: Constify properties member in struct lpss_device_desc (Mark Langsdorf) [2067297]
- ACPI: platform: Constify properties parameter in acpi_create_platform_device() (Mark Langsdorf) [2067297]
- ACPI: battery: Add device HID and quirk for Microsoft Surface Go 3 (Mark Langsdorf) [2067297]
- ACPI: fan: Add additional attributes for fine grain control (Mark Langsdorf) [2067297]
- ACPI: fan: Properly handle fine grain control (Mark Langsdorf) [2067297]
- ACPI: fan: Optimize struct acpi_fan_fif (Mark Langsdorf) [2067297]
- ACPI: fan: Separate file for attributes creation (Mark Langsdorf) [2067297]
- ACPI: fan: Fix error reporting to user space (Mark Langsdorf) [2067297]
- ACPI: clean up double words in two comments (Mark Langsdorf) [2067297]
- ACPI: property: Get rid of redundant 'else' (Mark Langsdorf) [2067297]
- ACPI: scan: Use ida_alloc() instead of ida_simple_get() (Mark Langsdorf) [2067297]
- ACPI: EC: Rearrange code in acpi_ec_submit_event() (Mark Langsdorf) [2067297]
- ACPI: EC: Reduce indentation level in acpi_ec_submit_event() (Mark Langsdorf) [2067297]
- ACPI: EC: Do not return result from advance_transaction() (Mark Langsdorf) [2067297]
- ACPI: EC / PM: Print additional debug message in acpi_ec_dispatch_gpe() (Mark Langsdorf) [2067297]
- ACPI: PM: Print additional debug message in acpi_s2idle_wake() (Mark Langsdorf) [2067297]
- ACPI: tables: Add CEDT signature to the list of known tables (Mark Langsdorf) [2067297]
- ACPI: properties: Consistently return -ENOENT if there are no more references (Mark Langsdorf) [2067297]
- ACPI: OSL: Fix and clean up acpi_os_read/write_port() (Mark Langsdorf) [2067297]
- ACPICA: Use uintptr_t and offsetof() in Linux kernel builds (Mark Langsdorf) [2067297]

* Tue Aug 02 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-140.rt21.140.el9]
- [rt] build kernel-rt-5.14.0-140.rt21.140.el9 [2061574]
- tracing: Show size of requested perf buffer (Michael Petlan) [2106297]
- tracing: Increase PERF_MAX_TRACE_SIZE to handle Sentinel1 and docker together (Michael Petlan) [2106297]
- ibmvnic: Properly dispose of all skbs during a failover. (Steve Best) [2107561]
- powerpc/fadump: save CPU reg data in vmcore when PHYP terminates LPAR (Steve Best) [2104440]
- perf cpumap: Add perf_cpu_map__for_each_idx() (Michael Petlan) [2085427]
- perf stat: Make use of index clearer with perf_counts (Michael Petlan) [2085427]
- perf stat: Fix and validate CPU map inputs in synthetic PERF_RECORD_STAT events (Michael Petlan) [2085427]

* Tue Aug 02 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-139.rt21.139.el9]
- [rt] build kernel-rt-5.14.0-139.rt21.139.el9 [2061574]
- RDMA/irdma: Fix sleep from invalid context BUG (Kamal Heib) [2097326]
- RDMA/irdma: Do not advertise 1GB page size for x722 (Kamal Heib) [2097326]
- RDMA/cm: Fix memory leak in ib_cm_insert_listen (Kamal Heib) [2097326]
- RDMA/hfi1: Fix potential integer multiplication overflow errors (Kamal Heib) [2097326]
- RDMA/hfi1: Prevent use of lock before it is initialized (Kamal Heib) [2097326]
- KVM: selftests: Fix target thread to be migrated in rseq_test (Gavin Shan) [2106955]
- net: mld: fix reference count leak in mld_{query | report}_work() (Hangbin Liu) [2067774]
- vsock/virtio: add support for device suspend/resume (Stefano Garzarella) [2107589]
- vsock/virtio: factor our the code to initialize and delete VQs (Stefano Garzarella) [2107589]
- hv_sock: Add validation for untrusted Hyper-V values (Stefano Garzarella) [2107589]
- vsock/virtio: enable VQs early on probe (Stefano Garzarella) [2107589]
- vsock/virtio: read the negotiated features before using VQs (Stefano Garzarella) [2107589]
- vsock/virtio: initialize vdev->priv before using VQs (Stefano Garzarella) [2107589]
- af_vsock: SOCK_SEQPACKET broken buffer test (Stefano Garzarella) [2107589]
- af_vsock: SOCK_SEQPACKET receive timeout test (Stefano Garzarella) [2107589]
- vsock: each transport cycles only on its own sockets (Stefano Garzarella) [2107589]
- vhost/vsock: don't check owner in vhost_vsock_stop() while releasing (Stefano Garzarella) [2107589]
- vsock: remove vsock from connected table when connect is interrupted by a signal (Stefano Garzarella) [2107589]
- platform: goldfish: pipe: Use platform_get_irq() to get the interrupt (Mark Langsdorf) [2068298]
- MIPS: Loongson64: Add missing of_node_put() in ls2k_reset_init() (Mark Langsdorf) [2068298]
- MIPS: Loongson64: Add Loongson-2K1000 reset platform driver (Mark Langsdorf) [2068298]
- platform/mellanox: mlxbf-pmc: Fix an IS_ERR() vs NULL bug in mlxbf_pmc_map_counters (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-lc: fix error code in mlxreg_lc_create_static_devices() (Mark Langsdorf) [2068298]
- redhat/configs: enable CONFIG_MLXREG_LC (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-lc: Add initial support for Nvidia line card devices (Mark Langsdorf) [2068298]
- platform_data/mlxreg: Add new field for secured access (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-io: Extend number of hwmon attributes (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-hotplug: Extend logic for hotplug devices operations (Mark Langsdorf) [2068298]
- platform_data/mlxreg: Add new type to support modular systems (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-io: Fix read access of n-bytes size attributes (Mark Langsdorf) [2068298]
- platform/mellanox: mlxreg-io: Fix argument base in kstrtou32() call (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_debugfs: detach log reader wq from devm (Mark Langsdorf) [2068298]
- platform: chrome: Split trace include file (Mark Langsdorf) [2068298]
- platform/chrome: sensorhub: Add trace events for sample (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Update mux flags during partner removal (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Configure muxes at start of port update (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Get mux state inside configure_mux (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Move mux flag checks (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec: Make cros_ec_unregister() return void (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Check for EC device (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Make try power role optional (Mark Langsdorf) [2068298]
- redhat/configs: don't enable ChromeOS privacy screen (Mark Langsdorf) [2068298]
- platform/chrome: Add driver for ChromeOS privacy-screen (Mark Langsdorf) [2068298]
- drm/privacy-screen: Fix sphinx warning (Mark Langsdorf) [2068298]
- drm/privacy_screen: Add drvdata in drm_privacy_screen (Mark Langsdorf) [2068298]
- drm/connector: Add a drm_connector privacy-screen helper functions (v2) (Mark Langsdorf) [2068298]
- drm/privacy-screen: Add notifier support (v2) (Mark Langsdorf) [2068298]
- drm/privacy-screen: Add X86 specific arch init code (Mark Langsdorf) [2068298]
- drm: Add privacy-screen class (v4) (Mark Langsdorf) [2068298]
- drm/connector: Add support for privacy-screen properties (v4) (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_proto: Add version for ec_command (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_proto: Make data pointers void (Mark Langsdorf) [2068298]
- platform/chrome: cros_usbpd_notify: Move ec_command() (Mark Langsdorf) [2068298]
- platform/chrome: cros_usbpd_notify: Rename cros_ec_pd_command() (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec: Fix spelling mistake "responsed" -> "response" (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_sensorhub: simplify getting .driver_data (Mark Langsdorf) [2068298]
- platform/chrome: cros-ec-typec: Cleanup use of check_features (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_typec: Use existing feature check (Mark Langsdorf) [2068298]
- platform/chrome: cros_ec_proto: Fix check_features ret val (Mark Langsdorf) [2068298]
- drm/mgag200: Enable atomic gamma lut update (Jocelyn Falempe) [2078542]
- drm/mgag200: Optimize damage clips (Jocelyn Falempe) [2078542]
- drm/mgag200: Add FB_DAMAGE_CLIPS support (Jocelyn Falempe) [2078542]
- cgroup: use irqsave in cgroup_rstat_flush_locked(). (Waiman Long) [2060150]
- cgroup-v1: Correct privileges check in release_agent writes (Waiman Long) [2060150]
- cgroup/cpuset: Fix a race between cpuset_attach() and cpu hotplug (Waiman Long) [2060150]
- psi: Fix uaf issue when psi trigger is destroyed while being polled (Waiman Long) [2060150]
- cgroup/cpuset: Make child cpusets restrict parents on v1 hierarchy (Waiman Long) [2060150]
- cgroup/cpuset: Don't let child cpusets restrict parent in default hierarchy (Waiman Long) [2060150]
- mm/page_alloc: detect allocation forbidden by cpuset and bail out early (Waiman Long) [2060150]
- cgroup: Fix rootcg cpu.stat guest double counting (Waiman Long) [2060150]
- cgroup: no need for cgroup_mutex for /proc/cgroups (Waiman Long) [2060150]
- cgroup: remove cgroup_mutex from cgroupstats_build (Waiman Long) [2060150]
- cgroup: reduce dependency on cgroup_mutex (Waiman Long) [2060150]
- cgroup/cpuset: Change references of cpuset_mutex to cpuset_rwsem (Waiman Long) [2060150]

* Mon Aug 01 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-138.rt21.138.el9]
- [rt] build kernel-rt-5.14.0-138.rt21.138.el9 [2061574]
- tools/testing/nvdimm: Fix security_init() symbol collision (Jeff Moyer) [2096788]
- NFSD: Move fill_pre_wcc() and fill_post_wcc() (Benjamin Coddington) [2110576]
- Revert "nfsd: skip some unnecessary stats in the v4 case" (Benjamin Coddington) [2110576]
- Documentation: fix udp_wmem_min in ip-sysctl.rst (Xin Long) [2087560]
- redhat/configs/common: Enable CONFIG_LZ4_COMPRESS (Andrew Walsh) [2110097]
- net: bonding: fix use-after-free after 802.3ad slave unbind (Jonathan Toppins) [2109349]
- net: bonding: fix possible NULL deref in rlb code (Jonathan Toppins) [2109349]
- bonding: guard ns_targets by CONFIG_IPV6 (Jonathan Toppins) [2109349]
- bonding: show NS IPv6 targets in proc master info (Jonathan Toppins) [2109349]
- bonding: NS target should accept link local address (Jonathan Toppins) [2109349]
- bonding: combine netlink and console error messages (Jonathan Toppins) [2109349]
- usb: chipidea: udc: check request status before setting device address (Torez Smith) [2084667]
- USB: gadget: Fix double-free bug in raw_gadget driver (Torez Smith) [2084667]
- xhci-pci: Allow host runtime PM as default for Intel Meteor Lake xHCI (Torez Smith) [2084667]
- xhci-pci: Allow host runtime PM as default for Intel Raptor Lake xHCI (Torez Smith) [2084667]
- xhci: turn off port power in shutdown (Torez Smith) [2084667]
- xhci: Keep interrupt disabled in initialization until host is running. (Torez Smith) [2084667]
- USB: serial: option: add Quectel RM500K module support (Torez Smith) [2084667]
- USB: serial: option: add Quectel EM05-G modem (Torez Smith) [2084667]
- USB: serial: pl2303: add support for more HXN (G) types (Torez Smith) [2084667]
- usb: typec: wcove: Drop wrong dependency to INTEL_SOC_PMIC (Torez Smith) [2084667]
- usb: gadget: uvc: fix list double add in uvcg_video_pump (Torez Smith) [2084667]
- dt-bindings: usb: ehci: Increase the number of PHYs (Torez Smith) [2084667]
- dt-bindings: usb: ohci: Increase the number of PHYs (Torez Smith) [2084667]
- usb: gadget: Fix non-unique driver names in raw-gadget driver (Torez Smith) [2084667]
- USB: serial: option: add Telit LE910Cx 0x1250 composition (Torez Smith) [2084667]
- usb: gadget: f_fs: change ep->ep safe in ffs_epfile_io() (Torez Smith) [2084667]
- usb: gadget: f_fs: change ep->status safe in ffs_epfile_io() (Torez Smith) [2084667]
- xhci: Fix null pointer dereference in resume if xhci has only one roothub (Torez Smith) [2084667]
- USB: fixup for merge issue with "usb: dwc3: Don't switch OTG -> peripheral if extcon is present" (Torez Smith) [2084667]
- usb: cdnsp: Fixed setting last_trb incorrectly (Torez Smith) [2084667]
- usb: gadget: u_ether: fix regression in setting fixed MAC address (Torez Smith) [2084667]
- usb: gadget: lpc32xx_udc: Fix refcount leak in lpc32xx_udc_probe (Torez Smith) [2084667]
- usb: dwc2: Fix memory leak in dwc2_hcd_init (Torez Smith) [2084667]
- usb: dwc3: gadget: Fix IN endpoint max packet size allocation (Torez Smith) [2084667]
- docs: usb: fix literal block marker in usbmon verification example (Torez Smith) [2084667]
- USB: serial: option: add support for Cinterion MV31 with new baseline (Torez Smith) [2084667]
- USB: serial: io_ti: add Agilent E5805A support (Torez Smith) [2084667]
- dt-bindings: reset: update st,stih407-powerdown.yaml references (Torez Smith) [2084667]
- dt-bindings: Update QCOM USB subsystem maintainer information (Torez Smith) [2084667]
- dt-bindings: usb: snps,dwc3: Add missing 'dma-coherent' property (Torez Smith) [2084667]
- usb: typec: ucsi: acpi: fix a NULL vs IS_ERR() check in probe (Torez Smith) [2084667]
- USB: new quirk for Dell Gen 2 devices (Torez Smith) [2084667]
- tty: remove CMSPAR ifdefs (Torez Smith) [2084667]
- usb: dwc3: core: Add error log when core soft reset failed (Torez Smith) [2084667]
- usb: dwc3: gadget: Move null pinter check to proper place (Torez Smith) [2084667]
- usb: hub: Simplify error and success path in port_over_current_notify (Torez Smith) [2084667]
- usb: cdns3: allocate TX FIFO size according to composite EP number (Torez Smith) [2084667]
- usb: dwc3: Fix ep0 handling when getting reset while doing control transfer (Torez Smith) [2084667]
- usb: Probe EHCI, OHCI controllers asynchronously (Torez Smith) [2084667]
- usb: isp1760: Fix out-of-bounds array access (Torez Smith) [2084667]
- xhci: Don't defer primary roothub registration if there is only one roothub (Torez Smith) [2084667]
- USB: serial: option: add Quectel BG95 modem (Torez Smith) [2084667]
- USB: serial: pl2303: fix type detection for odd device (Torez Smith) [2084667]
- dt-bindings: usb: ci-hdrc-usb2: fix node node for ethernet controller (Torez Smith) [2084667]
- media: stkwebcam: move stk_camera_read_reg() scratch buffer to struct stk_camera (Torez Smith) [2084667]
- media: pvrusb2: fix array-index-out-of-bounds in pvr2_i2c_core_init (Torez Smith) [2084667]
- media: gspca: make the read-only array table static const (Torez Smith) [2084667]
- usb: xhci-mtk: remove bandwidth budget table (Torez Smith) [2084667]
- usb: xhci-mtk: fix fs isoc's transfer error (Torez Smith) [2084667]
- usb: gadget: fix race when gadget driver register via ioctl (Torez Smith) [2084667]
- usb: typec: tcpci_mt6360: Update for BMC PHY setting (Torez Smith) [2084667]
- xhci: Allow host runtime PM as default for Intel Alder Lake N xHCI (Torez Smith) [2084667]
- xhci: Remove quirk for over 10 year old evaluation hardware (Torez Smith) [2084667]
- xhci: prevent U2 link power state if Intel tier policy prevented U1 (Torez Smith) [2084667]
- xhci: use generic command timer for stop endpoint commands. (Torez Smith) [2084667]
- usb: host: xhci-plat: omit shared hcd if either root hub has no ports (Torez Smith) [2084667]
- usb: host: xhci-plat: prepare operation w/o shared hcd (Torez Smith) [2084667]
- usb: host: xhci-plat: create shared hcd after having added main hcd (Torez Smith) [2084667]
- xhci: prepare for operation w/o shared hcd (Torez Smith) [2084667]
- xhci: factor out parts of xhci_gen_setup() (Torez Smith) [2084667]
- xhci: Set HCD flag to defer primary roothub registration (Torez Smith) [2084667]
- usb: core: hcd: Add support for deferring roothub registration (Torez Smith) [2084667]
- usb: host: ehci-xilinx: adding description for return value (Torez Smith) [2084667]
- usb: gadget: udc: Remove useless variable assignment in xudc_read_fifo() (Torez Smith) [2084667]
- USB: c67x00: remove unnecessary check of res (Torez Smith) [2084667]
- usb: host: ehci-xilinx: Fix quoted string split across lines (Torez Smith) [2084667]
- USB / dwc3: Fix a checkpatch warning in core.c (Torez Smith) [2084667]
- thunderbolt: Add KUnit test for devices with no DisplayPort adapters (Torez Smith) [2084667]
- thunderbolt: Fix buffer allocation of devices with no DisplayPort adapters (Torez Smith) [2084667]
- USB: gadget: Add ID numbers to gadget names (Torez Smith) [2084667]
- media: uvcvideo: Add UVC_GUID_FORMAT_H265 (Torez Smith) [2084667]
- media: uvcvideo: Undup use uvc_endpoint_max_bpi() code (Torez Smith) [2084667]
- media: uvcvideo: Simplify uvc_endpoint_max_bpi() (Torez Smith) [2084667]
- media: uvcvideo: Fix memory leak if uvc_ctrl_add_mapping fails (Torez Smith) [2084667]
- media: uvcvideo: Fix bit overflow in uvc_probe_video (Torez Smith) [2084667]
- media: uvcvideo: Fix missing check to determine if element is found in list (Torez Smith) [2084667]
- media: docs: media: uvcvideo: Use linux-media mailing list (Torez Smith) [2084667]
- usb: gadget: uvc: allow for application to cleanly shutdown (Torez Smith) [2084667]
- usb: typec: tcpci: Don't skip cleanup in .remove() on error (Torez Smith) [2084667]
- usb: cdc-wdm: fix reading stuck on device close (Torez Smith) [2084667]
- usb: gadget: uvc: track frames in format entries (Torez Smith) [2084667]
- usb: gadget: uvc: move structs to common header (Torez Smith) [2084667]
- usb: gadget: uvc: prevent index variables to start from 0 (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: fix clock matching (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: add IPQ8074, MSM8994, QCS404 and SM6125 (Torez Smith) [2084667]
- usb: dwc3: gadget: Delay issuing End Transfer (Torez Smith) [2084667]
- usb: dwc3: gadget: Only End Transfer for ep0 data phase (Torez Smith) [2084667]
- usb: dwc3: ep0: Don't prepare beyond Setup stage (Torez Smith) [2084667]
- usb: dwc3: gadget: Don't modify GEVNTCOUNT in pullup() (Torez Smith) [2084667]
- usb: dwc3: gadget: Refactor pullup() (Torez Smith) [2084667]
- usb: dwc3: gadget: Prevent repeat pullup() (Torez Smith) [2084667]
- usb: dwc3: xilinx: Add gpio-reset support (Torez Smith) [2084667]
- dt-bindings: usb: dwc3-xilinx: add optional property reset-gpios (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: Add binding for SDX65 (Torez Smith) [2084667]
- dt-bindings: usb: da8xx-usb: deprecate '#dma-channels' (Torez Smith) [2084667]
- dt-bindings: usb: am33xx-usb: deprecate '#dma-channels' (Torez Smith) [2084667]
- usb: dwc3: remove a possible unnecessary 'out of memory' message (Torez Smith) [2084667]
- usb: dwc3: host: Stop setting the ACPI companion (Torez Smith) [2084667]
- usb: core: acpi: Use the sysdev pointer instead of controller device (Torez Smith) [2084667]
- dt-bindings: usb: mediatek,mtu3: add binding for MT8195 SoC (Torez Smith) [2084667]
- usb: ehci-omap: drop unused ehci_read() function (Torez Smith) [2084667]
- USB: gadget: Fix return of -EBUSY (Torez Smith) [2084667]
- usb: dwc2: gadget: don't reset gadget's driver->bus (Torez Smith) [2084667]
- USB: serial: qcserial: add support for Sierra Wireless EM7590 (Torez Smith) [2084667]
- USB: serial: ftdi_sio: clean up printk format specifier (Torez Smith) [2084667]
- USB: serial: option: add Fibocom MA510 modem (Torez Smith) [2084667]
- USB: serial: option: add Fibocom L610 modem (Torez Smith) [2084667]
- USB: serial: pl2303: add device id for HP LM930 Display (Torez Smith) [2084667]
- thunderbolt: Add support for XDomain lane bonding (Torez Smith) [2084667]
- thunderbolt: Ignore port locked error in tb_port_wait_for_link_width() (Torez Smith) [2084667]
- thunderbolt: Split setting link width and lane bonding into own functions (Torez Smith) [2084667]
- thunderbolt: Move tb_port_state() prototype to correct place (Torez Smith) [2084667]
- thunderbolt: Add debug logging when lane is enabled/disabled (Torez Smith) [2084667]
- Revert "usb: misc: Add onboard_usb_hub driver" (Torez Smith) [2084667]
- Revert "usb: core: hcd: Create platform devices for onboard hubs in probe()" (Torez Smith) [2084667]
- thunderbolt: Link USB4 ports to their USB Type-C connectors (Torez Smith) [2084667]
- thunderbolt: Make iommu_dma_protection more accurate (Torez Smith) [2084667]
- iommu: Add capability for pre-boot DMA protection (Torez Smith) [2084667]
- iommu: Introduce device_iommu_capable() (Torez Smith) [2084667]
- usb: typec: ucsi: acpi: Map the mailbox with memremap() (Torez Smith) [2084667]
- usb: phy: generic: Get the vbus supply (Torez Smith) [2084667]
- usb: dwc3: gadget: Return proper request status (Torez Smith) [2084667]
- usb: core: hcd: Create platform devices for onboard hubs in probe() (Torez Smith) [2084667]
- usb: misc: Add onboard_usb_hub driver (Torez Smith) [2084667]
- USB: gadget: Add a new bus for gadgets (Torez Smith) [2084667]
- USB: gadget: Fix mistakes in UDC core kerneldoc (Torez Smith) [2084667]
- USB: gadget: Register udc before gadget (Torez Smith) [2084667]
- USB: gadget: Rename usb_gadget_probe_driver() (Torez Smith) [2084667]
- usb: core: devices: drop redundant buffer overflow checks (Torez Smith) [2084667]
- dt-bindings: usb: generic-ohci: Add HPE GXP ohci binding (Torez Smith) [2084667]
- usb: Enable various new TypeC drivers. (Torez Smith) [2084667]
- dt-bindings: usb: generic-ehci: Add HPE GXP ehci binding (Torez Smith) [2084667]
- usb: typec: mux: Add On Semi fsa4480 driver (Torez Smith) [2084667]
- dt-bindings: usb: Add binding for fcs,fsa4480 (Torez Smith) [2084667]
- usb: typec: mux: Allow multiple mux_devs per mux (Torez Smith) [2084667]
- usb: typec: mux: Introduce indirection (Torez Smith) [2084667]
- usb: typec: mux: Check dev_set_name() return value (Torez Smith) [2084667]
- device property: Add helper to match multiple connections (Torez Smith) [2084667]
- usb: dwc3: pci: add support for the Intel Meteor Lake-P (Torez Smith) [2084667]
- usb: typec: ucsi: Wait for the USB role switches (Torez Smith) [2084667]
- usb: typec: ucsi: add a common function ucsi_unregister_connectors() (Torez Smith) [2084667]
- dt-bindings: usb: renesas,usbhs: Document RZ/G2UL bindings (Torez Smith) [2084667]
- testusb: Fix warning comparing pointer to 0 (Torez Smith) [2084667]
- USB: hcd-pci: Fully suspend across freeze/thaw cycle (Torez Smith) [2084667]
- usb: deprecate the third argument of usb_maxpacket() (Torez Smith) [2084667]
- usb: dwc3: pci: Fix pm_runtime_get_sync() error checking (Torez Smith) [2084667]
- USB: core: Disable remote wakeup for freeze/quiesce (Torez Smith) [2084667]
- drivers: usb: host: Fix deadlock in oxu_bus_suspend() (Torez Smith) [2084667]
- usb: dwc3: gadget: Replace list_for_each_entry_safe() if using giveback (Torez Smith) [2084667]
- usb: dwc3: EP clear halt leading to clearing of delayed_status (Torez Smith) [2084667]
- usb: dwc3: core: Only handle soft-reset in DCTL (Torez Smith) [2084667]
- usb: dwc3: Don't switch OTG -> peripheral if extcon is present (Torez Smith) [2084667]
- usb: gadget: configfs: clear deactivation flag in configfs_composite_unbind() (Torez Smith) [2084667]
- usb: misc: eud: Fix an error handling path in eud_probe() (Torez Smith) [2084667]
- usb: musb: mediatek: Use clk_bulk API to simplify clock operations (Torez Smith) [2084667]
- USB: dwc2: Add OTG support for Ingenic SoCs. (Torez Smith) [2084667]
- dt-bindings: dwc2: Add bindings for new Ingenic SoCs. (Torez Smith) [2084667]
- usb: gadget: net2272: clean up comments (Torez Smith) [2084667]
- usb: core: devices: remove dead code under #ifdef PROC_EXTRA (Torez Smith) [2084667]
- USB: omap_udc: clean up comment (Torez Smith) [2084667]
- usb: gadget: pxa27x_udc: clean up comment (Torez Smith) [2084667]
- usb: gadget: s3c-hsudc: clean up comments (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: clean up comments (Torez Smith) [2084667]
- usb: musb: Fix missing of_node_put() in omap2430_probe (Torez Smith) [2084667]
- usb: gadget: f_acm: add support for USB_CDC_REQ_SEND_BREAK (Torez Smith) [2084667]
- usb: dwc3: gadget: increase tx fifo size for ss isoc endpoints (Torez Smith) [2084667]
- usb: host: ohci-omap: Make it CCF clk API compatible (Torez Smith) [2084667]
- usb: gadget: omap_udc: Make it CCF clk API compatible (Torez Smith) [2084667]
- USB / dwc3: Fix three doc-build warnings (Torez Smith) [2084667]
- usb: core: Don't hold the device lock while sleeping in do_proc_control() (Torez Smith) [2084667]
- usb: dwc3: Try usb-role-switch first in dwc3_drd_init (Torez Smith) [2084667]
- usb: dwc3: core: Fix tx/rx threshold settings (Torez Smith) [2084667]
- usb: mtu3: fix USB 3.0 dual-role-switch from device to host (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-usb2: add missing required reg (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-usb2: include usb-hcd schema (Torez Smith) [2084667]
- USB: storage: karma: fix rio_karma_init return (Torez Smith) [2084667]
- usb: gadget: net2280: use swap() instead of open coding it (Torez Smith) [2084667]
- usb: gadget: u_audio: clean up some inconsistent indenting (Torez Smith) [2084667]
- USB: host: isp116x: check return value after calling platform_get_resource() (Torez Smith) [2084667]
- usb:oxu210hp-hcd: Use platform_get_irq() to get the interrupt (Torez Smith) [2084667]
- usb-storage: isd200: fix initFunction error return (Torez Smith) [2084667]
- usb-storage: shuttle_usbat: fix initFunction error return (Torez Smith) [2084667]
- usb-storage: alauda: fix initFunction error return (Torez Smith) [2084667]
- usb: Prepare cleanup of powerpc's asm/prom.h (Torez Smith) [2084667]
- usb: usbip: add missing device lock on tweak configuration cmd (Torez Smith) [2084667]
- usb: usbip: fix a refcount leak in stub_probe() (Torez Smith) [2084667]
- xhci: Enable runtime PM on second Alderlake controller (Torez Smith) [2084667]
- usb: dwc3: fix backwards compat with rockchip devices (Torez Smith) [2084667]
- usb: misc: fix improper handling of refcount in uss720_probe() (Torez Smith) [2084667]
- USB: Fix ehci infinite suspend-resume loop issue in zhaoxin (Torez Smith) [2084667]
- usb: typec: tcpm: Fix undefined behavior due to shift overflowing the constant (Torez Smith) [2084667]
- usb: typec: rt1719: Fix build error without CONFIG_POWER_SUPPLY (Torez Smith) [2084667]
- usb: typec: ucsi: Fix role swapping (Torez Smith) [2084667]
- usb: typec: ucsi: Fix reuse of completion structure (Torez Smith) [2084667]
- usb: xhci: tegra:Fix PM usage reference leak of tegra_xusb_unpowergate_partitions (Torez Smith) [2084667]
- drivers: usb: dwc3: Add AM62 USB wrapper driver (Torez Smith) [2084667]
- dt-bindings: usb: Add documentation for AM62 USB Wrapper module (Torez Smith) [2084667]
- usb: typec: tipd: Only update power status on IRQ (Torez Smith) [2084667]
- usb: typec: mux: intel_pmc_mux: Add retry logic to a PMC command (Torez Smith) [2084667]
- usb: gadget: uvc: improve sg exit condition (Torez Smith) [2084667]
- usb: gadget: uvc: giveback vb2 buffer on req complete (Torez Smith) [2084667]
- usb: gadget: uvc: rework uvcg_queue_next_buffer to uvcg_complete_buffer (Torez Smith) [2084667]
- usb: gadget: uvc: remove pause flag use (Torez Smith) [2084667]
- usb: gadget: uvc: allow changing interface name via configfs (Torez Smith) [2084667]
- ARM: omap: dma: make usb support optional (Torez Smith) [2084667]
- ARM: omap1: innovator: move ohci phy power handling to board file (Torez Smith) [2084667]
- usb: omap: avoid mach/*.h headers (Torez Smith) [2084667]
- ARM: omap1: move mach/usb.h to include/linux/soc (Torez Smith) [2084667]
- USB: serial: whiteheat: fix heap overflow in WHITEHEAT_GET_DTR_RTS (Torez Smith) [2084667]
- USB: serial: cp210x: add PIDs for Kamstrup USB Meter Reader (Torez Smith) [2084667]
- USB: serial: option: add support for Cinterion MV32-WA/MV32-WB (Torez Smith) [2084667]
- usb: gadget: uvc: Fix crash when encoding data for usb request (Torez Smith) [2084667]
- thunderbolt: Use different lane for second DisplayPort tunnel (Torez Smith) [2084667]
- thunderbolt: Dump path config space entries during discovery (Torez Smith) [2084667]
- thunderbolt: Use decimal number with port numbers (Torez Smith) [2084667]
- thunderbolt: Fix typo in comment (Torez Smith) [2084667]
- media: dvb-usb: dib0700_devices: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: dibusb-mc: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: dibusb-mb: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: vp7045: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: vp702x: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: umt-010: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: ttusb2: use an enum for the device number (Torez Smith) [2084667]
- media: technisat-usb2: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: pctv452e: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: opera1: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: nova-t-usb2: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: m920x: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: gp8psk: use an enum for the device number (Torez Smith) [2084667]
- media: dw2102: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dtv5100: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: dtt200u: use an enum for the device number (Torez Smith) [2084667]
- media: digitv: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: cxusb: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: cinergyT2-core: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: az6027: use an enum for the device number (Torez Smith) [2084667]
- media: af9005: use the newer dvb-usb macros for USB device (Torez Smith) [2084667]
- media: dvb-usb: a800: use an enum for the device number (Torez Smith) [2084667]
- media: dvb-usb: Add helper macros for using USB VID/PID (Torez Smith) [2084667]
- media: dvb-usb: vp702x: reference to usb ID table (Torez Smith) [2084667]
- media: dvb-usb: move USB IDs to dvb-usb-ids.h (Torez Smith) [2084667]
- media: dvb-usb-ids.h: sort entries (Torez Smith) [2084667]
- USB: quirks: add STRING quirk for VCOM device (Torez Smith) [2084667]
- USB: quirks: add a Realtek card reader (Torez Smith) [2084667]
- cdc_ether: export usbnet_cdc_zte_rx_fixup (Torez Smith) [2084667]
- USB: serial: option: add Telit 0x1057, 0x1058, 0x1075 compositions (Torez Smith) [2084667]
- usb: cdns3: Fix issue for clear halt endpoint (Torez Smith) [2084667]
- xhci: increase usb U3 -> U0 link resume timeout from 100ms to 500ms (Torez Smith) [2084667]
- xhci: stop polling roothubs after shutdown (Torez Smith) [2084667]
- USB: Fix xhci event ring dequeue pointer ERDP update issue (Torez Smith) [2084667]
- thunderbolt: test: use NULL macros (Torez Smith) [2084667]
- thunderbolt: Replace usage of found with dedicated list iterator variable (Torez Smith) [2084667]
- usb: gadget: fsl_qe_udc: Add missing semicolon in qe_ep_dequeue() (Torez Smith) [2084667]
- dt-bindings: usb: mtk-xhci: add compatible for mt8186 (Torez Smith) [2084667]
- usb: dwc3: Issue core soft reset before enabling run/stop (Torez Smith) [2084667]
- usb: gadget: Makefile: remove ccflags-y (Torez Smith) [2084667]
- USB: usb-storage: Fix use of bitfields for hardware data in ene_ub6250.c (Torez Smith) [2084667]
- usb: gadget: eliminate anonymous module_init & module_exit (Torez Smith) [2084667]
- usb: usbip: eliminate anonymous module_init & module_exit (Torez Smith) [2084667]
- xen/usb: harden xen_hcd against malicious backends (Torez Smith) [2084667]
- usb: dwc3: gadget: Wait for ep0 xfers to complete during dequeue (Torez Smith) [2084667]
- usb: dwc3: gadget: move cmd_endtransfer to extra function (Torez Smith) [2084667]
- usb: dwc3: gadget: ep_queue simplify isoc start condition (Torez Smith) [2084667]
- xen/usb: don't use arbitrary_virt_to_machine() (Torez Smith) [2084667]
- usb: common: usb-conn-gpio: Make VBUS supply completely optional (Torez Smith) [2084667]
- USB: storage: ums-realtek: fix error code in rts51x_read_mem() (Torez Smith) [2084667]
- usb: early: xhci-dbc: Fix xdbc number parsing (Torez Smith) [2084667]
- usb: early: xhci-dbc: Remove duplicate keep parsing (Torez Smith) [2084667]
- usb: gadget: udc: s3c2410: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: dummy_hcd: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: core: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: composite: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: pxa27x_udc: replace usage of rc to check if a list element was found (Torez Smith) [2084667]
- usb: gadget: composite: remove check of list iterator against head past the loop body (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: udc: max3420_udc: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: legacy: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: configfs: remove using list iterator after loop body as a ptr (Torez Smith) [2084667]
- usb: gadget: aspeed: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc-xilinx: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: s3c-hsudc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: omap_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: net2280: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: net2272: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: mv_udc_core: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: mv_u3d: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: lpc32xx_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: gr_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: goku_udc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: at91: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: pxa25x: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: udc: atmel: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: bdc: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: gadget: fsl: remove usage of list iterator past the loop body (Torez Smith) [2084667]
- usb: dwc3: pci: Add support for Intel Alder Lake (Torez Smith) [2084667]
- usb: dwc3: omap: fix "unbalanced disables for smps10_out1" on omap5evm (Torez Smith) [2084667]
- usb: dwc3: gadget: Give some time to schedule isoc (Torez Smith) [2084667]
- usb: dwc3: core: do not use 3.0 clock when operating in 2.0 mode (Torez Smith) [2084667]
- dt-bindings: usb: add rk3568 compatible to rockchip, dwc3 (Torez Smith) [2084667]
- usb: dwc3: imx8mp: Add support for setting SOC specific flags (Torez Smith) [2084667]
- dt-bindings: usb: dwc3-imx8mp: Add imx8mp specific flags (Torez Smith) [2084667]
- usb: dwc3: imx8mp: rename iomem base pointer (Torez Smith) [2084667]
- usb: dwc3-meson-g12a: constify drvdata structs (Torez Smith) [2084667]
- usb: raw-gadget: return -EINVAL if no proper ep address available (Torez Smith) [2084667]
- dt-bindings: usb: hcd: correct usb-device path (Torez Smith) [2084667]
- usb: raw-gadget: use kzalloc (Torez Smith) [2084667]
- usb: gadget: udc: fix typos in comments (Torez Smith) [2084667]
- media: xc2028: rename the driver from tuner-xc2028 (Torez Smith) [2084667]
- USB: serial: usb_wwan: remove redundant assignment to variable i (Torez Smith) [2084667]
- USB: serial: pl2303: fix GS type detection (Torez Smith) [2084667]
- media: hdpvr: initialize dev->worker at hdpvr_register_videodev (Torez Smith) [2084667]
- media: stk1160: use dma_alloc_noncontiguous API (Torez Smith) [2084667]
- media: stk1160: move transfer_buffer and urb to same struct 'stk1160_urb' (Torez Smith) [2084667]
- media: stk1160: If start stream fails, return buffers with VB2_BUF_STATE_QUEUED (Torez Smith) [2084667]
- media: stk1160: fix number of buffers in case not all buffers are created (Torez Smith) [2084667]
- media: Revert "media: em28xx: add missing em28xx_close_extension" (Torez Smith) [2084667]
- thunderbolt: Rename EEPROM handling bits to match USB4 spec (Torez Smith) [2084667]
- thunderbolt: Clarify register definitions for `tb_cap_plug_events` (Torez Smith) [2084667]
- USB: serial: pl2303: add IBM device IDs (Torez Smith) [2084667]
- usb: host: xhci: Remove some unnecessary return value initializations (Torez Smith) [2084667]
- usb: host: xhci: add blank line in xhci_halt() (Torez Smith) [2084667]
- usb: host: xhci: update hci_version operation in xhci_gen_setup() (Torez Smith) [2084667]
- usb: host: xhci: fix a comment typo in xhci_mem_init() (Torez Smith) [2084667]
- usb: host: xhci: use ffs() in xhci_mem_init() (Torez Smith) [2084667]
- xhci: fix runtime PM imbalance in USB2 resume (Torez Smith) [2084667]
- xhci: fix uninitialized string returned by xhci_decode_ctrl_ctx() (Torez Smith) [2084667]
- xhci: fix garbage USBSTS being logged in some cases (Torez Smith) [2084667]
- xhci: make xhci_handshake timeout for xhci_reset() adjustable (Torez Smith) [2084667]
- usb: typec: tipd: Forward plug orientation to typec subsystem (Torez Smith) [2084667]
- usb: Drop commas after SoC match table sentinels (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-usb2: convert to dtschema (Torez Smith) [2084667]
- dt-bindings: usb: samsung,exynos-dwc3: convert to dtschema (Torez Smith) [2084667]
- USB: serial: simple: add Nokia phone driver (Torez Smith) [2084667]
- ACPI: bus: Introduce acpi_bus_for_each_dev() (Torez Smith) [2084667]
- dt-bindings: usb: dwc2: add disable-over-current (Torez Smith) [2084667]
- dt-bindings: usb: dwc2: add iommus (Torez Smith) [2084667]
- dt-bindings: usb: dwc2: fix compatible of Intel Agilex (Torez Smith) [2084667]
- dt-bindings: usb: renesas,usbhs: Document RZ/V2L bindings (Torez Smith) [2084667]
- USB: serial: make use of UART_LCR_WLEN() + tty_get_char_size() (Torez Smith) [2084667]
- USB: core: Update kerneldoc for usb_get_dev() and usb_get_intf() (Torez Smith) [2084667]
- Revert "usb: host: xhci: mvebu: make USB 3.0 PHY optional for Armada 3720" (Torez Smith) [2084667]
- dt-bindings: usb: qcom,dwc3: Add msm8953 compatible (Torez Smith) [2084667]
- usb: misc: USB_QCOM_EUD should depend on ARCH_QCOM (Torez Smith) [2084667]
- xhci: omit mem read just after allocation of trb (Torez Smith) [2084667]
- usb: host: ehci-q: make qtd_fill() return *unsigned int* (Torez Smith) [2084667]
- scsi: usb: Stop using the SCSI pointer (Torez Smith) [2084667]
- scsi: Remove drivers/scsi/scsi.h (Torez Smith) [2084667]
- dt-bindings: usb: do not use deprecated synopsys prefix (Torez Smith) [2084667]
- stkwebcam: add new Asus laptop to upside_down table (Torez Smith) [2084667]
- media: usb: go7007: s2250-board: fix leak in probe() (Torez Smith) [2084667]
- media: gspca: remove redundant assignment of variable n (Torez Smith) [2084667]
- media: go7007: Constify static struct snd_device_ops (Torez Smith) [2084667]
- media: em28xx: initialize refcount before kref_get (Torez Smith) [2084667]
- media: usb: pwc-uncompress: Use struct_size() helper in pwc_decompress() (Torez Smith) [2084667]
- thunderbolt: Drop duplicate NULL checks around nvmem_unregister() (Torez Smith) [2084667]
- usb: dwc3: pci: Also apply Bay Trail GPIO mappings to ulpi-device (Torez Smith) [2084667]
- usb: dwc3: pci: Set "linux,phy_charger_detect" property on some Bay Trail boards (Torez Smith) [2084667]
- usb: dwc3: pci: Set the swnode from inside dwc3_pci_quirks() (Torez Smith) [2084667]
- usb: typec: Support the WUSB3801 port controller (Torez Smith) [2084667]
- usb: typec: Factor out non-PD fwnode properties (Torez Smith) [2084667]
- dt-bindings: usb: Add WUSB3801 Type-C Port Controller (Torez Smith) [2084667]
- usb: xhci: fix minmax.cocci warnings (Torez Smith) [2084667]
- usb: host: xhci: drop redundant checks (Torez Smith) [2084667]
- usb: remove Link Powermanagement (LPM) disable before port reset. (Torez Smith) [2084667]
- xhci: Allocate separate command structures for each LPM command (Torez Smith) [2084667]
- xhci: dbgtty: use IDR to support several dbc instances. (Torez Smith) [2084667]
- xhci: dbc: Don't call dbc_tty_init() on every dbc tty probe (Torez Smith) [2084667]
- xhci: dbc: Rename xhci_dbc_init and xhci_dbc_exit (Torez Smith) [2084667]
- xhci: dbc: create and remove dbc structure in dbgtty driver. (Torez Smith) [2084667]
- xhci: dbc: refactor xhci_dbc_init() (Torez Smith) [2084667]
- usb: dwc3: drd: Don't check against CONFIG_OF (Torez Smith) [2084667]
- usb: host: xhci-mtk: Simplify supplies handling with regulator_bulk (Torez Smith) [2084667]
- media: uvcvideo: Add support for Apple T2-attached FaceTime HD Camera (Torez Smith) [2084667]
- usb: host: ehci-platform: Update brcm, xgs-iproc-ehci workaround (Torez Smith) [2084667]
- usb: host: {e|o}hci-dbg: kill useless 'ret' variable initializers (Torez Smith) [2084667]
- usbip: vudc: Make use of the helper macro LIST_HEAD() (Torez Smith) [2084667]
- usb: ulpi: Add debugfs support (Torez Smith) [2084667]
- usb: misc: eud: Add driver support for Embedded USB Debugger(EUD) (Torez Smith) [2084667]
- bindings: usb: dwc3: Update dwc3 properties for EUD connector (Torez Smith) [2084667]
- usb: typec: rt1719: Add support for Richtek RT1719 (Torez Smith) [2084667]
- dt-bindings: usb: rt1719: Add binding for Richtek RT1719 (Torez Smith) [2084667]
- usb: xhci-mtk: add support ip-sleep wakeup for mt8195 (Torez Smith) [2084667]
- dt-bindings: usb: mtk-xhci: add support ip-sleep for mt8195 (Torez Smith) [2084667]
- usb: dwc2: Add platform specific data for Intel's Agilex (Torez Smith) [2084667]
- USB: usbfs: Use a spinlock instead of atomic accesses to tally used memory. (Torez Smith) [2084667]
- usb: ehci: add pci device support for Aspeed platforms (Torez Smith) [2084667]
- usb: dwc3: Program GFLADJ (Torez Smith) [2084667]
- usb: dwc3: Calculate REFCLKPER based on reference clock (Torez Smith) [2084667]
- usb: dwc3: Get clocks individually (Torez Smith) [2084667]
- dt-bindings: usb: dwc3: Deprecate snps,ref-clock-period-ns (Torez Smith) [2084667]
- scsi: usb: storage: Complete the SCSI request directly (Torez Smith) [2084667]
- usb: gadget: f_uac2: Neaten and reduce size of afunc_validate_opts (Torez Smith) [2084667]
- usb: gadget: f_uac2: change maxpctksize/maxpcktsize to wMaxPacketSize (Torez Smith) [2084667]
- thunderbolt: Replace acpi_bus_get_device() (Torez Smith) [2084667]
- thunderbolt: Add internal xHCI connect flows for Thunderbolt 3 devices (Torez Smith) [2084667]
- thunderbolt: Add missing device ID to tb_switch_is_alpine_ridge() (Torez Smith) [2084667]
- thunderbolt: Disable LTTPR on Intel Titan Ridge (Torez Smith) [2084667]
- usb: gadget: f_uac2: Add speed names to bInterval dbg/warn (Torez Smith) [2084667]
- usb: gadget: f_uac2: Optionally determine bInterval for HS and SS (Torez Smith) [2084667]
- usb: gadget: audio: Add HS/SS bInterval params for UAC2 (Torez Smith) [2084667]
- usb: gadget: f_uac2: Add HS/SS bInterval to configfs (Torez Smith) [2084667]
- usb: udc: Fix typo in comment (Torez Smith) [2084667]
- USB: ACPI: Replace acpi_bus_get_device() (Torez Smith) [2084667]
- usb: gadget: f_uac2: allow changing interface name via configfs (Torez Smith) [2084667]
- usb: gadget: f_uac1: allow changing interface name via configfs (Torez Smith) [2084667]
- usb: gadget: f_uac1: Add suspend callback (Torez Smith) [2084667]
- usb: gadget: f_uac2: Add suspend callback (Torez Smith) [2084667]
- usb: gadget: u_audio: Add suspend call (Torez Smith) [2084667]
- usb: gadget: u_audio: Rate ctl notifies about current srate (0=stopped) (Torez Smith) [2084667]
- usb: gadget: f_uac1: Support multiple sampling rates (Torez Smith) [2084667]
- usb: gadget: f_uac2: Support multiple sampling rates (Torez Smith) [2084667]
- usb: gadget: u_audio: Add capture/playback srate getter (Torez Smith) [2084667]
- usb: gadget: u_audio: Move dynamic srate from params to rtd (Torez Smith) [2084667]
- usb: gadget: u_audio: Support multiple sampling rates (Torez Smith) [2084667]
- usb: gadget:audio: Replace deprecated macro S_IRUGO (Torez Smith) [2084667]
- usb: gadget: f_mass_storage: Make CD-ROM emulation work with Mac OS-X (Torez Smith) [2084667]
- usb: xhci-mtk: Use struct_size() helper in create_sch_ep() (Torez Smith) [2084667]
- USB: hcd-pci: Use PCI_STD_NUM_BARS when checking standard BARs (Torez Smith) [2084667]
- usb: gadget: f_fs: Use struct_size() and flex_array_size() helpers (Torez Smith) [2084667]
- usb: host: fotg210: Use struct_size() helper in kzalloc() (Torez Smith) [2084667]
- usb: core: Bail out when port is stuck in reset loop (Torez Smith) [2084667]
- usb: gadget: f_phonet: Use struct_size() helper in kzalloc() (Torez Smith) [2084667]
- usb: host: xhci-plat: Remove useless DMA-32 fallback configuration (Torez Smith) [2084667]
- dt-bindings: usb: add bindings for microchip mpfs musb (Torez Smith) [2084667]
- scsi: usb: Call scsi_done() directly (Torez Smith) [2084667]
- usb: cdnsp: remove not used temp_64 variables (Torez Smith) [2084667]
- usb: cdnsp: fix cdnsp_decode_trb function to properly handle ret value (Torez Smith) [2084667]
- usb: dwc3: drd: Add support for usb-conn-gpio based usb-role-switch (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: Fix control endpoint's definitions (Torez Smith) [2084667]
- usb: gadget: f_serial: Ensure gserial disconnected during unbind (Torez Smith) [2084667]
- usb: gadget: tegra-xudc: Do not program SPARAM (Torez Smith) [2084667]
- usb: host: ehci-sched: Use struct_size() in kzalloc() (Torez Smith) [2084667]
- thunderbolt: Remove useless DMA-32 fallback configuration (Torez Smith) [2084667]
- usb: enable Design Ware Drivers (Torez Smith) [2084667]
- tty: serial: define UART_LCR_WLEN() macro (Torez Smith) [2084667]
- media: gspca: make array regs_to_read static const (Torez Smith) [2084667]
- block: Fix handling of offline queues in blk_mq_alloc_request_hctx() (Ming Lei) [2108481]
- nvme: fix RCU hole that allowed for endless looping in multipath round robin (Gopal Tiwari) [2108624]
- vdpa/mlx5: Use consistent RQT size (Cindy Lu) [2063693]
- vdpa/mlx5: add validation for VIRTIO_NET_CTRL_MQ_VQ_PAIRS_SET command (Cindy Lu) [2063693]
- vdpa/mlx5: should verify CTRL_VQ feature exists for MQ (Cindy Lu) [2063693]
- fscache: Avoid ASSERTCMP if two threads race into fscache_disable_cookie (Dave Wysochanski) [2073727]
- blk-mq: don't create hctx debugfs dir until q->debugfs_dir is created (Ming Lei) [2105622]
- redhat: enable CONFIG_MAXLINEAR_GPHY as module (Petr Oros) [2071857]
- net: phy: enhance GPY115 loopback disable function (Petr Oros) [2071857]
- net: phy: add Maxlinear GPY115/21x/24x driver (Petr Oros) [2071857]
- net: phy: add API to read 802.3-c45 IDs (Petr Oros) [2071857]

* Mon Aug 01 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-137.rt21.137.el9]
- [rt] build kernel-rt-5.14.0-137.rt21.137.el9 [2061574]
- md: fix double free of io_acct_set bioset (Nigel Croxon) [2105293]
- md: Don't set mddev private to NULL in raid0 pers->free (Nigel Croxon) [2105293]
- md: remove most calls to bdevname (Nigel Croxon) [2105293]
- md: protect md_unregister_thread from reentrancy (Nigel Croxon) [2105293]
- md: don't unregister sync_thread with reconfig_mutex held (Nigel Croxon) [2105293]
- md: Replace role magic numbers with defined constants (Nigel Croxon) [2105293]
- md/raid0: Ignore RAID0 layout if the second zone has only one device (Nigel Croxon) [2105293]
- md/raid5: Annotate functions that hold device_lock with __must_hold (Nigel Croxon) [2105293]
- md/raid5-ppl: Annotate with rcu_dereference_protected() (Nigel Croxon) [2105293]
- md/raid5: Annotate rdev/replacement access when mddev_lock is held (Nigel Croxon) [2105293]
- md/raid5: Annotate rdev/replacement accesses when nr_pending is elevated (Nigel Croxon) [2105293]
- md/raid5: Add __rcu annotation to struct disk_info (Nigel Croxon) [2105293]
- md/raid5: Un-nest struct raid5_percpu definition (Nigel Croxon) [2105293]
- md/raid5: Cleanup setup_conf() error returns (Nigel Croxon) [2105293]
- md: replace deprecated strlcpy & remove duplicated line (Nigel Croxon) [2105293]
- md/bitmap: don't set sb values if can't pass sanity check (Nigel Croxon) [2105293]
- md: fix an incorrect NULL check in md_reload_sb (Nigel Croxon) [2105293]
- md: fix an incorrect NULL check in does_sb_need_changing (Nigel Croxon) [2105293]
- raid5: introduce MD_BROKEN (Nigel Croxon) [2105293]
- md: Set MD_BROKEN for RAID1 and RAID10 (Nigel Croxon) [2105293]
- raid5: initialize the stripe_head embeeded bios as needed (Nigel Croxon) [2105293]
- raid5-cache: statically allocate the recovery ra bio (Nigel Croxon) [2105293]
- raid5-cache: fully initialize flush_bio when needed (Nigel Croxon) [2105293]
- raid5-ppl: fully initialize the bio in ppl_new_iounit (Nigel Croxon) [2105293]
- md: use msleep() in md_notify_reboot() (Nigel Croxon) [2105293]
- md: raid1/raid10: drop pending_cnt (Nigel Croxon) [2105293]
- net: Don't include filter.h from net/sock.h (Petr Oros) [2101792]
- sfc: fix considering that all channels have TX queues (Íñigo Huguet) [2106076]
- sfc: fix wrong tx channel offset with efx_separate_tx_channels (Íñigo Huguet) [2106076]
- NFSv4.1 support for NFS4_RESULT_PRESERVER_UNLINKED (Scott Mayhew) [2066368]
- bpf: Fix request_sock leak in sk lookup helpers (Felix Maurer) [2102742]
- xsk: Fix generic transmit when completion queue reservation fails (Felix Maurer) [2102742]
- xsk: Fix handling of invalid descriptors in XSK TX batching API (Felix Maurer) [2102742]
- xsk: Fix possible crash when multiple sockets are created (Felix Maurer) [2102742]
- xsk: Fix l2fwd for copy mode + busy poll combo (Felix Maurer) [2102742]
- bpf: Support dual-stack sockets in bpf_tcp_check_syncookie (Felix Maurer) [2102742]
- xsk: Fix race at socket teardown (Felix Maurer) [2102742]
- netdevsim: don't overwrite read only ethtool parms (Antoine Tenart) [2101836]
- Bluetooth: btmtksdio: fix possible FW initialization failure (Gopal Tiwari) [2097262]
- Bluetooth: btmtksdio: fix the reset takes too long (Gopal Tiwari) [2097262]
- Bluetooth: btmtksdio: Fix kernel oops when sdio suspend. (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: support bluetooth reset mechanism (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: fix btmtksdio_[drv|fw]_pmctrl() (Gopal Tiwari) [2097262]
- Bluetooth: btmtksdio: refactor btmtksdio_runtime_[suspend|resume]() (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: fix bus hang with wrong privilege (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: Enable SCO over I2S (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: fix firmware coredump retrieve (Gopal Tiwari) [2097262]
- Bluetooth: mt7921s: Support wake on bluetooth (Gopal Tiwari) [2097262]
- Enable MTK BT Support for RHEL (Gopal Tiwari) [2097262]
- redhat: workaround CKI cross compilation for scripts (Jan Stancek) [2101805]
- redhat/configs: Support QAT devices for x86 only (Vladis Dronov) [2040726]
- crypto: qat - expose device config through sysfs for 4xxx (Vladis Dronov) [2040726]
- crypto: qat - relocate and rename adf_sriov_prepare_restart() (Vladis Dronov) [2040726]
- crypto: qat - change behaviour of adf_cfg_add_key_value_param() (Vladis Dronov) [2040726]
- crypto: qat - expose device state through sysfs for 4xxx (Vladis Dronov) [2040726]
- crypto: qat - Removes the x86 dependency on the QAT drivers (Vladis Dronov) [2040726]
- crypto: qat - replace get_current_node() with numa_node_id() (Vladis Dronov) [2040726]
- crypto: qat - add support for 401xx devices (Vladis Dronov) [2040726]
- crypto: qat - re-enable registration of algorithms (Vladis Dronov) [2040726]
- crypto: qat - honor CRYPTO_TFM_REQ_MAY_SLEEP flag (Vladis Dronov) [2040726]
- crypto: qat - add param check for DH (Vladis Dronov) [2040726]
- crypto: qat - add param check for RSA (Vladis Dronov) [2040726]
- crypto: qat - remove dma_free_coherent() for DH (Vladis Dronov) [2040726]
- crypto: qat - fix memory leak in RSA (Vladis Dronov) [2040726]
- crypto: qat - add backlog mechanism (Vladis Dronov) [2040726]
- crypto: qat - refactor submission logic (Vladis Dronov) [2040726]
- crypto: qat - use pre-allocated buffers in datapath (Vladis Dronov) [2040726]
- crypto: qat - set to zero DH parameters before free (Vladis Dronov) [2040726]
- crypto: qat - Fix unsigned function returning negative constant (Vladis Dronov) [2040726]
- crypto: qat - remove line wrapping for pfvf_ops functions (Vladis Dronov) [2040726]
- crypto: qat - use u32 variables in all GEN4 pfvf_ops (Vladis Dronov) [2040726]
- crypto: qat - replace disable_vf2pf_interrupts() (Vladis Dronov) [2040726]
- crypto: qat - leverage the GEN2 VF mask definiton (Vladis Dronov) [2040726]
- crypto: qat - rework the VF2PF interrupt handling logic (Vladis Dronov) [2040726]
- crypto: qat - fix off-by-one error in PFVF debug print (Vladis Dronov) [2040726]
- crypto: qat - fix wording and formatting in code comment (Vladis Dronov) [2040726]
- crypto: qat - test PFVF registers for spurious interrupts on GEN4 (Vladis Dronov) [2040726]
- crypto: qat - add check for invalid PFVF protocol version 0 (Vladis Dronov) [2040726]
- crypto: qat - add missing restarting event notification in VFs (Vladis Dronov) [2040726]
- crypto: qat - remove unnecessary tests to detect PFVF support (Vladis Dronov) [2040726]
- crypto: qat - remove unused PFVF stubs (Vladis Dronov) [2040726]
- crypto: qat - remove unneeded braces (Vladis Dronov) [2040726]
- crypto: qat - fix ETR sources enabled by default on GEN2 devices (Vladis Dronov) [2040726]
- crypto: qat - set COMPRESSION capability for DH895XCC (Vladis Dronov) [2040726]
- crypto: qat - set CIPHER capability for DH895XCC (Vladis Dronov) [2040726]
- crypto: qat - stop using iommu_present() (Vladis Dronov) [2040726]
- crypto: qat - fix initialization of pfvf rts_map_msg structures (Vladis Dronov) [2040726]
- crypto: qat - fix initialization of pfvf cap_msg structures (Vladis Dronov) [2040726]
- crypto: qat - remove unneeded assignment (Vladis Dronov) [2040726]
- crypto: qat - disable registration of algorithms (Vladis Dronov) [2040726]
- crypto: qat - enable power management for QAT GEN4 (Vladis Dronov) [2040726]
- crypto: qat - move and rename GEN4 error register definitions (Vladis Dronov) [2040726]
- crypto: qat - add misc workqueue (Vladis Dronov) [2040726]
- crypto: qat - don't cast parameter in bit operations (Vladis Dronov) [2040726]
- crypto: qat - fix access to PFVF interrupt registers for GEN4 (Vladis Dronov) [2040726]
- crypto: qat - fix a signedness bug in get_service_enabled() (Vladis Dronov) [2040726]
- e1000e: Fix possible overflow in LTR decoding (Ken Cox) [2037986]
- e1000e: Print PHY register address when MDI read/write fails (Ken Cox) [2037986]
- e1000e: Correct NVM checksum verification flow (Ken Cox) [2037986]
- e1000e: Fix possible HW unit hang after an s0ix exit (Ken Cox) [2037986 2049953]
- e1000e: Handshake with CSME starts from ADL platforms (Ken Cox) [2037986 2049953]
- e1000e: Separate ADP board type from TGP (Ken Cox) [2037986 2049953]
- e1000e: Fix packet loss on Tiger Lake and later (Ken Cox) [2037986]
- e1000e: Separate TGP board type from SPT (Ken Cox) [2037986]
- e1000e: Remove redundant statement (Ken Cox) [2037986]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2037986]
- net: e1000e: solve insmod 'Unknown symbol mutex_lock' error (Ken Cox) [2037986]
- net/e1000e: Fix spelling mistake "The" -> "This" (Ken Cox) [2037986]
- e1000e: Add space to the debug print (Ken Cox) [2037986]
- e1000e: Add support for Lunar Lake (Ken Cox) [2037986]
- e1000e: Additional PHY power saving in S0ix (Ken Cox) [2037986 2049953]
- e1000e: Add polling mechanism to indicate CSME DPG exit (Ken Cox) [2037986 2049953]
- e1000e: Add handshake with the CSME to support S0ix (Ken Cox) [2037986 2049953]
- cpuidle,intel_idle: Fix CPUIDLE_FLAG_IRQ_ENABLE (Lenny Szubowicz) [2075710]
- intel_idle: Add AlderLake support (Lenny Szubowicz) [2075710]
- intel_idle: Fix SPR C6 optimization (Lenny Szubowicz) [2075710]
- intel_idle: Fix the 'preferred_cstates' module parameter (Lenny Szubowicz) [2075710]
- cpuidle: intel_idle: Update intel_idle() kerneldoc comment (Lenny Szubowicz) [2075710]

* Tue Jul 26 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-136.rt21.136.el9]
- [rt] build kernel-rt-5.14.0-136.rt21.136.el9 [2061574]
- nfsd: destroy percpu stats counters after reply cache shutdown (Jeffrey Layton) [1998042]
- drivers/base: fix userspace break from using bin_attributes for cpumap and cpulist (Phil Auld) [2107713]
- x86/kexec: fix memory leak of elf header buffer (Tao Liu) [2072422]
- xfs: use setattr_copy to set vfs inode attributes (Pavel Reichl) [2085722]
- xfs: ensure log flush at the end of a synchronous fallocate call (Pavel Reichl) [2085722]
- xfs: set prealloc flag in xfs_alloc_file_space() (Pavel Reichl) [2085722]
- xfs: fallocate() should call file_modified() (Pavel Reichl) [2085722]
- xfs: remove XFS_PREALLOC_SYNC (Pavel Reichl) [2085722]
- ipv4: drop dst in multicast routing path (Guillaume Nault) [2104124]
- net: igmp: respect RCU rules in ip_mc_source() and ip_mc_msfilter() (Guillaume Nault) [2104124]
- net/ipv4/igmp: Use struct_size() helper (Guillaume Nault) [2104124]
- selftests: net: fix nexthop warning cleanup double ip typo (Guillaume Nault) [2104124]
- selftests: net: add delete nexthop route warning test (Guillaume Nault) [2104124]
- net: ipv4: fix route with nexthop object delete warning (Guillaume Nault) [2104124]
- ipv4: Check attribute length for RTA_FLOW in multipath route (Guillaume Nault) [2104124]
- ipv4: Check attribute length for RTA_GATEWAY in multipath route (Guillaume Nault) [2104124]
- bpftool: Enable libbpf's strict mode by default (Yauheni Kaliuta) [2100795]
- irqchip/gicv3: Handle resource request failure consistently (Mark Salter) [2083380]
- genirq: Remove WARN_ON_ONCE() in generic_handle_domain_irq() (Mark Salter) [2083380]
- irqchip/gic-v3: Fix priority mask handling (Mark Salter) [2083380]
- irqchip/gic-v3: Refactor ISB + EOIR at ack time (Mark Salter) [2083380]
- irqchip/gic-v3: Ensure pseudo-NMIs have an ISB between ack and handling (Mark Salter) [2083380]
- irqchip/gic-v3: Claim iomem resources (Mark Salter) [2083380]
- irqchip/gic-v3: Relax polling of GIC{R,D}_CTLR.RWP (Mark Salter) [2083380]
- irqchip/gic-v3: Detect LPI invalidation MMIO registers (Mark Salter) [2083380]
- irqchip/gic-v3: Exposes bit values for GICR_CTLR.{IR, CES} (Mark Salter) [2083380]
- irqchip/gic, gic-v3: Prevent GSI to SGI translations (Mark Salter) [2083380]
- irqchip/gic-v3: Fix GICR_CTLR.RWP polling (Mark Salter) [2083380]
- irqchip/gic-v4: Wait for GICR_VPENDBASER.Dirty to clear before descheduling (Mark Salter) [2083380]
- irqchip/gic-v3: Use dsb(ishst) to order writes with ICC_SGI1R_EL1 accesses (Mark Salter) [2083380]
- irqchip/gic-v3-its: Skip HP notifier when no ITS is registered (Mark Salter) [2083380]
- irqchip/gic-v3-its: Reset each ITS's BASERn register before probe (Mark Salter) [2083380]
- irqchip/gic-v3-its: Fix build for !SMP (Mark Salter) [2083380]
- irqchip/gic-v4: Disable redistributors' view of the VPE table at boot time (Mark Salter) [2083380]
- irqchip/gic-v2m: Add const to of_device_id (Mark Salter) [2083380]
- irqchip/gic-v3-its: Limit memreserve cpuhp state lifetime (Mark Salter) [2083380]
- irqchip/gic-v3-its: Postpone LPI pending table freeing and memreserve (Mark Salter) [2083380]
- irqchip/gic-v3-its: Give the percpu rdist struct its own flags field (Mark Salter) [2083380]
- irqchip/irq-gic-v3-its.c: Force synchronisation when issuing INVALL (Mark Salter) [2083380]
- irq: remove handle_domain_{irq,nmi}() (Mark Salter) [2083380]
- Documentation: Fix irq-domain.rst build warning (Mark Salter) [2083380]
- Documentation: Update irq_domain.rst with new lookup APIs (Mark Salter) [2083380]
- irq: remove CONFIG_HANDLE_DOMAIN_IRQ_IRQENTRY (Mark Salter) [2083380]
- irq: arm64: perform irqentry in entry code (Mark Salter) [2083380]
- irq: add a (temporary) CONFIG_HANDLE_DOMAIN_IRQ_IRQENTRY (Mark Salter) [2083380]
- irq: add generic_handle_arch_irq() (Mark Salter) [2083380]
- irq: simplify handle_domain_{irq,nmi}() (Mark Salter) [2083380]
- irqchip/gic: Work around broken Renesas integration (Mark Salter) [2083380]
- irqchip/gic-v3-its: Fix potential VPE leak on error (Mark Salter) [2083380]
- irqchip/gic-v3: Fix priority comparison when non-secure priorities are used (Mark Salter) [2083380]
- irqchip/gic-v3: Fix selection of partition domain for EPPIs (Mark Salter) [2083380]
- irqchip/gic-v3: Add __gic_get_ppi_index() to find the PPI number from hwirq (Mark Salter) [2083380]
- irqchip/gic-v3: Switch to bitmap_zalloc() (Mark Salter) [2083380]
- irqchip/gic-v2m: Switch to bitmap_zalloc() (Mark Salter) [2083380]

* Thu Jul 21 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-135.rt21.135.el9]
- [rt] build kernel-rt-5.14.0-135.rt21.135.el9 [2061574]
- PCI/PM: Fix bridge_d3_blacklist[] Elo i2 overwrite of Gigabyte X299 (Myron Stowe) [2015786]
- PCI/PM: Avoid putting Elo i2 PCIe Ports in D3cold (Myron Stowe) [2015786]
- PCI/ACPI: Allow D3 only if Root Port can signal and wake from D3 (Myron Stowe) [2015786]
- thunderbolt: Do not make DROM read success compulsory (Myron Stowe) [2015786]
- thunderbolt: Do not resume routers if UID is not set (Myron Stowe) [2015786]
- thunderbolt: Retry DROM reads for more failure scenarios (Myron Stowe) [2015786]
- PCI: PM: Fix ordering of operations in pci_back_from_sleep() (Myron Stowe) [2015786]
- PCI: PM: Do not call platform_pci_power_manageable() unnecessarily (Myron Stowe) [2015786]
- PCI: PM: Make pci_choose_state() call pci_target_state() (Myron Stowe) [2015786]
- PCI: PM: Rearrange pci_target_state() (Myron Stowe) [2015786]
- PCI: PM: Simplify acpi_pci_power_manageable() (Myron Stowe) [2015786]
- PCI: PM: Drop struct pci_platform_pm_ops (Myron Stowe) [2015786]
- PCI: ACPI: PM: Do not use pci_platform_pm_ops for ACPI (Myron Stowe) [2015786]
- PCI: PM: Do not use pci_platform_pm_ops for Intel MID PM (Myron Stowe) [2015786]
- driver core: Split device_platform_notify() (Myron Stowe) [2015786]
- software nodes: Split software_node_notify() (Myron Stowe) [2015786]
- PCI: PM: Enable PME if it can be signaled from D3cold (Myron Stowe) [2015786]
- PCI: PM: Avoid forcing PCI_D0 for wakeup reasons inconsistently (Myron Stowe) [2015786]
- PCI: Use pci_update_current_state() in pci_enable_device_flags() (Myron Stowe) [2015786]
- net: tipc: fix possible refcount leak in tipc_sk_create() (Xin Long) [2106046]
- tipc: fix use-after-free Read in tipc_named_reinit (Xin Long) [2106046]
- tipc: check attribute length for bearer name (Xin Long) [2106046]
- nvdimm/blk: add error handling support for add_disk() (Ming Lei) [2103992]
- nvdimm/blk: avoid calling del_gendisk() on early failures (Ming Lei) [2103992]
- nvdimm/btt: add error handling support for add_disk() (Ming Lei) [2103992]
- nvdimm/btt: use goto error labels on btt_blk_init() (Ming Lei) [2103992]
- nvdimm/btt: do not call del_gendisk() if not needed (Ming Lei) [2103992]
- nvdimm/pmem: use add_disk() error handling (Ming Lei) [2103992]
- mmc: block: Add error handling support for add_disk() (Ming Lei) [2103992]
- memstick: mspro_block: Add error handling support for add_disk() (Ming Lei) [2103992]
- netfilter: nf_tables: stricter validation of element data (Florian Westphal) [2104594] {CVE-2022-34918}
- net: openvswitch: fix misuse of the cached connection on tuple changes (Timothy Redaelli) [2104139]
- ethtool: Fix get module eeprom fallback (Davide Caratti) [2103977]
- veth: Add updating of trans_start (Davide Caratti) [2103977]
- selftests: mptcp: Initialize variables to quiet gcc 12 warnings (Davide Caratti) [2103906]
- mptcp: fix conflict with <netinet/in.h> (Davide Caratti) [2103906]
- selftests: mptcp: more stable diag tests (Davide Caratti) [2103906]
- mptcp: fix race on unaccepted mptcp sockets (Davide Caratti) [2103906]
- mptcp: consistent map handling on failure (Davide Caratti) [2103906]
- mptcp: fix shutdown vs fallback race (Davide Caratti) [2103906]
- mptcp: invoke MP_FAIL response when needed (Davide Caratti) [2103906]
- mptcp: introduce MAPPING_BAD_CSUM (Davide Caratti) [2103906]
- mptcp: fix error mibs accounting (Davide Caratti) [2103906]
- selftests: mptcp: add MP_FAIL reset testcase (Davide Caratti) [2103906]
- mptcp: Do not traverse the subflow connection list without lock (Davide Caratti) [2103906]
- mptcp: Check for orphaned subflow before handling MP_FAIL timer (Davide Caratti) [2103906]
- mptcp: stop using the mptcp_has_another_subflow() helper (Davide Caratti) [2103906]
- net: sched: add barrier to fix packet stuck problem for lockless qdisc (Davide Caratti) [2103902]
- net: sched: fixed barrier to prevent skbuff sticking in qdisc backlog (Davide Caratti) [2103902]
- tipc: move bc link creation back to tipc_node_create (Xin Long) [2086388]
- netfilter: nf_tables: replace BUG_ON by element length check (Florian Westphal) [2102148]
- netfilter: nf_log: incorrect offset to network header (Florian Westphal) [2102148]
- netfilter: conntrack: fix crash due to confirmed bit load reordering (Florian Westphal) [2102148]
- netfilter: nft_set_pipapo: release elements in clone from abort path (Florian Westphal) [2102148]
- netfilter: nf_tables: avoid skb access on nf_stolen (Florian Westphal) [2102148]
- netfilter: nf_tables: consolidate rule verdict trace call (Florian Westphal) [2102148]
- netfilter: br_netfilter: do not skip all hooks with 0 priority (Florian Westphal) [2102148]
- netfilter: nft_dynset: restore set element counter when failing to update (Florian Westphal) [2102148]
- selftests: netfilter: correct PKTGEN_SCRIPT_PATHS in nft_concat_range.sh (Florian Westphal) [2102148]
- netfilter: use get_random_u32 instead of prandom (Florian Westphal) [2102148]
- netfilter: nf_tables: bail out early if hardware offload is not supported (Florian Westphal) [2102148]
- netfilter: nf_tables: memleak flow rule from commit path (Florian Westphal) [2102148]
- netfilter: nf_tables: release new hooks on unsupported flowtable flags (Florian Westphal) [2102148]
- netfilter: nf_tables: always initialize flowtable hook list in transaction (Florian Westphal) [2102148]
- netfilter: nf_tables: delete flowtable hooks via transaction list (Florian Westphal) [2102148]
- netfilter: nf_tables: hold mutex on netns pre_exit path (Florian Westphal) [2102148]
- netfilter: conntrack: re-fetch conntrack after insertion (Florian Westphal) [2102148]
- netfilter: flowtable: move dst_check to packet path (Florian Westphal) [2102148]
- netfilter: flowtable: fix TCP flow teardown (Florian Westphal) [2102148]
- netfilter: flowtable: pass flowtable to nf_flow_table_iterate() (Florian Westphal) [2102148]
- netfilter: nft_flow_offload: fix offload with pppoe + vlan (Florian Westphal) [2102148]
- netfilter: nft_flow_offload: skip dst neigh lookup for ppp devices (Florian Westphal) [2102148]
- netfilter: flowtable: fix excessive hw offload attempts after failure (Florian Westphal) [2102148]
- netfilter: nf_nat_h323: eliminate anonymous module_init & module_exit (Florian Westphal) [2102148]
- netfilter: ip6t_rt: fix rt0_hdr parsing in rt_mt6 (Florian Westphal) [2102148]
- netfilter: socket: icmp6: fix use-after-scope (Florian Westphal) [2102148]
- selftests/net: fix section name when using xdp_dummy.o (Hangbin Liu) [2103541]
- selftests/net: enable lo.accept_local in psock_snd test (Hangbin Liu) [2103541]
- tunnels: do not assume mac header is set in skb_tunnel_check_pmtu() (Guillaume Nault) [2101491]
- erspan: do not assume transport header is always set (Guillaume Nault) [2101491]
- ip_gre: test csum_start instead of transport header (Guillaume Nault) [2101491]
- udp_tunnel: Fix end of loop test in udp_tunnel_nic_unregister() (Guillaume Nault) [2101491]
- tcp: fix tcp_mtup_probe_success vs wrong snd_cwnd (Paolo Abeni) [2101465]
- tcp: add accessors to read/set tp->snd_cwnd (Paolo Abeni) [2101465]
- ipv6: take care of disable_policy when restoring routes (Hangbin Liu) [2100718]
- mld: respect RCU rules in ip6_mc_source() and ip6_mc_msfilter() (Hangbin Liu) [2100718]
- net/ipv6/mcast: Use struct_size() helper (Hangbin Liu) [2100718]
- gso: do not skip outer ip header in case of ipip and net_failover (Hangbin Liu) [2100718]


* Thu Jul 21 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-134.rt21.134.el9]
- [rt] build kernel-rt-5.14.0-134.rt21.134.el9 [2061574]
- redhat: fix kernel_variant_package option definition (Herton R. Krzesinski)
- audit: free module name (Richard Guy Briggs) [2100261]
- audit,io_uring,io-wq: call __audit_uring_exit for dummy contexts (Richard Guy Briggs) [2100261]
- certs: Add FIPS selftests (David Howells) [2080044]
- certs: Move load_certificate_list() to be with the asymmetric keys code (David Howells) [2080044]
- scsi: core: Add scsi_done_direct() for immediate completion (Ewan D. Milne) [2094105]
- scsi: core: Rename scsi_mq_done() into scsi_done() and export it (Ewan D. Milne) [2094105]
- scsi: core: Use a structure member to track the SCSI command submitter (Ewan D. Milne) [2094105]

* Wed Jul 20 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-133.rt21.133.el9]
- [rt] build kernel-rt-5.14.0-133.rt21.133.el9 [2061574]
- lockd: fix nlm_close_files (Jeffrey Layton) [2082816]
- lockd: set fl_owner when unlocking files (Jeffrey Layton) [2082816]
- intel/igb:fix repeated words in comments (Corinna Vinschen) [2037984]
- igb: remove unexpected word "the" (Corinna Vinschen) [2037984]
- igb: Make DMA faster when CPU is active on the PCIe link (Corinna Vinschen) [2037984]
- igb: fix a use-after-free issue in igb_clean_tx_ring (Corinna Vinschen) [2037984]
- igb: Remove duplicate defines (Corinna Vinschen) [2037984]
- igb: skip phy status check where unavailable (Corinna Vinschen) [2037984]
- igb: Convert kmap() to kmap_local_page() (Corinna Vinschen) [2037984]
- igb: zero hwtstamp by default (Corinna Vinschen) [2037984]
- igb: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037984]
- igb: support EXTTS on 82580/i354/i350 (Corinna Vinschen) [2037984]
- igb: support PEROUT on 82580/i354/i350 (Corinna Vinschen) [2037984]
- igb: move PEROUT and EXTTS isr logic to separate functions (Corinna Vinschen) [2037984]
- igb: move SDP config initialization to separate function (Corinna Vinschen) [2037984]
- igb: switch to napi_build_skb() (Corinna Vinschen) [2037984]
- igb: remove never changed variable `ret_val' (Corinna Vinschen) [2037984]
- soc: qcom: aoss: Fix missing put_device call in qmp_get (Steve Best) [2100219]
- soc: qcom: aoss: Expose send for generic usecase (Steve Best) [2100219]
- soc: qcom: mdt_loader: be more informative on errors (Steve Best) [2100219]
- soc: qcom: mdt_loader: Split out split-file-loader (Steve Best) [2100219]
- revert remoteproc: qcom: pas: Carry PAS metadata context (Steve Best) [2100219]
- net: openvswitch: fix parsing of nw_proto for IPv6 fragments (Antoine Tenart) [2101452]
- net: openvswitch: fix misuse of the cached connection on tuple changes (Antoine Tenart) [2101452]
- kasan: fix a missing header include of static_keys.h (Mark Salter) [2070169]
- linkage: Fix issue with missing symbol size (Mark Salter) [2070169]
- arm64: mte: Ensure the cleared tags are visible before setting the PTE (Mark Salter) [2070169]
- arm64: Enable repeat tlbi workaround on KRYO4XX gold CPUs (Mark Salter) [2070169]
- arm64: cpufeature: remove duplicate ID_AA64ISAR2_EL1 entry (Mark Salter) [2070169]
- arm64: vdso: fix makefile dependency on vdso.so (Mark Salter) [2070169]
- arm[64]/memremap: don't abuse pfn_valid() to ensure presence of linear map (Mark Salter) [2070169]
- arm64: mm: fix p?d_leaf() (Mark Salter) [2070169]
- arm64: Add part number for Arm Cortex-A78AE (Mark Salter) [2070169]
- arm64: patch_text: Fixup last cpu should be master (Mark Salter) [2070169]
- cpuidle: PSCI: Move the `has_lpi` check to the beginning of the function (Mark Salter) [2070169]
- docs: sysfs-devices-system-cpu: document "asymm" value for mte_tcf_preferred (Mark Salter) [2070169]
- arm64/mte: Remove asymmetric mode from the prctl() interface (Mark Salter) [2070169]
- arm64/mte: Add userspace interface for enabling asymmetric mode (Mark Salter) [2070169]
- arm64/mte: Add hwcap for asymmetric mode (Mark Salter) [2070169]
- arm64/mte: Add a little bit of documentation for mte_update_sctlr_user() (Mark Salter) [2070169]
- arm64/mte: Document ABI for asymmetric mode (Mark Salter) [2070169]
- arm64: mte: avoid clearing PSTATE.TCO on entry unless necessary (Mark Salter) [2070169]
- kasan: split kasan_*enabled() functions into a separate header (Mark Salter) [2070169]
- arm64: Add cavium_erratum_23154_cpus missing sentinel (Mark Salter) [2070169]
- irqchip/gic-v3: Workaround Marvell erratum 38545 when reading IAR (Mark Salter) [2070169]
- arm64: drop unused includes of <linux/personality.h> (Mark Salter) [2070169]
- arm64: prevent instrumentation of bp hardening callbacks (Mark Salter) [2070169]
- arm64: cpufeature: Remove cpu_has_fwb() check (Mark Salter) [2070169]
- arm64: atomics: remove redundant static branch (Mark Salter) [2070169]
- arm64: entry: Save some nops when CONFIG_ARM64_PSEUDO_NMI is not set (Mark Salter) [2070169]
- arm64/mm: Drop use_1G_block() (Mark Salter) [2070169]
- arm64: avoid flushing icache multiple times on contiguous HugeTLB (Mark Salter) [2070169]
- arm64/hugetlb: Define __hugetlb_valid_size() (Mark Salter) [2070169]
- arm64/mm: Consolidate TCR_EL1 fields (Mark Salter) [2070169]
- Revert "arm64: Mitigate MTE issues with str{n}cmp()" (Mark Salter) [2070169]
- arm64: lib: Import latest version of Arm Optimized Routines' strncmp (Mark Salter) [2070169]
- arm64: lib: Import latest version of Arm Optimized Routines' strcmp (Mark Salter) [2070169]
- arm64: cpufeature: Warn if we attempt to read a zero width field (Mark Salter) [2070169]
- arm64: cpufeature: Add missing .field_width for GIC system registers (Mark Salter) [2070169]
- arm64: signal: nofpsimd: Do not allocate fp/simd context when not available (Mark Salter) [2070169]
- arm64: cpufeature: Always specify and use a field width for capabilities (Mark Salter) [2070169]
- arm64: module: remove (NOLOAD) from linker script (Mark Salter) [2070169]
- arm64: clean up symbol aliasing (Mark Salter) [2070169]
- linkage: add SYM_FUNC_ALIAS{,_LOCAL,_WEAK}() (Mark Salter) [2070169]
- arm64: Add support of PAuth QARMA3 architected algorithm (Mark Salter) [2070169]
- arm64: cpufeature: Mark existing PAuth architected algorithm as QARMA5 (Mark Salter) [2070169]
- arm64: cpufeature: Account min_field_value when cheking secondaries for PAuth (Mark Salter) [2070169]
- arm64: insn: add encoders for atomic operations (Mark Salter) [2070169]
- arm64: move AARCH64_BREAK_FAULT into insn-def.h (Mark Salter) [2070169]
- arm64: insn: Generate 64 bit mask immediates correctly (Mark Salter) [2070169]
- arm64: booting.rst: Clarify on requiring non-secure EL2 (Mark Salter) [2070169]
- arm64: fix clang warning about TRAMP_VALIAS (Mark Salter) [2070169]
- arm64: Do not include __READ_ONCE() block in assembly files (Mark Salter) [2070169]
- arm64: kasan: fix include error in MTE functions (Mark Salter) [2070169]
- arm64: Ensure execute-only permissions are not allowed without EPAN (Mark Salter) [2070169]
- arm64: Enable Cortex-A510 erratum 2051678 by default (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_ERRATUM_2051678 workaround (Mark Salter) [2070169]
- arm64: cpufeature: List early Cortex-A510 parts as having broken dbm (Mark Salter) [2070169]
- arm64: errata: Update ARM64_ERRATUM_[2119858|2224489] with Cortex-X2 ranges (Mark Salter) [2070169]
- arm64: vdso: Fix "no previous prototype" warning (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE trace data corruption (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE invalid prohibited states (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE ignored system register writes (Mark Salter) [2070169]
- arm64: mm: apply __ro_after_init to memory_limit (Mark Salter) [2070169]
- arm64: atomics: lse: Dereference matching size (Mark Salter) [2070169]
- asm-generic: Add missing brackets for io_stop_wc macro (Mark Salter) [2070169]
- arm64: Use correct method to calculate nomap region boundaries (Mark Salter) [2070169]
- arm64: Drop outdated links in comments (Mark Salter) [2070169]
- arm64: errata: Fix exec handling in erratum 1418040 workaround (Mark Salter) [2070169]
- arm64: Unhash early pointer print plus improve comment (Mark Salter) [2070169]
- asm-generic: introduce io_stop_wc() and add implementation for ARM64 (Mark Salter) [2070169]
- arm64: errata: Enable TRBE workaround for write to out-of-range address (Mark Salter) [2070169]
- arm64: errata: Enable workaround for TRBE overwrite in FILL mode (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_WORKAROUND_TRBE_WRITE_OUT_OF_RANGE (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE write to out-of-range (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_WORKAROUND_TSB_FLUSH_FAILURE (Mark Salter) [2070169]
- arm64: errata: Add workaround for TSB flush failures (Mark Salter) [2070169]
- redhat/configs: aarch64: Enable ARM64_WORKAROUND_TRBE_OVERWRITE_FILL_MODE (Mark Salter) [2070169]
- arm64: errata: Add detection for TRBE overwrite in FILL mode (Mark Salter) [2070169]
- arm64: remove __dma_*_area() aliases (Mark Salter) [2070169]
- docs/arm64: delete a space from tagged-address-abi (Mark Salter) [2070169]
- arm64/fp: Add comments documenting the usage of state restore functions (Mark Salter) [2070169]
- arm64: mm: Use asid feature macro for cheanup (Mark Salter) [2070169]
- arm64: mm: Rename asid2idx() to ctxid2asid() (Mark Salter) [2070169]
- arm64: kexec: reduce calls to page_address() (Mark Salter) [2070169]
- arm64: extable: remove unused ex_handler_t definition (Mark Salter) [2070169]
- arm64: entry: Use SDEI event constants (Mark Salter) [2070169]
- arm64: Simplify checking for populated DT (Mark Salter) [2070169]
- arm64: Ensure that the 'bti' macro is defined where linkage.h is included (Mark Salter) [2070169]
- arm64: Use BTI C directly and unconditionally (Mark Salter) [2070169]
- arm64: Unconditionally override SYM_FUNC macros (Mark Salter) [2070169]
- arm64: Add macro version of the BTI instruction (Mark Salter) [2070169]
- arm64: Enable KCSAN (Mark Salter) [2070169]
- arm64/sve: Minor clarification of ABI documentation (Mark Salter) [2070169]
- arm64/sve: Generalise vector length configuration prctl() for SME (Mark Salter) [2070169]
- arm64/sve: Make sysctl interface for SVE reusable by SME (Mark Salter) [2070169]
- arm64: perf: Support new DT compatibles (Mark Salter) [2070169]
- arm64: perf: Simplify registration boilerplate (Mark Salter) [2070169]
- arm64: perf: Support Denver and Carmel PMUs (Mark Salter) [2070169]
- arm64: atomics: lse: define RETURN ops in terms of FETCH ops (Mark Salter) [2070169]
- arm64: atomics: lse: improve constraints for simple ops (Mark Salter) [2070169]
- arm64: atomics: lse: define ANDs in terms of ANDNOTs (Mark Salter) [2070169]
- arm64: atomics lse: define SUBs in terms of ADDs (Mark Salter) [2070169]
- arm64: atomics: format whitespace consistently (Mark Salter) [2070169]
- arm64/xor: use EOR3 instructions when available (Mark Salter) [2070169]
- arm64: mm: log potential KASAN shadow alias (Mark Salter) [2070169]
- arm64: mm: use die_kernel_fault() in do_mem_abort() (Mark Salter) [2070169]
- arm64: mte: DC {GVA,GZVA} shouldn't be used when DCZID_EL0.DZP == 1 (Mark Salter) [2070169]
- arm64: clear_page() shouldn't use DC ZVA when DCZID_EL0.DZP == 1 (Mark Salter) [2070169]
- arm64: Snapshot thread flags (Mark Salter) [2070169]
- dlm: fix missing lkb refcount handling (Alexander Aring) [2084605]

* Tue Jul 19 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-132.rt21.132.el9]
- [rt] build kernel-rt-5.14.0-132.rt21.132.el9 [2061574]
- SUNRPC: Don't leak sockets in xs_local_connect() (Jeffrey Layton) [2089430]
- SUNRPC: clean up some inconsistent indenting (Jeffrey Layton) [2089430]
- SUNRPC: Ensure we flush any closed sockets before xs_xprt_free() (Jeffrey Layton) [2089430]
- SUNRPC: Don't call connect() more than once on a TCP socket (Jeffrey Layton) [2089430]
- kdump: round up the total memory size to 128M for crashkernel reservation (Tao Liu) [2058040]
- topology/sysfs: Add PPIN in sysfs under cpu topology (Mark Langsdorf) [2067284]
- x86/cpu: Read/save PPIN MSR during initialization (Mark Langsdorf) [2067284]
- x86/cpu: Merge Intel and AMD ppin_init() functions (Mark Langsdorf) [2067284]
- x86/build: Use the proper name CONFIG_FW_LOADER (Mark Langsdorf) [2067252]
- gpio: mockup: Convert to use software nodes (Mark Langsdorf) [2067252]
- of: unittest: update text of expected warnings (Mark Langsdorf) [2067284]
- rtc: mc146818-lib: fix signedness bug in mc146818_get_time() (Mark Langsdorf) [2067284]
- topology/sysfs: get rid of htmldoc warning (Mark Langsdorf) [2067284]
- topology: Fix up build warning in topology_is_visible() (Mark Langsdorf) [2067284]
- arch_topology: Do not set llc_sibling if llc_id is invalid (Mark Langsdorf) [2067284]
- topology/sysfs: Hide PPIN on systems that do not support it. (Mark Langsdorf) [2067284]
- regmap: allow a defined reg_base to be added to every address (Mark Langsdorf) [2067284]
- regmap: add configurable downshift for addresses (Mark Langsdorf) [2067284]
- drivers/base/dd.c : Remove the initial value of the global variable (Mark Langsdorf) [2067284]
- devres: fix typos in comments (Mark Langsdorf) [2067284]
- base: soc: Make soc_device_match() simpler and easier to read (Mark Langsdorf) [2067284]
- driver core: dd: fix return value of __setup handler (Mark Langsdorf) [2067284]
- driver core: Refactor sysfs and drv/bus remove hooks (Mark Langsdorf) [2067284]
- driver core: Refactor multiple copies of device cleanup (Mark Langsdorf) [2067284]
- arch_topology: obtain cpu capacity using information from CPPC (Mark Langsdorf) [2067284]
- PM: core: keep irq flags in device_pm_check_callbacks() (Mark Langsdorf) [2067284]
- PM: sleep: Add device name to suspend_report_result() (Mark Langsdorf) [2067284]
- PM: runtime: Have devm_pm_runtime_enable() handle pm_runtime_dont_use_autosuspend() (Mark Langsdorf) [2067284]
- PM: sleep: wakeup: Fix typos in comments (Mark Langsdorf) [2067284]
- PM: domains: Fix sleep-in-atomic bug caused by genpd_debug_remove() (Mark Langsdorf) [2067284]
- PM: domains: use dev_err_probe() to simplify error handling (Mark Langsdorf) [2067284]
- PM: domains: Prevent power off for parent unless child is in deepest state (Mark Langsdorf) [2067284]
- firmware_loader: EXTRA_FIRMWARE does not support compressed files (Mark Langsdorf) [2067284]
- driver core: cleanup double words comments (Mark Langsdorf) [2067284]
- device property: Don't split fwnode_get_irq*() APIs in the code (Mark Langsdorf) [2067284]
- regmap: irq: cleanup comments (Mark Langsdorf) [2067284]
- platform: use dev_err_probe() in platform_get_irq_byname() (Mark Langsdorf) [2067284]
- devtmpfs: drop redundant fs parameters from internal fs (Mark Langsdorf) [2067284]
- topology/sysfs: Add format parameter to macro defining "show" functions for proc (Mark Langsdorf) [2067284]
- component: Replace most references to 'master' with 'aggregate device' (Mark Langsdorf) [2067284]
- device property: Add fwnode_irq_get_byname (Mark Langsdorf) [2067284]
- regmap-irq: Fix typo in comment (Mark Langsdorf) [2067284]
- driver core: Free DMA range map when device is released (Mark Langsdorf) [2067284]
- regmap-irq: Update interrupt clear register for proper reset (Mark Langsdorf) [2067284]
- PM: s2idle: ACPI: Fix wakeup interrupts handling (Mark Langsdorf) [2067284]
- devtmpfs regression fix: reconfigure on each mount (Mark Langsdorf) [2067284]
- regmap: debugfs: Fix indentation (Mark Langsdorf) [2067284]
- regmap: Call regmap_debugfs_exit() prior to _init() (Mark Langsdorf) [2067284]
- driver core: Make bus notifiers in right order in really_probe() (Mark Langsdorf) [2067284]
- driver core: Move driver_sysfs_remove() after driver_sysfs_add() (Mark Langsdorf) [2067284]
- headers/uninline: Uninline single-use function: kobject_has_children() (Mark Langsdorf) [2067284]
- redhat: enable CONFIG_DEVTMPFS_SAFE (Mark Langsdorf) [2067284]
- devtmpfs: mount with noexec and nosuid (Mark Langsdorf) [2067284]
- driver core: Simplify async probe test code by using ktime_ms_delta() (Mark Langsdorf) [2067284]
- kobject: remove kset from struct kset_uevent_ops callbacks (Mark Langsdorf) [2067284]
- driver core: make kobj_type constant. (Mark Langsdorf) [2067284]
- PM: runtime: Simplify locking in pm_runtime_put_suppliers() (Mark Langsdorf) [2067284]
- software node: fix wrong node passed to find nargs_prop (Mark Langsdorf) [2067284]
- driver core: platform: document registration-failure requirement (Mark Langsdorf) [2067284]
- device property: Add fwnode_iomap() (Mark Langsdorf) [2067284]
- device property: Drop fwnode_graph_get_remote_node() (Mark Langsdorf) [2067284]
- device property: Use fwnode_graph_for_each_endpoint() macro (Mark Langsdorf) [2067284]
- device property: Implement fwnode_graph_get_endpoint_count() (Mark Langsdorf) [2067284]
- device property: Fix documentation for FWNODE_GRAPH_DEVICE_DISABLED (Mark Langsdorf) [2067284]
- device property: Fix fwnode_graph_devcon_match() fwnode leak (Mark Langsdorf) [2067284]
- PM: runtime: Add safety net to supplier device release (Mark Langsdorf) [2067284]
- PM: runtime: Capture device status before disabling runtime PM (Mark Langsdorf) [2067284]
- rtc: Check return value from mc146818_get_time() (Mark Langsdorf) [2067284]
- rtc: mc146818-lib: change return values of mc146818_get_time() (Mark Langsdorf) [2067284]
- rtc: cmos: take rtc_lock while reading from CMOS (Mark Langsdorf) [2067284]
- device property: Check fwnode->secondary when finding properties (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Move the text into the code (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Clarify the release of devices from find device (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Clarify __auxiliary_driver_register (Mark Langsdorf) [2067284]
- Documentation/auxiliary_bus: Clarify auxiliary_device creation (Mark Langsdorf) [2067284]
- topology/sysfs: rework book and drawer topology ifdefery (Mark Langsdorf) [2067284]
- topology/sysfs: export cluster attributes only if an architectures has support (Mark Langsdorf) [2067284]
- topology/sysfs: export die attributes only if an architectures has support (Mark Langsdorf) [2067284]
- driver core: platform: Make use of the helper function dev_err_probe() (Mark Langsdorf) [2067284]
- device property: Remove device_add_properties() API (Mark Langsdorf) [2067284]
- PCI: Convert to device_create_managed_software_node() (Mark Langsdorf) [2067284]
- driver core: Don't call device_remove_properties() from device_del() (Mark Langsdorf) [2067284]
- arch_topology: Remove unused topology_set_thermal_pressure() and related (Mark Langsdorf) [2067284]
- thermal: cpufreq_cooling: Use new thermal pressure update function (Mark Langsdorf) [2067284]
- arch_topology: Introduce thermal pressure update function (Mark Langsdorf) [2067284]
- regmap: allow to define reg_update_bits for no bus configuration (Mark Langsdorf) [2067284]
- PM: sleep: Fix error handling in dpm_prepare() (Mark Langsdorf) [2067252]
- arch_numa: simplify numa_distance allocation (Mark Langsdorf) [2067252]
- arm64: support page mapping percpu first chunk allocator (Mark Langsdorf) [2067252]
- PM: sleep: Avoid calling put_device() under dpm_list_mtx (Mark Langsdorf) [2067252]
- PM: sleep: Fix runtime PM based cpuidle support (Mark Langsdorf) [2067252]
- PM / wakeirq: support enabling wake-up irq after runtime_suspend called (Mark Langsdorf) [2067252]
- device property: Drop redundant NULL checks (Mark Langsdorf) [2067252]
- PM: sleep: Pause cpuidle later and resume it earlier during system transitions (Mark Langsdorf) [2067252]
- PM: suspend: Do not pause cpuidle in the suspend-to-idle path (Mark Langsdorf) [2067252]
- regmap: spi: Set regmap max raw r/w from max_transfer_size (Mark Langsdorf) [2067252]
- PM: sleep: Do not let "syscore" devices runtime-suspend during system transitions (Mark Langsdorf) [2067252]
- x86/build: Tuck away built-in firmware under FW_LOADER (Mark Langsdorf) [2067252]
- vmlinux.lds.h: wrap built-in firmware support under FW_LOADER (Mark Langsdorf) [2067252]
- firmware_loader: move struct builtin_fw to the only place used (Mark Langsdorf) [2067252]
- x86/microcode: Use the firmware_loader built-in API (Mark Langsdorf) [2067252]
- firmware_loader: remove old DECLARE_BUILTIN_FIRMWARE() (Mark Langsdorf) [2067252]
- firmware_loader: formalize built-in firmware API (Mark Langsdorf) [2067252]
- component: do not leave master devres group open after bind (Mark Langsdorf) [2067252]
- driver core: Provide device_match_acpi_handle() helper (Mark Langsdorf) [2067252]
- regmap: Fix possible double-free in regcache_rbtree_exit() (Mark Langsdorf) [2067252]
- device property: build kunit tests without structleak plugin (Mark Langsdorf) [2067252]
- driver core: Reject pointless SYNC_STATE_ONLY device links (Mark Langsdorf) [2067252]
- firmware_loader: add a sanity check for firmware_request_builtin() (Mark Langsdorf) [2067252]
- firmware_loader: split built-in firmware call (Mark Langsdorf) [2067252]
- firmware_loader: fix pre-allocated buf built-in firmware use (Mark Langsdorf) [2067252]
- drivers/base/component.c: remove superfluous header files from component.c (Mark Langsdorf) [2067252]
- drivers/base/arch_topology.c: remove superfluous header (Mark Langsdorf) [2067252]
- driver core: use NUMA_NO_NODE during device_initialize (Mark Langsdorf) [2067252]
- driver core: Fix possible memory leak in device_link_add() (Mark Langsdorf) [2067252]
- driver core: Add debug logs when fwnode links are added/deleted (Mark Langsdorf) [2067252]
- driver core: Create __fwnode_link_del() helper function (Mark Langsdorf) [2067252]
- driver core: Set deferred probe reason when deferred by driver core (Mark Langsdorf) [2067252]
- driver core: fw_devlink: Add support for FWNODE_FLAG_NEEDS_CHILD_BOUND_ON_ADD (Mark Langsdorf) [2067252]
- driver core: Clarify that dev_err_probe() is OK even w/out -EPROBE_DEFER (Mark Langsdorf) [2067252]
- driver core: fw_devlink: Improve handling of cyclic dependencies (Mark Langsdorf) [2067252]
- driver core: platform: Make use of the helper macro SET_RUNTIME_PM_OPS() (Mark Langsdorf) [2067252]
- PM: base: power: don't try to use non-existing RTC for storing data (Mark Langsdorf) [2067252]
- PM: sleep: core: Avoid setting power.must_resume to false (Mark Langsdorf) [2067252]
- PM: sleep: wakeirq: drop useless parameter from dev_pm_attach_wake_irq() (Mark Langsdorf) [2067252]
- PM: domains: Fix domain attach for CONFIG_PM_OPP=n (Mark Langsdorf) [2067252]
- PM: runtime: add devm_pm_clk_create helper (Mark Langsdorf) [2067252]
- PM: runtime: add devm_pm_runtime_enable helper (Mark Langsdorf) [2067252]
- regmap: teach regmap to use raw spinlocks if requested in the config (Mark Langsdorf) [2067252]
- driver core: platform: Remove platform_device_add_properties() (Mark Langsdorf) [2067252]
- PM: domains: Add support for 'required-opps' to set default perf state (Mark Langsdorf) [2067252]
- Revert "media: device property: Call fwnode_graph_get_endpoint_by_id() for fwnode->secondary" (Mark Langsdorf) [2067252]
- device property: Check fwnode->secondary in fwnode_graph_get_next_endpoint() (Mark Langsdorf) [2067252]
- drivers/base/node.c: use bin_attribute to break the size limitation of cpumap ABI (Mark Langsdorf) [2067252]
- regmap: allow const array for {devm_,}regmap_field_bulk_alloc reg_fields (Mark Langsdorf) [2067252]
- driver: base: Prefer unsigned int to bare use of unsigned (Mark Langsdorf) [2067252]
- cacheinfo: clear cache_leaves(cpu) in free_cache_attributes() (Mark Langsdorf) [2067252]
- driver core: Fix error return code in really_probe() (Mark Langsdorf) [2067252]
- firmware: fix theoretical UAF race with firmware cache and resume (Mark Langsdorf) [2067252]
- driver: base: Replace symbolic permissions with octal permissions (Mark Langsdorf) [2067252]
- driver core: Split device_platform_notify() (Mark Langsdorf) [2067252]
- software nodes: Split software_node_notify() (Mark Langsdorf) [2067252]
- regmap: Prefer unsigned int to bare use of unsigned (Mark Langsdorf) [2067252]
- regmap: fix the offset of register error log (Mark Langsdorf) [2067252]
- nfs: reexport documentation (Dave Wysochanski) [2006399]

* Mon Jul 18 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-131.rt21.131.el9]
- [rt] build kernel-rt-5.14.0-131.rt21.131.el9 [2061574]
- scsi: lpfc: Copyright updates for 14.2.0.5 patches (Paul Ely) [2102818]
- scsi: lpfc: Update lpfc version to 14.2.0.5 (Paul Ely) [2102818]
- scsi: lpfc: Remove Menlo/Hornet related code (Paul Ely) [2102818]
- scsi: lpfc: Refactor lpfc_nvmet_prep_abort_wqe() into lpfc_sli_prep_abort_xri() (Paul Ely) [2102818]
- scsi: lpfc: Fix lost NVMe paths during LIF bounce stress test (Paul Ely) [2102818]
- scsi: lpfc: Fix attempted FA-PWWN usage after feature disable (Paul Ely) [2102818]
- scsi: lpfc: Fix possible memory leak when failing to issue CMF WQE (Paul Ely) [2102818]
- scsi: lpfc: Remove extra atomic_inc on cmd_pending in queuecommand after VMID (Paul Ely) [2102818]
- scsi: lpfc: Set PU field when providing D_ID in XMIT_ELS_RSP64_CX iocb (Paul Ely) [2102818]
- scsi: lpfc: Prevent buffer overflow crashes in debugfs with malformed user input (Paul Ely) [2102818]
- scsi: lpfc: Fix uninitialized cqe field in lpfc_nvme_cancel_iocb() (Paul Ely) [2102818]
- scsi: lpfc: Change FA-PWWN detection methodology (Paul Ely) [2102818]
- scsi: lpfc: Remove failing soft_wwn support (Paul Ely) [2102818]
- scsi: lpfc: Update lpfc version to 14.2.0.4 (Paul Ely) [2102818]
- scsi: lpfc: Allow reduced polling rate for nvme_admin_async_event cmd completion (Paul Ely) [2102818]
- scsi: lpfc: Add more logging of cmd and cqe information for aborted NVMe cmds (Paul Ely) [2102818]
- scsi: lpfc: Fix port stuck in bypassed state after LIP in PT2PT topology (Paul Ely) [2102818]
- scsi: lpfc: Resolve NULL ptr dereference after an ELS LOGO is aborted (Paul Ely) [2102818]
- scsi: lpfc: Address NULL pointer dereference after starget_to_rport() (Paul Ely) [2102818]
- scsi: lpfc: Resolve some cleanup issues following SLI path refactoring (Paul Ely) [2102818]
- scsi: lpfc: Resolve some cleanup issues following abort path refactoring (Paul Ely) [2102818]
- scsi: lpfc: Correct BDE type for XMIT_SEQ64_WQE in lpfc_ct_reject_event() (Paul Ely) [2102818]
- scsi: lpfc: Add support for ATTO Fibre Channel devices (Paul Ely) [2102818]
- scsi: lpfc: Add support for VMID tagging of NVMe I/Os (Paul Ely) [2102818]
- scsi: lpfc: Rework lpfc_vmid_get_appid() to be protocol independent (Paul Ely) [2102818]
- scsi: lpfc: Commonize VMID code location (Paul Ely) [2102818]
- scsi: nvme-fc: Add new routine nvme_fc_io_getuuid() (Paul Ely) [2102818]
- scsi: target: pscsi: Set SCF_TREAT_READ_AS_NORMAL flag only if there is valid data (Maurizio Lombardi) [2080216]
- x86/speculation/mmio: Print SMT warning (Waiman Long) [2090256] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- KVM: x86/speculation: Disable Fill buffer clear within guests (Waiman Long) [2090256] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Reuse SRBDS mitigation for SBDS (Waiman Long) [2090256] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/srbds: Update SRBDS mitigation selection (Waiman Long) [2090256] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Add sysfs reporting for Processor MMIO Stale Data (Waiman Long) [2090256] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Enable CPU Fill buffer clearing on idle (Waiman Long) [2090256] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/bugs: Group MDS, TAA & Processor MMIO Stale Data mitigations (Waiman Long) [2090256] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Add mitigation for Processor MMIO Stale Data (Waiman Long) [2090256] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation: Add a common function for MD_CLEAR mitigation update (Waiman Long) [2090256] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/speculation/mmio: Enumerate Processor MMIO Stale Data bug (Waiman Long) [2090256] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- Documentation: Add documentation for Processor MMIO Stale Data (Waiman Long) [2090256] {CVE-2022-21123 CVE-2022-21125 CVE-2022-21166}
- x86/tsx: Disable TSX development mode at boot (Waiman Long) [2090256]
- x86/tsx: Use MSR_TSX_CTRL to clear CPUID bits (Waiman Long) [2090256]
- Documentation: Add L1D flushing Documentation (Waiman Long) [2090256]
- x86, prctl: Hook L1D flushing in via prctl (Waiman Long) [2090256]
- x86/mm: Prepare for opt-in based L1D flush in switch_mm() (Waiman Long) [2090256]
- x86/process: Make room for TIF_SPEC_L1D_FLUSH (Waiman Long) [2090256]
- sched: Add task_work callback for paranoid L1D flush (Waiman Long) [2090256]
- x86/mm: Refactor cond_ibpb() to support other use cases (Waiman Long) [2090256]
- cpuidle: psci: Fix regression leading to no genpd governor (Mark Langsdorf) [2067314]
- cpuidle: Factor-out power domain related code from PSCI domain driver (Mark Langsdorf) [2067314]
- cpuidle: haltpoll: Call cpuidle_poll_state_init() later (Mark Langsdorf) [2067314]
- cpuidle: use default_groups in kobj_type (Mark Langsdorf) [2067314]
- cpuidle: Fix cpuidle_remove_state_sysfs() kerneldoc comment (Mark Langsdorf) [2067314]
- cpuidle: menu: Fix typo in a comment (Mark Langsdorf) [2067314]
- cpuidle: Fix kobject memory leaks in error paths (Mark Langsdorf) [2067314]
- Reinstate some of "swiotlb: rework "fix info leak with DMA_FROM_DEVICE"" (Chris von Recklinghausen) [2059704] {CVE-2022-0854}
- swiotlb: fix info leak with DMA_FROM_DEVICE (Chris von Recklinghausen) [2059704] {CVE-2022-0854}

* Fri Jul 15 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-130.rt21.130.el9]
- [rt] build kernel-rt-5.14.0-130.rt21.130.el9 [2061574]
- scsi: iscsi: Fix session removal on shutdown (Chris Leech) [2101762]
- scsi: qedi: Use QEDI_MODE_NORMAL for error handling (Chris Leech) [2101762]
- scsi: iscsi: Add helper to remove a session from the kernel (Chris Leech) [2101762]
- scsi: iscsi: Clean up bound endpoints during shutdown (Chris Leech) [2101762]
- scsi: iscsi: Allow iscsi_if_stop_conn() to be called from kernel (Chris Leech) [2101762]
- scsi: iscsi: Fix HW conn removal use after free (Chris Leech) [2101762]
- scsi: iscsi: Make iscsi_unregister_transport() return void (Chris Leech) [2101762]
- scsi: core: iscsi: Directly use ida_alloc()/ida_free() (Chris Leech) [2101762]
- scsi: iscsi: Exclude zero from the endpoint ID range (Chris Leech) [2101762]
- scsi: iscsi: Fix harmless double shift bug (Chris Leech) [2101762]
- scsi: libiscsi: Remove unnecessary memset() in iscsi_conn_setup() (Chris Leech) [2101762]
- scsi: libiscsi: Teardown iscsi_cls_conn gracefully (Chris Leech) [2101762]
- scsi: libiscsi: Add iscsi_cls_conn to sysfs after initialization (Chris Leech) [2101762]
- scsi: iscsi: Add helper functions to manage iscsi_cls_conn (Chris Leech) [2101762]
- scsi: iscsi: Drop temp workq_name (Chris Leech) [2101762]
- scsi: iscsi: Use the session workqueue for recovery (Chris Leech) [2101762]
- scsi: iscsi: ql4xxx: Use per-session workqueue for unbinding (Chris Leech) [2101762]
- scsi: iscsi: Remove iscsi_scan_finished() (Chris Leech) [2101762]
- scsi: libiscsi: Fix UAF in iscsi_conn_get_param()/iscsi_conn_teardown() (Chris Leech) [2101762]
- scsi: libiscsi: Move ehwait initialization to iscsi_session_setup() (Chris Leech) [2101762]
- filemap: Fix serialization adding transparent huge pages to page cache (Aristeu Rozanski) [2083861]
- mm/huge_memory: Fix xarray node memory leak (Aristeu Rozanski) [2083861]
- filemap: Cache the value of vm_flags (Aristeu Rozanski) [2083861]
- mm/readahead: Fix readahead with large folios (Aristeu Rozanski) [2083861]
- mm/hwpoison: use pr_err() instead of dump_page() in get_any_page() (Aristeu Rozanski) [2083861]
- XArray: Disallow sibling entries of nodes (Aristeu Rozanski) [2083861]
- tmpfs: fix regressions from wider use of ZERO_PAGE (Aristeu Rozanski) [2083861]
- mm/rmap: Fix handling of hugetlbfs pages in page_vma_mapped_walk (Aristeu Rozanski) [2083861]
- mm/mempolicy: Use vma_alloc_folio() in new_page() (Aristeu Rozanski) [2083861]
- mm: Add vma_alloc_folio() (Aristeu Rozanski) [2083861]
- mm/migrate: Use a folio in migrate_misplaced_transhuge_page() (Aristeu Rozanski) [2083861]
- mm/migrate: Use a folio in alloc_migration_target() (Aristeu Rozanski) [2083861]
- mm/munlock: update Documentation/vm/unevictable-lru.rst (Aristeu Rozanski) [2083861]
- mm/munlock: add lru_add_drain() to fix memcg_stat_test (Aristeu Rozanski) [2083861]
- XArray: Update the LRU list in xas_split() (Aristeu Rozanski) [2083861]
- XArray: Fix xas_create_range() when multi-order entry present (Aristeu Rozanski) [2083861]
- mm: unmap_mapping_range_tree() with i_mmap_rwsem shared (Aristeu Rozanski) [2083861]
- mm: warn on deleting redirtied only if accounted (Aristeu Rozanski) [2083861]
- mm/thp: fix NR_FILE_MAPPED accounting in page_*_file_rmap() (Aristeu Rozanski) [2083861]
- mm: filemap_unaccount_folio() large skip mapcount fixup (Aristeu Rozanski) [2083861]
- mm: delete __ClearPageWaiters() (Aristeu Rozanski) [2083861]
- mm/hugetlb.c: export PageHeadHuge() (Aristeu Rozanski) [2083861]
- mm: rework swap handling of zap_pte_range (Aristeu Rozanski) [2083861]
- mm: change zap_details.zap_mapping into even_cows (Aristeu Rozanski) [2083861]
- mm: rename zap_skip_check_mapping() to should_zap_page() (Aristeu Rozanski) [2083861]
- mm: don't skip swap entry even if zap_details specified (Aristeu Rozanski) [2083861]
- mm: replace multiple dcache flush with flush_dcache_folio() (Aristeu Rozanski) [2083861]
- mm: userfaultfd: fix missing cache flush in mcopy_atomic_pte() and __mcopy_atomic() (Aristeu Rozanski) [2083861]
- mm: shmem: fix missing cache flush in shmem_mfill_atomic_pte() (Aristeu Rozanski) [2083861]
- mm: hugetlb: fix missing cache flush in hugetlb_mcopy_atomic_pte() (Aristeu Rozanski) [2083861]
- mm: hugetlb: fix missing cache flush in copy_huge_page_from_user() (Aristeu Rozanski) [2083861]
- mm: fix missing cache flush for all tail pages of compound page (Aristeu Rozanski) [2083861]
- mm: thp: fix wrong cache flush in remove_migration_pmd() (Aristeu Rozanski) [2083861]
- tmpfs: do not allocate pages on read (Aristeu Rozanski) [2083861]
- shmem: mapping_set_exiting() to help mapped resilience (Aristeu Rozanski) [2083861]
- selftests/vm/transhuge-stress: Support file-backed PMD folios (Aristeu Rozanski) [2083861]
- mm/filemap: Support VM_HUGEPAGE for file mappings (Aristeu Rozanski) [2083861]
- mm/readahead: Switch to page_cache_ra_order (Aristeu Rozanski) [2083861]
- mm/readahead: Add large folio readahead (Aristeu Rozanski) [2083861]
- mm: Support arbitrary THP sizes (Aristeu Rozanski) [2083861]
- mm: Make large folios depend on THP (Aristeu Rozanski) [2083861]
- mm: Fix READ_ONLY_THP warning (Aristeu Rozanski) [2083861]
- mm/filemap: Allow large folios to be added to the page cache (Aristeu Rozanski) [2083861]
- mm: Turn can_split_huge_page() into can_split_folio() (Aristeu Rozanski) [2083861]
- mm/vmscan: Convert pageout() to take a folio (Aristeu Rozanski) [2083861]
- mm/vmscan: Turn page_check_references() into folio_check_references() (Aristeu Rozanski) [2083861]
- mm/vmscan: Account large folios correctly (Aristeu Rozanski) [2083861]
- mm/vmscan: Optimise shrink_page_list for non-PMD-sized folios (Aristeu Rozanski) [2083861]
- mm/vmscan: Free non-shmem folios without splitting them (Aristeu Rozanski) [2083861]
- mm/rmap: Constify the rmap_walk_control argument (Aristeu Rozanski) [2083861]
- mm/rmap: Convert rmap_walk() to take a folio (Aristeu Rozanski) [2083861]
- mm: Turn page_anon_vma() into folio_anon_vma() (Aristeu Rozanski) [2083861]
- mm/rmap: Turn page_lock_anon_vma_read() into folio_lock_anon_vma_read() (Aristeu Rozanski) [2083861]
- mm/damon: Convert damon_pa_young() to use a folio (Aristeu Rozanski) [2083861]
- mm/damon: Convert damon_pa_mkold() to use a folio (Aristeu Rozanski) [2083861]
- mm/migrate: Convert remove_migration_ptes() to folios (Aristeu Rozanski) [2083861]
- mm/rmap: Convert make_device_exclusive_range() to use folios (Aristeu Rozanski) [2083861]
- mm/rmap: Convert try_to_migrate() to folios (Aristeu Rozanski) [2083861]
- mm/rmap: Convert try_to_unmap() to take a folio (Aristeu Rozanski) [2083861]
- mm/rmap: Turn page_referenced() into folio_referenced() (Aristeu Rozanski) [2083861]
- mm/mlock: Add mlock_vma_folio() (Aristeu Rozanski) [2083861]
- mm/rmap: Use a folio in page_mkclean_one() (Aristeu Rozanski) [2083861]
- mm/page_idle: Convert page_idle_clear_pte_refs() to use a folio (Aristeu Rozanski) [2083861]
- mm: Convert page_vma_mapped_walk to work on PFNs (Aristeu Rozanski) [2083861]
- sparc32: Add pmd_pfn() (Aristeu Rozanski) [2083861]
- powerpc: Add pmd_pfn() (Aristeu Rozanski) [2083861]
- mm: Add DEFINE_PAGE_VMA_WALK and DEFINE_FOLIO_VMA_WALK (Aristeu Rozanski) [2083861]
- mm: Add folio_pgoff() (Aristeu Rozanski) [2083861]
- mm: Add split_folio_to_list() (Aristeu Rozanski) [2083861]
- mm: Add folio_mapcount() (Aristeu Rozanski) [2083861]
- mm: Turn head_compound_mapcount() into folio_entire_mapcount() (Aristeu Rozanski) [2083861]
- mm/vmscan: Turn page_check_dirty_writeback() into folio_check_dirty_writeback() (Aristeu Rozanski) [2083861]
- fs: Move many prototypes to pagemap.h (Aristeu Rozanski) [2083861]
- mm/truncate: Combine invalidate_mapping_pagevec() and __invalidate_mapping_pages() (Aristeu Rozanski) [2083861]
- mm: Turn deactivate_file_page() into deactivate_file_folio() (Aristeu Rozanski) [2083861]
- mm/truncate: Convert __invalidate_mapping_pages() to use a folio (Aristeu Rozanski) [2083861]
- mm/truncate: Split invalidate_inode_page() into mapping_evict_folio() (Aristeu Rozanski) [2083861]
- mm: Convert remove_mapping() to take a folio (Aristeu Rozanski) [2083861]
- mm/truncate: Replace page_mapped() call in invalidate_inode_page() (Aristeu Rozanski) [2083861]
- mm/truncate: Convert invalidate_inode_page() to use a folio (Aristeu Rozanski) [2083861]
- mm/truncate: Inline invalidate_complete_page() into its one caller (Aristeu Rozanski) [2083861]
- splice: Use a folio in page_cache_pipe_buf_try_steal() (Aristeu Rozanski) [2083861]
- mm/vmscan: Convert __remove_mapping() to take a folio (Aristeu Rozanski) [2083861]
- mm: Turn putback_lru_page() into folio_putback_lru() (Aristeu Rozanski) [2083861]
- mm: Add lru_to_folio() (Aristeu Rozanski) [2083861]
- mm/memcg: Convert mem_cgroup_swapout() to take a folio (Aristeu Rozanski) [2083861]
- mm/workingset: Convert workingset_eviction() to take a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert check_and_migrate_movable_pages() to use a folio (Aristeu Rozanski) [2083861]
- mm: Add three folio wrappers (Aristeu Rozanski) [2083861]
- mm: Turn isolate_lru_page() into folio_isolate_lru() (Aristeu Rozanski) [2083861]
- mm/gup: Turn compound_range_next() into gup_folio_range_next() (Aristeu Rozanski) [2083861]
- mm/gup: Turn compound_next() into gup_folio_next() (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_huge_pgd() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_huge_pud() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_huge_pmd() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_hugepte() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Convert gup_pte_range() to use a folio (Aristeu Rozanski) [2083861]
- mm/hugetlb: Use try_grab_folio() instead of try_grab_compound_head() (Aristeu Rozanski) [2083861]
- mm/gup: Add gup_put_folio() (Aristeu Rozanski) [2083861]
- mm: Remove page_cache_add_speculative() and page_cache_get_speculative() (Aristeu Rozanski) [2083861]
- mm/gup: Convert try_grab_page() to use a folio (Aristeu Rozanski) [2083861]
- mm/gup: Add try_get_folio() and try_grab_folio() (Aristeu Rozanski) [2083861]
- mm: Turn page_maybe_dma_pinned() into folio_maybe_dma_pinned() (Aristeu Rozanski) [2083861]
- mm: Add folio_pincount_ptr() (Aristeu Rozanski) [2083861]
- mm: Make compound_pincount always available (Aristeu Rozanski) [2083861]
- mm/gup: Remove hpage_pincount_sub() (Aristeu Rozanski) [2083861]
- mm/gup: Remove hpage_pincount_add() (Aristeu Rozanski) [2083861]
- mm/gup: Handle page split race more efficiently (Aristeu Rozanski) [2083861]
- mm/gup: Remove an assumption of a contiguous memmap (Aristeu Rozanski) [2083861]
- mm/gup: Fix some contiguous memmap assumptions (Aristeu Rozanski) [2083861]
- mm/gup: Change the calling convention for compound_next() (Aristeu Rozanski) [2083861]
- mm/gup: Optimise compound_range_next() (Aristeu Rozanski) [2083861]
- mm/gup: Change the calling convention for compound_range_next() (Aristeu Rozanski) [2083861]
- mm/gup: Remove for_each_compound_head() (Aristeu Rozanski) [2083861]
- mm/gup: Remove for_each_compound_range() (Aristeu Rozanski) [2083861]
- mm/gup: Increment the page refcount before the pincount (Aristeu Rozanski) [2083861]
- mm: Convert swap_set_page_dirty() to swap_dirty_folio() (Aristeu Rozanski) [2083861]
- fs: Add aops->dirty_folio (Aristeu Rozanski) [2083861]
- fs: Add aops->launder_folio (Aristeu Rozanski) [2083861]
- fs: Add invalidate_folio() aops method (Aristeu Rozanski) [2083861]
- fs: Turn do_invalidatepage() into folio_invalidate() (Aristeu Rozanski) [2083861]
- buffer: Add folio_buffers() (Aristeu Rozanski) [2083861]
- fs/remap_range: Pass the file pointer to read_mapping_folio() (Aristeu Rozanski) [2083861]
- fs: read_mapping_page() should take a struct file argument (Aristeu Rozanski) [2083861]
- mm: refactor check_and_migrate_movable_pages (Aristeu Rozanski) [2083861]
- mm: don't include <linux/memremap.h> in <linux/mm.h> (Aristeu Rozanski) [2083861]
- mm: simplify freeing of devmap managed pages (Aristeu Rozanski) [2083861]
- mm: move free_devmap_managed_page to memremap.c (Aristeu Rozanski) [2083861]
- mm/munlock: mlock_vma_page() check against VM_SPECIAL (Aristeu Rozanski) [2083861]
- mm: fix use-after-free bug when mm->mmap is reused after being freed (Aristeu Rozanski) [2083861]
- mm/thp: shrink_page_list() avoid splitting VM_LOCKED THP (Aristeu Rozanski) [2083861]
- mm/thp: collapse_file() do try_to_unmap(TTU_BATCH_FLUSH) (Aristeu Rozanski) [2083861]
- mm/munlock: page migration needs mlock pagevec drained (Aristeu Rozanski) [2083861]
- mm/munlock: mlock_page() munlock_page() batch by pagevec (Aristeu Rozanski) [2083861]
- mm/munlock: delete smp_mb() from __pagevec_lru_add_fn() (Aristeu Rozanski) [2083861]
- mm/migrate: __unmap_and_move() push good newpage to LRU (Aristeu Rozanski) [2083861]
- mm/munlock: mlock_pte_range() when mlocking or munlocking (Aristeu Rozanski) [2083861]
- mm/munlock: maintain page->mlock_count while unevictable (Aristeu Rozanski) [2083861]
- mm/munlock: replace clear_page_mlock() by final clearance (Aristeu Rozanski) [2083861]
- mm/munlock: rmap call mlock_vma_page() munlock_vma_page() (Aristeu Rozanski) [2083861]
- mm/munlock: delete munlock_vma_pages_all(), allow oomreap (Aristeu Rozanski) [2083861]
- mm/munlock: delete FOLL_MLOCK and FOLL_POPULATE (Aristeu Rozanski) [2083861]
- mm/munlock: delete page_mlock() and all its works (Aristeu Rozanski) [2083861]
- fs/proc: task_mmu.c: don't read mapcount for migration entry (Aristeu Rozanski) [2083861]
- mm/migrate.c: rework migration_entry_wait() to not take a pageref (Aristeu Rozanski) [2083861]
- filemap: Use folio_put_refs() in filemap_free_folio() (Aristeu Rozanski) [2083861]
- mm: Add folio_put_refs() (Aristeu Rozanski) [2083861]
- mm: drop node from alloc_pages_vma (Aristeu Rozanski) [2083861]
- mm/oom_kill: allow process_mrelease to run under mmap_lock protection (Aristeu Rozanski) [2083861]
- mm: document locking restrictions for vm_operations_struct::close (Aristeu Rozanski) [2083861]
- mm: protect free_pgtables with mmap_lock write lock in exit_mmap (Aristeu Rozanski) [2083861]
- pagevec: Initialise folio_batch->percpu_pvec_drained (Aristeu Rozanski) [2083861]
- mm: Use multi-index entries in the page cache (Aristeu Rozanski) [2083861]
- XArray: Add xas_advance() (Aristeu Rozanski) [2083861]
- truncate,shmem: Handle truncates that split large folios (Aristeu Rozanski) [2083861]
- truncate: Convert invalidate_inode_pages2_range to folios (Aristeu Rozanski) [2083861]
- fs: Convert vfs_dedupe_file_range_compare to folios (Aristeu Rozanski) [2083861]
- mm: Remove pagevec_remove_exceptionals() (Aristeu Rozanski) [2083861]
- mm: Convert find_lock_entries() to use a folio_batch (Aristeu Rozanski) [2083861]
- filemap: Return only folios from find_get_entries() (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_get_read_batch() to use a folio_batch (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_read() to use a folio (Aristeu Rozanski) [2083861]
- truncate: Add invalidate_complete_folio2() (Aristeu Rozanski) [2083861]
- truncate: Convert invalidate_inode_pages2_range() to use a folio (Aristeu Rozanski) [2083861]
- truncate: Skip known-truncated indices (Aristeu Rozanski) [2083861]
- truncate,shmem: Add truncate_inode_folio() (Aristeu Rozanski) [2083861]
- shmem: Convert part of shmem_undo_range() to use a folio (Aristeu Rozanski) [2083861]
- mm: Add unmap_mapping_folio() (Aristeu Rozanski) [2083861]
- mm/slub: Convert __free_slab() to use struct slab (Aristeu Rozanski) [2083861]
- mm/slub: Convert alloc_slab_page() to return a struct slab (Aristeu Rozanski) [2083861]
- mm/slub: Convert print_page_info() to print_slab_info() (Aristeu Rozanski) [2083861]
- mm/slub: Convert kfree() to use a struct slab (Aristeu Rozanski) [2083861]
- mm/slub: Convert detached_freelist to use a struct slab (Aristeu Rozanski) [2083861]
- mm: Convert check_heap_object() to use struct slab (Aristeu Rozanski) [2083861]
- mm: Use struct slab in kmem_obj_info() (Aristeu Rozanski) [2083861]
- mm: Convert __ksize() to struct slab (Aristeu Rozanski) [2083861]
- mm: Convert virt_to_cache() to use struct slab (Aristeu Rozanski) [2083861]
- mm: Convert [un]account_slab_page() to struct slab (Aristeu Rozanski) [2083861]
- mm: Split slab into its own type (Aristeu Rozanski) [2083861]
- truncate: Add truncate_cleanup_folio() (Aristeu Rozanski) [2083861]
- filemap: Add filemap_release_folio() (Aristeu Rozanski) [2083861]
- filemap: Use a folio in filemap_page_mkwrite (Aristeu Rozanski) [2083861]
- filemap: Use a folio in filemap_map_pages (Aristeu Rozanski) [2083861]
- filemap: Use folios in next_uptodate_page (Aristeu Rozanski) [2083861]
- filemap: Convert page_cache_delete_batch to folios (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_get_pages to use folios (Aristeu Rozanski) [2083861]
- filemap: Drop the refcount while waiting for page lock (Aristeu Rozanski) [2083861]
- filemap: Add read_cache_folio and read_mapping_folio (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_fault to folio (Aristeu Rozanski) [2083861]
- filemap: Convert do_async_mmap_readahead to take a folio (Aristeu Rozanski) [2083861]
- readahead: Convert page_cache_ra_unbounded to folios (Aristeu Rozanski) [2083861]
- readahead: Convert page_cache_async_ra() to take a folio (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_range_uptodate to folios (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_create_page to folio (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_read_page to take a folio (Aristeu Rozanski) [2083861]
- filemap: Convert find_get_pages_contig to folios (Aristeu Rozanski) [2083861]
- filemap: Convert filemap_get_read_batch to use folios (Aristeu Rozanski) [2083861]
- filemap: Remove thp_contains() (Aristeu Rozanski) [2083861]
- filemap: Convert find_get_entry to return a folio (Aristeu Rozanski) [2083861]
- filemap: Add filemap_remove_folio and __filemap_remove_folio (Aristeu Rozanski) [2083861]
- filemap: Convert tracing of page cache operations to folio (Aristeu Rozanski) [2083861]
- filemap: Add filemap_unaccount_folio() (Aristeu Rozanski) [2083861]
- filemap: Convert page_cache_delete to take a folio (Aristeu Rozanski) [2083861]
- filemap: Add folio_put_wait_locked() (Aristeu Rozanski) [2083861]
- mm: Add folio_test_pmd_mappable() (Aristeu Rozanski) [2083861]
- iov_iter: Convert iter_xarray to use folios (Aristeu Rozanski) [2083861]
- iov_iter: Add copy_folio_to_iter() (Aristeu Rozanski) [2083861]
- pagevec: Add folio_batch (Aristeu Rozanski) [2083861]
- mm/writeback: Improve __folio_mark_dirty() comment (Aristeu Rozanski) [2083861]
- mm/doc: Add documentation for folio_test_uptodate (Aristeu Rozanski) [2083861]
- fs/writeback: Convert inode_switch_wbs_work_fn to folios (Aristeu Rozanski) [2083861]
- mm: add virt_to_folio() and folio_address() (Aristeu Rozanski) [2083861]
- dax: remove the pgmap sanity checks in generic_fsdax_supported (Aristeu Rozanski) [2083861]
- mm: migrate: simplify the file-backed pages validation when migrating its mapping (Aristeu Rozanski) [2083861]
- mm/rmap.c: avoid double faults migrating device private pages (Aristeu Rozanski) [2083861]
- mm: add zap_skip_check_mapping() helper (Aristeu Rozanski) [2083861]
- mm: drop first_index/last_index in zap_details (Aristeu Rozanski) [2083861]
- mm: clear vmf->pte after pte_unmap_same() returns (Aristeu Rozanski) [2083861]
- mm/shmem: unconditionally set pte dirty in mfill_atomic_install_pte (Aristeu Rozanski) [2083861]
- dax: stop using bdevname (Aristeu Rozanski) [2083861]
- bpf: Let bpf_warn_invalid_xdp_action() report more info (Ivan Vecera) [2073454]
- bpf: Do not WARN in bpf_warn_invalid_xdp_action() (Ivan Vecera) [2073454]
- redhat: make kernel-zfcpdump-core to not provide kernel-core/kernel (Herton R. Krzesinski) [2027654]
- scsi: csiostor: Add module softdep on cxgb4 (Rahul Lakkireddy) [1977553]

* Thu Jul 14 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-129.rt21.129.el9]
- [rt] build kernel-rt-5.14.0-129.rt21.129.el9 [2061574]
- fuse: send security context of inode on file (Vivek Goyal) [2101526]
- fuse: extend init flags (Vivek Goyal) [2101526]
- security, lsm: dentry_init_security() Handle multi LSM registration (Vivek Goyal) [2101526]
- security: Return xattr name from security_dentry_init_security() (Vivek Goyal) [2101526]
- fuse: add FOPEN_NOFLUSH (Vivek Goyal) [2101526]
- net: fix data-race in dev_isalive() (Hangbin Liu) [2101278]
- net: Write lock dev_base_lock without disabling bottom halves. (Hangbin Liu) [2101278]
- net: fix IFF_TX_SKB_NO_LINEAR definition (Hangbin Liu) [2101278]
- sock: redo the psock vs ULP protection check (Hangbin Liu) [2101278]
- net: fix dev_fill_forward_path with pppoe + bridge (Hangbin Liu) [2101278]
- net: Fix features skip in for_each_netdev_feature() (Hangbin Liu) [2101278]
- RDMA/irdma: Add SW mechanism to generate completions on error (Kamal Heib) [2100317]
- RDMA/irdma: Remove the redundant variable (Kamal Heib) [2100317]
- RDMA/irdma: Add support for DSCP (Kamal Heib) [2100317]
- RDMA/irdma: Use irq_update_affinity_hint() (Kamal Heib) [2100317]
- RDMA/irdma: Set protocol based on PF rdma_mode flag (Kamal Heib) [2096127 2100317]
- spec: Keep .BTF section in modules (Viktor Malik) [2097188]
- NFSD: Instantiate a struct file when creating a regular NFSv4 file (Benjamin Coddington) [1905809]
- NFSD: Clean up nfsd_open_verified() (Benjamin Coddington) [1905809]
- NFSD: Remove do_nfsd_create() (Benjamin Coddington) [1905809]
- NFSD: Refactor NFSv4 OPEN(CREATE) (Benjamin Coddington) [1905809]
- NFSD: Refactor NFSv3 CREATE (Benjamin Coddington) [1905809]
- NFSD: Refactor nfsd_create_setattr() (Benjamin Coddington) [1905809]
- NFSD: Avoid calling fh_drop_write() twice in do_nfsd_create() (Benjamin Coddington) [1905809]
- NFSD: Clean up nfsd3_proc_create() (Benjamin Coddington) [1905809]
- ext4: fix up test_dummy_encryption handling for new mount API (Lukas Czerner) [2099577]
- ext4: only allow test_dummy_encryption when supported (Lukas Czerner) [2099577]
- fscrypt: add new helper functions for test_dummy_encryption (Lukas Czerner) [2099577]
- fscrypt: factor out fscrypt_policy_to_key_spec() (Lukas Czerner) [2099577]
- ext4: fix super block checksum incorrect after mount (Lukas Czerner) [2099577]
- ext4: fix bug_on ext4_mb_use_inode_pa (Lukas Czerner) [2099577]
- ext4: make variable "count" signed (Lukas Czerner) [2099577]
- ext4: add reserved GDT blocks check (Lukas Czerner) [2099577]
- ext4: fix bug_on in __es_tree_search (Lukas Czerner) [2099577]
- ext4: avoid cycles in directory h-tree (Lukas Czerner) [2099577]
- ext4: verify dir block before splitting it (Lukas Czerner) [2099577]
- ext4: filter out EXT4_FC_REPLAY from on-disk superblock field s_state (Lukas Czerner) [2099577]
- ext4: fix bug_on in ext4_writepages (Lukas Czerner) [2099577]
- ext4: fix memory leak in parse_apply_sb_mount_options() (Lukas Czerner) [2099577]
- ext4: reject the 'commit' option on ext2 filesystems (Lukas Czerner) [2099577]
- ext4: fix race condition between ext4_write and ext4_convert_inline_data (Lukas Czerner) [2099577]
- ext4: fix journal_ioprio mount option handling (Lukas Czerner) [2099577]
- ext4: mark group as trimmed only if it was fully scanned (Lukas Czerner) [2099577]
- ext4: fix use-after-free in ext4_rename_dir_prepare (Lukas Czerner) [2099577]
- ext4: fix warning in ext4_handle_inode_extension (Lukas Czerner) [2099577]
- redhat/configs: enable CONFIG_SAMPLE_VFIO_MDEV_MTTY (Patrick Talbert) [2071955]
- Revert "mm: remove the extra ZONE_DEVICE struct page refcount" (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.17..v5.18 (Karol Herbst) [2043115]
- seq_file: include linux/string_helpers.h (Karol Herbst) [2043115]
- iosys-map: Add a few more helpers (Karol Herbst) [2043115]
- iosys-map: Add offset to iosys_map_memcpy_to() (Karol Herbst) [2043115]
- dma-buf-map: Rename to iosys-map (Karol Herbst) [2043115]
- Revert "virtio: wrap config->reset calls" (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.16..v5.17 (Karol Herbst) [2043115]
- drm/i915/rpl-s: Add PCI IDS for Raptor Lake S (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.15..v5.16 (Karol Herbst) [2043115]
- Merge DRM changes from upstream v5.14..v5.15 (Karol Herbst) [2043115]
- fbdev: fbmem: add a helper to determine if an aperture is used by a fw fb (Karol Herbst) [2043115]
- redhat/configs: enable CONFIG_UDMABUF (Karol Herbst) [2012748]
- redhat/configs: set new DRM configs (Karol Herbst) [2043115]
- Makefiles: set initial DRM version (Karol Herbst) [2043115]

* Thu Jul 14 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-128.rt21.128.el9]
- [rt] build kernel-rt-5.14.0-128.rt21.128.el9 [2061574]
- block: remove WARN_ON() from bd_link_disk_holder (Ming Lei) [2094256]
- block: pop cached rq before potentially blocking rq_qos_throttle() (Ming Lei) [2094256]
- block: remove queue from struct blk_independent_access_range (Ming Lei) [2094256]
- block: freeze the queue earlier in del_gendisk (Ming Lei) [2094256]
- block: remove per-disk debugfs files in blk_unregister_queue (Ming Lei) [2094256]
- block: serialize all debugfs operations using q->debugfs_mutex (Ming Lei) [2094256]
- block: disable the elevator int del_gendisk (Ming Lei) [2094256]
- net: add missing include in include/net/gro.h (Ivan Vecera) [2101789]
- net: gro: populate net/core/gro.c (Ivan Vecera) [2101789]
- net: gro: move skb_gro_receive into net/core/gro.c (Ivan Vecera) [2101789]
- net: gro: move skb_gro_receive_list to udp_offload.c (Ivan Vecera) [2101789]
- net: move gro definitions to include/net/gro.h (Ivan Vecera) [2101789]
- net:dev: Change napi_gro_complete return type to void (Ivan Vecera) [2101789]
- move netdev_boot_setup into Space.c (Ivan Vecera) [2101789]
- sched: Fix balance_push() vs __sched_setscheduler() (Phil Auld) [2100215]
- selftests, xsk: Fix bpf_res cleanup test (Felix Maurer) [2090981]

* Mon Jul 11 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-127.rt21.127.el9]
- [rt] build kernel-rt-5.14.0-127.rt21.127.el9 [2061574]
- intel/igbvf:fix repeated words in comments (Corinna Vinschen) [2037985]
- igbvf: Remove useless DMA-32 fallback configuration (Corinna Vinschen) [2037985]
- x86/sme: Explicitly map new EFI memmap table as encrypted (Rafael Aquini) [2091830]
- x86/sme: Use #define USE_EARLY_PGTABLE_L5 in mem_encrypt_identity.c (Rafael Aquini) [2091830]
- aarch64: Enable NVIDIA Jetson Xavier SoCs (Craig Magina) [2098285]
- r8169: improve driver unload and system shutdown behavior on DASH-enabled systems (Jose Ignacio Tornos Martinez) [2070952]
- r8169: factor out redundant RTL8168d PHY config functionality to rtl8168d_1_common() (Jose Ignacio Tornos Martinez) [2070952]
- r8169: support L1.2 control on RTL8168h (Jose Ignacio Tornos Martinez) [2070952]
- r8169: add rtl_disable_exit_l1() (Jose Ignacio Tornos Martinez) [2070952]
- r8169: enable ASPM L1.2 if system vendor flags it as safe (Jose Ignacio Tornos Martinez) [2070952]
- r8169: don't use pci_irq_vector() in atomic context (Jose Ignacio Tornos Martinez) [2070952]
- r8169: Avoid misuse of pm_ptr() macro (Jose Ignacio Tornos Martinez) [2070952]
- r8169: fix incorrect mac address assignment (Jose Ignacio Tornos Martinez) [2070952]
- r8169: enable ASPM L1/L1.1 from RTL8168h (Jose Ignacio Tornos Martinez) [2070952]
- r8169: Add device 10ec:8162 to driver r8169 (Jose Ignacio Tornos Martinez) [2070952]
- ethernet: r8169: use eth_hw_addr_set() (Jose Ignacio Tornos Martinez) [2070952]
- r8169: add rtl_enable_exit_l1 (Jose Ignacio Tornos Martinez) [2070952]
- r8169: enable ASPM L0s state (Jose Ignacio Tornos Martinez) [2070952]
- r8169: rename rtl_csi_access_enable to rtl_set_aspm_entry_latency (Jose Ignacio Tornos Martinez) [2070952]
- powercap: intel_rapl: add support for RaptorLake (David Arcari) [2076725]
- perf/x86/cstate: Add SAPPHIRERAPIDS_X CPU support (Michael Petlan) [2094573]
- fs: dlm: filter user dlm messages for kernel locks (Alexander Aring) [2026117]
- scsi: storvsc: Fix unsigned comparison to zero (Mohammed Gamal) [2030695]
- scsi: storvsc: Fix validation for unsolicited incoming packets (Mohammed Gamal) [2030695]
- scsi: storvsc: Fix storvsc_queuecommand() memory leak (Mohammed Gamal) [2030695]

* Fri Jul 08 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-126.rt21.126.el9]
- [rt] build kernel-rt-5.14.0-126.rt21.126.el9 [2061574]
- mm/page_alloc: always attempt to allocate at least one page during bulk allocation (Joel Savitz) [2094045]
- KVM: arm64: Warn if accessing timer pending state outside of vcpu context (Gavin Shan) [2075082]
- KVM: arm64: Replace vgic_v3_uaccess_read_pending with vgic_uaccess_read_pending (Gavin Shan) [2075082]
- KVM: arm64: Don't read a HW interrupt pending state in user context (Gavin Shan) [2075082]
- KVM: arm64: Always start with clearing SVE flag on load (Gavin Shan) [2075082]
- KVM: arm64: Don't hypercall before EL2 init (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Consistently populate ID_AA64PFR0_EL1.GIC (Gavin Shan) [2075082]
- KVM: arm64: Inject exception on out-of-IPA-range translation fault (Gavin Shan) [2075082]
- KVM/arm64: Don't emulate a PMU for 32-bit guests if feature not set (Gavin Shan) [2075082]
- KVM: arm64: Handle host stage-2 faults from 32-bit EL0 (Gavin Shan) [2075082]
- selftests: KVM: Free the GIC FD when cleaning up in arch_timer (Gavin Shan) [2075082]
- KVM: arm64: selftests: Introduce vcpu_width_config (Gavin Shan) [2075082]
- KVM: arm64: mixed-width check should be skipped for uninitialized vCPUs (Gavin Shan) [2075082]
- arm64: alternatives: mark patch_alternative() as `noinstr` (Gavin Shan) [2075082]
- KVM: arm64: vgic: Remove unnecessary type castings (Gavin Shan) [2075082]
- KVM: arm64: Don't split hugepages outside of MMU write lock (Gavin Shan) [2075082]
- KVM: arm64: Drop unneeded minor version check from PSCI v1.x handler (Gavin Shan) [2075082]
- KVM: arm64: Actually prevent SMC64 SYSTEM_RESET2 from AArch32 (Gavin Shan) [2075082]
- KVM: arm64: Generally disallow SMC64 for AArch32 guests (Gavin Shan) [2075082]
- arm64: Fix comments in macro __init_el2_gicv3 (Gavin Shan) [2075082]
- arm64: errata: avoid duplicate field initializer (Gavin Shan) [2075082]
- KVM: arm64: fix typos in comments (Gavin Shan) [2075082]
- KVM: arm64: Generalise VM features into a set of flags (Gavin Shan) [2075082]
- KVM: arm64: Really propagate PSCI SYSTEM_RESET2 arguments to userspace (Gavin Shan) [2075082]
- KVM: arm64: Only open the interrupt window on exit due to an interrupt (Gavin Shan) [2075082]
- KVM: arm64: Enable Cortex-A510 erratum 2077057 by default (Gavin Shan) [2075082]
- arm64: Always use individual bits in CPACR floating point enables (Gavin Shan) [2075082]
- arm64: Define CPACR_EL1_FPEN similarly to other floating point controls (Gavin Shan) [2075082]
- KVM: arm64: Remove unneeded semicolons (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Skip tests if we can't create a vgic-v3 (Gavin Shan) [2075082]
- KVM: arm64: Indicate SYSTEM_RESET2 in kvm_run::system_event flags field (Gavin Shan) [2075082]
- KVM: arm64: Expose PSCI SYSTEM_RESET2 call to the guest (Gavin Shan) [2075082]
- KVM: arm64: Bump guest PSCI version to 1.1 (Gavin Shan) [2075082]
- KVM: arm64: Don't miss pending interrupts for suspended vCPU (Gavin Shan) [2075082]
- arm64: Correct wrong label in macro __init_el2_gicv3 (Gavin Shan) [2075082]
- KVM: arm64: vgic: Read HW interrupt pending state from the HW (Gavin Shan) [2075082]
- KVM: arm64: Refuse to run VCPU if the PMU doesn't match the physical CPU (Gavin Shan) [2075082]
- KVM: arm64: Add KVM_ARM_VCPU_PMU_V3_SET_PMU attribute (Gavin Shan) [2075082]
- KVM: arm64: Keep a list of probed PMUs (Gavin Shan) [2075082]
- KVM: arm64: Keep a per-VM pointer to the default PMU (Gavin Shan) [2075082]
- perf: Fix wrong name in comment for struct perf_cpu_context (Gavin Shan) [2075082]
- KVM: arm64: Do not change the PMU event filter after a VCPU has run (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Implement CONFIG_DEBUG_LIST at EL2 (Gavin Shan) [2075082]
- KVM: arm64: Drop unused param from kvm_psci_version() (Gavin Shan) [2075082]
- kvm: selftests: aarch64: use a tighter assert in vgic_poke_irq() (Gavin Shan) [2075082]
- kvm: selftests: aarch64: fix some vgic related comments (Gavin Shan) [2075082]
- kvm: selftests: aarch64: fix the failure check in kvm_set_gsi_routing_irqchip_check (Gavin Shan) [2075082]
- kvm: selftests: aarch64: pass vgic_irq guest args as a pointer (Gavin Shan) [2075082]
- kvm: selftests: aarch64: fix assert in gicv3_access_reg (Gavin Shan) [2075082]
- KVM: arm64: Make active_vmids invalid on vCPU schedule out (Gavin Shan) [2075082]
- KVM: arm64: Align the VMID allocation with the arm64 ASID (Gavin Shan) [2075082]
- KVM: arm64: Make VMID bits accessible outside of allocator (Gavin Shan) [2075082]
- KVM: arm64: Introduce a new VMID allocator for KVM (Gavin Shan) [2075082]
- arm64/fpsimd: Clarify the purpose of using last in fpsimd_save() (Gavin Shan) [2075082]
- KVM: arm64: Add some more comments in kvm_hyp_handle_fpsimd() (Gavin Shan) [2075082]
- KVM: arm64: Add comments for context flush and sync callbacks (Gavin Shan) [2075082]
- KVM: arm64: Add fast path to handle permission relaxation during dirty logging (Gavin Shan) [2075082]
- KVM: arm64: Use read/write spin lock for MMU protection (Gavin Shan) [2075082]
- KVM: arm64: Emulate the OS Lock (Gavin Shan) [2075082]
- KVM: arm64: Allow guest to set the OSLK bit (Gavin Shan) [2075082]
- KVM: arm64: Stash OSLSR_EL1 in the cpu context (Gavin Shan) [2075082]
- KVM: arm64: Correctly treat writes to OSLSR_EL1 as undefined (Gavin Shan) [2075082]
- redhat/configs: aarch64: Enable ARM64_ERRATUM_2077057 (Gavin Shan) [2075082]
- KVM: arm64: Workaround Cortex-A510's single-step and PAC trap errata (Gavin Shan) [2075082]
- KVM: arm64: Stop handle_exit() from handling HVC twice when an SError occurs (Gavin Shan) [2075082]
- KVM: arm64: Avoid consuming a stale esr value when SError occur (Gavin Shan) [2075082]
- kvm/arm64: rework guest entry logic (Gavin Shan) [2075082]
- KVM: arm64: Use shadow SPSR_EL1 when injecting exceptions on !VHE (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Restrict SEIS workaround to known broken systems (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Use the mm_ops indirection for cache maintenance (Gavin Shan) [2075082]
- KVM: arm64: Put kvm_arch_vcpu_get_ip() inside CONFIG_GUEST_PERF_EVENTS (Gavin Shan) [2075082]
- KVM: arm64: vgic: Replace kernel.h with the necessary inclusions (Gavin Shan) [2075082]
- KVM: arm64: Fix comment typo in kvm_vcpu_finalize_sve() (Gavin Shan) [2075082]
- KVM: arm64: selftests: get-reg-list: Add pauth configuration (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add test for restoring active IRQs (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add ISPENDR write tests in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add tests for IRQFD in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: Add IRQ GSI routing library functions (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add test_inject_fail to vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add tests for LEVEL_INFO in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Level-sensitive interrupts tests in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add preemption tests in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Cmdline arg to set EOI mode in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Cmdline arg to set number of IRQs in vgic_irq test (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Abstract the injection functions in vgic_irq (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add vgic_irq to test userspace IRQ injection (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add vGIC library functions to deal with vIRQ state (Gavin Shan) [2075082]
- KVM: selftests: Add kvm_irq_line library function (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add GICv3 register accessor library functions (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Add function for accessing GICv3 dist and redist registers (Gavin Shan) [2075082]
- KVM: selftests: aarch64: Move gic_v3.h to shared headers (Gavin Shan) [2075082]
- KVM: arm64: Fix comment on barrier in kvm_psci_vcpu_on() (Gavin Shan) [2075082]
- KVM: arm64: Fix comment for kvm_reset_vcpu() (Gavin Shan) [2075082]
- KVM: arm64: Use defined value for SCTLR_ELx_EE (Gavin Shan) [2075082]
- KVM: arm64: Rework kvm_pgtable initialisation (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Unshare guest structs during teardown (Gavin Shan) [2075082]
- KVM: arm64: Expose unshare hypercall to the host (Gavin Shan) [2075082]
- KVM: arm64: Implement do_unshare() helper for unsharing memory (Gavin Shan) [2075082]
- KVM: arm64: Implement __pkvm_host_share_hyp() using do_share() (Gavin Shan) [2075082]
- KVM: arm64: Implement do_share() helper for sharing memory (Gavin Shan) [2075082]
- KVM: arm64: Introduce wrappers for host and hyp spin lock accessors (Gavin Shan) [2075082]
- KVM: arm64: Extend pkvm_page_state enumeration to handle absent pages (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Refcount the pages shared with EL2 (Gavin Shan) [2075082]
- KVM: arm64: Introduce kvm_share_hyp() (Gavin Shan) [2075082]
- KVM: arm64: Implement kvm_pgtable_hyp_unmap() at EL2 (Gavin Shan) [2075082]
- KVM: arm64: Hook up ->page_count() for hypervisor stage-1 page-table (Gavin Shan) [2075082]
- KVM: arm64: Fixup hyp stage-1 refcount (Gavin Shan) [2075082]
- KVM: arm64: Refcount hyp stage-1 pgtable pages (Gavin Shan) [2075082]
- KVM: arm64: Provide {get,put}_page() stubs for early hyp allocator (Gavin Shan) [2075082]
- KVM: arm64: vgic: Demote userspace-triggered console prints to kvm_debug() (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Make kvm_host_owns_hyp_mappings() robust to VHE (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Stub io map functions (Gavin Shan) [2075082]
- KVM: arm64: Make __io_map_base static (Gavin Shan) [2075082]
- KVM: arm64: Make the hyp memory pool static (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Disable GICv2 support (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Fix hyp_pool max order (Gavin Shan) [2075082]
- KVM: arm64: Use Makefile.kvm for common files (Gavin Shan) [2075082]
- KVM: arm64: Drop unused workaround_flags vcpu field (Gavin Shan) [2075082]
- KVM: arm64: Move vGIC v4 handling for WFI out arch callback hook (Gavin Shan) [2075082]
- arm64/kvm: Fix bitrotted comment for SVE handling in handle_exit.c (Gavin Shan) [2075082]
- KVM: arm64: Move host EL1 code out of hyp/ directory (Gavin Shan) [2075082]
- KVM: arm64: Generate hyp_constants.h for the host (Gavin Shan) [2075082]
- arm64: Add missing include of asm/cpufeature.h to asm/mmu.h (Gavin Shan) [2075082]
- KVM: arm64: Constify kvm_io_gic_ops (Gavin Shan) [2075082]
- KVM: arm64: Add minimal handling for the ARMv8.7 PMU (Gavin Shan) [2075082]
- KVM: arm64: Drop vcpu->arch.has_run_once for vcpu->pid (Gavin Shan) [2075082]
- KVM: arm64: Merge kvm_arch_vcpu_run_pid_change() and kvm_vcpu_first_run_init() (Gavin Shan) [2075082]
- KVM: arm64: Restructure the point where has_run_once is advertised (Gavin Shan) [2075082]
- KVM: arm64: Move kvm_arch_vcpu_run_pid_change() out of line (Gavin Shan) [2075082]
- KVM: arm64: Move SVE state mapping at HYP to finalize-time (Gavin Shan) [2075082]
- KVM: arm64: Move pkvm's special 32bit handling into a generic infrastructure (Gavin Shan) [2075082]
- KVM: arm64: Save PSTATE early on exit (Gavin Shan) [2075082]
- arm64/fpsimd: Document the use of TIF_FOREIGN_FPSTATE by KVM (Gavin Shan) [2075082]
- KVM: arm64: Stop mapping current thread_info at EL2 (Gavin Shan) [2075082]
- KVM: arm64: Introduce flag shadowing TIF_FOREIGN_FPSTATE (Gavin Shan) [2075082]
- KVM: arm64: Remove unused __sve_save_state (Gavin Shan) [2075082]
- KVM: arm64: Get rid of host SVE tracking/saving (Gavin Shan) [2075082]
- KVM: arm64: Reorder vcpu flag definitions (Gavin Shan) [2075082]
- KVM: arm64: Cap KVM_CAP_NR_VCPUS by kvm_arm_default_max_vcpus() (Gavin Shan) [2075082]
- KVM: arm64: Fix host stage-2 finalization (Gavin Shan) [2075082]
- KVM: arm64: Change the return type of kvm_vcpu_preferred_target() (Gavin Shan) [2075082]
- KVM: arm64: nvhe: Fix a non-kernel-doc comment (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Give priority to standard traps over pvm handling (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Pass vpcu instead of kvm to kvm_get_exit_handler_array() (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Move kvm_handle_pvm_restricted around (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Consolidate include files (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Preserve pending SError on exit from AArch32 (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Handle GICv3 traps as required (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Drop sysregs that should never be routed to the host (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Drop AArch32-specific registers (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Make the ERR/ERX*_EL1 registers RAZ/WI (Gavin Shan) [2075082]
- KVM: arm64: pkvm: Use a single function to expose all id-regs (Gavin Shan) [2075082]
- KVM: arm64: Fix early exit ptrauth handling (Gavin Shan) [2075082]
- KVM: arm64: Add memcg accounting to KVM allocations (Gavin Shan) [2075082]
- KVM: arm64: vgic: Add memcg accounting to vgic allocations (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Align emulated cpuif LPI state machine with the pseudocode (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Don't advertise ICC_CTLR_EL1.SEIS (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Reduce common group trapping to ICV_DIR_EL1 when possible (Gavin Shan) [2075082]
- KVM: arm64: vgic-v3: Work around GICv3 locally generated SErrors (Gavin Shan) [2075082]
- KVM: arm64: Force ID_AA64PFR0_EL1.GIC=1 when exposing a virtual GICv3 (Gavin Shan) [2075082]
- KVM: arm64: Fix reporting of endianess when the access originates at EL0 (Gavin Shan) [2075082]
- KVM: arm64: Handle protected guests at 32 bits (Gavin Shan) [2075082]
- KVM: arm64: Trap access to pVM restricted features (Gavin Shan) [2075082]
- KVM: arm64: Move sanitized copies of CPU features (Gavin Shan) [2075082]
- KVM: arm64: Initialize trap registers for protected VMs (Gavin Shan) [2075082]
- KVM: arm64: Add handlers for protected VM System Registers (Gavin Shan) [2075082]
- KVM: arm64: Simplify masking out MTE in feature id reg (Gavin Shan) [2075082]
- KVM: arm64: Add missing field descriptor for MDCR_EL2 (Gavin Shan) [2075082]
- KVM: arm64: Pass struct kvm to per-EC handlers (Gavin Shan) [2075082]
- KVM: arm64: Move early handlers to per-EC handlers (Gavin Shan) [2075082]
- KVM: arm64: Don't include switch.h into nvhe/kvm-main.c (Gavin Shan) [2075082]
- KVM: arm64: Move __get_fault_info() and co into their own include file (Gavin Shan) [2075082]
- KVM: arm64: Replace get_raz_id_reg() with get_raz_reg() (Gavin Shan) [2075082]
- KVM: arm64: Use get_raz_reg() for userspace reads of PMSWINC_EL0 (Gavin Shan) [2075082]
- KVM: arm64: Return early from read_id_reg() if register is RAZ (Gavin Shan) [2075082]
- KVM: arm64: Depend on HAVE_KVM instead of OF (Gavin Shan) [2075082]
- KVM: arm64: Unconditionally include generic KVM's Kconfig (Gavin Shan) [2075082]
- KVM: arm64: Allow KVM to be disabled from the command line (Gavin Shan) [2075082]
- KVM: arm64: Disable privileged hypercalls after pKVM finalisation (Gavin Shan) [2075082]
- KVM: arm64: Prevent re-finalisation of pKVM for a given CPU (Gavin Shan) [2075082]
- KVM: arm64: Propagate errors from __pkvm_prot_finalize hypercall (Gavin Shan) [2075082]
- KVM: arm64: Reject stub hypercalls after pKVM has been initialised (Gavin Shan) [2075082]
- arm64: Prevent kexec and hibernation if is_protected_kvm_enabled() (Gavin Shan) [2075082]
- KVM: arm64: Turn __KVM_HOST_SMCCC_FUNC_* into an enum (mostly) (Gavin Shan) [2075082]
- KVM: arm64: Revert "KVM: arm64: Count VMID-wide TLB invalidations" (Gavin Shan) [2075082]
- cxl/core: Remove cxld_const_init in cxl_decoder_alloc() (John W. Linville) [2072584]
- cxl/pmem: Fix module reload vs workqueue state (John W. Linville) [2072584]
- cxl/memdev: Remove unused cxlmd field (John W. Linville) [2072584]
- cxl/core: Convert to EXPORT_SYMBOL_NS_GPL (John W. Linville) [2072584]
- cxl/memdev: Change cxl_mem to a more descriptive name (John W. Linville) [2072584]
- cxl/mbox: Remove bad comment (John W. Linville) [2072584]
- cxl/pmem: Fix reference counting for delayed work (John W. Linville) [2072584]
- cxl/pci: Split cxl_pci_setup_regs() (John W. Linville) [2072584]
- cxl/pci: Add @base to cxl_register_map (John W. Linville) [2072584]
- cxl/pci: Make more use of cxl_register_map (John W. Linville) [2072584]
- cxl/pci: Remove pci request/release regions (John W. Linville) [2072584]
- cxl/pci: Fix NULL vs ERR_PTR confusion (John W. Linville) [2072584]
- cxl/pci: Remove dev_dbg for unknown register blocks (John W. Linville) [2072584]
- cxl/pci: Convert register block identifiers to an enum (John W. Linville) [2072584]
- cxl/acpi: Do not fail cxl_acpi_probe() based on a missing CHBS (John W. Linville) [2072584]
- cxl/pci: Disambiguate cxl_pci further from cxl_mem (John W. Linville) [2072584]
- cxl/core: Split decoder setup into alloc + add (John W. Linville) [2072584]
- tools/testing/cxl: Introduce a mock memory device + driver (John W. Linville) [2072584]
- cxl/mbox: Move command definitions to common location (John W. Linville) [2072584]
- cxl/bus: Populate the target list at decoder create (John W. Linville) [2072584]
- tools/testing/cxl: Introduce a mocked-up CXL port hierarchy (John W. Linville) [2072584]
- cxl/pmem: Add support for multiple nvdimm-bridge objects (John W. Linville) [2072584]
- cxl/pmem: Translate NVDIMM label commands to CXL label commands (John W. Linville) [2072584]
- cxl/mbox: Add exclusive kernel command support (John W. Linville) [2072584]
- cxl/mbox: Convert 'enabled_cmds' to DECLARE_BITMAP (John W. Linville) [2072584]
- cxl/pci: Use module_pci_driver (John W. Linville) [2072584]
- cxl/mbox: Move mailbox and other non-PCI specific infrastructure to the core (John W. Linville) [2072584]
- cxl/pci: Drop idr.h (John W. Linville) [2072584]
- cxl/mbox: Introduce the mbox_send operation (John W. Linville) [2072584]
- cxl/pci: Clean up cxl_mem_get_partition_info() (John W. Linville) [2072584]
- cxl/pci: Make 'struct cxl_mem' device type generic (John W. Linville) [2072584]
- cxl/registers: Fix Documentation warning (John W. Linville) [2072584]
- cxl/pmem: Fix Documentation warning (John W. Linville) [2072584]
- cxl/pci: Fix debug message in cxl_probe_regs() (John W. Linville) [2072584]
- cxl/pci: Fix lockdown level (John W. Linville) [2072584]
- cxl/acpi: Do not add DSDT disabled ACPI0016 host bridge ports (John W. Linville) [2072584]
- cxl/mem: Adjust ram/pmem range to represent DPA ranges (John W. Linville) [2072584]
- cxl/mem: Account for partitionable space in ram/pmem ranges (John W. Linville) [2072584]
- cxl/pci: Store memory capacity values (John W. Linville) [2072584]
- cxl/pci: Simplify register setup (John W. Linville) [2072584]
- cxl/pci: Ignore unknown register block types (John W. Linville) [2072584]
- cxl/core: Move memdev management to core (John W. Linville) [2072584]
- cxl/pci: Introduce cdevm_file_operations (John W. Linville) [2072584]
- cxl/core: Move register mapping infrastructure (John W. Linville) [2072584]
- cxl/core: Move pmem functionality (John W. Linville) [2072584]
- cxl/core: Improve CXL core kernel docs (John W. Linville) [2072584]
- cxl: Move cxl_core to new directory (John W. Linville) [2072584]

* Wed Jul 06 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-125.rt21.125.el9]
- [rt] build kernel-rt-5.14.0-125.rt21.125.el9 [2061574]
- rt: Revert "net: Use skbufhead with raw lock" (Juri Lelli) [2096689]
- cifs: fix bad fids sent over wire (Ronnie Sahlberg) [2088775]
- SMB3: EBADF/EIO errors in rename/open caused by race condition in smb2_compound_op (Ronnie Sahlberg) [2088775]
- i40e: Fix call trace in setup_tx_descriptors (Ivan Vecera) [2037980]
- i40e: Fix calculating the number of queue pairs (Ivan Vecera) [2037980]
- i40e: Fix adding ADQ filter to TC0 (Ivan Vecera) [2037980]
- i40e: i40e_main: fix a missing check on list iterator (Ivan Vecera) [2037980]
- i40e, xsk: Get rid of redundant 'fallthrough' (Ivan Vecera) [2037980]
- i40e, xsk: Diversify return values from xsk_wakeup call paths (Ivan Vecera) [2037980]
- i40e, xsk: Terminate Rx side of NAPI when XSK Rx queue gets full (Ivan Vecera) [2037980]
- i40e: Add Ethernet Connection X722 for 10GbE SFP+ support (Ivan Vecera) [2037980]
- i40e: Add vsi.tx_restart to i40e ethtool stats (Ivan Vecera) [2037980]
- i40e: Add tx_stopped stat (Ivan Vecera) [2037980]
- i40e: Add support for MPLS + TSO (Ivan Vecera) [2037980]
- i40e: little endian only valid checksums (Ivan Vecera) [2037980]
- i40e: stop disabling VFs due to PF error responses (Ivan Vecera) [2037980]
- Revert "i40e: Fix reset bw limit when DCB enabled with 1 TC" (Ivan Vecera) [2037980]
- i40e: remove dead stores on XSK hotpath (Ivan Vecera) [2037980]
- i40e: Add a stat for tracking busy rx pages (Ivan Vecera) [2037980]
- i40e: Add a stat for tracking pages waived (Ivan Vecera) [2037980]
- i40e: Add a stat tracking new RX page allocations (Ivan Vecera) [2037980]
- i40e: Aggregate and export RX page reuse stat (Ivan Vecera) [2037980]
- i40e: Remove rx page reuse double count (Ivan Vecera) [2037980]
- i40e: Fix race condition while adding/deleting MAC/VLAN filters (Ivan Vecera) [2037980]
- i40e: Add new version of i40e_aq_add_macvlan function (Ivan Vecera) [2037980]
- i40e: Add new versions of send ASQ command functions (Ivan Vecera) [2037980]
- i40e: Add sending commands in atomic context (Ivan Vecera) [2037980]
- i40e: Remove unused RX realloc stat (Ivan Vecera) [2037980]
- i40e: Disable hw-tc-offload feature on driver load (Ivan Vecera) [2037980]
- i40e: Fix reset path while removing the driver (Ivan Vecera) [2037980]
- i40e: Fix reset bw limit when DCB enabled with 1 TC (Ivan Vecera) [2037980]
- i40e: respect metadata on XSK Rx to skb (Ivan Vecera) [2037980]
- i40e: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Ivan Vecera) [2037980]
- i40e: Remove useless DMA-32 fallback configuration (Ivan Vecera) [2037980]
- i40e: fix unsigned stat widths (Ivan Vecera) [2037980]
- i40e: Fix for failed to init adminq while VF reset (Ivan Vecera) [2037980]
- i40e: Fix queues reservation for XDP (Ivan Vecera) [2037980]
- i40e: Fix issue when maximum queues is exceeded (Ivan Vecera) [2037980]
- i40e: Increase delay to 1 s after global EMP reset (Ivan Vecera) [2037980]
- i40e: remove variables set but not used (Ivan Vecera) [2037980]
- i40e: Remove non-inclusive language (Ivan Vecera) [2037980]
- i40e: Update FW API version (Ivan Vecera) [2037980]
- i40e: Minimize amount of busy-waiting during AQ send (Ivan Vecera) [2037980]
- i40e: Add ensurance of MacVlan resources for every trusted VF (Ivan Vecera) [2037980]
- i40e: Fix incorrect netdev's real number of RX/TX queues (Ivan Vecera) [2037980]
- i40e: Fix for displaying message regarding NVM version (Ivan Vecera) [2037980]
- i40e: fix use-after-free in i40e_sync_filters_subtask() (Ivan Vecera) [2037980]
- i40e: Fix to not show opcode msg on unsuccessful VF MAC change (Ivan Vecera) [2037980]
- i40e: switch to napi_build_skb() (Ivan Vecera) [2037980]
- i40e: Use irq_update_affinity_hint() (Ivan Vecera) [2037980]
- i40e: Fix NULL pointer dereference in i40e_dbg_dump_desc (Ivan Vecera) [2037980]
- i40e: Fix pre-set max number of queues for VF (Ivan Vecera) [2037980]
- i40e: Fix failed opcode appearing if handling messages from VF (Ivan Vecera) [2037980]
- i40e: Fix display error code in dmesg (Ivan Vecera) [2037980]
- i40e: Fix creation of first queue by omitting it if is not power of two (Ivan Vecera) [2037980]
- i40e: Fix warning message and call stack during rmmod i40e driver (Ivan Vecera) [2037980]
- i40e: Fix ping is lost after configuring ADq on VF (Ivan Vecera) [2037980]
- i40e: Fix changing previously set num_queue_pairs for PFs (Ivan Vecera) [2037980]
- i40e: Fix NULL ptr dereference on VSI filter sync (Ivan Vecera) [2037980]
- i40e: Fix correct max_pkt_size on VF RX queue (Ivan Vecera) [2037980]
- i40e: Simplify bool conversion (Ivan Vecera) [2037980]
- i40e: Fix freeing of uninitialized misc IRQ vector (Ivan Vecera) [2037980]
- i40e: Use the xsk batched rx allocation interface (Ivan Vecera) [2037980]
- i40e: Fix spelling mistake "dissable" -> "disable" (Ivan Vecera) [2037980]
- i40e: add support for PTP external synchronization clock (Ivan Vecera) [2037980]
- i40e: improve locking of mac_filter_hash (Ivan Vecera) [2037980]
- time: Handle negative seconds correctly in timespec64_to_ns() (Íñigo Huguet) [2097394]
- iavf: Fix issue with MAC address of VF shown as zero (Petr Oros) [2037976]
- Revert "iavf: Fix deadlock occurrence during resetting VF interface" (Petr Oros) [2037976]
- iavf: Fix hang during reboot/shutdown (Petr Oros) [2037976]
- iavf: Fix double free in iavf_reset_task (Petr Oros) [2037976]
- iavf: Fix adopting new combined setting (Petr Oros) [2037976]
- iavf: Fix handling of vlan strip virtual channel messages (Petr Oros) [2037976]
- iavf: Fix __IAVF_RESETTING state usage (Petr Oros) [2037976]
- iavf: Fix missing check for running netdev (Petr Oros) [2037976]
- iavf: Fix deadlock in iavf_reset_task (Petr Oros) [2037976]
- iavf: Fix race in init state (Petr Oros) [2037976]
- iavf: Fix locking for VIRTCHNL_OP_GET_OFFLOAD_VLAN_V2_CAPS (Petr Oros) [2037976]
- iavf: Fix init state closure on remove (Petr Oros) [2037976]
- iavf: Add waiting so the port is initialized in remove (Petr Oros) [2037976]
- iavf: Rework mutexes for better synchronisation (Petr Oros) [2037976]
- iavf: Remove non-inclusive language (Petr Oros) [2037976]
- iavf: Fix incorrect use of assigning iavf_status to int (Petr Oros) [2037976]
- iavf: stop leaking iavf_status as "errno" values (Petr Oros) [2037976]
- iavf: remove redundant ret variable (Petr Oros) [2037976]
- iavf: Add usage of new virtchnl format to set default MAC (Petr Oros) [2037976]
- iavf: refactor processing of VLAN V2 capability message (Petr Oros) [2037976]
- iavf: Add support for 50G/100G in AIM algorithm (Petr Oros) [2037976]
- iavf: Remove useless DMA-32 fallback configuration (Petr Oros) [2037976]
- iavf: Use irq_update_affinity_hint() (Petr Oros) [2037976]
- iavf: remove an unneeded variable (Petr Oros) [2037976]
- iavf: Fix limit of total number of queues to active queues of VF (Petr Oros) [2037976]
- iavf: switch to napi_build_skb() (Petr Oros) [2037976]
- iavf: Restrict maximum VLAN filters for VIRTCHNL_VF_OFFLOAD_VLAN_V2 (Petr Oros) [2037976]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 offload enable/disable (Petr Oros) [2037976]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 hotpath (Petr Oros) [2037976]
- iavf: Add support VIRTCHNL_VF_OFFLOAD_VLAN_V2 during netdev config (Petr Oros) [2037976]
- iavf: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 negotiation (Petr Oros) [2037976]
- iavf: do not override the adapter state in the watchdog task (again) (Petr Oros) [2037976]
- iavf: missing unlocks in iavf_watchdog_task() (Petr Oros) [2037976]
- iavf: Fix reporting when setting descriptor count (Petr Oros) [2037976]
- iavf: restore MSI state on reset (Petr Oros) [2037976]
- iavf: Fix displaying queue statistics shown by ethtool (Petr Oros) [2037976]
- iavf: Refactor string format to avoid static analysis warnings (Petr Oros) [2037976]
- iavf: Refactor text of informational message (Petr Oros) [2037976]
- iavf: Fix static code analysis warning (Petr Oros) [2037976]
- iavf: Refactor iavf_mac_filter struct memory usage (Petr Oros) [2037976]
- iavf: Enable setting RSS hash key (Petr Oros) [2037976]
- iavf: Add trace while removing device (Petr Oros) [2037976]
- iavf: return errno code instead of status code (Petr Oros) [2037976]
- iavf: Log info when VF is entering and leaving Allmulti mode (Petr Oros) [2037976]
- iavf: Add change MTU message (Petr Oros) [2037976]
- iavf: Fix VLAN feature flags after VFR (Petr Oros) [2037976]
- iavf: Fix refreshing iavf adapter stats on ethtool request (Petr Oros) [2037976]
- iavf: Fix deadlock occurrence during resetting VF interface (Petr Oros) [2037976]
- iavf: Prevent changing static ITR values if adaptive moderation is on (Petr Oros) [2037976]
- iavf: Restore VLAN filters after link down (Petr Oros) [2037976]
- iavf: Fix for setting queues to 0 (Petr Oros) [2037976]
- iavf: Fix for the false positive ASQ/ARQ errors while issuing VF reset (Petr Oros) [2037976]
- iavf: validate pointers (Petr Oros) [2037976]
- iavf: prevent accidental free of filter structure (Petr Oros) [2037976]
- iavf: Fix failure to exit out from last all-multicast mode (Petr Oros) [2037976]
- iavf: don't clear a lock we don't hold (Petr Oros) [2037976]
- iavf: free q_vectors before queues in iavf_disable_vf (Petr Oros) [2037976]
- iavf: check for null in iavf_fix_features (Petr Oros) [2037976]
- iavf: Fix return of set the new channel count (Petr Oros) [2037976]
- iavf: Fix kernel BUG in free_msi_irqs (Petr Oros) [2037976]
- iavf: Add helper function to go from pci_dev to adapter (Petr Oros) [2037976]
- iavf: Combine init and watchdog state machines (Petr Oros) [2037976]
- iavf: Add __IAVF_INIT_FAILED state (Petr Oros) [2037976]
- iavf: Refactor iavf state machine tracking (Petr Oros) [2037976]
- iavf: fix double unlock of crit_lock (Petr Oros) [2037976]
- iavf: use mutexes for locking of critical sections (Petr Oros) [2037976]
- iavf: fix locking of critical sections (Petr Oros) [2037976]
- iavf: do not override the adapter state in the watchdog task (Petr Oros) [2037976]
- bnxt_en: parse and report result field when NVRAM package install fails (Ken Cox) [2042819 2043783]
- bnxt_en: Enable packet timestamping for all RX packets (Ken Cox) [2042819 2043783]
- bnxt_en: Configure ptp filters during bnxt open (Ken Cox) [2042819 2043783]
- bnxt_en: Update firmware interface to 1.10.2.95 (Ken Cox) [2042819 2043783]
- bnxt_en: Fix unnecessary dropping of RX packets (Ken Cox) [2042819 2043783]
- bnxt_en: Initiallize bp->ptp_lock first before using it (Ken Cox) [2042819 2043783]
- bnxt_en: Fix possible bnxt_open() failure caused by wrong RFS flag (Ken Cox) [2042819 2043783]
- bnxt: add page_pool support for aggregation ring when using xdp (Ken Cox) [2042819 2043783]
- bnxt: change receive ring space parameters (Ken Cox) [2042819 2043783]
- bnxt: rename bnxt_rx_pages to bnxt_rx_agg_pages_skb (Ken Cox) [2042819 2043783]
- bnxt: refactor bnxt_rx_pages operate on skb_shared_info (Ken Cox) [2042819 2043783]
- bnxt: add flag to denote that an xdp program is currently attached (Ken Cox) [2042819 2043783]
- bnxt: refactor bnxt_rx_xdp to separate xdp_init_buff/xdp_prepare_buff (Ken Cox) [2042819 2043783]
- bnxt_en: Prevent XDP redirect from running when stopping TX queue (Ken Cox) [2042819 2043783]
- bnxt_en: reserve space inside receive page for skb_shared_info (Ken Cox) [2042819 2043783]
- bnxt_en: Synchronize tx when xdp redirects happen on same ring (Ken Cox) [2042819 2043783]
- net: bnxt_ptp: fix compilation error (Ken Cox) [2042819 2043783]
- bnxt: revert hastily merged uAPI aberrations (Ken Cox) [2042819 2043783]
- bnxt_en: add an nvm test for hw diagnose (Ken Cox) [2042819 2043783]
- bnxt_en: implement hw health reporter (Ken Cox) [2042819 2043783]
- bnxt_en: Do not destroy health reporters during reset (Ken Cox) [2042819 2043783]
- bnxt_en: Eliminate unintended link toggle during FW reset (Ken Cox) [2042819 2043783]
- bnxt_en: Properly report no pause support on some cards (Ken Cox) [2042819 2043783]
- bnxt_en: introduce initial link state of unknown (Ken Cox) [2042819 2043783]
- bnxt_en: parse result field when NVRAM package install fails (Ken Cox) [2042819 2043783]
- bnxt_en: add more error checks to HWRM_NVM_INSTALL_UPDATE (Ken Cox) [2042819 2043783]
- bnxt_en: refactor error handling of HWRM_NVM_INSTALL_UPDATE (Ken Cox) [2042819 2043783]
- bnxt_en: Handle async event when the PHC is updated in RTC mode (Ken Cox) [2042819 2043783]
- bnxt_en: Implement .adjtime() for PTP RTC mode (Ken Cox) [2042819 2043783]
- bnxt_en: Add driver support to use Real Time Counter for PTP (Ken Cox) [2042819 2043783]
- bnxt_en: PTP: Refactor PTP initialization functions (Ken Cox) [2042819 2043783]
- bnxt_en: Update firmware interface to 1.10.2.73 (Ken Cox) [2042819 2043783]
- bnxt_en: fix kernel doc warnings in bnxt_hwrm.c (Ken Cox) [2042819 2043783]
- bnxt_en: Increase firmware message response DMA wait time (Ken Cox) [2042819 2043783]
- bnxt_en: Fix devlink fw_activate (Ken Cox) [2042819 2043783]
- bnxt_en: Restore the resets_reliable flag in bnxt_open() (Ken Cox) [2042819 2043783]
- bnxt_en: Fix incorrect multicast rx mask setting when not requested (Ken Cox) [2042819 2043783]
- bnxt_en: Fix occasional ethtool -t loopback test failures (Ken Cox) [2042819 2043783]
- bnxt_en: Fix offline ethtool selftest with RDMA enabled (Ken Cox) [2042819 2043783]
- bnxt_en: Fix active FEC reporting to ethtool (Ken Cox) [2042819 2043783]
- bnxt_en: improve firmware timeout messaging (Ken Cox) [2042819 2043783]
- bnxt_en: use firmware provided max timeout for messages (Ken Cox) [2042819 2043783]
- bnxt_en: improve VF error messages when PF is unavailable (Ken Cox) [2042819 2043783]
- bnxt_en: add dynamic debug support for HWRM messages (Ken Cox) [2042819 2043783]
- bnxt_en: Use page frag RX buffers for better software GRO performance (Ken Cox) [2042819 2043783]
- bnxt_en: convert to xdp_do_flush (Ken Cox) [2042819 2043783]
- bnxt_en: Support CQE coalescing mode in ethtool (Ken Cox) [2042819 2043783]
- bnxt_en: Support configurable CQE coalescing mode (Ken Cox) [2042819 2043783]
- bnxt_en: enable interrupt sampling on 5750X for DIM (Ken Cox) [2042819 2043783]
- bnxt_en: Log error report for dropped doorbell (Ken Cox) [2042819 2043783]
- bnxt_en: Add event handler for PAUSE Storm event (Ken Cox) [2042819 2043783]
- flow_offload: reject to offload tc actions in offload drivers (Ken Cox) [2042819 2043783]
- bnxt_en: Fix compile error regression when CONFIG_BNXT_SRIOV is not set (Ken Cox) [2042819 2043783]
- bnxt_en: reject indirect blk offload when hw-tc-offload is off (Ken Cox) [2042819 2043783]
- bnxt_en: fix format specifier in live patch error message (Ken Cox) [2042819 2043783]
- bnxt_en: extend RTNL to VF check in devlink driver_reinit (Ken Cox) [2042819 2043783]
- bnxt_en: avoid newline at end of message in NL_SET_ERR_MSG_MOD (Ken Cox) [2042819 2043783]
- bnxt_en: Remove not used other ULP define (Ken Cox) [2042819 2043783]
- bnxt_en: Provide stored devlink "fw" version on older firmware (Ken Cox) [2042819 2043783]
- bnxt_en: implement firmware live patching (Ken Cox) [2042819 2043783]
- bnxt_en: Update firmware interface to 1.10.2.63 (Ken Cox) [2042819 2043783]
- bnxt_en: implement dump callback for fw health reporter (Ken Cox) [2042819 2043783]
- bnxt_en: Retrieve coredump and crashdump size via FW command (Ken Cox) [2042819 2043783]
- bnxt_en: move coredump functions into dedicated file (Ken Cox) [2042819 2043783]
- bnxt_en: Refactor coredump functions (Ken Cox) [2042819 2043783]
- bnxt_en: improve fw diagnose devlink health messages (Ken Cox) [2042819 2043783]
- bnxt_en: consolidate fw devlink health reporters (Ken Cox) [2042819 2043783]
- bnxt_en: remove fw_reset devlink health reporter (Ken Cox) [2042819 2043783]
- bnxt_en: improve error recovery information messages (Ken Cox) [2042819 2043783]
- bnxt_en: add enable_remote_dev_reset devlink parameter (Ken Cox) [2042819 2043783]
- bnxt_en: implement devlink dev reload fw_activate (Ken Cox) [2042819 2043783]
- bnxt_en: implement devlink dev reload driver_reinit (Ken Cox) [2042819 2043783]
- bnxt_en: refactor cancellation of resource reservations (Ken Cox) [2042819 2043783]
- bnxt_en: refactor printing of device info (Ken Cox) [2042819 2043783]
- ethernet: constify references to netdev->dev_addr in drivers (Ken Cox) [2042819 2043783]
- bnxt: use netif_is_rxfh_configured instead of open code (Ken Cox) [2042819 2043783]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2042819 2043783]
- bnxt_en: Fix TX timeout when TX ring size is set to the smallest (Ken Cox) [2042819 2043783]
- net/{mlx5|nfp|bnxt}: Remove unnecessary RTNL lock assert (Ken Cox) [2042819 2043783]
- bnxt_en: Clean up completion ring page arrays completely (Ken Cox) [2042819 2043783]
- bnxt_en: make bnxt_free_skbs() safe to call after bnxt_free_mem() (Ken Cox) [2042819 2043783]
- bnxt_en: Fix error recovery regression (Ken Cox) [2042819 2043783]
- bnxt: Search VPD with pci_vpd_find_ro_info_keyword() (Ken Cox) [2042819 2043783]
- bnxt: Read VPD with pci_vpd_alloc() (Ken Cox) [2042819 2043783]
- bnxt_en: Fix possible unintended driver initiated error recovery (Ken Cox) [2042819 2043783]
- bnxt_en: Fix UDP tunnel logic (Ken Cox) [2042819 2043783]
- bnxt_en: Fix asic.rev in devlink dev info command (Ken Cox) [2042819 2043783]
- bnxt_en: fix read of stored FW_PSID version on P5 devices (Ken Cox) [2042819 2043783]
- bnxt_en: fix stored FW_PSID version masks (Ken Cox) [2042819 2043783]
- bnxt_en: Fix 64-bit doorbell operation on 32-bit kernels (Ken Cox) [2042819 2043783]
- bnxt_en: support multiple HWRM commands in flight (Ken Cox) [2042819 2043783]
- bnxt_en: discard out of sequence HWRM responses (Ken Cox) [2042819 2043783]
- bnxt_en: remove legacy HWRM interface (Ken Cox) [2042819 2043783]
- bnxt_en: update all firmware calls to use the new APIs (Ken Cox) [2042819 2043783]
- bnxt_en: use link_lock instead of hwrm_cmd_lock to protect link_info (Ken Cox) [2042819 2043783]
- bnxt_en: add support for HWRM request slices (Ken Cox) [2042819 2043783]
- bnxt_en: add HWRM request assignment API (Ken Cox) [2042819 2043783]
- bnxt_en: introduce new firmware message API based on DMA pools (Ken Cox) [2042819 2043783]
- bnxt_en: move HWRM API implementation into separate file (Ken Cox) [2042819 2043783]
- bnxt_en: Refactor the HWRM_VER_GET firmware calls (Ken Cox) [2042819 2043783]
- bnxt_en: remove DMA mapping for KONG response (Ken Cox) [2042819 2043783]
- bnxt: count discards due to memory allocation errors (Ken Cox) [2042819 2043783]
- bnxt: count packets discarded because of netpoll (Ken Cox) [2042819 2043783]
- net: broadcom: switch from 'pci_' to 'dma_' API (Ken Cox) [2042819 2043783]
- Revert "bnxt: Read VPD with pci_vpd_alloc()" (Ken Cox) [2042819 2043783]
- Revert "bnxt: Search VPD with pci_vpd_find_ro_info_keyword()" (Ken Cox) [2042819 2043783]
- bnxt_en: Increase maximum RX ring size if jumbo ring is not used (Ken Cox) [2042819 2043783]
- bnxt_en: Don't use static arrays for completion ring pages (Ken Cox) [2042819 2043783]
- bnxt_en: Log if an invalid signal detected on TSIO pin (Ken Cox) [2042819 2043783]
- gfs2: Make sure FITRIM minlen is rounded up to fs block size (Andrew Price) [2066375]
- redhat/configs enable CONFIG_ICE_HWTS (Petr Oros) [2037974]
- redhat/configs enable CONFIG_ICE_SWITCHDEV (Petr Oros) [2037974]
- ice: Fix memory corruption in VF driver (Petr Oros) [2037974]
- ice: Fix queue config fail handling (Petr Oros) [2037974]
- ice: Sync VLAN filtering features for DVM (Petr Oros) [2037974]
- ice: Fix PTP TX timestamp offset calculation (Petr Oros) [2037974]
- ice: Fix interrupt moderation settings getting cleared (Petr Oros) [2037974]
- ice: fix possible under reporting of ethtool Tx and Rx statistics (Petr Oros) [2037974]
- ice: fix crash when writing timestamp on RX rings (Petr Oros) [2037974]
- ice: fix PTP stale Tx timestamps cleanup (Petr Oros) [2037974]
- ice: clear stale Tx queue settings before configuring (Petr Oros) [2037974]
- ice: Fix race during aux device (un)plugging (Petr Oros) [2037974]
- ice: fix use-after-free when deinitializing mailbox snapshot (Petr Oros) [2037974]
- ice: wait 5 s for EMP reset after firmware flash (Petr Oros) [2037974]
- ice: Protect vf_state check by cfg_lock in ice_vc_process_vf_msg() (Petr Oros) [2037974]
- ice: Fix incorrect locking in ice_vc_process_vf_msg() (Petr Oros) [2037974]
- ice: Fix memory leak in ice_get_orom_civd_data() (Petr Oros) [2037974]
- ice: fix crash in switchdev mode (Petr Oros) [2037974]
- ice: allow creating VFs for !CONFIG_NET_SWITCHDEV (Petr Oros) [2037974]
- ice: xsk: check if Rx ring was filled up to the end (Petr Oros) [2037974]
- ice: arfs: fix use-after-free when freeing @rx_cpu_rmap (Petr Oros) [2037974]
- ice: clear cmd_type_offset_bsz for TX rings (Petr Oros) [2037974]
- ice: xsk: fix VSI state check in ice_xsk_wakeup() (Petr Oros) [2037974]
- ice: synchronize_rcu() when terminating rings (Petr Oros) [2037974]
- ice: Do not skip not enabled queues in ice_vc_dis_qs_msg (Petr Oros) [2037974]
- ice: Set txq_teid to ICE_INVAL_TEID on ring creation (Petr Oros) [2037974]
- ice: Fix broken IFF_ALLMULTI handling (Petr Oros) [2037974]
- ice: Fix MAC address setting (Petr Oros) [2037974]
- ice: Clear default forwarding VSI during VSI release (Petr Oros) [2037974]
- ice: xsk: Fix indexing in ice_tx_xsk_pool() (Petr Oros) [2037974]
- ice: xsk: Stop Rx processing when ntc catches ntu (Petr Oros) [2037974]
- ice: xsk: Eliminate unnecessary loop iteration (Petr Oros) [2037974]
- ice: don't allow to run ice_send_event_to_aux() in atomic ctx (Petr Oros) [2037974]
- ice: fix 'scheduling while atomic' on aux critical err interrupt (Petr Oros) [2037974]
- ice: add trace events for tx timestamps (Petr Oros) [2037974]
- ice: fix return value check in ice_gnss.c (Petr Oros) [2037974]
- ice: destroy flow director filter mutex after releasing VSIs (Petr Oros) [2037974]
- ice: fix NULL pointer dereference in ice_update_vsi_tx_ring_stats() (Petr Oros) [2037974]
- ice: remove PF pointer from ice_check_vf_init (Petr Oros) [2037974]
- ice: introduce ice_virtchnl.c and ice_virtchnl.h (Petr Oros) [2037974]
- ice: cleanup long lines in ice_sriov.c (Petr Oros) [2037974]
- ice: introduce ICE_VF_RESET_LOCK flag (Petr Oros) [2037974]
- ice: introduce ICE_VF_RESET_NOTIFY flag (Petr Oros) [2037974]
- ice: convert ice_reset_vf to take flags (Petr Oros) [2037974]
- ice: convert ice_reset_vf to standard error codes (Petr Oros) [2037974]
- ice: make ice_reset_all_vfs void (Petr Oros) [2037974]
- ice: drop is_vflr parameter from ice_reset_all_vfs (Petr Oros) [2037974]
- ice: move reset functionality into ice_vf_lib.c (Petr Oros) [2037974]
- ice: fix a long line warning in ice_reset_vf (Petr Oros) [2037974]
- ice: introduce VF operations structure for reset flows (Petr Oros) [2037974]
- ice: fix incorrect dev_dbg print mistaking 'i' for vf->vf_id (Petr Oros) [2037974]
- ice: introduce ice_vf_lib.c, ice_vf_lib.h, and ice_vf_lib_private.h (Petr Oros) [2037974]
- ice: use ice_is_vf_trusted helper function (Petr Oros) [2037974]
- ice: log an error message when eswitch fails to configure (Petr Oros) [2037974]
- ice: cleanup error logging for ice_ena_vfs (Petr Oros) [2037974]
- ice: move ice_set_vf_port_vlan near other .ndo ops (Petr Oros) [2037974]
- ice: refactor spoofchk control code in ice_sriov.c (Petr Oros) [2037974]
- ice: rename ICE_MAX_VF_COUNT to avoid confusion (Petr Oros) [2037974]
- ice: remove unused definitions from ice_sriov.h (Petr Oros) [2037974]
- ice: convert vf->vc_ops to a const pointer (Petr Oros) [2037974]
- ice: remove circular header dependencies on ice.h (Petr Oros) [2037974]
- ice: rename ice_virtchnl_pf.c to ice_sriov.c (Petr Oros) [2037974]
- ice: rename ice_sriov.c to ice_vf_mbx.c (Petr Oros) [2037974]
- ice: Fix FV offset searching (Petr Oros) [2037974]
- ice: Add support for outer dest MAC for ADQ tunnels (Petr Oros) [2037974]
- ice: avoid XDP checks in ice_clean_tx_irq() (Petr Oros) [2037974]
- ice: change "can't set link" message to dbg level (Petr Oros) [2037974]
- ice: Add slow path offload stats on port representor in switchdev (Petr Oros) [2037974]
- ice: Add support for inner etype in switchdev (Petr Oros) [2037974]
- ice: Fix curr_link_speed advertised speed (Petr Oros) [2037974]
- ice: Don't use GFP_KERNEL in atomic context (Petr Oros) [2037974]
- ice: stop disabling VFs due to PF error responses (Petr Oros) [2037974]
- ice: xsk: fix GCC version checking against pragma unroll presence (Petr Oros) [2037974]
- ice: convert VF storage to hash table with krefs and RCU (Petr Oros) [2037974]
- ice: introduce VF accessor functions (Petr Oros) [2037974]
- ice: factor VF variables to separate structure (Petr Oros) [2037974]
- ice: convert ice_for_each_vf to include VF entry iterator (Petr Oros) [2037974]
- ice: use ice_for_each_vf for iteration during removal (Petr Oros) [2037974]
- ice: remove checks in ice_vc_send_msg_to_vf (Petr Oros) [2037974]
- ice: move VFLR acknowledge during ice_free_vfs (Petr Oros) [2037974]
- ice: move clear_malvf call in ice_free_vfs (Petr Oros) [2037974]
- ice: pass num_vfs to ice_set_per_vf_res() (Petr Oros) [2037974]
- ice: store VF pointer instead of VF ID (Petr Oros) [2037974]
- ice: refactor unwind cleanup in eswitch mode (Petr Oros) [2037974]
- ice: add TTY for GNSS module for E810T device (Petr Oros) [2037974]
- ice: initialize local variable 'tlv' (Petr Oros) [2037974]
- ice: check the return of ice_ptp_gettimex64 (Petr Oros) [2037974]
- ice: fix concurrent reset and removal of VFs (Petr Oros) [2037974]
- ice: fix setting l4 port flag when adding filter (Petr Oros) [2037974]
- ice: Match on all profiles in slow-path (Petr Oros) [2037974]
- ice: enable parsing IPSEC SPI headers for RSS (Petr Oros) [2037974]
- ice: Simplify tracking status of RDMA support (Petr Oros) [2037974]
- ice: fix IPIP and SIT TSO offload (Petr Oros) [2037974]
- ice: fix an error code in ice_cfg_phy_fec() (Petr Oros) [2037974]
- ice: Add ability for PF admin to enable VF VLAN pruning (Petr Oros) [2037974]
- ice: Add support for 802.1ad port VLANs VF (Petr Oros) [2037974]
- ice: Advertise 802.1ad VLAN filtering and offloads for PF netdev (Petr Oros) [2037974]
- ice: Support configuring the device to Double VLAN Mode (Petr Oros) [2037974]
- ice: Add support for VIRTCHNL_VF_OFFLOAD_VLAN_V2 (Petr Oros) [2037974]
- ice: Add hot path support for 802.1Q and 802.1ad VLAN offloads (Petr Oros) [2037974]
- ice: Add outer_vlan_ops and VSI specific VLAN ops implementations (Petr Oros) [2037974]
- ice: Adjust naming for inner VLAN operations (Petr Oros) [2037974]
- ice: Use the proto argument for VLAN ops (Petr Oros) [2037974]
- ice: Refactor vf->port_vlan_info to use ice_vlan (Petr Oros) [2037974]
- ice: Introduce ice_vlan struct (Petr Oros) [2037974]
- ice: Add new VSI VLAN ops (Petr Oros) [2037974]
- ice: Add helper function for adding VLAN 0 (Petr Oros) [2037974]
- ice: Refactor spoofcheck configuration functions (Petr Oros) [2037974]
- ice: xsk: Borrow xdp_tx_active logic from i40e (Petr Oros) [2037974]
- ice: xsk: Improve AF_XDP ZC Tx and use batching API (Petr Oros) [2037974]
- ice: xsk: Avoid potential dead AF_XDP Tx processing (Petr Oros) [2037974]
- ice: Make Tx threshold dependent on ring length (Petr Oros) [2037974]
- ice: xsk: Handle SW XDP ring wrap and bump tail more often (Petr Oros) [2037974]
- ice: xsk: Force rings to be sized to power of 2 (Petr Oros) [2037974]
- ice: Remove likely for napi_complete_done (Petr Oros) [2037974]
- ice: add support for DSCP QoS for IDC (Petr Oros) [2037974]
- ice: respect metadata on XSK Rx to skb (Petr Oros) [2037974]
- ice: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Petr Oros) [2037974]
- ice: respect metadata in legacy-rx/ice_construct_skb() (Petr Oros) [2037974]
- ice: Remove useless DMA-32 fallback configuration (Petr Oros) [2037974]
- ice: Use bitmap_free() to free bitmap (Petr Oros) [2037974]
- ice: Optimize a few bitmap operations (Petr Oros) [2037974]
- ice: Slightly simply ice_find_free_recp_res_idx (Petr Oros) [2037974]
- ice: improve switchdev's slow-path (Petr Oros) [2037974]
- ice: replay advanced rules after reset (Petr Oros) [2037974]
- net: fixup build after bpf header changes (Petr Oros) [2037974]
- net: Don't include filter.h from net/sock.h (Petr Oros) [2037974]
- ice: Add flow director support for channel mode (Petr Oros) [2037974]
- ice: switch to napi_build_skb() (Petr Oros) [2037974]
- ice: xsk: fix cleaned_count setting (Petr Oros) [2037974]
- ice: xsk: allow empty Rx descriptors on XSK ZC data path (Petr Oros) [2037974]
- ice: xsk: do not clear status_error0 for ntu + nb_buffs descriptor (Petr Oros) [2037974]
- ice: remove dead store on XSK hotpath (Petr Oros) [2037974]
- ice: xsk: allocate separate memory for XDP SW ring (Petr Oros) [2037974]
- ice: xsk: return xsk buffers back to pool when cleaning the ring (Petr Oros) [2037974]
- ice: trivial: fix odd indenting (Petr Oros) [2037974]
- ice: support crosstimestamping on E822 devices if supported (Petr Oros) [2037974]
- ice: exit bypass mode once hardware finishes timestamp calibration (Petr Oros) [2037974]
- ice: ensure the hardware Clock Generation Unit is configured (Petr Oros) [2037974]
- ice: implement basic E822 PTP support (Petr Oros) [2037974]
- ice: convert clk_freq capability into time_ref (Petr Oros) [2037974]
- ice: introduce ice_ptp_init_phc function (Petr Oros) [2037974]
- ice: use 'int err' instead of 'int status' in ice_ptp_hw.c (Petr Oros) [2037974]
- ice: PTP: move setting of tstamp_config (Petr Oros) [2037974]
- ice: introduce ice_base_incval function (Petr Oros) [2037974]
- ice: Fix E810 PTP reset flow (Petr Oros) [2037974]
- ice: Don't put stale timestamps in the skb (Petr Oros) [2037974]
- ice: Use div64_u64 instead of div_u64 in adjfine (Petr Oros) [2037974]
- ice: use modern kernel API for kick (Petr Oros) [2037974]
- ice: tighter control over VSI_DOWN state (Petr Oros) [2037974]
- ice: use prefetch methods (Petr Oros) [2037974]
- ice: update to newer kernel API (Petr Oros) [2037974]
- ice: support immediate firmware activation via devlink reload (Petr Oros) [2037974]
- ice: reduce time to read Option ROM CIVD data (Petr Oros) [2037974]
- ice: move ice_devlink_flash_update and merge with ice_flash_pldm_image (Petr Oros) [2037974]
- ice: move and rename ice_check_for_pending_update (Petr Oros) [2037974]
- ice: devlink: add shadow-ram region to snapshot Shadow RAM (Petr Oros) [2037974]
- ice: Remove unused ICE_FLOW_SEG_HDRS_L2_MASK (Petr Oros) [2037974]
- ice: Remove unnecessary casts (Petr Oros) [2037974]
- ice: Propagate error codes (Petr Oros) [2037974]
- ice: Remove excess error variables (Petr Oros) [2037974]
- ice: Cleanup after ice_status removal (Petr Oros) [2037974]
- ice: Remove enum ice_status (Petr Oros) [2037974]
- ice: Use int for ice_status (Petr Oros) [2037974]
- ice: Remove string printing for ice_status (Petr Oros) [2037974]
- ice: Refactor status flow for DDP load (Petr Oros) [2037974]
- ice: Refactor promiscuous functions (Petr Oros) [2037974]
- ice: refactor PTYPE validating (Petr Oros) [2037974]
- ice: Add package PTYPE enable information (Petr Oros) [2037974]
- ice: safer stats processing (Petr Oros) [2037974]
- ice: fix adding different tunnels (Petr Oros) [2037974]
- ice: fix choosing UDP header type (Petr Oros) [2037974]
- ice: ignore dropped packets during init (Petr Oros) [2037974]
- ice: rearm other interrupt cause register after enabling VFs (Petr Oros) [2037974]
- ice: fix FDIR init missing when reset VF (Petr Oros) [2037974]
- ice: xsk: clear status_error0 for each allocated desc (Petr Oros) [2037974]
- net/ice: Remove unused enum (Petr Oros) [2037974]
- net/ice: Fix boolean assignment (Petr Oros) [2037974]
- ice: avoid bpf_prog refcount underflow (Petr Oros) [2037974]
- ice: fix vsi->txq_map sizing (Petr Oros) [2037974]
- net/ice: Add support for enable_iwarp and enable_roce devlink param (Petr Oros) [2037974]
- ice: Hide bus-info in ethtool for PRs in switchdev mode (Petr Oros) [2037974]
- ice: Clear synchronized addrs when adding VFs in switchdev mode (Petr Oros) [2037974]
- intel: Simplify bool conversion (Petr Oros) [2037974]
- ice: fix error return code in ice_get_recp_frm_fw() (Petr Oros) [2037974]
- ice: Fix clang -Wimplicit-fallthrough in ice_pull_qvec_from_rc() (Petr Oros) [2037974]
- ice: Add support to print error on PHY FW load failure (Petr Oros) [2037974]
- ice: Add support for changing MTU on PR in switchdev mode (Petr Oros) [2037974]
- ice: send correct vc status in switchdev (Petr Oros) [2037974]
- ice: support for GRE in eswitch (Petr Oros) [2037974]
- ice: low level support for tunnels (Petr Oros) [2037974]
- ice: VXLAN and Geneve TC support (Petr Oros) [2037974]
- ice: support for indirect notification (Petr Oros) [2037974]
- ice: Add tc-flower filter support for channel (Petr Oros) [2037974]
- ice: enable ndo_setup_tc support for mqprio_qdisc (Petr Oros) [2037974]
- ice: Add infrastructure for mqprio support via ndo_setup_tc (Petr Oros) [2037974]
- ice: fix an error code in ice_ena_vfs() (Petr Oros) [2037974]
- ice: Refactor PR ethtool ops (Petr Oros) [2037974]
- ice: Manage act flags for switchdev offloads (Petr Oros) [2037974]
- ice: Forbid trusted VFs in switchdev mode (Petr Oros) [2037974]
- ice: introduce XDP_TX fallback path (Petr Oros) [2037974]
- ice: optimize XDP_TX workloads (Petr Oros) [2037974]
- ice: propagate xdp_ring onto rx_ring (Petr Oros) [2037974]
- ice: do not create xdp_frame on XDP_TX (Petr Oros) [2037974]
- ice: unify xdp_rings accesses (Petr Oros) [2037974]
- ice: ndo_setup_tc implementation for PR (Petr Oros) [2037974]
- ice: ndo_setup_tc implementation for PF (Petr Oros) [2037974]
- ice: Allow changing lan_en and lb_en on all kinds of filters (Petr Oros) [2037974]
- ice: cleanup rules info (Petr Oros) [2037974]
- ice: allow deleting advanced rules (Petr Oros) [2037974]
- ice: allow adding advanced rules (Petr Oros) [2037974]
- ice: create advanced switch recipe (Petr Oros) [2037974]
- ice: manage profiles and field vectors (Petr Oros) [2037974]
- ice: implement low level recipes functions (Petr Oros) [2037974]
- ice: add port representor ethtool ops and stats (Petr Oros) [2037974]
- ice: switchdev slow path (Petr Oros) [2037974]
- ice: rebuild switchdev when resetting all VFs (Petr Oros) [2037974]
- ice: enable/disable switchdev when managing VFs (Petr Oros) [2037974]
- ice: introduce new type of VSI for switchdev (Petr Oros) [2037974]
- ice: set and release switchdev environment (Petr Oros) [2037974]
- ice: allow changing lan_en and lb_en on dflt rules (Petr Oros) [2037974]
- ice: manage VSI antispoof and destination override (Petr Oros) [2037974]
- ice: allow process VF opcodes in different ways (Petr Oros) [2037974]
- ice: introduce VF port representor (Petr Oros) [2037974]
- ice: Move devlink port to PF/VF struct (Petr Oros) [2037974]
- ice: support basic E-Switch mode control (Petr Oros) [2037974]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Petr Oros) [2037974]
- ice: Use the xsk batched rx allocation interface (Petr Oros) [2037974]
- ice: Use xdp_buf instead of rx_buf for xsk zero-copy (Petr Oros) [2037974]
- ice: Only lock to update netdev dev_addr (Petr Oros) [2037974]
- ice: restart periodic outputs around time changes (Petr Oros) [2037974]
- ice: fix Tx queue iteration for Tx timestamp enablement (Petr Oros) [2037974]

* Mon Jul 04 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-124.rt21.124.el9]
- [rt] build kernel-rt-5.14.0-124.rt21.124.el9 [2061574]
- scsi: ibmvfc: Allocate/free queue resource only during probe/remove (Diego Domingos) [2099962]
- ceph: wait on async create before checking caps for syncfs (Jeffrey Layton) [2094965]
- lib: bitmap: Introduce node-aware alloc API (Ivan Vecera) [2101768]
- dm raid: fix accesses beyond end of raid member array (Benjamin Marzinski) [2090507]
- block: remove bioset_init_from_src (Benjamin Marzinski) [2090507]
- dm: fix bio_set allocation (Benjamin Marzinski) [2090507]
- dm mirror log: clear log bits up to BITS_PER_LONG boundary (Benjamin Marzinski) [2090507]
- dm: fix BLK_STS_DM_REQUEUE handling when dm_io represents split bio (Benjamin Marzinski) [2090507]
- dm: do not return early from dm_io_complete if BLK_STS_AGAIN without polling (Benjamin Marzinski) [2090507]
- dm era: commit metadata in postsuspend after worker stops (Benjamin Marzinski) [2090507]
- dm: fix narrow race for REQ_NOWAIT bios being issued despite no support (Benjamin Marzinski) [2090507]
- dm: fix use-after-free in dm_put_live_table_bio (Benjamin Marzinski) [2090507]
- dm: improve abnormal bio processing (Benjamin Marzinski) [2090507]
- dm: simplify bio-based IO accounting further (Benjamin Marzinski) [2090507]
- dm: improve dm_io reference counting (Benjamin Marzinski) [2090507]
- dm: don't grab target io reference in dm_zone_map_bio (Benjamin Marzinski) [2090507]
- dm: improve bio splitting and associated IO accounting (Benjamin Marzinski) [2090507]
- dm: introduce dm_{get,put}_live_table_bio called from dm_submit_bio (Benjamin Marzinski) [2090507]
- dm mirror log: round up region bitmap size to BITS_PER_LONG (Benjamin Marzinski) [2090507]
- dm: fix race in dm_start_io_acct (Benjamin Marzinski) [2090507]
- dm verity: set DM_TARGET_IMMUTABLE feature flag (Benjamin Marzinski) [2090507]
- dm table: fix dm_table_supports_poll to return false if no data devices (Benjamin Marzinski) [2090507]
- dm cache metadata: remove unnecessary variable in __dump_mapping (Benjamin Marzinski) [2090507]
- dm mpath: provide high-resolution timer to HST for bio-based (Benjamin Marzinski) [2090507]
- dm crypt: make printing of the key constant-time (Benjamin Marzinski) [2090507]
- dm integrity: fix error code in dm_integrity_ctr() (Benjamin Marzinski) [2090507]
- dm stats: add cond_resched when looping over entries (Benjamin Marzinski) [2090507]
- dm: put all polled dm_io instances into a single list (Benjamin Marzinski) [2090507]
- dm: switch to bdev based IO accounting interfaces (Benjamin Marzinski) [2090507]
- dm: pass dm_io instance to dm_io_acct directly (Benjamin Marzinski) [2090507]
- dm: don't pass bio to __dm_start_io_acct and dm_end_io_acct (Benjamin Marzinski) [2090507]
- dm: use bio_sectors in dm_aceept_partial_bio (Benjamin Marzinski) [2090507]
- dm: simplify basic targets (Benjamin Marzinski) [2090507]
- dm: conditionally enable branching for less used features (Benjamin Marzinski) [2090507]
- dm: move hot dm_io members to same cacheline as dm_target_io (Benjamin Marzinski) [2090507]
- dm: add local variables to clone_endio and __map_bio (Benjamin Marzinski) [2090507]
- dm: mark various branches unlikely (Benjamin Marzinski) [2090507]
- dm: simplify dm_start_io_acct (Benjamin Marzinski) [2090507]
- dm: simplify dm_io access in dm_split_and_process_bio (Benjamin Marzinski) [2090507]
- dm: factor out dm_io_set_error and __dm_io_dec_pending (Benjamin Marzinski) [2090507]
- dm: conditionally enable BIOSET_PERCPU_CACHE for dm_io bioset (Benjamin Marzinski) [2090507]
- dm: allow dm_accept_partial_bio() for dm_io without duplicate bios (Benjamin Marzinski) [2090507]
- dm zone: fix NULL pointer dereference in dm_zone_map_bio (Benjamin Marzinski) [2090507]
- dm mpath: only use ktime_get_ns() in historical selector (Benjamin Marzinski) [2090507]
- dm: fix bio polling to handle possibile BLK_STS_AGAIN (Benjamin Marzinski) [2090507]
- dm: fix dm_io and dm_target_io flags race condition on Alpha (Benjamin Marzinski) [2090507]
- dm integrity: set journal entry unused when shrinking device (Benjamin Marzinski) [2090507]
- dm ioctl: log an error if the ioctl structure is corrupted (Benjamin Marzinski) [2090507]
- dm: consolidate spinlocks in dm_io struct (Benjamin Marzinski) [2090507]
- dm: reduce size of dm_io and dm_target_io structs (Benjamin Marzinski) [2090507]
- dm: switch dm_target_io booleans over to proper flags (Benjamin Marzinski) [2090507]
- dm: switch dm_io booleans over to proper flags (Benjamin Marzinski) [2090507]
- dm: update email address in MAINTAINERS (Benjamin Marzinski) [2090507]
- dm: return void from __send_empty_flush (Benjamin Marzinski) [2090507]
- dm: factor out dm_io_complete (Benjamin Marzinski) [2090507]
- dm cache: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: simplify dm_sumbit_bio_remap interface (Benjamin Marzinski) [2090507]
- dm thin: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: add WARN_ON_ONCE to dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: support bio polling (Benjamin Marzinski) [2090507]
- block: add ->poll_bio to block_device_operations (Benjamin Marzinski) [2090507]
- dm mpath: use DMINFO instead of printk with KERN_INFO (Benjamin Marzinski) [2090507]
- dm: stop using bdevname (Benjamin Marzinski) [2090507]
- dm-zoned: remove the ->name field in struct dmz_dev (Benjamin Marzinski) [2090507]
- dm: remove unnecessary local variables in __bind (Benjamin Marzinski) [2090507]
- dm: requeue IO if mapping table not yet available (Benjamin Marzinski) [2090507]
- dm io: remove stale comment block for dm_io() (Benjamin Marzinski) [2090507]
- dm thin metadata: remove unused dm_thin_remove_block and __remove (Benjamin Marzinski) [2090507]
- dm thin: use time_is_before_jiffies instead of open coding it (Benjamin Marzinski) [2090507]
- dm crypt: fix get_key_size compiler warning if !CONFIG_KEYS (Benjamin Marzinski) [2090507]
- dm: fix use-after-free in dm_cleanup_zoned_dev() (Benjamin Marzinski) [2090507]
- dm ioctl: prevent potential spectre v1 gadget (Benjamin Marzinski) [2090507]
- dm: cleanup double word in comment (Benjamin Marzinski) [2090507]
- dm ima: fix wrong length calculation for no_data string (Benjamin Marzinski) [2090507]
- dm cache policy smq: make static read-only array table const (Benjamin Marzinski) [2090507]
- dm delay: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm crypt: use dm_submit_bio_remap (Benjamin Marzinski) [2090507]
- dm: add dm_submit_bio_remap interface (Benjamin Marzinski) [2090507]
- dm: flag clones created by __send_duplicate_bios (Benjamin Marzinski) [2090507]
- dm: reduce dm_io and dm_target_io struct sizes (Benjamin Marzinski) [2090507]
- dm: move duplicate code from callers of alloc_tio into alloc_tio (Benjamin Marzinski) [2090507]
- dm: record old_sector in dm_target_io before calling map function (Benjamin Marzinski) [2090507]
- dm: remove legacy code only needed before submit_bio recursion (Benjamin Marzinski) [2090507]
- dm: remove unused mapped_device argument from free_tio (Benjamin Marzinski) [2090507]
- dm: remove impossible BUG_ON in __send_empty_flush (Benjamin Marzinski) [2090507]
- dm: reduce code duplication in __map_bio (Benjamin Marzinski) [2090507]
- dm: refactor dm_split_and_process_bio a bit (Benjamin Marzinski) [2090507]
- dm: fold __clone_and_map_data_bio into __split_and_process_bio (Benjamin Marzinski) [2090507]
- dm: rename split functions (Benjamin Marzinski) [2090507]
- dm: reorder members in mapped_device struct (Benjamin Marzinski) [2090507]
- dm: eliminate copying of dm_io fields in dm_io_dec_pending (Benjamin Marzinski) [2090507]

* Mon Jul 04 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-123.rt21.123.el9]
- [rt] build kernel-rt-5.14.0-123.rt21.123.el9 [2061574]
- exec: Force single empty string when argv is empty (Diego Domingos) [2099482]
- scsi: ibmvfc: Store vhost pointer during subcrq allocation (Gustavo Walbon) [2098103]
- powerpc: Enable execve syscall exit tracepoint (Steve Best) [2095526]
- rcu-tasks: Use delayed_work to delay rcu_tasks_verify_self_tests() (Waiman Long) [2094506]
- rcu-tasks: Be more patient for RCU Tasks boot-time testing (Waiman Long) [2094506]
- redhat/configs: Add new refcnt tracker options (Ivan Vecera) [2096377]
- net/sched: cls_u32: fix possible leak in u32_init_knode() (Ivan Vecera) [2096377]
- net/sched: cls_u32: fix netns refcount changes in u32_change() (Ivan Vecera) [2096377]
- net: add dev->dev_registered_tracker (Ivan Vecera) [2096377]
- net/smc: use GFP_ATOMIC allocation in smc_pnet_add_eth() (Ivan Vecera) [2096377]
- net/smc: fix ref_tracker issue in smc_pnet_add() (Ivan Vecera) [2096377]
- net: refine dev_put()/dev_hold() debugging (Ivan Vecera) [2096377]
- ref_tracker: add a count of untracked references (Ivan Vecera) [2096377]
- ref_tracker: implement use-after-free detection (Ivan Vecera) [2096377]
- SUNRPC: add netns refcount tracker to struct rpc_xprt (Ivan Vecera) [2096377]
- SUNRPC: add netns refcount tracker to struct gss_auth (Ivan Vecera) [2096377]
- SUNRPC: add netns refcount tracker to struct svc_xprt (Ivan Vecera) [2096377]
- net/smc: fix possible NULL deref in smc_pnet_add_eth() (Ivan Vecera) [2096377]
- net: bridge: fix net device refcount tracking issue in error path (Ivan Vecera) [2096377]
- ref_tracker: use __GFP_NOFAIL more carefully (Ivan Vecera) [2096377]
- net: sched: do not allocate a tracker in tcf_exts_init() (Ivan Vecera) [2096377]
- af_packet: fix tracking issues in packet_do_bind() (Ivan Vecera) [2096377]
- netlink: do not allocate a device refcount tracker in ethnl_default_notify() (Ivan Vecera) [2096377]
- net/sched: add missing tracker information in qdisc_create() (Ivan Vecera) [2096377]
- netfilter: nf_nat_masquerade: add netns refcount tracker to masq_dev_work (Ivan Vecera) [2096377]
- netfilter: nf_nat_masquerade: defer conntrack walk to work queue (Ivan Vecera) [2096377]
- netfilter: nf_nat_masquerade: make async masq_inet6_event handling generic (Ivan Vecera) [2096377]
- netfilter: nfnetlink: add netns refcount tracker to struct nfulnl_instance (Ivan Vecera) [2096377]
- ethtool: always write dev in ethnl_parse_header_dev_get (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct packet_type (Ivan Vecera) [2096377]
- ethtool: use ethnl_parse_header_dev_put() (Ivan Vecera) [2096377]
- net: dev_replace_track() cleanup (Ivan Vecera) [2096377]
- net: linkwatch: be more careful about dev->linkwatch_dev_tracker (Ivan Vecera) [2096377]
- mptcp: adjust to use netns refcount tracker (Ivan Vecera) [2096377]
- ipv6: use GFP_ATOMIC in rt6_probe() (Ivan Vecera) [2096377]
- xfrm: add net device refcount tracker to struct xfrm_state_offload (Ivan Vecera) [2096377]
- ethtool: fix null-ptr-deref on ref tracker (Ivan Vecera) [2096377]
- ppp: add netns refcount tracker (Ivan Vecera) [2096377]
- l2tp: add netns refcount tracker to l2tp_dfs_seq_data (Ivan Vecera) [2096377]
- net: sched: add netns refcount tracker to struct tcf_exts (Ivan Vecera) [2096377]
- net: add netns refcount tracker to struct seq_net_private (Ivan Vecera) [2096377]
- net: add netns refcount tracker to struct sock (Ivan Vecera) [2096377]
- net: add networking namespace refcount tracker (Ivan Vecera) [2096377]
- xfrm: use net device refcount tracker helpers (Ivan Vecera) [2096377]
- net: sched: act_mirred: add net device refcount tracker (Ivan Vecera) [2096377]
- openvswitch: add net device refcount tracker to struct vport (Ivan Vecera) [2096377]
- netlink: add net device refcount tracker to struct ethnl_req_info (Ivan Vecera) [2096377]
- net/smc: add net device tracker to struct smc_pnetentry (Ivan Vecera) [2096377]
- pktgen add net device refcount tracker (Ivan Vecera) [2096377]
- llc: add net device refcount tracker (Ivan Vecera) [2096377]
- ax25: add net device refcount tracker (Ivan Vecera) [2096377]
- inet: add net device refcount tracker to struct fib_nh_common (Ivan Vecera) [2096377]
- net: switchdev: add net device refcount tracker (Ivan Vecera) [2096377]
- net: watchdog: add net device refcount tracker (Ivan Vecera) [2096377]
- net: bridge: add net device refcount tracker (Ivan Vecera) [2096377]
- vlan: add net device refcount tracker (Ivan Vecera) [2096377]
- net: eql: add net device refcount tracker (Ivan Vecera) [2096377]
- vrf: use dev_replace_track() for better tracking (Ivan Vecera) [2096377]
- netpoll: add net device refcount tracker to struct netpoll (Ivan Vecera) [2096377]
- ipmr, ip6mr: add net device refcount tracker to struct vif_device (Ivan Vecera) [2096377]
- net: failover: add net device refcount tracker (Ivan Vecera) [2096377]
- net: linkwatch: add net device refcount tracker (Ivan Vecera) [2096377]
- net/sched: add net device refcount tracker to struct Qdisc (Ivan Vecera) [2096377]
- ipv4: add net device refcount tracker to struct in_device (Ivan Vecera) [2096377]
- ipv6: add net device refcount tracker to struct inet6_dev (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct netdev_adjacent (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct neigh_parms (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct pneigh_entry (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct neighbour (Ivan Vecera) [2096377]
- ipv6: add net device refcount tracker to struct ip6_tnl (Ivan Vecera) [2096377]
- sit: add net device refcount tracking to ip_tunnel (Ivan Vecera) [2096377]
- ipv6: add net device refcount tracker to rt6_probe_deferred() (Ivan Vecera) [2096377]
- net: dst: add net device refcount tracking to dst_entry (Ivan Vecera) [2096377]
- drop_monitor: add net device refcount tracker (Ivan Vecera) [2096377]
- net: add net device refcount tracker to dev_ifsioc() (Ivan Vecera) [2096377]
- net: add net device refcount tracker to ethtool_phys_id() (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct netdev_queue (Ivan Vecera) [2096377]
- net: add net device refcount tracker to struct netdev_rx_queue (Ivan Vecera) [2096377]
- net: add net device refcount tracker infrastructure (Ivan Vecera) [2096377]
- lib: add tests for reference tracker (Ivan Vecera) [2096377]
- lib: add reference counting tracking infrastructure (Ivan Vecera) [2096377]
- net: drop nopreempt requirement on sock_prot_inuse_add() (Ivan Vecera) [2096377]
- net: merge net->core.prot_inuse and net->core.sock_inuse (Ivan Vecera) [2096377]
- net: make sock_inuse_add() available (Ivan Vecera) [2096377]
- net: inline sock_prot_inuse_add() (Ivan Vecera) [2096377]
- netdevice: move xdp_rxq within netdev_rx_queue (Ivan Vecera) [2096377]
- nfs: fix broken handling of the softreval mount option (Benjamin Coddington) [2095275]

* Thu Jun 30 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-122.rt21.122.el9]
- [rt] build kernel-rt-5.14.0-122.rt21.122.el9 [2061574]
- bonding: ARP monitor spams NETDEV_NOTIFY_PEERS notifiers (Jonathan Toppins) [2094911]
- exec: Force single empty string when argv is empty (Rafael Aquini) [2097485]
- mptcp: Do TCP fallback on early DSS checksum failure (Paolo Abeni) [2100072]
- mptcp: fix checksum byte order (Paolo Abeni) [2100072]
- platform/x86/intel/sdsi: Fix bug in multi packet reads (David Arcari) [2098067]
- platform/x86/intel/sdsi: Poll on ready bit for writes (David Arcari) [2098067]
- platform/x86/intel/sdsi: Handle leaky bucket (David Arcari) [2098067]
- hv_netvsc: Fix potential dereference of NULL pointer (Mohammed Gamal) [2086626]
- hv_netvsc: Add support for XDP_REDIRECT (Mohammed Gamal) [2086626]
- hv_netvsc: Print value of invalid ID in netvsc_send_{completion,tx_complete}() (Mohammed Gamal) [2086626]
- net: hyperv: remove use of bpf_op_t (Mohammed Gamal) [2086626]
- hv_netvsc: Add check for kvmalloc_array (Mohammed Gamal) [2086626]
- net: netvsc: remove break after return (Mohammed Gamal) [2086626]
- Netvsc: Call hv_unmap_memory() in the netvsc_device_remove() (Mohammed Gamal) [2086626]
- net: netvsc: Add Isolation VM support for netvsc driver (Mohammed Gamal) [2086626]
- hv_netvsc: Use bitmap_zalloc() when applicable (Mohammed Gamal) [2086626]
- hv_netvsc: Add comment of netvsc_xdp_xmit() (Mohammed Gamal) [2086626]
- hv_netvsc: use netif_is_bond_master() instead of open code (Mohammed Gamal) [2086626]
- arm64: kdump: Do not allocate crash low memory if not needed (Pingfan Liu) [2091852]
- docs: kdump: Update the crashkernel description for arm64 (Pingfan Liu) [2091852]
- of: Support more than one crash kernel regions for kexec -s (Pingfan Liu) [2091852]
- of: fdt: Add memory for devices by DT property "linux,usable-memory-range" (Pingfan Liu) [2091852]
- arm64: kdump: Reimplement crashkernel=X (Pingfan Liu) [2091852]
- arm64: Use insert_resource() to simplify code (Pingfan Liu) [2091852]
- kdump: return -ENOENT if required cmdline option does not exist (Pingfan Liu) [2091852]
- arm64: mm: use IS_ENABLED(CONFIG_KEXEC_CORE) instead of #ifdef (Pingfan Liu) [2091852]
- arm64: mm: Drop 'const' from conditional arm64_dma_phys_limit definition (Pingfan Liu) [2091852]
- arm64: Do not defer reserve_crashkernel() for platforms with no DMA memory zones (Pingfan Liu) [2091852]
- efi: apply memblock cap after memblock_add() (Pingfan Liu) [2091852]
- arm64: kdump: Remove custom linux,usable-memory-range handling (Pingfan Liu) [2091852]
- arm64: kdump: Remove custom linux,elfcorehdr handling (Pingfan Liu) [2091852]
- of/fdt: move elfcorehdr reservation early for crash dump kernel (Pingfan Liu) [2091852]
- of/fdt: Don't worry about non-memory region overlap for no-map (Pingfan Liu) [2091852]
- of: fdt: Aggregate the processing of "linux,usable-memory-range" (Pingfan Liu) [2091852]
- of/fdt: Rework early_init_dt_scan_memory() to call directly (Pingfan Liu) [2091852]
- of/fdt: Rework early_init_dt_scan_root() to call directly (Pingfan Liu) [2091852]
- of/fdt: Rework early_init_dt_scan_chosen() to call directly (Pingfan Liu) [2091852]
- of/fdt: Remove of_scan_flat_dt() usage for __fdt_scan_reserved_mem() (Pingfan Liu) [2091852]
- of: fdt: Rename reserve_elfcorehdr() to fdt_reserve_elfcorehdr() (Pingfan Liu) [2091852]
- of: fdt: Use IS_ENABLED(CONFIG_BLK_DEV_INITRD) instead of #ifdef (Pingfan Liu) [2091852]
- of: fdt: Add generic support for handling usable memory range property (Pingfan Liu) [2091852]
- of: fdt: Add generic support for handling elf core headers property (Pingfan Liu) [2091852]
- of: fdt: Remove weak early_init_dt_mark_hotplug_memory_arch() (Pingfan Liu) [2091852]
- of: fdt: Remove early_init_dt_reserve_memory_arch() override capability (Pingfan Liu) [2091852]
- of: fdt: do not update local variable after use (Pingfan Liu) [2091852]
- of: fdt: remove unnecessary codes (Pingfan Liu) [2091852]
- mei: me: add Alder Lake N device id. (David Arcari) [2072663]
- mei: me: disable driver on the ign firmware (David Arcari) [2072663]
- mei: me: add Ice Lake-N device id. (David Arcari) [2072663]
- iwlwifi: fix use-after-free (Jose Ignacio Tornos Martinez) [2093882]
- ucounts: Handle wrapping in is_ucounts_overlimit (Alexey Gladkov) [2092422]
- ucount: Make get_ucount a safe get_user replacement (Alexey Gladkov) [2092422]
- ucounts: Fix rlimit max values check (Alexey Gladkov) [2092422]
- ucounts: Use atomic_long_sub_return for clarity (Alexey Gladkov) [2092422]
- ucounts: Add get_ucounts_or_wrap for clarity (Alexey Gladkov) [2092422]
- ucounts: Remove unnecessary test for NULL ucount in get_ucounts (Alexey Gladkov) [2092422]
- redhat/configs: Allow CRYPTO_CHACHA20 to remain a module (Vladis Dronov) [1917926]
- crypto: s390 - add crypto library interface for ChaCha20 (Vladis Dronov) [1917926]
- s390/crypto: add SIMD implementation for ChaCha20 (Vladis Dronov) [1917926]

* Thu Jun 30 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-121.rt21.121.el9]
- [rt] build kernel-rt-5.14.0-121.rt21.121.el9 [2061574]
- redhat/configs: Set CONFIG_VIRTIO_IOMMU on x86_64 (Eric Auger) [2089765]
- crypto: fips - make proc files report fips module name and version (Simo Sorce) [2080499]
- fuse: clean up error exits in fuse_fill_super() (Miklos Szeredi) [2021800]
- fuse: always initialize sb->s_fs_info (Miklos Szeredi) [2021800]
- fuse: clean up fuse_mount destruction (Miklos Szeredi) [2021800]
- fuse: get rid of fuse_put_super() (Miklos Szeredi) [2021800]
- fuse: check s_root when destroying sb (Miklos Szeredi) [2021800]
- fuse: allow sharing existing sb (Miklos Szeredi) [2021800]
- fuse: move fget() to fuse_get_tree() (Miklos Szeredi) [2021800]
- fuse: move option checking into fuse_fill_super() (Miklos Szeredi) [2021800]
- fuse: name fs_context consistently (Miklos Szeredi) [2021800]
- gfs2: Stop using glock holder auto-demotion for now (Andreas Gruenbacher) [2082193]
- gfs2: buffered write prefaulting (Andreas Gruenbacher) [2082193]
- gfs2: Align read and write chunks to the page cache (Andreas Gruenbacher) [2082193]
- gfs2: Pull return value test out of should_fault_in_pages (Andreas Gruenbacher) [2082193]
- gfs2: Clean up use of fault_in_iov_iter_{read,write}able (Andreas Gruenbacher) [2082193]
- gfs2: Variable rename (Andreas Gruenbacher) [2082193]
- gfs2: Fix filesystem block deallocation for short writes (Andreas Gruenbacher) [2082193]
- iomap: iomap_write_end cleanup (Andreas Gruenbacher) [2082193]
- iomap: iomap_write_failed fix (Andreas Gruenbacher) [2082193]
- gfs2: Don't re-check for write past EOF unnecessarily (Andreas Gruenbacher) [2082193]
- gfs2: No short reads or writes upon glock contention (Andreas Gruenbacher) [2082193]
- fs/iomap: Fix buffered write page prefaulting (Andreas Gruenbacher) [2082193]
- gfs2: Make sure not to return short direct writes (Andreas Gruenbacher) [2082193]
- gfs2: Remove dead code in gfs2_file_read_iter (Andreas Gruenbacher) [2082193]
- gfs2: Fix gfs2_file_buffered_write endless loop workaround (Andreas Gruenbacher) [2082193]
- gfs2: Minor retry logic cleanup (Andreas Gruenbacher) [2082193]
- gfs2: Disable page faults during lockless buffered reads (Andreas Gruenbacher) [2082193]
- gfs2: Fix should_fault_in_pages() logic (Andreas Gruenbacher) [2082193]
- gfs2: Initialize gh_error in gfs2_glock_nq (Andreas Gruenbacher) [2082193]
- gfs2: Make use of list_is_first (Andreas Gruenbacher) [2082193]
- gfs2: Switch lock order of inode and iopen glock (Andreas Gruenbacher) [2082193]
- gfs2: cancel timed-out glock requests (Andreas Gruenbacher) [2082193]
- gfs2: Expect -EBUSY after canceling dlm locking requests (Andreas Gruenbacher) [2082193]
- gfs2: gfs2_setattr_size error path fix (Andreas Gruenbacher) [2082193]
- gfs2: assign rgrp glock before compute_bitstructs (Bob Peterson) [2082193]
- redhat/kernel.spec.template: fix standalone tools build (Jan Stancek) [2081992]
- arm64/mte: Clarify mode reported by PR_GET_TAGGED_ADDR_CTRL (Mark Salter) [2076088]
- arm64: mte: change PR_MTE_TCF_NONE back into an unsigned long (Mark Salter) [2076088]
- tools headers UAPI: Sync linux/prctl.h with the kernel sources (Mark Salter) [2076088]
- kselftest/arm64: Skip VL_INHERIT tests for unsupported vector types (Mark Salter) [2076088]
- kselftest/arm64: Parameterise ptrace vector length information (Mark Salter) [2076088]
- arm64: extable: fix load_unaligned_zeropad() reg indices (Mark Salter) [2076088]
- arm64: kexec: Fix missing error code 'ret' warning in load_other_segments() (Mark Salter) [2076088]
- arm64: ftrace: add missing BTIs (Mark Salter) [2076088]
- arm64: kexec: use __pa_symbol(empty_zero_page) (Mark Salter) [2076088]
- arm64: update PAC description for kernel (Mark Salter) [2076088]
- arm64: uaccess: avoid blocking within critical sections (Mark Salter) [2076088]
- arm64: mm: Fix VM_BUG_ON(mm != &init_mm) for trans_pgd (Mark Salter) [2076088]
- arm64: pgtable: make __pte_to_phys/__phys_to_pte_val inline functions (Mark Salter) [2076088]
- arm64: Track no early_pgtable_alloc() for kmemleak (Mark Salter) [2076088]
- arm64: vdso: remove -nostdlib compiler flag (Mark Salter) [2076088]
- arm64: arm64_ftr_reg->name may not be a human-readable string (Mark Salter) [2076088]
- kasan: arm64: fix pcpu_page_first_chunk crash with KASAN_VMALLOC (Mark Salter) [2076088]
- arm64: support page mapping percpu first chunk allocator (Mark Salter) [2076088]
- arm64: cpufeature: Export this_cpu_has_cap helper (Mark Salter) [2076088]
- arm64: Select POSIX_CPU_TIMERS_TASK_WORK (Mark Salter) [2076088]
- arm64: Document boot requirements for FEAT_SME_FA64 (Mark Salter) [2076088]
- arm64: ftrace: use function_nocfi for _mcount as well (Mark Salter) [2076088]
- arm64: asm: setup.h: export common variables (Mark Salter) [2076088]
- arm64/traps: Avoid unnecessary kernel/user pointer conversion (Mark Salter) [2076088]
- arm64/sve: Fix warnings when SVE is disabled (Mark Salter) [2076088]
- arm64/sve: Add stub for sve_max_virtualisable_vl() (Mark Salter) [2076088]
- arm64/sve: Track vector lengths for tasks in an array (Mark Salter) [2076088]
- arm64/sve: Explicitly load vector length when restoring SVE state (Mark Salter) [2076088]
- arm64/sve: Put system wide vector length information into structs (Mark Salter) [2076088]
- arm64/sve: Use accessor functions for vector lengths in thread_struct (Mark Salter) [2076088]
- arm64/sve: Rename find_supported_vector_length() (Mark Salter) [2076088]
- arm64/sve: Make access to FFR optional (Mark Salter) [2076088]
- arm64/sve: Make sve_state_size() static (Mark Salter) [2076088]
- arm64/sve: Remove sve_load_from_fpsimd_state() (Mark Salter) [2076088]
- arm64/fp: Reindent fpsimd_save() (Mark Salter) [2076088]
- selftests: arm64: Factor out utility functions for assembly FP tests (Mark Salter) [2076088]
- selftests: arm64: Add coverage of ptrace flags for SVE VL inheritance (Mark Salter) [2076088]
- selftests: arm64: Verify that all possible vector lengths are handled (Mark Salter) [2076088]
- selftests: arm64: Fix and enable test for setting current VL in vec-syscfg (Mark Salter) [2076088]
- selftests: arm64: Remove bogus error check on writing to files (Mark Salter) [2076088]
- selftests: arm64: Fix printf() format mismatch in vec-syscfg (Mark Salter) [2076088]
- selftests: arm64: Move FPSIMD in SVE ptrace test into a function (Mark Salter) [2076088]
- selftests: arm64: More comprehensively test the SVE ptrace interface (Mark Salter) [2076088]
- selftests: arm64: Verify interoperation of SVE and FPSIMD register sets (Mark Salter) [2076088]
- selftests: arm64: Clarify output when verifying SVE register set (Mark Salter) [2076088]
- selftests: arm64: Document what the SVE ptrace test is doing (Mark Salter) [2076088]
- selftests: arm64: Remove extraneous register setting code (Mark Salter) [2076088]
- selftests: arm64: Don't log child creation as a test in SVE ptrace test (Mark Salter) [2076088]
- selftests: arm64: Use a define for the number of SVE ptrace tests to be run (Mark Salter) [2076088]
- arm64: vmlinux.lds.S: remove `.fixup` section (Mark Salter) [2076088]
- arm64: extable: add load_unaligned_zeropad() handler (Mark Salter) [2076088]
- arm64: extable: add a dedicated uaccess handler (Mark Salter) [2076088]
- arm64: extable: add `type` and `data` fields (Mark Salter) [2076088]
- arm64: extable: use `ex` for `exception_table_entry` (Mark Salter) [2076088]
- arm64: extable: make fixup_exception() return bool (Mark Salter) [2076088]
- arm64: extable: consolidate definitions (Mark Salter) [2076088]
- arm64: gpr-num: support W registers (Mark Salter) [2076088]
- arm64: factor out GPR numbering helpers (Mark Salter) [2076088]
- arm64: kvm: use kvm_exception_table_entry (Mark Salter) [2076088]
- arm64: lib: __arch_copy_to_user(): fold fixups into body (Mark Salter) [2076088]
- arm64: lib: __arch_copy_from_user(): fold fixups into body (Mark Salter) [2076088]
- arm64: lib: __arch_clear_user(): fold fixups into body (Mark Salter) [2076088]
- arm64: vdso32: require CROSS_COMPILE_COMPAT for gcc+bfd (Mark Salter) [2076088]
- arm64: vdso32: suppress error message for 'make mrproper' (Mark Salter) [2076088]
- arm64: vdso32: drop test for -march=armv8-a (Mark Salter) [2076088]
- arm64: vdso32: drop the test for dmb ishld (Mark Salter) [2076088]
- arm64: Add a capability for FEAT_ECV (Mark Salter) [2076088]
- arm64: mte: Add asymmetric mode support (Mark Salter) [2076088]
- arm64: mte: CPU feature detection for Asymm MTE (Mark Salter) [2076088]
- arm64: mte: Bitfield definitions for Asymm MTE (Mark Salter) [2076088]
- arm64: kasan: mte: move GCR_EL1 switch to task switch when KASAN disabled (Mark Salter) [2076088]
- arm64/mm: drop HAVE_ARCH_PFN_VALID (Mark Salter) [2076088]
- arm64: trans_pgd: remove trans_pgd_map_page() (Mark Salter) [2076088]
- arm64: kexec: remove cpu-reset.h (Mark Salter) [2076088]
- arm64: kexec: remove the pre-kexec PoC maintenance (Mark Salter) [2076088]
- arm64: kexec: keep MMU enabled during kexec relocation (Mark Salter) [2076088]
- arm64: kexec: install a copy of the linear-map (Mark Salter) [2076088]
- arm64: kexec: use ld script for relocation function (Mark Salter) [2076088]
- arm64: kexec: relocate in EL1 mode (Mark Salter) [2076088]
- arm64: kexec: configure EL2 vectors for kexec (Mark Salter) [2076088]
- arm64: kexec: pass kimage as the only argument to relocation function (Mark Salter) [2076088]
- arm64: kexec: Use dcache ops macros instead of open-coding (Mark Salter) [2076088]
- arm64: kexec: skip relocation code for inplace kexec (Mark Salter) [2076088]
- arm64: kexec: flush image and lists during kexec load time (Mark Salter) [2076088]
- arm64: hibernate: abstract ttrb0 setup function (Mark Salter) [2076088]
- arm64: trans_pgd: hibernate: Add trans_pgd_copy_el2_vectors (Mark Salter) [2076088]
- arm64: kernel: add helper for booted at EL2 and not VHE (Mark Salter) [2076088]
- arm64: mm: update max_pfn after memory hotplug (Mark Salter) [2076088]
- arm64/mm: Add pud_sect_supported() (Mark Salter) [2076088]
- arm64: mm: Drop pointless call to set_max_mapnr() (Mark Salter) [2076088]
- arm64/hugetlb: fix CMA gigantic page order for non-4K PAGE_SIZE (Mark Salter) [2076088]
- kselftest/arm64: signal: Skip tests if required features are missing (Mark Salter) [2076088]
- arm64: Mitigate MTE issues with str{n}cmp() (Mark Salter) [2076088]
- arm64: add MTE supported check to thread switching and syscall entry/exit (Mark Salter) [2076088]
- arm64: Mark __stack_chk_guard as __ro_after_init (Mark Salter) [2076088]
- arm64/kernel: remove duplicate include in process.c (Mark Salter) [2076088]
- arm64/sve: Use correct size when reinitialising SVE state (Mark Salter) [2076088]
- arm64: remove GCC version check for ARCH_SUPPORTS_INT128 (Mark Salter) [2076088]
- arm64: mm: limit linear region to 51 bits for KVM in nVHE mode (Mark Salter) [2076088]
- arm64: mm: fix comment typo of pud_offset_phys() (Mark Salter) [2076088]
- arm64: signal32: Drop pointless call to sigdelsetmask() (Mark Salter) [2076088]
- arm64/sve: Better handle failure to allocate SVE register storage (Mark Salter) [2076088]
- arm64: Document the requirement for SCR_EL3.HCE (Mark Salter) [2076088]
- arm64: head: avoid over-mapping in map_memory (Mark Salter) [2076088]
- arm64/sve: Add a comment documenting the binutils needed for SVE asm (Mark Salter) [2076088]
- arm64/sve: Add some comments for sve_save/load_state() (Mark Salter) [2076088]
- arm64: replace in_irq() with in_hardirq() (Mark Salter) [2076088]
- arm64: mm: Fix TLBI vs ASID rollover (Mark Salter) [2076088]
- arm64: entry: Add SYM_CODE annotation for __bad_stack (Mark Salter) [2076088]
- arm64: fix typo in a comment (Mark Salter) [2076088]
- arm64: move the (z)install rules to arch/arm64/Makefile (Mark Salter) [2076088]
- arm64/sve: Make fpsimd_bind_task_to_cpu() static (Mark Salter) [2076088]
- arm64: unnecessary end 'return;' in void functions (Mark Salter) [2076088]
- arm64/sme: Document boot requirements for SME (Mark Salter) [2076088]
- arm64: use __func__ to get function name in pr_err (Mark Salter) [2076088]
- arm64: SSBS/DIT: print SSBS and DIT bit when printing PSTATE (Mark Salter) [2076088]
- arm64: cpufeature: Use defined macro instead of magic numbers (Mark Salter) [2076088]
- kselftest/arm64: signal: Add a TODO list for signal handling tests (Mark Salter) [2076088]
- kselftest/arm64: signal: Add test case for SVE register state in signals (Mark Salter) [2076088]
- kselftest/arm64: signal: Verify that signals can't change the SVE vector length (Mark Salter) [2076088]
- kselftest/arm64: signal: Check SVE signal frame shows expected vector length (Mark Salter) [2076088]
- kselftest/arm64: signal: Support signal frames with SVE register data (Mark Salter) [2076088]
- kselftest/arm64: signal: Add SVE to the set of features we can check for (Mark Salter) [2076088]
- kselftest/arm64: pac: Fix skipping of tests on systems without PAC (Mark Salter) [2076088]
- kselftest/arm64: mte: Fix misleading output when skipping tests (Mark Salter) [2076088]
- kselftest/arm64: Add a TODO list for floating point tests (Mark Salter) [2076088]
- kselftest/arm64: Add tests for SVE vector configuration (Mark Salter) [2076088]
- kselftest/arm64: Validate vector lengths are set in sve-probe-vls (Mark Salter) [2076088]
- kselftest/arm64: Provide a helper binary and "library" for SVE RDVL (Mark Salter) [2076088]
- kselftest/arm64: Ignore check_gcr_el1_cswitch binary (Mark Salter) [2076088]
- Documentation: arm64: describe asymmetric 32-bit support (Mark Salter) [2076088]
- arm64: Remove logic to kill 32-bit tasks on 64-bit-only cores (Mark Salter) [2076088]
- arm64: Hook up cmdline parameter to allow mismatched 32-bit EL0 (Mark Salter) [2076088]
- arm64: Advertise CPUs capable of running 32-bit applications in sysfs (Mark Salter) [2076088]
- arm64: Prevent offlining first CPU with 32-bit EL0 on mismatched system (Mark Salter) [2076088]
- arm64: exec: Adjust affinity for compat tasks with mismatched 32-bit EL0 (Mark Salter) [2076088]
- arm64: Implement task_cpu_possible_mask() (Mark Salter) [2076088]
- KVM: arm64: Add feature register flag definitions (Mark Salter) [2076088]
- arm64/perf: Replace '0xf' instances with ID_AA64DFR0_PMUVER_IMP_DEF (Mark Salter) [2076088]
- arm64: entry: call exit_to_user_mode() from C (Mark Salter) [2076088]
- arm64: entry: move bulk of ret_to_user to C (Mark Salter) [2076088]
- arm64: entry: clarify entry/exit helpers (Mark Salter) [2076088]
- arm64: entry: consolidate entry/exit helpers (Mark Salter) [2076088]
- arm64/cpufeature: Optionally disable MTE via command-line (Mark Salter) [2076088]
- arm64: kasan: mte: remove redundant mte_report_once logic (Mark Salter) [2076088]
- arm64: kasan: mte: use a constant kernel GCR_EL1 value (Mark Salter) [2076088]
- arm64: avoid double ISB on kernel entry (Mark Salter) [2076088]
- arm64: mte: optimize GCR_EL1 modification on kernel entry/exit (Mark Salter) [2076088]
- Documentation: document the preferred tag checking mode feature (Mark Salter) [2076088]
- arm64: mte: introduce a per-CPU tag checking mode preference (Mark Salter) [2076088]
- arm64: move preemption disablement to prctl handlers (Mark Salter) [2076088]
- arm64: mte: change ASYNC and SYNC TCF settings into bitfields (Mark Salter) [2076088]
- arm64: mte: rename gcr_user_excl to mte_ctrl (Mark Salter) [2076088]
- arm64: mte: avoid TFSRE0_EL1 related operations unless in async mode (Mark Salter) [2076088]
- arm64/kexec: Test page size support with new TGRAN range values (Mark Salter) [2076088]
- arm64: Add compile-time asserts for siginfo_t offsets (Mark Salter) [2076088]
- Kbuild: use -std=gnu11 for KBUILD_USERCFLAGS (Waiman Long) [2074118]
- Kbuild: move to -std=gnu11 (Waiman Long) [2074118]
- Kbuild: use -Wdeclaration-after-statement (Waiman Long) [2074118]
- Kbuild: add -Wno-shift-negative-value where -Wextra is used (Waiman Long) [2074118]
- kbuild: Add a comment above -Wno-gnu (Waiman Long) [2074118]
- kbuild: Remove -Wno-format-invalid-specifier from clang block (Waiman Long) [2074118]

* Wed Jun 29 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-120.rt21.120.el9]
- [rt] build kernel-rt-5.14.0-120.rt21.120.el9 [2061574]
- vmxnet3: disable overlay offloads if UPT device does not support (Kamal Heib) [2095826]
- vmxnet3: update to version 7 (Kamal Heib) [2095826]
- vmxnet3: use ext1 field to indicate encapsulated packet (Kamal Heib) [2095826]
- vmxnet3: limit number of TXDs used for TSO packet (Kamal Heib) [2095826]
- vmxnet3: add command to set ring buffer sizes (Kamal Heib) [2095826]
- vmxnet3: add support for out of order rx completion (Kamal Heib) [2095826]
- vmxnet3: add support for large passthrough BAR register (Kamal Heib) [2095826]
- vmxnet3: add support for capability registers (Kamal Heib) [2095826]
- vmxnet3: prepare for version 7 changes (Kamal Heib) [2095826]
- net: vmxnet3: fix possible NULL pointer dereference in vmxnet3_rq_cleanup() (Kamal Heib) [2095826]
- net: vmxnet3: fix possible use-after-free bugs in vmxnet3_rq_alloc_rx_buf() (Kamal Heib) [2095826]
- netfilter: nf_tables: sanitize nft_set_desc_concat_parse() (Florian Westphal) [2096402] {CVE-2022-2078}
- fanotify: Fix stale file descriptor in copy_event_to_user() (Andrey Albershteyn) [2100470] {CVE-2022-1998}
- scsi: mpi3mr: Fix kernel-doc (Tomas Henzl) [2091880]
- scsi: mpi3mr: Rework mrioc->bsg_device model to fix warnings (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add target device related sysfs attributes (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add shost related sysfs attributes (Tomas Henzl) [2091880]
- scsi: mpi3mr: Return error if dma_alloc_coherent() fails (Tomas Henzl) [2091880]
- scsi: mpi3mr: Fix a NULL vs IS_ERR() bug in mpi3mr_bsg_init() (Tomas Henzl) [2091880]
- scsi: mpi3mr: Return I/Os to an unrecoverable HBA with DID_ERROR (Tomas Henzl) [2091880]
- scsi: mpi3mr: Hidden drives not removed during soft reset (Tomas Henzl) [2091880]
- scsi: mpi3mr: Increase I/O timeout value to 60s (Tomas Henzl) [2091880]
- scsi: mpi3mr: Update driver version to 8.0.0.69.0 (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for NVMe passthrough (Tomas Henzl) [2091880]
- scsi: mpi3mr: Expose adapter state to sysfs (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for PEL commands (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for MPT commands (Tomas Henzl) [2091880]
- scsi: mpi3mr: Move data structures/definitions from MPI headers to uapi header (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add support for driver commands (Tomas Henzl) [2091880]
- scsi: mpi3mr: Add bsg device support (Tomas Henzl) [2091880]
- tcp: Don't acquire inet_listen_hashbucket::lock with disabled BH. (Paolo Abeni) [2090409]
- block/bfq: Enable I/O statistics (Ming Lei) [2083917]
- blk-mq: don't clear flush_rq from tags->rqs[] (Ming Lei) [2083917]
- blk-mq: avoid to touch q->elevator without any protection (Ming Lei) [2083917]
- blk-mq: protect q->elevator by ->sysfs_lock in blk_mq_elv_switch_none (Ming Lei) [2083917]
- md/raid5-ppl: Fix argument order in bio_alloc_bioset() (Ming Lei) [2083917]
- dm: fix bio length of empty flush (Ming Lei) [2083917]
- rhel: configs: add config option CONFIG_CRYPTO_CRC64* (Ming Lei) [2083917]
- rhel: configs: enable BLOCK_LEGACY_AUTOLOAD (Ming Lei) [2083917]
- bcache: put bch_bio_map() back to correct location in journal_write_unlocked() (Ming Lei) [2083917]
- bcache: fix wrong bdev parameter when calling bio_alloc_clone() in do_bio_hook() (Ming Lei) [2083917]
- block: null_blk: Fix null_zone_write() (Ming Lei) [2083917]
- nbd: use pr_err to output error message (Ming Lei) [2083917]
- nbd: fix possible overflow on 'first_minor' in nbd_dev_add() (Ming Lei) [2083917]
- nbd: fix io hung while disconnecting device (Ming Lei) [2083917]
- nbd: don't clear 'NBD_CMD_INFLIGHT' flag if request is not completed (Ming Lei) [2083917]
- nbd: fix race between nbd_alloc_config() and module removal (Ming Lei) [2083917]
- nbd: call genl_unregister_family() first in nbd_cleanup() (Ming Lei) [2083917]
- blk-mq: remove the done argument to blk_execute_rq_nowait (Ming Lei) [2083917]
- blk-mq: avoid a mess of casts for blk_end_sync_rq (Ming Lei) [2083917]
- blk-mq: remove __blk_execute_rq_nowait (Ming Lei) [2083917]
- block: Fix potential deadlock in blk_ia_range_sysfs_show() (Ming Lei) [2083917]
- block: fix bio_clone_blkg_association() to associate with proper blkcg_gq (Ming Lei) [2083917]
- block: remove useless BUG_ON() in blk_mq_put_tag() (Ming Lei) [2083917]
- blk-mq: do not update io_ticks with passthrough requests (Ming Lei) [2083917]
- block: make bioset_exit() fully resilient against being called twice (Ming Lei) [2083917]
- block: use bio_queue_enter instead of blk_queue_enter in bio_poll (Ming Lei) [2083917]
- block: document BLK_STS_AGAIN usage (Ming Lei) [2083917]
- block: take destination bvec offsets into account in bio_copy_data_iter (Ming Lei) [2083917]
- blk-iolatency: Fix inflight count imbalances and IO hangs on offline (Ming Lei) [2083917]
- blk-mq: don't touch ->tagset in blk_mq_get_sq_hctx (Ming Lei) [2083917]
- mtip32xx: fix typo in comment (Ming Lei) [2083917]
- nbd: Fix hung on disconnect request if socket is closed before (Ming Lei) [2083917]
- loop: remove most the top-of-file boilerplate comment from the UAPI header (Ming Lei) [2083917]
- loop: remove most the top-of-file boilerplate comment (Ming Lei) [2083917]
- loop: add a SPDX header (Ming Lei) [2083917]
- loop: remove loop.h (Ming Lei) [2083917]
- block: null_blk: Improve device creation with configfs (Ming Lei) [2083917]
- block: null_blk: Cleanup messages (Ming Lei) [2083917]
- block: null_blk: Cleanup device creation and deletion (Ming Lei) [2083917]
- block: null_blk: Fix code style issues (Ming Lei) [2083917]
- xen-blkback: use bdev_discard_alignment (Ming Lei) [2083917]
- rnbd-srv: use bdev_discard_alignment (Ming Lei) [2083917]
- nvme: remove a spurious clear of discard_alignment (Ming Lei) [2083917]
- loop: remove a spurious clear of discard_alignment (Ming Lei) [2083917]
- dasd: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- raid5: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- dm-zoned: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- virtio_blk: fix the discard_granularity and discard_alignment queue limits (Ming Lei) [2083917]
- null_blk: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- nbd: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- ubd: don't set the discard_alignment queue limit (Ming Lei) [2083917]
- aoe: Avoid flush_scheduled_work() usage (Ming Lei) [2083917]
- null-blk: save memory footprint for struct nullb_cmd (Ming Lei) [2083917]
- block/rnbd-clt: Avoid flush_workqueue(system_long_wq) usage (Ming Lei) [2083917]
- loop: don't destroy lo->workqueue in __loop_clr_fd (Ming Lei) [2083917]
- loop: remove lo_refcount and avoid lo_mutex in ->open / ->release (Ming Lei) [2083917]
- loop: avoid loop_validate_mutex/lo_mutex in ->release (Ming Lei) [2083917]
- loop: suppress uevents while reconfiguring the device (Ming Lei) [2083917]
- loop: implement ->free_disk (Ming Lei) [2083917]
- loop: only freeze the queue in __loop_clr_fd when needed (Ming Lei) [2083917]
- loop: don't freeze the queue in lo_release (Ming Lei) [2083917]
- loop: remove the racy bd_inode->i_mapping->nrpages asserts (Ming Lei) [2083917]
- loop: initialize the worker tracking fields once (Ming Lei) [2083917]
- loop: de-duplicate the idle worker freeing code (Ming Lei) [2083917]
- block: turn bdev->bd_openers into an atomic_t (Ming Lei) [2083917]
- block: add a disk_openers helper (Ming Lei) [2083917]
- zram: cleanup zram_remove (Ming Lei) [2083917]
- zram: cleanup reset_store (Ming Lei) [2083917]
- nbd: use the correct block_device in nbd_bdev_reset (Ming Lei) [2083917]
- drdb: Switch to kvfree_rcu() API (Ming Lei) [2083917]
- drbd: Replace "unsigned" with "unsigned int" (Ming Lei) [2083917]
- drbd: Make use of PFN_UP helper macro (Ming Lei) [2083917]
- block: drbd: drbd_receiver: Remove redundant assignment to err (Ming Lei) [2083917]
- drbd: address enum mismatch warnings (Ming Lei) [2083917]
- drbd: fix duplicate array initializer (Ming Lei) [2083917]
- blk-mq: fix typo in comment (Ming Lei) [2083917]
- bfq: Remove bfq_requeue_request_body() (Ming Lei) [2083917]
- bfq: Remove superfluous conversion from RQ_BIC() (Ming Lei) [2083917]
- bfq: Allow current waker to defend against a tentative one (Ming Lei) [2083917]
- bfq: Relax waker detection for shared queues (Ming Lei) [2083917]
- blk-cgroup: delete rcu_read_lock_held() WARN_ON_ONCE() (Ming Lei) [2083917]
- blk-throttle: Set BIO_THROTTLED when bio has been throttled (Ming Lei) [2083917]
- blk-cgroup: Remove unnecessary rcu_read_lock/unlock() (Ming Lei) [2083917]
- blk-cgroup: always terminate io.stat lines (Ming Lei) [2083917]
- block, bfq: make bfq_has_work() more accurate (Ming Lei) [2083917]
- block, bfq: protect 'bfqd->queued' by 'bfqd->lock' (Ming Lei) [2083917]
- block: cleanup the VM accounting in submit_bio (Ming Lei) [2083917]
- block: Fix the bio.bi_opf comment (Ming Lei) [2083917]
- block: reorder the REQ_ flags (Ming Lei) [2083917]
- blk-iocost: combine local_stat and desc_stat to stat (Ming Lei) [2083917]
- block: improve the error message from bio_check_eod (Ming Lei) [2083917]
- block: allow passing a NULL bdev to bio_alloc_clone/bio_init_clone (Ming Lei) [2083917]
- block: remove superfluous calls to blkcg_bio_issue_init (Ming Lei) [2083917]
- kthread: unexport kthread_blkcg (Ming Lei) [2083917]
- blk-cgroup: cleanup blkcg_maybe_throttle_current (Ming Lei) [2083917]
- blk-cgroup: cleanup blk_cgroup_congested (Ming Lei) [2083917]
- blk-cgroup: move blkcg_css to blk-cgroup.c (Ming Lei) [2083917]
- blk-cgroup: remove unneeded includes from <linux/blk-cgroup.h> (Ming Lei) [2083917]
- blk-cgroup: remove pointless CONFIG_BLOCK ifdefs (Ming Lei) [2083917]
- blk-cgroup: replace bio_blkcg with bio_blkcg_css (Ming Lei) [2083917]
- blktrace: cleanup the __trace_note_message interface (Ming Lei) [2083917]
- blk-cgroup: move struct blkcg to block/blk-cgroup.h (Ming Lei) [2083917]
- blk-cgroup: move blkcg_{pin,unpin}_online out of line (Ming Lei) [2083917]
- blk-cgroup: move blk_cgroup_congested out line (Ming Lei) [2083917]
- blk-cgroup: move blkcg_{get,set}_fc_appid out of line (Ming Lei) [2083917]
- nvme-fc: fold t fc_update_appid into fc_appid_store (Ming Lei) [2083917]
- nvme-fc: don't support the appid attribute without CONFIG_BLK_CGROUP_FC_APPID (Ming Lei) [2083917]
- blk-cgroup: remove __bio_blkcg (Ming Lei) [2083917]
- block/partitions/ldm: Remove redundant assignments (Ming Lei) [2083917]
- block/partitions/atari: Remove redundant assignment (Ming Lei) [2083917]
- block/partitions/acorn: Remove redundant assignments (Ming Lei) [2083917]
- block/blk-map: Remove redundant assignment (Ming Lei) [2083917]
- block/badblocks: Remove redundant assignments (Ming Lei) [2083917]
- block: change exported IO accounting interface from gendisk to bdev (Ming Lei) [2083917]
- direct-io: remove random prefetches (Ming Lei) [2083917]
- block: decouple REQ_OP_SECURE_ERASE from REQ_OP_DISCARD (Ming Lei) [2083917]
- block: add a bdev_discard_granularity helper (Ming Lei) [2083917]
- block: remove QUEUE_FLAG_DISCARD (Ming Lei) [2083917]
- block: add a bdev_max_discard_sectors helper (Ming Lei) [2083917]
- block: refactor discard bio size limiting (Ming Lei) [2083917]
- block: move {bdev,queue_limit}_discard_alignment out of line (Ming Lei) [2083917]
- block: use bdev_discard_alignment in part_discard_alignment_show (Ming Lei) [2083917]
- block: remove queue_discard_alignment (Ming Lei) [2083917]
- block: move bdev_alignment_offset and queue_limit_alignment_offset out of line (Ming Lei) [2083917]
- block: use bdev_alignment_offset in disk_alignment_offset_show (Ming Lei) [2083917]
- block: use bdev_alignment_offset in part_alignment_offset_show (Ming Lei) [2083917]
- block: add a bdev_max_zone_append_sectors helper (Ming Lei) [2083917]
- block: add a bdev_stable_writes helper (Ming Lei) [2083917]
- block: add a bdev_fua helper (Ming Lei) [2083917]
- block: add a bdev_write_cache helper (Ming Lei) [2083917]
- block: add a bdev_nonrot helper (Ming Lei) [2083917]
- mm: use bdev_is_zoned in claim_swapfile (Ming Lei) [2083917]
- drbd: cleanup decide_on_discard_support (Ming Lei) [2083917]
- drbd: use bdev_alignment_offset instead of queue_alignment_offset (Ming Lei) [2083917]
- drbd: use bdev based limit helpers in drbd_send_sizes (Ming Lei) [2083917]
- drbd: remove assign_p_sizes_qlim (Ming Lei) [2083917]
- target: fix discard alignment on partitions (Ming Lei) [2083917]
- target: pass a block_device to target_configure_unmap_from_queue (Ming Lei) [2083917]
- target: remove an incorrect unmap zeroes data deduction (Ming Lei) [2083917]
- bfq: Make sure bfqg for which we are queueing requests is online (Ming Lei) [2083917]
- bfq: Get rid of __bio_blkcg() usage (Ming Lei) [2083917]
- bfq: Track whether bfq_group is still online (Ming Lei) [2083917]
- bfq: Remove pointless bfq_init_rq() calls (Ming Lei) [2083917]
- bfq: Drop pointless unlock-lock pair (Ming Lei) [2083917]
- bfq: Update cgroup information before merging bio (Ming Lei) [2083917]
- bfq: Split shared queues on move between cgroups (Ming Lei) [2083917]
- bfq: Avoid merging queues with different parents (Ming Lei) [2083917]
- bfq: Avoid false marking of bic as stably merged (Ming Lei) [2083917]
- pktcdvd: stop using bio_reset (Ming Lei) [2083917]
- block: turn bio_kmalloc into a simple kmalloc wrapper (Ming Lei) [2083917]
- target/pscsi: remove pscsi_get_bio (Ming Lei) [2083917]
- squashfs: always use bio_kmalloc in squashfs_bio_read (Ming Lei) [2083917]
- block: allow use of per-cpu bio alloc cache by block drivers (Ming Lei) [2083917]
- block: allow using the per-cpu bio cache from bio_alloc_bioset (Ming Lei) [2083917]
- blk-mq: fix passthrough plugging (Ming Lei) [2083917]
- block: wire-up support for passthrough plugging (Ming Lei) [2083917]
- scsi: block: Remove REQ_OP_WRITE_SAME support (Ming Lei) [2083917]
- scsi: dm: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: md: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: sd: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: rnbd: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: drbd: Remove WRITE_SAME support (Ming Lei) [2083917]
- scsi: cxlflash: Query write_zeroes limit for zeroing (Ming Lei) [2083917]
- block/mq-deadline: Set the fifo_time member also if inserting at head (Ming Lei) [2083917]
- Revert "block: release rq qos structures for queue without disk" (Ming Lei) [2083917]
- bfq: Fix warning in bfqq_request_over_limit() (Ming Lei) [2083917]
- Revert "block: inherit request start time from bio for BLK_CGROUP" (Ming Lei) [2083917]
- iocost: don't reset the inuse weight of under-weighted debtors (Ming Lei) [2083917]
- block: don't print I/O error warning for dead disks (Ming Lei) [2083917]
- block/compat_ioctl: fix range check in BLKGETSIZE (Ming Lei) [2083917]
- block: null_blk: end timed out poll request (Ming Lei) [2083917]
- block: fix offset/size check in bio_trim() (Ming Lei) [2083917]
- asm-generic: fix __get_unaligned_be48() on 32 bit platforms (Ming Lei) [2083917]
- block: move lower_48_bits() to block (Ming Lei) [2083917]
- drbd: set QUEUE_FLAG_STABLE_WRITES (Ming Lei) [2083917]
- drbd: fix an invalid memory access caused by incorrect use of list iterator (Ming Lei) [2083917]
- drbd: Fix five use after free bugs in get_initial_state (Ming Lei) [2083917]
- cdrom: remove unused variable (Ming Lei) [2083917]
- Revert "nbd: fix possible overflow on 'first_minor' in nbd_dev_add()" (Ming Lei) [2083917]
- drbd: remove check of list iterator against head past the loop body (Ming Lei) [2083917]
- drbd: remove usage of list iterator variable after loop (Ming Lei) [2083917]
- nbd: fix possible overflow on 'first_minor' in nbd_dev_add() (Ming Lei) [2083917]
- MAINTAINERS: add drbd co-maintainer (Ming Lei) [2083917]
- drbd: fix potential silent data corruption (Ming Lei) [2083917]
- loop: fix ioctl calls using compat_loop_info (Ming Lei) [2083917]
- n64cart: convert bi_disk to bi_bdev->bd_disk fix build (Ming Lei) [2083917]
- blk-wbt: remove wbt_track stub (Ming Lei) [2083917]
- block: use dedicated list iterator variable (Ming Lei) [2083917]
- block: Fix the maximum minor value is blk_alloc_ext_minor() (Ming Lei) [2083917]
- block: avoid calling blkg_free() in atomic context (Ming Lei) [2083917]
- crypto: fix crc64 testmgr digest byte order (Ming Lei) [2083917]
- nvme: add support for enhanced metadata (Ming Lei) [2083917]
- block: add pi for extended integrity (Ming Lei) [2083917]
- crypto: add rocksoft 64b crc guard tag framework (Ming Lei) [2083917]
- lib: add rocksoft model crc64 (Ming Lei) [2083917]
- linux/kernel: introduce lower_48_bits function (Ming Lei) [2083917]
- asm-generic: introduce be48 unaligned accessors (Ming Lei) [2083917]
- nvme: allow integrity on extended metadata formats (Ming Lei) [2083917]
- block: support pi with extended metadata (Ming Lei) [2083917]
- fs: do not pass __GFP_HIGHMEM to bio_alloc in do_mpage_readpage (Ming Lei) [2083917]
- f2fs: pass the bio operation to bio_alloc_bioset (Ming Lei) [2083917]
- f2fs: don't pass a bio to f2fs_target_device (Ming Lei) [2083917]
- nilfs2: pass the operation to bio_alloc (Ming Lei) [2083917]
- ext4: pass the operation to bio_alloc (Ming Lei) [2083917]
- mpage: pass the operation to bio_alloc (Ming Lei) [2083917]
- virtio_blk: eliminate anonymous module_init & module_exit (Ming Lei) [2083917]
- floppy: use memcpy_{to,from}_bvec (Ming Lei) [2083917]
- drbd: use bvec_kmap_local in recv_dless_read (Ming Lei) [2083917]
- drbd: use bvec_kmap_local in drbd_csum_bio (Ming Lei) [2083917]
- bcache: use bvec_kmap_local in bio_csum (Ming Lei) [2083917]
- nvdimm-btt: use bvec_kmap_local in btt_rw_integrity (Ming Lei) [2083917]
- nvdimm-blk: use bvec_kmap_local in nd_blk_rw_integrity (Ming Lei) [2083917]
- zram: use memcpy_from_bvec in zram_bvec_write (Ming Lei) [2083917]
- zram: use memcpy_to_bvec in zram_bvec_read (Ming Lei) [2083917]
- aoe: use bvec_kmap_local in bvcpy (Ming Lei) [2083917]
- iss-simdisk: use bvec_kmap_local in simdisk_submit_bio (Ming Lei) [2083917]
- null_blk: null_alloc_page() cleanup (Ming Lei) [2083917]
- null_blk: remove hardcoded null_alloc_page() param (Ming Lei) [2083917]
- null_blk: remove hardcoded alloc_cmd() parameter (Ming Lei) [2083917]
- loop: allow user to set the queue depth (Ming Lei) [2083917]
- loop: remove extra variable in lo_req_flush (Ming Lei) [2083917]
- loop: remove extra variable in lo_fallocate() (Ming Lei) [2083917]
- loop: use sysfs_emit() in the sysfs xxx show() (Ming Lei) [2083917]
- null_blk: fix return value from null_add_dev() (Ming Lei) [2083917]
- loop: clean up grammar in warning message (Ming Lei) [2083917]
- block/rnbd: Remove a useless mutex (Ming Lei) [2083917]
- block/rnbd: client device does not care queue/rotational (Ming Lei) [2083917]
- block/rnbd-clt: fix CHECK:BRACES warning (Ming Lei) [2083917]
- block: cancel all throttled bios in del_gendisk() (Ming Lei) [2083917]
- block: let blkcg_gq grab request queue's refcnt (Ming Lei) [2083917]
- block: avoid use-after-free on throttle data (Ming Lei) [2083917]
- block/bfq-iosched: Fix spelling mistake "tenative" -> "tentative" (Ming Lei) [2083917]
- sr: simplify the local variable initialization in sr_block_open() (Ming Lei) [2083917]
- block: don't merge across cgroup boundaries if blkcg is enabled (Ming Lei) [2083917]
- block: move rq_qos_exit() into disk_release() (Ming Lei) [2083917]
- block: do more work in elevator_exit (Ming Lei) [2083917]
- block: move blk_exit_queue into disk_release (Ming Lei) [2083917]
- block: move q_usage_counter release into blk_queue_release (Ming Lei) [2083917]
- block: don't remove hctx debugfs dir from blk_mq_exit_queue (Ming Lei) [2083917]
- block: move blkcg initialization/destroy into disk allocation/release handler (Ming Lei) [2083917]
- sr: implement ->free_disk to simplify refcounting (Ming Lei) [2083917]
- sd: implement ->free_disk to simplify refcounting (Ming Lei) [2083917]
- blk-mq: handle already freed tags gracefully in blk_mq_free_rqs (Ming Lei) [2083917]
- blk-mq: do not include passthrough requests in I/O accounting (Ming Lei) [2083917]
- blk-mq: manage hctx map via xarray (Ming Lei) [2083917]
- blk-mq: prepare for implementing hctx table via xarray (Ming Lei) [2083917]
- block: mtip32xx: don't touch q->queue_hw_ctx (Ming Lei) [2083917]
- blk-mq: reconfigure poll after queue map is changed (Ming Lei) [2083917]
- blk-mq: simplify reallocation of hw ctxs a bit (Ming Lei) [2083917]
- blk-mq: figure out correct numa node for hw queue (Ming Lei) [2083917]
- Revert "Revert "block, bfq: honor already-setup queue merges"" (Ming Lei) [2083917]
- block: remove bio_devname (Ming Lei) [2083917]
- raid5-ppl: stop using bio_devname (Ming Lei) [2083917]
- raid1: stop using bio_devname (Ming Lei) [2083917]
- md-multipath: stop using bio_devname (Ming Lei) [2083917]
- dm-integrity: stop using bio_devname (Ming Lei) [2083917]
- dm-crypt: stop using bio_devname (Ming Lei) [2083917]
- pktcdvd: remove a pointless debug check in pkt_submit_bio (Ming Lei) [2083917]
- block: remove handle_bad_sector (Ming Lei) [2083917]
- block: fix and cleanup bio_check_ro (Ming Lei) [2083917]
- bfq: fix use-after-free in bfq_dispatch_request (Ming Lei) [2083917]
- blk-crypto: show crypto capabilities in sysfs (Ming Lei) [2083917]
- block: don't delete queue kobject before its children (Ming Lei) [2083917]
- block: simplify calling convention of elv_unregister_queue() (Ming Lei) [2083917]
- block: remove redundant semicolon (Ming Lei) [2083917]
- block: default BLOCK_LEGACY_AUTOLOAD to y (Ming Lei) [2083917]
- block, bfq: don't move oom_bfqq (Ming Lei) [2083917]
- block, bfq: avoid moving bfqq to it's parent bfqg (Ming Lei) [2083917]
- block, bfq: cleanup bfq_bfqq_to_bfqg() (Ming Lei) [2083917]
- block/bfq_wf2q: correct weight to ioprio (Ming Lei) [2083917]
- blk-mq: avoid extending delays of active hctx from blk_mq_delay_run_hw_queues (Ming Lei) [2083917]
- virtio_blk: simplify refcounting (Ming Lei) [2083917]
- memstick/mspro_block: simplify refcounting (Ming Lei) [2083917]
- memstick/mspro_block: fix handling of read-only devices (Ming Lei) [2083917]
- memstick/ms_block: simplify refcounting (Ming Lei) [2083917]
- block: add a ->free_disk method (Ming Lei) [2083917]
- block: revert 4f1e9630afe6 ("blk-throtl: optimize IOPS throttle for large IO scenarios") (Ming Lei) [2083917]
- block: don't try to throttle split bio if iops limit isn't set (Ming Lei) [2083917]
- block: throttle split bio in case of iops limit (Ming Lei) [2083917]
- block: merge submit_bio_checks() into submit_bio_noacct (Ming Lei) [2083917]
- block: don't check bio in blk_throtl_dispatch_work_fn (Ming Lei) [2083917]
- block: don't declare submit_bio_checks in local header (Ming Lei) [2083917]
- block: move blk_crypto_bio_prep() out of blk-mq.c (Ming Lei) [2083917]
- block: move submit_bio_checks() into submit_bio_noacct (Ming Lei) [2083917]
- dm: remove dm_dispatch_clone_request (Ming Lei) [2083917]
- dm: remove useless code from dm_dispatch_clone_request (Ming Lei) [2083917]
- blk-mq: remove the request_queue argument to blk_insert_cloned_request (Ming Lei) [2083917]
- blk-mq: fold blk_cloned_rq_check_limits into blk_insert_cloned_request (Ming Lei) [2083917]
- blk-mq: make the blk-mq stacking code optional (Ming Lei) [2083917]
- blk-cgroup: set blkg iostat after percpu stat aggregation (Ming Lei) [2083917]
- blk-lib: don't check bdev_get_queue() NULL check (Ming Lei) [2083917]
- block: remove biodoc.rst (Ming Lei) [2083917]
- docs: block: biodoc.rst: Drop the obsolete and incorrect content (Ming Lei) [2083917]
- block: partition include/linux/blk-cgroup.h (Ming Lei) [2083917]
- block: move initialization of q->blkg_list into blkcg_init_queue (Ming Lei) [2083917]
- block: remove THROTL_IOPS_MAX (Ming Lei) [2083917]
- block: introduce block_rq_error tracepoint (Ming Lei) [2083917]
- sbitmap: Delete old sbitmap_queue_get_shallow() (Ming Lei) [2083917]
- block: pass a block_device to bio_clone_fast (Ming Lei) [2083917]
- block: initialize the target bio in __bio_clone_fast (Ming Lei) [2083917]
- dm: use bio_clone_fast in alloc_io/alloc_tio (Ming Lei) [2083917]
- block: clone crypto and integrity data in __bio_clone_fast (Ming Lei) [2083917]
- dm-cache: remove __remap_to_origin_clear_discard (Ming Lei) [2083917]
- dm: simplify the single bio fast path in __send_duplicate_bios (Ming Lei) [2083917]
- dm: retun the clone bio from alloc_tio (Ming Lei) [2083917]
- dm: pass the bio instead of tio to __map_bio (Ming Lei) [2083917]
- dm: move cloning the bio into alloc_tio (Ming Lei) [2083917]
- dm: fold __send_duplicate_bios into __clone_and_map_simple_bio (Ming Lei) [2083917]
- dm: fold clone_bio into __clone_and_map_data_bio (Ming Lei) [2083917]
- dm: add a clone_to_tio helper (Ming Lei) [2083917]
- drbd: set ->bi_bdev in drbd_req_new (Ming Lei) [2083917]
- block: call bio_associate_blkg from bio_reset (Ming Lei) [2083917]
- scsi: use BLK_STS_OFFLINE for not fully online devices (Ming Lei) [2083917]
- block: return -ENODEV for BLK_STS_OFFLINE (Ming Lei) [2083917]
- block: introduce BLK_STS_OFFLINE (Ming Lei) [2083917]
- block: fix boolreturn.cocci warning (Ming Lei) [2083917]
- MAINTAINERS: add bio.h to the block section (Ming Lei) [2083917]
- block: fix the kerneldoc for bio_end_io_acct (Ming Lei) [2083917]
- block: check that there is a plug in blk_flush_plug (Ming Lei) [2083917]
- block: remove blk_needs_flush_plug (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_reset (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_init (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_alloc (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_alloc_kiocb (Ming Lei) [2083917]
- block: pass a block_device and opf to bio_alloc_bioset (Ming Lei) [2083917]
- block: pass a block_device and opf to blk_next_bio (Ming Lei) [2083917]
- block: move blk_next_bio to bio.c (Ming Lei) [2083917]
- xen-blkback: bio_alloc can't fail if it is allow to sleep (Ming Lei) [2083917]
- rnbd-srv: remove struct rnbd_dev_blk_io (Ming Lei) [2083917]
- rnbd-srv: simplify bio mapping in process_rdma (Ming Lei) [2083917]
- drbd: bio_alloc can't fail if it is allow to sleep (Ming Lei) [2083917]
- dm-thin: use blkdev_issue_flush instead of open coding it (Ming Lei) [2083917]
- dm-snap: use blkdev_issue_flush instead of open coding it (Ming Lei) [2083917]
- dm-crypt: remove clone_init (Ming Lei) [2083917]
- dm: bio_alloc can't fail if it is allowed to sleep (Ming Lei) [2083917]
- nfs/blocklayout: remove bl_alloc_init_bio (Ming Lei) [2083917]
- nilfs2: remove nilfs_alloc_seg_bio (Ming Lei) [2083917]
- fs: remove mpage_alloc (Ming Lei) [2083917]
- block: remove genhd.h (Ming Lei) [2083917]
- block: move blk_drop_partitions to blk.h (Ming Lei) [2083917]
- block: move disk_{block,unblock,flush}_events to blk.h (Ming Lei) [2083917]
- block: deprecate autoloading based on dev_t (Ming Lei) [2083917]
- zram_drv: allow reclaim on bio_alloc (Ming Lei) [2083917]
- block: Add bio_for_each_folio_all() (Ming Lei) [2083917]
- block: Add bio_add_folio() (Ming Lei) [2083917]
- [s390] s390/zcrypt: Filter admin CPRBs on custom devices (Mete Durlu) [2076921]
- [s390] s390/zcrypt: CCA control CPRB sending (Mete Durlu) [2076921]
- [s390] s390/zcrypt: Add admask to zcdn (Mete Durlu) [2076921]
- ntb: intel: fix port config status offset for SPR (John W. Linville) [2048751]
- NTB/msi: Use struct_size() helper in devm_kzalloc() (John W. Linville) [2048751]
- ntb_hw_switchtec: Fix a minor issue in config_req_id_table() (John W. Linville) [2048751]
- ntb_hw_switchtec: Remove code for disabling ID protection (John W. Linville) [2048751]
- ntb_hw_switchtec: Update the way of getting VEP instance ID (John W. Linville) [2048751]
- ntb_hw_switchtec: AND with the part_map for a valid tpart_vec (John W. Linville) [2048751]
- ntb_hw_switchtec: Fix bug with more than 32 partitions (John W. Linville) [2048751]
- ntb_hw_switchtec: Fix pff ioread to read into mmio_part_cfg_all (John W. Linville) [2048751]
- ntb_hw_switchtec: fix the spelling of "its" (John W. Linville) [2048751]
- NTB/msi: Fix ntbm_msi_request_threaded_irq() kernel-doc comment (John W. Linville) [2048751]
- ntb_hw_amd: Add NTB PCI ID for new gen CPU (John W. Linville) [2048751]
- NTB: switch from 'pci_' to 'dma_' API (John W. Linville) [2048751]
- ntb: ntb_pingpong: remove redundant initialization of variables msg_data and spad_data (John W. Linville) [2048751]
- NTB: perf: Fix an error code in perf_setup_inbuf() (John W. Linville) [2048751]
- NTB: Fix an error code in ntb_msit_probe() (John W. Linville) [2048751]
- ntb: intel: remove invalid email address in header comment (John W. Linville) [2048751]
- redhat: spec: trigger dracut when modules are installed separately (Jan Stancek) [2062518]

* Fri Jun 24 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-119.rt21.119.el9]
- [rt] build kernel-rt-5.14.0-119.rt21.119.el9 [2061574]
- revert bus: Make remove callback return void (Steve Best) [2097921]
- [s390] s390/ism: switch from 'pci_' to 'dma_' API (Tobias Huschle) [2044294]
- [s390] net/smc: Fix sock leak when release after smc_shutdown() (Tobias Huschle) [2044294]
- [s390] net/smc: Fix af_ops of child socket pointing to released memory (Tobias Huschle) [2044294]
- [s390] net/smc: Fix NULL pointer dereference in smc_pnet_find_ib() (Tobias Huschle) [2044294]
- [s390] net/smc: use memcpy instead of snprintf to avoid out of bounds read (Tobias Huschle) [2044294]
- [s390] net/smc: Send out the remaining data in sndbuf before close (Tobias Huschle) [2044294]
- [s390] net/smc: fix a memory leak in smc_sysctl_net_exit() (Tobias Huschle) [2044294]
- [s390] net/smc: fix -Wmissing-prototypes warning when CONFIG_SYSCTL not set (Tobias Huschle) [2044294]
- [s390] net/smc: fix compile warning for smc_sysctl (Tobias Huschle) [2044294]
- [s390] Revert "net/smc: don't req_notify until all CQEs drained" (Tobias Huschle) [2044294]
- [s390] net/smc: fix unexpected SMC_CLC_DECL_ERR_REGRMB error cause by server (Tobias Huschle) [2044294]
- [s390] net/smc: fix unexpected SMC_CLC_DECL_ERR_REGRMB error generated by client (Tobias Huschle) [2044294]
- [s390] net: smc: fix different types in min() (Tobias Huschle) [2044294]
- [s390] net/smc: don't send in the BH context if sock_owned_by_user (Tobias Huschle) [2044294]
- [s390] net/smc: don't req_notify until all CQEs drained (Tobias Huschle) [2044294]
- [s390] net/smc: correct settings of RMB window update limit (Tobias Huschle) [2044294]
- [s390] net/smc: send directly on setting TCP_NODELAY (Tobias Huschle) [2044294]
- [s390] net/smc: add sysctl for autocorking (Tobias Huschle) [2044294]
- [s390] net/smc: add autocorking support (Tobias Huschle) [2044294]
- [s390] net/smc: add sysctl interface for SMC (Tobias Huschle) [2044294]
- [s390] net/smc: Call trace_smc_tx_sendmsg when data corked (Tobias Huschle) [2044294]
- [s390] net/smc: Fix cleanup when register ULP fails (Tobias Huschle) [2044294]
- [s390] net/smc: fix connection leak (Tobias Huschle) [2044294]
- [s390] net/smc: Use a mutex for locking "struct smc_pnettable" (Tobias Huschle) [2044294]
- [s390] net/smc: unlock on error paths in __smc_setsockopt() (Tobias Huschle) [2044294]
- [s390] net/smc: return ETIMEDOUT when smc_connect_clc() timeout (Tobias Huschle) [2044294]
- [s390] net/smc: Add comment for smc_tx_pending (Tobias Huschle) [2044294]
- [s390] net/smc: Add global configure for handshake limitation by netlink (Tobias Huschle) [2044294]
- [s390] net/smc: Dynamic control handshake limitation by socket options (Tobias Huschle) [2044294]
- [s390] net/smc: Limit SMC visits when handshake workqueue congested (Tobias Huschle) [2044294]
- [s390] net/smc: Limit backlog connections (Tobias Huschle) [2044294]
- [s390] net/smc: Make smc_tcp_listen_work() independent (Tobias Huschle) [2044294]
- [s390] net/smc: Avoid overwriting the copies of clcsock callback functions (Tobias Huschle) [2044294]
- [s390] Partially revert "net/smc: Add netlink net namespace support" (Tobias Huschle) [2044294]
- [s390] net/smc: Cork when sendpage with MSG_SENDPAGE_NOTLAST flag (Tobias Huschle) [2044294]
- [s390] net/smc: Remove corked dealyed work (Tobias Huschle) [2044294]
- [s390] net/smc: Send directly when TCP_CORK is cleared (Tobias Huschle) [2044294]
- [s390] net/smc: Forward wakeup to smc socket waitqueue after fallback (Tobias Huschle) [2044294]
- [s390] net/smc: Transitional solution for clcsock race issue (Tobias Huschle) [2044294]
- [s390] net/smc: Fix hung_task when removing SMC-R devices (Tobias Huschle) [2044294]
- [s390] net/smc: Remove unused function declaration (Tobias Huschle) [2044294]
- [s390] net/smc: Resolve the race between SMC-R link access and clear (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce a new conn->lgr validity check helper (Tobias Huschle) [2044294]
- [s390] net/smc: Resolve the race between link group access and termination (Tobias Huschle) [2044294]
- [s390] net/smc: Reset conn->lgr when link group registration fails (Tobias Huschle) [2044294]
- [s390] net/smc: add comments for smc_link_{usable|sendable} (Tobias Huschle) [2044294]
- [s390] net/smc: remove redundant re-assignment of pointer link (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce TCP ULP support (Tobias Huschle) [2044294]
- [s390] net/smc: Add net namespace for tracepoints (Tobias Huschle) [2044294]
- [s390] net/smc: Print net namespace in log (Tobias Huschle) [2044294]
- [s390] net/smc: Add netlink net namespace support (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce net namespace support for linkgroup (Tobias Huschle) [2044294]
- [s390] net/smc: Use the bitmap API when applicable (Tobias Huschle) [2044294]
- [s390] net/smc: fix kernel panic caused by race of smc_sock (Tobias Huschle) [2044294]
- [s390] net/smc: don't send CDC/LLC message if link not ready (Tobias Huschle) [2044294]
- [s390] net/smc: fix using of uninitialized completions (Tobias Huschle) [2044294]
- [s390] net/smc: Prevent smc_release() from long blocking (Tobias Huschle) [2044294]
- [s390] net/smc: Clear memory when release and reuse buffer (Tobias Huschle) [2044294]
- [s390] net/smc: Keep smc_close_final rc during active close (Tobias Huschle) [2044294]
- [s390] net/smc: fix wrong list_del in smc_lgr_cleanup_early (Tobias Huschle) [2044294]
- [s390] net/smc: Don't call clcsock shutdown twice when smc shutdown (Tobias Huschle) [2044294]
- [s390] net/smc: Fix loop in smc_listen (Tobias Huschle) [2044294]
- [s390] net/smc: Fix NULL pointer dereferencing in smc_vlan_by_tcpsk() (Tobias Huschle) [2044294]
- [s390] net/smc: Ensure the active closing peer first closes clcsock (Tobias Huschle) [2044294]
- [s390] net/smc: Clean up local struct sock variables (Tobias Huschle) [2044294]
- [s390] net/smc: Avoid warning of possible recursive locking (Tobias Huschle) [2044294]
- [s390] net/smc: Make sure the link_id is unique (Tobias Huschle) [2044294]
- [s390] net/smc: Transfer remaining wait queue entries during fallback (Tobias Huschle) [2044294]
- [s390] net/smc: fix sk_refcnt underflow on linkdown and fallback (Tobias Huschle) [2044294]
- [s390] net/smc: Print function name in smcr_link_down tracepoint (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce tracepoint for smcr link down (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce tracepoints for tx and rx msg (Tobias Huschle) [2044294]
- [s390] net/smc: Introduce tracepoint for fallback (Tobias Huschle) [2044294]
- [s390] net/smc: Correct spelling mistake to TCPF_SYN_RECV (Tobias Huschle) [2044294]
- [s390] net/smc: Fix smc_link->llc_testlink_time overflow (Tobias Huschle) [2044294]
- [s390] net/smc: stop links when their GID is removed (Tobias Huschle) [2044294]
- [s390] net/smc: add netlink support for SMC-Rv2 (Tobias Huschle) [2044294]
- [s390] net/smc: extend LLC layer for SMC-Rv2 (Tobias Huschle) [2044294]
- [s390] net/smc: add v2 support to the work request layer (Tobias Huschle) [2044294]
- [s390] net/smc: retrieve v2 gid from IB device (Tobias Huschle) [2044294]
- [s390] net/smc: add v2 format of CLC decline message (Tobias Huschle) [2044294]
- [s390] net/smc: add listen processing for SMC-Rv2 (Tobias Huschle) [2044294]
- [s390] net/smc: add SMC-Rv2 connection establishment (Tobias Huschle) [2044294]
- [s390] net/smc: prepare for SMC-Rv2 connection (Tobias Huschle) [2044294]
- [s390] net/smc: save stack space and allocate smc_init_info (Tobias Huschle) [2044294]
- [s390] net/smc: add generic netlink support for system EID (Tobias Huschle) [2044294]
- [s390] net/smc: keep static copy of system EID (Tobias Huschle) [2044294]
- [s390] net/smc: add support for user defined EIDs (Tobias Huschle) [2044294]
- [s390] net/smc: Allow SMC-D 1MB DMB allocations (Tobias Huschle) [2044294]
- revert bus: Make remove callback return void (Steve Best) [2096865]
- mt76: mt7921: Fix the error handling path of mt7921_pci_probe() (Íñigo Huguet) [2096777]
- redhat/configs: Add CONFIG_S390_UV_UAPI (Claudio Imbrenda) [2001936]
- [s390] s390/uv_uapi: depend on CONFIG_S390 (Claudio Imbrenda) [2001936]
- [s390] drivers/s390/char: Add Ultravisor io device (Claudio Imbrenda) [2001936]
- tg3: Remove redundant assignments (Ken Cox) [2043793]
- ethernet: Remove redundant statement (Ken Cox) [2043793]
- ethernet: tg3: remove direct netdev->dev_addr writes (Ken Cox) [2043793]
- net: tg3: fix redundant check of true expression (Ken Cox) [2043793]
- net: tg3: fix obsolete check of !err (Ken Cox) [2043793]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2043793]
- net: broadcom: switch from 'pci_' to 'dma_' API (Ken Cox) [2043793]
- powerpc/doc: Fix htmldocs errors (Gustavo Walbon) [1873825]
- powerpc/pseries: Add support for FORM2 associativity (Gustavo Walbon) [1873825]
- powerpc/pseries: Consolidate different NUMA distance update code paths (Gustavo Walbon) [1873825]
- powerpc/pseries: Rename TYPE1_AFFINITY to FORM1_AFFINITY (Gustavo Walbon) [1873825]
- powerpc/pseries: rename min_common_depth to primary_domain_index (Gustavo Walbon) [1873825]
- powerpc/pseries: Add a helper for form1 cpu distance (Gustavo Walbon) [1873825]
- config: wireless: MT7921U=n (Íñigo Huguet) [2059999]
- rfkill: uapi: fix RFKILL_IOCTL_MAX_SIZE ioctl request definition (Íñigo Huguet) [2059999]
- nl80211: fix locking in nl80211_set_tx_bitrate_mask() (Íñigo Huguet) [2059999]
- mac80211_hwsim: call ieee80211_tx_prepare_skb under RCU protection (Íñigo Huguet) [2059999]
- mac80211_hwsim: fix RCU protected chanctx access (Íñigo Huguet) [2059999]
- mac80211: Reset MBSSID parameters upon connection (Íñigo Huguet) [2059999]
- cfg80211: retrieve S1G operating channel number (Íñigo Huguet) [2059999]
- nl80211: validate S1G channel width (Íñigo Huguet) [2059999]
- mac80211: fix rx reordering with non explicit / psmp ack policy (Íñigo Huguet) [2059999]
- ath11k: reduce the wait time of 11d scan and hw scan while add interface (Íñigo Huguet) [2059999]
- iwlwifi: iwl-dbg: Use del_timer_sync() before freeing (Íñigo Huguet) [2059999]
- bus: mhi: host: pci_generic: Flush recovery worker during freeze (Íñigo Huguet) [2059999]
- bus: mhi: host: pci_generic: Add missing poweroff() PM callback (Íñigo Huguet) [2059999]
- mac80211: fix ht_capa printout in debugfs (Íñigo Huguet) [2059999]
- cfg80211: hold bss_lock while updating nontrans_list (Íñigo Huguet) [2059999]
- nl80211: correctly check NL80211_ATTR_REG_ALPHA2 size (Íñigo Huguet) [2059999]
- ath9k: Fix usage of driver-private space in tx_info (Íñigo Huguet) [2059999]
- brcmfmac: sdio: Fix undefined behavior due to shift overflowing the constant (Íñigo Huguet) [2059999]
- mt76: Fix undefined behavior due to shift overflowing the constant (Íñigo Huguet) [2059999]
- Revert "ath11k: mesh: add support for 256 bitmap in blockack frames in 11ax" (Íñigo Huguet) [2059999]
- ath9k: Properly clear TX status area before reporting to mac80211 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Don't fail if PPAG isn't supported (Íñigo Huguet) [2059999]
- ar5523: fix typo "to short" -> "too short" (Íñigo Huguet) [2059999]
- bus: mhi: Make mhi_state_str[] array static inline and move to common.h (Íñigo Huguet) [2059999]
- bus: mhi: Move common MHI definitions out of host directory (Íñigo Huguet) [2059999]
- bus: mhi: host: Rename "struct mhi_tre" to "struct mhi_ring_element" (Íñigo Huguet) [2059999]
- bus: mhi: Cleanup the register definitions used in headers (Íñigo Huguet) [2059999]
- bus: mhi: Use bitfield operations for handling DWORDs of ring elements (Íñigo Huguet) [2059999]
- bus: mhi: Use bitfield operations for register read and write (Íñigo Huguet) [2059999]
- bus: mhi: Move host MHI code to "host" directory (Íñigo Huguet) [2059999]
- bus: mhi: Fix MHI DMA structure endianness (Íñigo Huguet) [2059999]
- bus: mhi: Fix pm_state conversion to string (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add mru_default for Quectel EM1xx series (Íñigo Huguet) [2059999]
- rfkill: make new event layout opt-in (Íñigo Huguet) [2059999]
- rtw89: implement stop and resume channels transmission v1 (Íñigo Huguet) [2059999]
- rtw89: extend mac tx_en bits from 16 to 32 (Íñigo Huguet) [2059999]
- rtw89: change value assignment style of rtw89_mac_cfg_gnt() (Íñigo Huguet) [2059999]
- rtw89: 8852c: add mac_ctrl_path and mac_cfg_gnt APIs (Íñigo Huguet) [2059999]
- rtw89: disable FW and H2C function if CPU disabled (Íñigo Huguet) [2059999]
- rtw89: initialize preload window of D-MAC (Íñigo Huguet) [2059999]
- rtw89: modify MAC enable functions (Íñigo Huguet) [2059999]
- rtw89: add config_rf_reg_v1 to configure RF parameter tables (Íñigo Huguet) [2059999]
- rtw89: 8852c: add read/write rf register function (Íñigo Huguet) [2059999]
- rtw89: 8852c: add setting of TB UL TX power offset (Íñigo Huguet) [2059999]
- rtw89: 8852c: add write/read crystal function in CFO tracking (Íñigo Huguet) [2059999]
- rtw89: modify dcfo_comp to share with chips (Íñigo Huguet) [2059999]
- rtw89: Fix spelling mistake "Mis-Match" -> "Mismatch" (Íñigo Huguet) [2059999]
- brcmfmac: p2p: Fix spelling mistake "Comback" -> "Comeback" (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix building iwlmei (Íñigo Huguet) [2059999]
- mt76: fix monitor rx FCS error in DFS channel (Íñigo Huguet) [2059999]
- mt76: mt7921: don't enable beacon filter when IEEE80211_CONF_CHANGE_MONITOR is set (Íñigo Huguet) [2059999]
- mt76: fix wrong HE data rate in sniffer tool (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce 802.11ax multi-bss support (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_init_hw in a dedicated work (Íñigo Huguet) [2059999]
- mt76: mt7921: add mt7921u driver (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_usb_sdio_tx_status_data in mac common code. (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_usb_sdio_tx_complete_skb in common mac code. (Íñigo Huguet) [2059999]
- mt76: mt7921: move mt7921_usb_sdio_tx_prepare_skb in common mac code (Íñigo Huguet) [2059999]
- mt76: mt7921: update mt7921_skb_add_usb_sdio_hdr to support usb (Íñigo Huguet) [2059999]
- mt76: mt7921: disable runtime pm for usb (Íñigo Huguet) [2059999]
- mt76: usb: introduce __mt76u_init utility routine (Íñigo Huguet) [2059999]
- mt76: usb: add req_type to ___mt76u_wr signature (Íñigo Huguet) [2059999]
- mt76: usb: add req_type to ___mt76u_rr signature (Íñigo Huguet) [2059999]
- mt76: mt7915: fix typos in comments (Íñigo Huguet) [2059999]
- mt76: mt7915: fix phy cap in mt7915_set_stream_he_txbf_caps() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix beamforming mib stats (Íñigo Huguet) [2059999]
- mt76: mt7915: set band1 TGID field in tx descriptor (Íñigo Huguet) [2059999]
- mt76: fix invalid rssi report (Íñigo Huguet) [2059999]
- mt76: use le32/16_get_bits() whenever possible (Íñigo Huguet) [2059999]
- mt76: connac: make read-only array ba_range static const (Íñigo Huguet) [2059999]
- mt76: mt7915: check for devm_pinctrl_get() failure (Íñigo Huguet) [2059999]
- mt76: mt7921: get rid of mt7921_wait_for_mcu_init declaration (Íñigo Huguet) [2059999]
- mt76: mt7915: add txpower init for 6GHz (Íñigo Huguet) [2059999]
- mt76: mt7915: fix eeprom fields of txpower init values (Íñigo Huguet) [2059999]
- mt76: mt7915: add 6 GHz support (Íñigo Huguet) [2059999]
- mt76: connac: add 6 GHz support for wtbl and starec configuration (Íñigo Huguet) [2059999]
- mt76: mt7915: allow beaconing on all chains (Íñigo Huguet) [2059999]
- mt76: fix monitor mode crash with sdio driver (Íñigo Huguet) [2059999]
- mt76: mt7921: fix mt7921_queues_acq implementation (Íñigo Huguet) [2059999]
- mt76: mt7921: fix xmit-queue dump for usb and sdio (Íñigo Huguet) [2059999]
- mt76: mt7921: make mt7921_init_tx_queues static (Íñigo Huguet) [2059999]
- mt76: split single ldpc cap bit into bits (Íñigo Huguet) [2059999]
- mt76: mt7915: fix DFS no radar detection event (Íñigo Huguet) [2059999]
- mt76: mt7921: use mt76_hw instead of open coding it (Íñigo Huguet) [2059999]
- mt76: mt7921: fix up the monitor mode (Íñigo Huguet) [2059999]
- mt76: mt7663u: introduce mt7663u_mcu_power_on routine (Íñigo Huguet) [2059999]
- mt76: mt7615: honor ret from mt7615_mcu_restart in mt7663u_mcu_init (Íñigo Huguet) [2059999]
- rtw89: fix uninitialized variable of rtw89_append_probe_req_ie() (Íñigo Huguet) [2059999]
- airo: fix typos in comments (Íñigo Huguet) [2059999]
- rtlwifi: rtl8821ae: fix typos in comments (Íñigo Huguet) [2059999]
- rtlwifi: rtl8192cu: Add On Networks N150 (Íñigo Huguet) [2059999]
- zd1201: use kzalloc (Íñigo Huguet) [2059999]
- mwifiex: make read-only array wmm_oui static const (Íñigo Huguet) [2059999]
- mac80211: update bssid_indicator in ieee80211_assign_beacon (Íñigo Huguet) [2059999]
- mac80211: MBSSID channel switch (Íñigo Huguet) [2059999]
- mac80211: MBSSID beacon handling in AP mode (Íñigo Huguet) [2059999]
- mac80211: always have ieee80211_sta_restart() (Íñigo Huguet) [2059999]
- mac80211: Add support to trigger sta disconnect on hardware restart (Íñigo Huguet) [2059999]
- mac80211: fix potential double free on mesh join (Íñigo Huguet) [2059999]
- mac80211: correct legacy rates check in ieee80211_calc_rx_airtime (Íñigo Huguet) [2059999]
- nl80211: fix typo of NL80211_IF_TYPE_OCB in documentation (Íñigo Huguet) [2059999]
- mac80211: Use GFP_KERNEL instead of GFP_ATOMIC when possible (Íñigo Huguet) [2059999]
- mac80211: replace DEFINE_SIMPLE_ATTRIBUTE with DEFINE_DEBUGFS_ATTRIBUTE (Íñigo Huguet) [2059999]
- rtw89: 8852c: process logic efuse map (Íñigo Huguet) [2059999]
- rtw89: 8852c: process efuse of phycap (Íñigo Huguet) [2059999]
- rtw89: support DAV efuse reading operation (Íñigo Huguet) [2059999]
- rtw89: 8852c: add chip::dle_mem (Íñigo Huguet) [2059999]
- rtw89: add page_regs to handle v1 chips (Íñigo Huguet) [2059999]
- rtw89: add chip_info::{h2c,c2h}_reg to support more chips (Íñigo Huguet) [2059999]
- rtw89: add hci_func_en_addr to support variant generation (Íñigo Huguet) [2059999]
- rtw89: add power_{on/off}_func (Íñigo Huguet) [2059999]
- rtw89: read chip version depends on chip ID (Íñigo Huguet) [2059999]
- rtw89: pci: use a struct to describe all registers address related to DMA channel (Íñigo Huguet) [2059999]
- rtw89: pci: add V1 of PCI channel address (Íñigo Huguet) [2059999]
- rtw89: pci: add struct rtw89_pci_info (Íñigo Huguet) [2059999]
- rtw89: 8852c: add 8852c empty files (Íñigo Huguet) [2059999]
- brcmfmac: make the read-only array pktflags static const (Íñigo Huguet) [2059999]
- rtlwifi: rtl8192ce: remove duplicated function '_rtl92ce_phy_set_rf_sleep' (Íñigo Huguet) [2059999]
- cw1200: use time_is_after_jiffies() instead of open coding it (Íñigo Huguet) [2059999]
- carl9170: devres-ing input_allocate_device (Íñigo Huguet) [2059999]
- carl9170: devres-ing hwrng_register usage (Íñigo Huguet) [2059999]
- carl9170: replace GFP_ATOMIC in ampdu_action, it can sleep (Íñigo Huguet) [2059999]
- ath10k: Fix error handling in ath10k_setup_msa_resources (Íñigo Huguet) [2059999]
- ath11k: remove unneeded flush_workqueue (Íñigo Huguet) [2059999]
- ath6kl: add device ID for WLU5150-D81 (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 72 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: acpi: move ppag code from mvm to fw/acpi (Íñigo Huguet) [2059999]
- iwlwifi: dbg: check trigger data before access (Íñigo Huguet) [2059999]
- iwlwifi: dbg: in sync mode don't call schedule (Íñigo Huguet) [2059999]
- iwlwifi: use 4k queue size for Bz A-step (Íñigo Huguet) [2059999]
- iwlwifi: pcie: fix SW error MSI-X mapping (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: dump IMR DRAM only for HW and FW error (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for IMR based on platform (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: disable IMR DRAM region if IMR is disabled (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove cipher scheme support (Íñigo Huguet) [2059999]
- iwlwifi: Configure FW debug preset via module param. (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add a flag to reduce power command. (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 71 for AX devices (Íñigo Huguet) [2059999]
- ath9k: make array voice_priority static const (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_aplist_event (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_disconnect_event (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_connect_event (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_channel_list_reply (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_start_scan_cmd (Íñigo Huguet) [2059999]
- ath6kl: wmi: Replace one-element array with flexible-array member in struct wmi_begin_scan_cmd (Íñigo Huguet) [2059999]
- rtw89: declare HE capabilities in 6G band (Íñigo Huguet) [2059999]
- rtw89: fix HE PHY bandwidth capability (Íñigo Huguet) [2059999]
- rtw89: add tx_wake notify for low ps mode (Íñigo Huguet) [2059999]
- rtw89: 8852a: add ieee80211_ops::hw_scan (Íñigo Huguet) [2059999]
- Revert "ath: add support for special 0x0 regulatory domain" (Íñigo Huguet) [2059999]
- rtw89: get channel parameters of 160MHz bandwidth (Íñigo Huguet) [2059999]
- mt76: fix dfs state issue with 160 MHz channels (Íñigo Huguet) [2059999]
- mt76: mt7915: simplify conditional (Íñigo Huguet) [2059999]
- mt76: mt7921: fix injected MPDU transmission to not use HW A-MSDU (Íñigo Huguet) [2059999]
- mt76: mt7915e: Enable thermal management by default (Íñigo Huguet) [2059999]
- mt76: mt7915e: Add a hwmon attribute to get the actual throttle state. (Íñigo Huguet) [2059999]
- mt76: mt7915e: Fix degraded performance after temporary overheat (Íñigo Huguet) [2059999]
- mt76: improve signal strength reporting (Íñigo Huguet) [2059999]
- mt76: mt7915: use min_t() to make code cleaner (Íñigo Huguet) [2059999]
- mt76: mt7915: fix the muru tlv issue (Íñigo Huguet) [2059999]
- mt76: mt7915: check band idx for bcc event (Íñigo Huguet) [2059999]
- mt76: mt7615: Fix assigning negative values to unsigned variable (Íñigo Huguet) [2059999]
- mt76: connac: adjust wlan_idx size from u8 to u16 (Íñigo Huguet) [2059999]
- mt76: mt7915: fix endianness warnings in mt7915_mac_tx_free() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix endianness warnings in mt7915_debugfs_rx_fw_monitor (Íñigo Huguet) [2059999]
- mt76: mt7615: fix compiler warning on frame size (Íñigo Huguet) [2059999]
- mt76: mt7915: initialize smps mode in mt7915_mcu_sta_rate_ctrl_tlv() (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce band_idx in mt7915_phy (Íñigo Huguet) [2059999]
- mt76: mt7915: add support for MT7986 (Íñigo Huguet) [2059999]
- ath10k: fix pointer arithmetic error in trace call (Íñigo Huguet) [2059999]
- carl9170: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath11k: add dbring debug support (Íñigo Huguet) [2059999]
- ath11k: translate HE status to radiotap format (Íñigo Huguet) [2059999]
- ath11k: decode HE status tlv (Íñigo Huguet) [2059999]
- ath11k: switch to using ieee80211_tx_status_ext() (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix missing fc type/sub-type for 802.11 pkts (Íñigo Huguet) [2059999]
- mt76: mt7915: fix potential memory leak of fw monitor packets (Íñigo Huguet) [2059999]
- mt76: mt7915: Fix channel state update error issue (Íñigo Huguet) [2059999]
- mt76: fix endianness errors in reverse_frag0_hdr_trans (Íñigo Huguet) [2059999]
- mt76: mt7615: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: mt7915: fix injected MPDU transmission to not use HW A-MSDU (Íñigo Huguet) [2059999]
- rtw88: change rtw_info() to proper message level (Íñigo Huguet) [2059999]
- rtw89: Limit the CFO boundaries of x'tal value (Íñigo Huguet) [2059999]
- rtw89: phy: handle txpwr lmt/lmt_ru of 160M bandwidth (Íñigo Huguet) [2059999]
- rtw89: phy: handle txpwr lmt/lmt_ru of 6G band (Íñigo Huguet) [2059999]
- ath11k: Fix frames flush failure caused by deadlock (Íñigo Huguet) [2059999]
- ath11k: Handle failure in qmi firmware ready (Íñigo Huguet) [2059999]
- ath11k: Invalidate cached reo ring entry before accessing it (Íñigo Huguet) [2059999]
- ath: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath6kl: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath11k: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- ath10k: Replace zero-length array with flexible-array member (Íñigo Huguet) [2059999]
- ath9k: use hw_random API instead of directly dumping into random.c (Íñigo Huguet) [2059999]
- ath11k: configure RDDM size to mhi for recovery by firmware (Íñigo Huguet) [2059999]
- ath11k: fix invalid m3 buffer address (Íñigo Huguet) [2059999]
- ath11k: add ath11k_qmi_free_resource() for recovery (Íñigo Huguet) [2059999]
- rtw89: core.h: Replace zero-length array with flexible-array member (Íñigo Huguet) [2059999]
- brcmfmac: Replace zero-length arrays with flexible-array members (Íñigo Huguet) [2059999]
- rtw89: fix RCU usage in rtw89_core_txq_push() (Íñigo Huguet) [2059999]
- rtw88: coex: Update rtl8822c COEX version to 22020720 (Íñigo Huguet) [2059999]
- rtw88: coex: Add C2H/H2C handshake with BT mailbox for asking HID Info (Íñigo Huguet) [2059999]
- rtw88: coex: Add WLAN MIMO power saving for Bluetooth gaming controller (Íñigo Huguet) [2059999]
- rtw88: coex: update BT PTA counter regularly (Íñigo Huguet) [2059999]
- rtw88: coex: Improve WLAN throughput when HFP COEX (Íñigo Huguet) [2059999]
- rtw88: 8822ce: add support for TX/RX 1ss mode (Íñigo Huguet) [2059999]
- iwlwifi: dbg_ini: Split memcpy() to avoid multi-field write (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Fix an error code in iwl_mvm_up() (Íñigo Huguet) [2059999]
- iwlwifi: Fix -EIO error code that is never returned (Íñigo Huguet) [2059999]
- iwlwifi: mvm: rfi: use kmemdup() to replace kzalloc + memcpy (Íñigo Huguet) [2059999]
- iwlwifi: Fix syntax errors in comments (Íñigo Huguet) [2059999]
- iwlwifi: dvm: use struct_size over open coded arithmetic (Íñigo Huguet) [2059999]
- iwlwifi/fw: use struct_size over open coded arithmetic (Íñigo Huguet) [2059999]
- iwlwifi: Make use of the helper macro LIST_HEAD() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix off by one in iwl_mvm_stat_iterator_all_macs() (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: send hcmd to fw after dump collection completes. (Íñigo Huguet) [2059999]
- iwlwifi: mvm: move only to an enabled channel (Íñigo Huguet) [2059999]
- iwlwifi: mvm: update BAID allocation command again (Íñigo Huguet) [2059999]
- iwlwifi: api: remove ttl field from TX command (Íñigo Huguet) [2059999]
- iwlwifi: support new queue allocation command (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: support dump policy for the dump size (Íñigo Huguet) [2059999]
- iwlwifi: pcie: iwlwifi: fix device id 7F70 struct (Íñigo Huguet) [2059999]
- iwlwifi: tlc: Add logs in rs_fw_rate_init func to print TLC configuration (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove iwl_mvm_disable_txq() flags argument (Íñigo Huguet) [2059999]
- iwlwifi: remove command ID argument from queue allocation (Íñigo Huguet) [2059999]
- iwlwifi: make iwl_txq_dyn_alloc_dma() return the txq (Íñigo Huguet) [2059999]
- iwlwifi: fix small doc mistake for iwl_fw_ini_addr_val (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add additional info for boot info failures (Íñigo Huguet) [2059999]
- iwlwifi: mvm: always remove the session protection after association (Íñigo Huguet) [2059999]
- iwlwifi: mvm: make iwl_mvm_reconfig_scd() static (Íñigo Huguet) [2059999]
- iwlwifi: mvm: refactor setting PPE thresholds in STA_HE_CTXT_CMD (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Disable WiFi bands selectively with BIOS (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add additional info for boot info failures (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't send BAID removal to the FW during hw_restart (Íñigo Huguet) [2059999]
- iwlwifi: don't dump_stack() when we get an unexpected interrupt (Íñigo Huguet) [2059999]
- iwlwifi: mvm: rfi: handle deactivation notification (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Consider P2P GO operation during scan (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 70 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Unify the scan iteration functions (Íñigo Huguet) [2059999]
- iwlwifi: mei: use C99 initializer for device IDs (Íñigo Huguet) [2059999]
- iwlwifi: debugfs: remove useless double condition (Íñigo Huguet) [2059999]
- iwlwifi: remove unused macros (Íñigo Huguet) [2059999]
- iwlwifi: eeprom: clean up macros (Íñigo Huguet) [2059999]
- iwlwifi: drv: load tlv debug data earlier (Íñigo Huguet) [2059999]
- iwlwifi: pcie: Adapt rx queue write pointer for Bz family (Íñigo Huguet) [2059999]
- iwlwifi: pcie: adjust to Bz completion descriptor (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Passively scan non PSC channels only when requested so (Íñigo Huguet) [2059999]
- iwlwifi: scan: Modify return value of a function (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: Avoid using dram data if allocation failed (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Correctly set fragmented EBS (Íñigo Huguet) [2059999]
- iwlwifi: nvm: Correct HE capability (Íñigo Huguet) [2059999]
- iwlwifi: mei: avoid -Wpointer-arith and -Wcast-qual warnings (Íñigo Huguet) [2059999]
- iwlwifi: make some functions friendly to sparse (Íñigo Huguet) [2059999]
- iwlwifi: avoid variable shadowing (Íñigo Huguet) [2059999]
- iwlwifi: remove unused DC2DC_CONFIG_CMD definitions (Íñigo Huguet) [2059999]
- iwlwifi: dbg-tlv: clean up iwl_dbg_tlv_update_drams() (Íñigo Huguet) [2059999]
- iwlwifi: move symbols into a separate namespace (Íñigo Huguet) [2059999]
- iwlwifi: fw: make dump_start callback void (Íñigo Huguet) [2059999]
- iwlwifi: pcie: make sure iwl_rx_packet_payload_len() will not underflow (Íñigo Huguet) [2059999]
- iwlwifi: mvm: use debug print instead of WARN_ON() (Íñigo Huguet) [2059999]
- iwlwifi: read and print OTP minor version (Íñigo Huguet) [2059999]
- iwlwifi: add support for BZ-U and BZ-L HW (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for CT-KILL notification version 2 (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: remove DBGI_SRAM address reset writing (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support v3 of station HE context command (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: add IMR DRAM dump support (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: fix DBGC allocation flow (Íñigo Huguet) [2059999]
- iwlwifi: pcie: add support for MS devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: align locking in D3 test debugfs (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't iterate unadded vifs when handling FW SMPS req (Íñigo Huguet) [2059999]
- iwlwifi: advertise support for HE - DCM BPSK RX/TX (Íñigo Huguet) [2059999]
- iwlwifi: mvm: only enable HE DCM if we also support TX (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: fix DBGI_SRAM ini dump header. (Íñigo Huguet) [2059999]
- iwlwifi: dbg: add infra for tracking free buffer size (Íñigo Huguet) [2059999]
- iwlwifi: mvm: starting from 22000 we have 32 Rx AMPDU sessions (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support new BAID allocation command (Íñigo Huguet) [2059999]
- iwlwifi: mvm: refactor iwl_mvm_sta_rx_agg() (Íñigo Huguet) [2059999]
- iwlwifi: cfg: add support for 1K BA queue (Íñigo Huguet) [2059999]
- iwlwifi: avoid void pointer arithmetic (Íñigo Huguet) [2059999]
- iwlwifi: fix various more -Wcast-qual warnings (Íñigo Huguet) [2059999]
- iwlwifi: propagate (const) type qualifier (Íñigo Huguet) [2059999]
- iwlwifi: de-const properly where needed (Íñigo Huguet) [2059999]
- iwlwifi: make iwl_fw_lookup_cmd_ver() take a cmd_id (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fw: clean up hcmd struct creation (Íñigo Huguet) [2059999]
- iwlwifi: prefer WIDE_ID() over iwl_cmd_id() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: allow enabling UHB TAS in the USA via ACPI setting (Íñigo Huguet) [2059999]
- iwlwifi: mvm: offload channel switch timing to FW (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Don't call iwl_mvm_sta_from_mac80211() with NULL sta (Íñigo Huguet) [2059999]
- mac80211_hwsim: Advertise support for EHT capabilities (Íñigo Huguet) [2059999]
- mac80211: parse AddBA request with extended AddBA element (Íñigo Huguet) [2059999]
- mac80211: calculate max RX NSS for EHT mode (Íñigo Huguet) [2059999]
- mac80211: Add support for storing station EHT capabilities (Íñigo Huguet) [2059999]
- mac80211: Handle station association response with EHT (Íñigo Huguet) [2059999]
- mac80211: Add EHT capabilities to association/probe request (Íñigo Huguet) [2059999]
- mac80211: Add initial support for EHT and 320 MHz channels (Íñigo Huguet) [2059999]
- mac80211: Support parsing EHT elements (Íñigo Huguet) [2059999]
- cfg80211: Support configuration of station EHT capabilities (Íñigo Huguet) [2059999]
- cfg80211: add NO-EHT flag to regulatory (Íñigo Huguet) [2059999]
- nl80211: add support for 320MHz channel limitation (Íñigo Huguet) [2059999]
- nl80211: add EHT MCS support (Íñigo Huguet) [2059999]
- cfg80211: Add support for EHT 320 MHz channel width (Íñigo Huguet) [2059999]
- cfg80211: Add data structures to capture EHT capabilities (Íñigo Huguet) [2059999]
- ieee80211: add EHT 1K aggregation definitions (Íñigo Huguet) [2059999]
- ieee80211: Add EHT (802.11be) definitions (Íñigo Huguet) [2059999]
- mac80211_hwsim: Add custom regulatory for 6GHz (Íñigo Huguet) [2059999]
- mac80211_hwsim: don't shadow a global variable (Íñigo Huguet) [2059999]
- mac80211_hwsim: check TX and STA bandwidth (Íñigo Huguet) [2059999]
- nl80211: accept only HE capability elements with valid size (Íñigo Huguet) [2059999]
- mac80211: parse only HE capability elements with valid size (Íñigo Huguet) [2059999]
- ieee80211: add helper to check HE capability element size (Íñigo Huguet) [2059999]
- nl80211: use RCU to read regdom in reg get/dump (Íñigo Huguet) [2059999]
- mac80211_hwsim: Add debugfs to control rx status RSSI (Íñigo Huguet) [2059999]
- ieee80211: use tab to indent struct ieee80211_neighbor_ap_info (Íñigo Huguet) [2059999]
- rtw89: handle TX/RX 160M bandwidth (Íñigo Huguet) [2059999]
- rtw89: declare if chip support 160M bandwidth (Íñigo Huguet) [2059999]
- rtw89: add 6G support to rate adaptive mechanism (Íñigo Huguet) [2059999]
- rtw89: extend subband for 6G band (Íñigo Huguet) [2059999]
- rtw89: refine naming of rfk helpers with prefix (Íñigo Huguet) [2059999]
- rtw89: make rfk helpers common across chips (Íñigo Huguet) [2059999]
- brcmfmac: Add BCM43454/6 support (Íñigo Huguet) [2059999]
- wcn36xx: use struct_size over open coded arithmetic (Íñigo Huguet) [2059999]
- ath11k: fix destination monitor ring out of sync (Íñigo Huguet) [2059999]
- ath11k: fix radar detection in 160 Mhz (Íñigo Huguet) [2059999]
- ath11k: fix WARN_ON during ath11k_mac_update_vif_chan (Íñigo Huguet) [2059999]
- ath11k: fix uninitialized rate_idx in ath11k_dp_tx_update_txcompl() (Íñigo Huguet) [2059999]
- brcmfmac: of: remove redundant variable len (Íñigo Huguet) [2059999]
- brcmfmac: p2p: Replace one-element arrays with flexible-array members (Íñigo Huguet) [2059999]
- rtw89: coex: set EN bit to PLT register (Íñigo Huguet) [2059999]
- rtw89: recover rates of rate adaptive mechanism (Íñigo Huguet) [2059999]
- rtw88: recover rates of rate adaptive mechanism (Íñigo Huguet) [2059999]
- rtw89: declare AP mode support (Íñigo Huguet) [2059999]
- rtw89: debug: add stations entry to show ID assignment (Íñigo Huguet) [2059999]
- rtw89: implement ieee80211_ops::start_ap and stop_ap (Íñigo Huguet) [2059999]
- rtw89: maintain assoc/disassoc STA states of firmware and hardware (Íñigo Huguet) [2059999]
- rtw89: only STA mode change vif_type mapping dynamically (Íñigo Huguet) [2059999]
- rtw89: add addr_cam field to sta to support AP mode (Íñigo Huguet) [2059999]
- rtw89: extend role_maintain to support AP mode (Íñigo Huguet) [2059999]
- rtw88: fix use after free in rtw_hw_scan_update_probe_req() (Íñigo Huguet) [2059999]
- mac80211: Remove redundent assignment channel_type (Íñigo Huguet) [2059999]
- mac80211: remove useless ieee80211_vif_is_mesh() check (Íñigo Huguet) [2059999]
- mac80211: fix struct ieee80211_tx_info size (Íñigo Huguet) [2059999]
- mac80211: mlme: validate peer HE supported rates (Íñigo Huguet) [2059999]
- mac80211: remove unused macros (Íñigo Huguet) [2059999]
- cfg80211: pmsr: remove useless ifdef guards (Íñigo Huguet) [2059999]
- mac80211: airtime: avoid variable shadowing (Íñigo Huguet) [2059999]
- mac80211: mlme: add documentation from spec to code (Íñigo Huguet) [2059999]
- mac80211: vht: use HE macros for parsing HE capabilities (Íñigo Huguet) [2059999]
- ieee80211: radiotap: fix -Wcast-qual warnings (Íñigo Huguet) [2059999]
- cfg80211: fix -Wcast-qual warnings (Íñigo Huguet) [2059999]
- ieee80211: fix -Wcast-qual warnings (Íñigo Huguet) [2059999]
- cfg80211: don't add non transmitted BSS to 6GHz scanned channels (Íñigo Huguet) [2059999]
- cfg80211/mac80211: assume CHECKSUM_COMPLETE includes SNAP (Íñigo Huguet) [2059999]
- mac80211: consider RX NSS in UHB connection (Íñigo Huguet) [2059999]
- mac80211: limit bandwidth in HE capabilities (Íñigo Huguet) [2059999]
- mt76: redefine mt76_for_each_q_rx to adapt mt7986 changes (Íñigo Huguet) [2059999]
- mt76: dma: initialize skip_unmap in mt76_dma_rx_fill (Íñigo Huguet) [2059999]
- mt76: do not always copy ethhdr in reverse_frag0_hdr_trans (Íñigo Huguet) [2059999]
- mt76: mt76x02: use mt76_phy_dfs_state to determine radar detector state (Íñigo Huguet) [2059999]
- mt76: mt7615: fix/rewrite the dfs state handling logic (Íñigo Huguet) [2059999]
- mt76: mt7915: fix/rewrite the dfs state handling logic (Íñigo Huguet) [2059999]
- mt76: mt76x02: improve tx hang detection (Íñigo Huguet) [2059999]
- mt76x02: improve mac error check/reset reliability (Íñigo Huguet) [2059999]
- mt76: mt7921s: run sleep mode by default (Íñigo Huguet) [2059999]
- mt76: sdio: honor the largest Tx buffer the hardware can support (Íñigo Huguet) [2059999]
- mt76: mt7915: fix the nss setting in bitrates (Íñigo Huguet) [2059999]
- mt76: mt7915: update max_mpdu_size in mt7915_mcu_sta_amsdu_tlv() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix mcs_map in mt7915_mcu_set_sta_he_mcs() (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix a possible memory leak in mt7921_load_patch (Íñigo Huguet) [2059999]
- mt76: mt7915: fix possible memory leak in mt7915_mcu_add_sta (Íñigo Huguet) [2059999]
- mt76: stop the radar detector after leaving dfs channel (Íñigo Huguet) [2059999]
- mt76: mt7615: check sta_rates pointer in mt7615_sta_rate_tbl_update (Íñigo Huguet) [2059999]
- mt76: mt7603: check sta_rates pointer in mt7603_sta_rate_tbl_update (Íñigo Huguet) [2059999]
- mt76: mt7663s: flush runtime-pm queue after waking up the device (Íñigo Huguet) [2059999]
- mt76: mt7615: add support for LG LGSBWAC02 (MT7663BUN) (Íñigo Huguet) [2059999]
- mt76: mt7921: remove duplicated code in mt7921_mac_decode_he_radiotap (Íñigo Huguet) [2059999]
- mt76: mt7915: add missing DATA4_TB_SPTL_REUSE1 to mt7915_mac_decode_he_radiotap (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_lmac_mapping in mt76-connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: enable radar background detection (Íñigo Huguet) [2059999]
- mt76: mt7915: report radar pattern if detected by rdd2 (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce rdd_monitor debugfs node (Íñigo Huguet) [2059999]
- mt76: mt7915: enable radar trigger on rdd2 (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce mt7915_set_radar_background routine (Íñigo Huguet) [2059999]
- mt76: mt7915: set bssinfo/starec command when adding interface (Íñigo Huguet) [2059999]
- mt76: mt7921: toggle runtime-pm adding a monitor vif (Íñigo Huguet) [2059999]
- mt76: mt7921: fix endianness issues in mt7921_mcu_set_tx() (Íñigo Huguet) [2059999]
- mt76: sdio: disable interrupt in mt76s_sdio_irq (Íñigo Huguet) [2059999]
- mt76: mt7921: fix crash when startup fails. (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix mt7921s_mcu_[fw|drv]_pmctrl (Íñigo Huguet) [2059999]
- mt76: mt7921: fix ht mcs in mt7921_mac_add_txs_skb() (Íñigo Huguet) [2059999]
- mt76: mt7915: fix ht mcs in mt7915_mac_add_txs_skb() (Íñigo Huguet) [2059999]
- mt76: mt7615: fix a leftover race in runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7921: fix a leftover race in runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7921: do not always disable fw runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7915: add support for passing chip/firmware debug data to user space (Íñigo Huguet) [2059999]
- mt76: mt7615e: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059999]
- mt76: mt7915: update bss_info with cipher after setting the group key (Íñigo Huguet) [2059999]
- mt76: mt7615: update bss_info with cipher after setting the group key (Íñigo Huguet) [2059999]
- mt76: connac: add support for passing the cipher field in bss_info (Íñigo Huguet) [2059999]
- mt76: mt7921e: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059999]
- mt76: mt7615: fix a possible race enabling/disabling runtime-pm (Íñigo Huguet) [2059999]
- mt76: mt7921: set EDCA parameters with the MCU CE command (Íñigo Huguet) [2059999]
- mt76: mt76_connac: fix MCU_CE_CMD_SET_ROC definition error (Íñigo Huguet) [2059999]
- mt76: mt7921: forbid the doze mode when coredump is in progress (Íñigo Huguet) [2059999]
- mt76: mt7921e: make dev->fw_assert usage consistent (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_rdd_cmd in mt76-connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_set_rts_thresh (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_gen_dl_mode in mt76-connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_init_download (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_patch_sem_ctrl/mt76_connac_mcu_start_patch (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_restart in common module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_start_firmware (Íñigo Huguet) [2059999]
- mt76: mt7921: get rid of mt7921_mcu_get_eeprom (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_set_pm in connac module (Íñigo Huguet) [2059999]
- mt76: connac: introduce is_connac_v1 utility routine (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_wtbl_update_hdr_trans in connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_hdr_trans_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_ht_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_smps_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_uapsd (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_basic_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_generic_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_ba (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_wtbl_ba_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_sta_ba_tlv (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_bss_basic_tlv in connac module (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_bss_ext_tlv in connac module (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_bss_omac_tlv in connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: remove duplicated defs in mcu.h (Íñigo Huguet) [2059999]
- mt76: mt7915: move pci specific code back to pci.c (Íñigo Huguet) [2059999]
- mt76: mt7921s: update mt7921s_wfsys_reset sequence (Íñigo Huguet) [2059999]
- mt76: mt7921s: clear MT76_STATE_MCU_RUNNING immediately after reset (Íñigo Huguet) [2059999]
- mt76: sdio: lock sdio when it is needed (Íñigo Huguet) [2059999]
- mt76: mt7915: use proper aid value in mt7915_mcu_sta_basic_tlv (Íñigo Huguet) [2059999]
- mt76: mt7915: use proper aid value in mt7915_mcu_wtbl_generic_tlv in sta mode (Íñigo Huguet) [2059999]
- mt76: make mt76_sar_capa static (Íñigo Huguet) [2059999]
- mt76: mt7915: add device id for mt7916 (Íñigo Huguet) [2059999]
- mt76: set wlan_idx_hi on mt7916 (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_add_key in connac module (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_get_phy utilities (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_chan_bw in common code (Íñigo Huguet) [2059999]
- mt76: connac: move mt76_connac_mcu_get_cipher in common code (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_add_tlv routine (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_alloc_wtbl_req (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac_mcu_alloc_sta_req (Íñigo Huguet) [2059999]
- mt76: connac: fix sta_rec_wtbl tag len (Íñigo Huguet) [2059999]
- mt76: mt7915: add mt7916 calibrated data support (Íñigo Huguet) [2059999]
- mt76: mt7915: update mt7915_chan_mib_offs for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: update rx rate reporting for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: add txfree event v3 (Íñigo Huguet) [2059999]
- mt76: mt7915: enlarge wcid size to 544 (Íñigo Huguet) [2059999]
- mt76: mt7915: rework eeprom.c to adapt mt7916 changes (Íñigo Huguet) [2059999]
- mt76: mt7915: add firmware support for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: rework dma.c to adapt mt7916 changes (Íñigo Huguet) [2059999]
- mt76: add MT_RXQ_MAIN_WA for mt7916 (Íñigo Huguet) [2059999]
- mt76: mt7915: refine register definition (Íñigo Huguet) [2059999]
- mt76: mt7915: add mt7915_mmio_probe() as a common probing function (Íñigo Huguet) [2059999]
- mt76: mt7915: fix polling firmware-own status (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Read the console on init and shutdown (Íñigo Huguet) [2059999]
- brcmfmac: fwil: Constify iovar name arguments (Íñigo Huguet) [2059999]
- brcmfmac: of: Use devm_kstrdup for board_type & check for errors (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Fix crashes due to early IRQs (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Replace brcmf_pcie_copy_mem_todev with memcpy_toio (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Declare missing firmware files in pcie.c (Íñigo Huguet) [2059999]
- brcmfmac: firmware: Allocate space for default boardrev in nvram (Íñigo Huguet) [2059999]
- brcmfmac: pcie: Release firmwares in the brcmf_pcie_setup error path (Íñigo Huguet) [2059999]
- rtlwifi: remove redundant initialization of variable ul_encalgo (Íñigo Huguet) [2059999]
- ray_cs: Check ioremap return value (Íñigo Huguet) [2059999]
- ath11k: add debugfs for TWT debug calls (Íñigo Huguet) [2059999]
- ath11k: add WMI calls to manually add/del/pause/resume TWT dialogs (Íñigo Huguet) [2059999]
- ath11k: Add debugfs interface to configure firmware debug log level (Íñigo Huguet) [2059999]
- cw1200: wsm: make array queue_id_to_wmm_aci static const (Íñigo Huguet) [2059999]
- wilc1000: use min_t() to make code cleaner (Íñigo Huguet) [2059999]
- rtw88: rtw8821c: enable rfe 6 devices (Íñigo Huguet) [2059999]
- rtw88: fix memory overrun and memory leak during hw_scan (Íñigo Huguet) [2059999]
- rtw88: fix idle mode flow for hw scan (Íñigo Huguet) [2059999]
- rtw88: check for validity before using a pointer (Íñigo Huguet) [2059999]
- carl9170: fix missing bit-wise or operator for tx_params (Íñigo Huguet) [2059999]
- wcn36xx: Differentiate wcn3660 from wcn3620 (Íñigo Huguet) [2059999]
- ath11k: mhi: use mhi_sync_power_up() (Íñigo Huguet) [2059999]
- ath11k: pci: fix crash on suspend if board file is not found (Íñigo Huguet) [2059999]
- ath11k: Fix missing rx_desc_get_ldpc_support in wcn6855_ops (Íñigo Huguet) [2059999]
- ath11k: Fix uninitialized symbol 'rx_buf_sz' (Íñigo Huguet) [2059999]
- ath11k: fix kernel panic during unload/load ath11k modules (Íñigo Huguet) [2059999]
- ath11k: Rename ath11k_ahb_ext_irq_config (Íñigo Huguet) [2059999]
- brcmfmac: add CYW43570 PCIE device (Íñigo Huguet) [2059999]
- brcmfmac: use ISO3166 country code and 0 rev as fallback on some devices (Íñigo Huguet) [2059999]
- rtw89: use pci_read/write_config instead of dbi read/write (Íñigo Huguet) [2059999]
- rtw89: refine DIG feature to support 160M and CCK PD (Íñigo Huguet) [2059999]
- rtw89: fix maybe uninitialized `qempty` variable (Íñigo Huguet) [2059999]
- rtw89: include subband type in channel params (Íñigo Huguet) [2059999]
- rtw89: handle 6G band if supported by a chipset (Íñigo Huguet) [2059999]
- rtw89: separate {init,deinit}_addr_cam functions (Íñigo Huguet) [2059999]
- rtw89: set mac_id and port ID to TXWD (Íñigo Huguet) [2059999]
- rtw89: send broadcast/multicast packets via HIQ if STAs are in sleep mode (Íñigo Huguet) [2059999]
- rtw89: configure mac port HIQ registers (Íñigo Huguet) [2059999]
- rtw89: rename vif_maintain to role_maintain (Íñigo Huguet) [2059999]
- rtw89: extend firmware commands on states of sta_assoc and sta_disconnect (Íñigo Huguet) [2059999]
- rtw89: allocate mac_id for each station in AP mode (Íñigo Huguet) [2059999]
- rtw89: implement mac80211_ops::set_tim to indicate STA to receive packets (Íñigo Huguet) [2059999]
- rtw89: add C2H handle of BCN_CNT (Íñigo Huguet) [2059999]
- rtw89: download beacon content to firmware (Íñigo Huguet) [2059999]
- rtw89: use hardware SSN to TX management frame (Íñigo Huguet) [2059999]
- rtw89: configure rx_filter according to FIF_PROBE_REQ (Íñigo Huguet) [2059999]
- rtw89: correct use of BA CAM (Íñigo Huguet) [2059999]
- rtw89: encapsulate RX handlers to single function (Íñigo Huguet) [2059999]
- rtw89: Add RX counters of VHT MCS-10/11 to debugfs (Íñigo Huguet) [2059999]
- rtw89: remove duplicate definition of hardware port number (Íñigo Huguet) [2059999]
- rtw89: extract modules by chipset (Íñigo Huguet) [2059999]
- ath11k: avoid firmware crash when reg set for QCA6390/WCN6855 (Íñigo Huguet) [2059999]
- ath11k: set WMI_PEER_40MHZ while peer assoc for 6 GHz (Íñigo Huguet) [2059999]
- ath9k_htc: fix uninit value bugs (Íñigo Huguet) [2059999]
- wcn36xx: Implement get_snr() (Íñigo Huguet) [2059999]
- ath10k: abstract htt_rx_desc structure (Íñigo Huguet) [2059999]
- wcn36xx: Use platform_get_irq_byname() to get the interrupt (Íñigo Huguet) [2059999]
- ath9k: remove redundant status variable (Íñigo Huguet) [2059999]
- ath11k: Reconfigure hardware rate for WCN6855 after vdev is started (Íñigo Huguet) [2059999]
- ath: dfs_pattern_detector: Avoid open coded arithmetic in memory allocation (Íñigo Huguet) [2059999]
- ath10k: Use platform_get_irq() to get the interrupt (Íñigo Huguet) [2059999]
- ath5k: fix ah_txq_isr_txok_all setting (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_txurn member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_qcborn member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_qcburn member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath5k: remove unused ah_txq_isr_qtrig member from struct ath5k_hw (Íñigo Huguet) [2059999]
- ath11k: fix error code in ath11k_qmi_assign_target_mem_chunk() (Íñigo Huguet) [2059999]
- ath11k: move function ath11k_dp_rx_process_mon_status (Íñigo Huguet) [2059999]
- ath11k: enable RX PPDU stats in monitor co-exist mode (Íñigo Huguet) [2059999]
- ath5k: fix OOB in ath5k_eeprom_read_pcal_info_5111 (Íñigo Huguet) [2059999]
- ath11k: free peer for station when disconnect from AP for QCA6390/WCN6855 (Íñigo Huguet) [2059999]
- ath11k: add LDPC FEC type in 802.11 radiotap header (Íñigo Huguet) [2059999]
- ath11k: Refactor the fallback routine when peer create fails (Íñigo Huguet) [2059999]
- ath11k: fix workqueue not getting destroyed after rmmod (Íñigo Huguet) [2059999]
- ath10k: fix memory overwrite of the WoWLAN wakeup packet pattern (Íñigo Huguet) [2059999]
- ath11k: add missing of_node_put() to avoid leak (Íñigo Huguet) [2059999]
- Revert "ath10k: drop beacon and probe response which leak from other channel" (Íñigo Huguet) [2059999]
- iwlwifi: mvm: return value for request_ownership (Íñigo Huguet) [2059999]
- nl80211: Update bss channel on channel switch for P2P_CLIENT (Íñigo Huguet) [2059999]
- config: wireless: IWLMEI=n (Íñigo Huguet) [2059999]
- iwlwifi: fix build error for IWLMEI (Íñigo Huguet) [2059999]
- mac80211: treat some SAE auth steps as final (Íñigo Huguet) [2059999]
- nl80211: Handle nla_memdup failures in handle_nan_filter (Íñigo Huguet) [2059999]
- iwlwifi: mvm: check debugfs_dir ptr before use (Íñigo Huguet) [2059999]
- iwlwifi: don't advertise TWT support (Íñigo Huguet) [2059999]
- rfkill: define rfill_soft_blocked() if !RFKILL (Íñigo Huguet) [2059999]
- mac80211: fix forwarded mesh frames AC & queue selection (Íñigo Huguet) [2059999]
- mac80211: refuse aggregations sessions before authorized (Íñigo Huguet) [2059999]
- mac80211: fix EAPoL rekey fail in 802.3 rx path (Íñigo Huguet) [2059999]
- iwlwifi: fix use-after-free (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add mru_default for Cinterion MV31-W (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add mru_default for Foxconn SDX55 (Íñigo Huguet) [2059999]
- cfg80211: fix race in netlink owner interface destruction (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't send SAR GEO command for 3160 devices (Íñigo Huguet) [2059999]
- iwlwifi: remove deprecated broadcast filtering feature (Íñigo Huguet) [2059999]
- iwlwifi: mei: report RFKILL upon register when needed (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't feed the hardware RFKILL into iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: mei: retry mapping the shared area (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix the pskb_may_pull check in ipv4 (Íñigo Huguet) [2059999]
- iwlwifi: pcie: gen2: fix locking when "HW not ready" (Íñigo Huguet) [2059999]
- iwlwifi: pcie: fix locking when "HW not ready" (Íñigo Huguet) [2059999]
- iwlwifi: fix iwl_legacy_rate_to_fw_idx (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix condition which checks the version of rate_n_flags (Íñigo Huguet) [2059999]
- mac80211_hwsim: initialize ieee80211_tx_info at hw_scan_work (Íñigo Huguet) [2059999]
- mac80211_hwsim: report NOACK frames in tx_status (Íñigo Huguet) [2059999]
- mac80211: mlme: check for null after calling kmemdup (Íñigo Huguet) [2059999]
- brcmfmac: firmware: Fix crash in brcm_alt_fw_path (Íñigo Huguet) [2059999]
- mac80211: use ieee80211_bss_get_elem() (Íñigo Huguet) [2059999]
- nl80211: clarify comment for mesh PLINK_BLOCKED state (Íñigo Huguet) [2059999]
- mac80211: Add stations iterator where the iterator function may sleep (Íñigo Huguet) [2059999]
- mac80211: allow non-standard VHT MCS-10/11 (Íñigo Huguet) [2059999]
- codel: remove unnecessary pkt_sched.h include (Íñigo Huguet) [2059999]
- codel: remove unnecessary sock.h include (Íñigo Huguet) [2059999]
- wilc1000: Add reset/enable GPIO support to SPI driver (Íñigo Huguet) [2059999]
- wilc1000: Convert static "chipid" variable to device-local variable (Íñigo Huguet) [2059999]
- rtw88: don't consider deep PS mode when transmitting packet (Íñigo Huguet) [2059999]
- ath11k: add support of firmware logging for WCN6855 (Íñigo Huguet) [2059999]
- ath10k: replace strlcpy with strscpy (Íñigo Huguet) [2059999]
- rtw88: support SAR via kernel common API (Íñigo Huguet) [2059999]
- rtw88: 8822c: add ieee80211_ops::hw_scan (Íñigo Huguet) [2059999]
- iwlwifi: mei: wait before mapping the shared area (Íñigo Huguet) [2059999]
- iwlwifi: mei: clear the ownership when the driver goes down (Íñigo Huguet) [2059999]
- iwlwifi: fw: fix some scan kernel-doc (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove card state notification code (Íñigo Huguet) [2059999]
- iwlwifi: mvm: drop too short packets silently (Íñigo Huguet) [2059999]
- iwlwifi: return op_mode only in case the failure is from MEI (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support Bz TX checksum offload (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add US/CA to TAS block list if OEM isn't allowed (Íñigo Huguet) [2059999]
- iwlwifi: mvm: correctly set schedule scan profiles (Íñigo Huguet) [2059999]
- iwlwifi: mvm: correctly set channel flags (Íñigo Huguet) [2059999]
- iwlwifi: mvm: always store the PPAG table as the latest version. (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 69 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: support TLV-based firmware reset (Íñigo Huguet) [2059999]
- iwlwifi: mvm: change old-SN drop threshold (Íñigo Huguet) [2059999]
- iwlwifi: mvm: don't trust hardware queue number (Íñigo Huguet) [2059999]
- iwlwifi: mvm: handle RX checksum on Bz devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: use a define for checksum flags mask (Íñigo Huguet) [2059999]
- iwlwifi: remove module loading failure message (Íñigo Huguet) [2059999]
- iwlwifi: mvm: isolate offload assist (checksum) calculation (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for OCE scan (Íñigo Huguet) [2059999]
- iwlwifi: dump RCM error tables (Íñigo Huguet) [2059999]
- iwlwifi: dump both TCM error tables if present (Íñigo Huguet) [2059999]
- iwlwifi: dump CSR scratch from outer function (Íñigo Huguet) [2059999]
- iwlwifi: parse error tables from debug TLVs (Íñigo Huguet) [2059999]
- iwlwifi: recognize missing PNVM data and then log filename (Íñigo Huguet) [2059999]
- iwlwifi: rs: add support for TLC config command ver 4 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: rfi: update rfi table (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Add list of OEMs allowed to use TAS (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support revision 1 of WTAS table (Íñigo Huguet) [2059999]
- iwlwifi: fw: remove dead error log code (Íñigo Huguet) [2059999]
- iwlwifi: do not use __unused as variable name (Íñigo Huguet) [2059999]
- iwlwifi: iwl-eeprom-parse: mostly dvm only (Íñigo Huguet) [2059999]
- iwlwifi: mvm: clean up indenting in iwl_mvm_tlc_update_notif() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix a stray tab (Íñigo Huguet) [2059999]
- ath11k: add regdb.bin download for regdb offload (Íñigo Huguet) [2059999]
- rtl8xxxu: Improve the A-MPDU retransmission rate with RTS/CTS protection (Íñigo Huguet) [2059999]
- rtw88: don't check CRC of VHT-SIG-B in 802.11ac signal (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix imbalanced locking in iwl_mvm_start_get_nvm() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add dbg_time_point to debugfs (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add missing min_size to kernel-doc (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix W=1 warnings (Íñigo Huguet) [2059999]
- ath11k: add support for hardware rfkill for QCA6390 (Íñigo Huguet) [2059999]
- ath11k: report tx bitrate for iw wlan station dump (Íñigo Huguet) [2059999]
- ath11k: fix warning of RCU usage for ath11k_mac_get_arvif_by_vdev_id() (Íñigo Huguet) [2059999]
- ath11k: add signal report to mac80211 for QCA6390 and WCN6855 (Íñigo Huguet) [2059999]
- ath11k: report rssi of each chain to mac80211 for QCA6390/WCN6855 (Íñigo Huguet) [2059999]
- cfg80211: Enable regulatory enforcement checks for drivers supporting mesh iface (Íñigo Huguet) [2059999]
- rfkill: allow to get the software rfkill state (Íñigo Huguet) [2059999]
- cfg80211: refactor cfg80211_get_ies_channel_number() (Íñigo Huguet) [2059999]
- nl82011: clarify interface combinations wrt. channels (Íñigo Huguet) [2059999]
- nl80211: Add support to offload SA Query procedures for AP SME device (Íñigo Huguet) [2059999]
- nl80211: Add support to set AP settings flags with single attribute (Íñigo Huguet) [2059999]
- mac80211: add more HT/VHT/HE state logging (Íñigo Huguet) [2059999]
- cfg80211: Use the HE operation IE to determine a 6GHz BSS channel (Íñigo Huguet) [2059999]
- cfg80211: rename offchannel_chain structs to background_chain to avoid confusion with ETSI standard (Íñigo Huguet) [2059999]
- mac80211: Notify cfg80211 about association comeback (Íñigo Huguet) [2059999]
- cfg80211: Add support for notifying association comeback (Íñigo Huguet) [2059999]
- mac80211: introduce channel switch disconnect function (Íñigo Huguet) [2059999]
- cfg80211: Fix order of enum nl80211_band_iftype_attr documentation (Íñigo Huguet) [2059999]
- cfg80211: simplify cfg80211_chandef_valid() (Íñigo Huguet) [2059999]
- mac80211: Remove a couple of obsolete TODO (Íñigo Huguet) [2059999]
- mac80211: use coarse boottime for airtime fairness code (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix cmd timeout in throughput test (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix suspend error with enlarging mcu timeout value (Íñigo Huguet) [2059999]
- mt76: mt7921s: make pm->suspended usage consistent (Íñigo Huguet) [2059999]
- mt76: mt7921: clear pm->suspended in mt7921_mac_reset_work (Íñigo Huguet) [2059999]
- mt76: connac: rely on le16_add_cpu in mt76_connac_mcu_add_nested_tlv (Íñigo Huguet) [2059999]
- mt76: mt7921: remove dead definitions (Íñigo Huguet) [2059999]
- mt76: mt7915: add mu-mimo and ofdma debugfs knobs (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce mt76_vif in mt7915_vif (Íñigo Huguet) [2059999]
- mt76: mt7921: reduce log severity levels for informative messages (Íñigo Huguet) [2059999]
- mt76: mt7915: rely on mt76_connac definitions (Íñigo Huguet) [2059999]
- mt76: connac: rely on MCU_CMD macro (Íñigo Huguet) [2059999]
- mt76: connac: introduce MCU_CE_CMD macro (Íñigo Huguet) [2059999]
- mt76: connac: introduce MCU_UNI_CMD macro (Íñigo Huguet) [2059999]
- mt76: connac: remove MCU_FW_PREFIX bit (Íñigo Huguet) [2059999]
- mt76: connac: align MCU_EXT definitions with 7915 driver (Íñigo Huguet) [2059999]
- mt76: connac: introduce MCU_EXT macros (Íñigo Huguet) [2059999]
- mt76: mt7615: in debugfs queue stats, skip wmm index 3 on mt7663 (Íñigo Huguet) [2059999]
- mt76: mt7915: process txfree and txstatus without allocating skbs (Íñigo Huguet) [2059999]
- mt76: allow drivers to drop rx packets early (Íñigo Huguet) [2059999]
- mt76: mt7663: disable 4addr capability (Íñigo Huguet) [2059999]
- mt76: only access ieee80211_hdr after mt76_insert_ccmp_hdr (Íñigo Huguet) [2059999]
- mt76: move sar_capa configuration in common code (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix possible kernel crash due to invalid Rx count (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix bus hang with wrong privilege (Íñigo Huguet) [2059999]
- mt76: eeprom: tolerate corrected bit-flips (Íñigo Huguet) [2059999]
- mt76: mt7603: improve reliability of tx powersave filtering (Íñigo Huguet) [2059999]
- mt76: clear sta powersave flag after notifying driver (Íñigo Huguet) [2059999]
- mt76: mt7915: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: mt7603: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: mt7915: improve wmm index allocation (Íñigo Huguet) [2059999]
- mt76: mt7615: improve wmm index allocation (Íñigo Huguet) [2059999]
- mt76: mt7921s: fix the device cannot sleep deeply in suspend (Íñigo Huguet) [2059999]
- mt76: mt7615: fix decap offload corner case with 4-addr VLAN frames (Íñigo Huguet) [2059999]
- mt76: mt7915: fix decap offload corner case with 4-addr VLAN frames (Íñigo Huguet) [2059999]
- mt76: mt76x02: introduce SAR support (Íñigo Huguet) [2059999]
- mt76: move sar utilities to mt76-core module (Íñigo Huguet) [2059999]
- mt76: mt7921: honor mt76_connac_mcu_set_rate_txpower return value in mt7921_config (Íñigo Huguet) [2059999]
- mt76: do not pass the received frame with decryption error (Íñigo Huguet) [2059999]
- mt76: connac: remove PHY_MODE_AX_6G configuration in mt76_connac_get_phy_mode (Íñigo Huguet) [2059999]
- mt76: mt7615: remove dead code in get_omac_idx (Íñigo Huguet) [2059999]
- mt76: mt7921: introduce 160 MHz channel bandwidth support (Íñigo Huguet) [2059999]
- mt76: mt7921: add support for PCIe ID 0x0608/0x0616 (Íñigo Huguet) [2059999]
- mt76: testmode: add support to set MAC (Íñigo Huguet) [2059999]
- mt76: mt7915: add default calibrated data support (Íñigo Huguet) [2059999]
- mt76: only set rx radiotap flag from within decoder functions (Íñigo Huguet) [2059999]
- mt76: reverse the first fragmented frame to 802.11 (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Introduce Sierra EM919X support (Íñigo Huguet) [2059999]
- bus: mhi: core: Add an API for auto queueing buffers for DL channel (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Simplify code and axe the use of a deprecated API (Íñigo Huguet) [2059999]
- bus: mhi: core: Use macros for execution environment features (Íñigo Huguet) [2059999]
- bus: mhi: pci_generic: Add new device ID support for T99W175 (Íñigo Huguet) [2059999]
- ath11k: Use reserved host DDR addresses from DT for PCI devices (Íñigo Huguet) [2059999]
- wilc1000: Improve WILC TX performance when power_save is off (Íñigo Huguet) [2059999]
- wilc1000: Rename workqueue from "WILC_wq" to "NETDEV-wq" (Íñigo Huguet) [2059999]
- wilc1000: Rename tx task from "K_TXQ_TASK" to NETDEV-tx (Íñigo Huguet) [2059999]
- wilc1000: Rename irq handler from "WILC_IRQ" to netdev name (Íñigo Huguet) [2059999]
- wilc1000: Rename SPI driver from "WILC_SPI" to "wilc1000_spi" (Íñigo Huguet) [2059999]
- wilc1000: Remove misleading USE_SPI_DMA macro (Íñigo Huguet) [2059999]
- ath11k: Change qcn9074 fw to operate in mode-2 (Íñigo Huguet) [2059999]
- ath11k: add ab to TARGET_NUM_VDEVS & co (Íñigo Huguet) [2059999]
- brcmfmac: Fix incorrect type assignments for keep-alive (Íñigo Huguet) [2059999]
- ath11k: Avoid false DEADLOCK warning reported by lockdep (Íñigo Huguet) [2059999]
- ath11k: set DTIM policy to stick mode for station interface (Íñigo Huguet) [2059999]
- ath11k: support MAC address randomization in scan (Íñigo Huguet) [2059999]
- ath10k: wmi: remove array of flexible structures (Íñigo Huguet) [2059999]
- ath10k: htt: remove array of flexible structures (Íñigo Huguet) [2059999]
- ath10k: drop beacon and probe response which leak from other channel (Íñigo Huguet) [2059999]
- ath11k: Process full monitor mode rx support (Íñigo Huguet) [2059999]
- ath11k: add software monitor ring descriptor for full monitor (Íñigo Huguet) [2059999]
- ath11k: Add htt cmd to enable full monitor mode (Íñigo Huguet) [2059999]
- ath11k: enable IEEE80211_HW_SINGLE_SCAN_ON_ALL_BANDS for WCN6855 (Íñigo Huguet) [2059999]
- wilc1000: Add id_table to spi_driver (Íñigo Huguet) [2059999]
- rtw88: refine tx_pwr_tbl debugfs to show channel and bandwidth (Íñigo Huguet) [2059999]
- rtw88: add debugfs to fix tx rate (Íñigo Huguet) [2059999]
- ath: regdom: extend South Korea regulatory domain support (Íñigo Huguet) [2059999]
- ath11k: add wait operation for tx management packets for flush from mac80211 (Íñigo Huguet) [2059999]
- ath11k: add 11d scan offload support (Íñigo Huguet) [2059999]
- ath11k: add configure country code for QCA6390 and WCN6855 (Íñigo Huguet) [2059999]
- ath11k: avoid deadlock by change ieee80211_queue_work for regd_update_work (Íñigo Huguet) [2059999]
- iwlwifi: work around reverse dependency on MEI (Íñigo Huguet) [2059999]
- iwlwifi: mvm: optionally suppress assert log (Íñigo Huguet) [2059999]
- iwlwifi: fw: correctly detect HW-SMEM region subtype (Íñigo Huguet) [2059999]
- iwlwifi: implement reset flow for Bz devices (Íñigo Huguet) [2059999]
- iwlwifi: dbg: disable ini debug in 8000 family and below (Íñigo Huguet) [2059999]
- iwlwifi: support SAR GEO Offset Mapping override via BIOS (Íñigo Huguet) [2059999]
- iwlwifi: pcie: retake ownership after reset (Íñigo Huguet) [2059999]
- iwlwifi: mvm: always use 4K RB size by default (Íñigo Huguet) [2059999]
- iwlwifi: mvm/api: define system control command (Íñigo Huguet) [2059999]
- iwlwifi: bump FW API to 68 for AX devices (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add some missing command strings (Íñigo Huguet) [2059999]
- iwlwifi: fw: add support for splitting region type bits (Íñigo Huguet) [2059999]
- iwlwifi: swap 1650i and 1650s killer struct names (Íñigo Huguet) [2059999]
- iwlwifi: yoyo: support for DBGC4 for dram (Íñigo Huguet) [2059999]
- iwlwifi: mvm: update rate scale in moving back to assoc state (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for statistics update version 15 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: Add support for a new version of scan request command (Íñigo Huguet) [2059999]
- iwlwifi: mvm: remove session protection upon station removal (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add support for PHY context command v4 (Íñigo Huguet) [2059999]
- iwlwifi: fw: api: add link to PHY context command struct v1 (Íñigo Huguet) [2059999]
- iwlwifi: mvm: support RLC configuration command (Íñigo Huguet) [2059999]
- iwlwifi: mvm: d3: support v12 wowlan status (Íñigo Huguet) [2059999]
- iwlwifi: mvm: parse firmware alive message version 6 (Íñigo Huguet) [2059999]
- iwlwifi: pcie: support Bz suspend/resume trigger (Íñigo Huguet) [2059999]
- iwlwifi: mvm: d3: move GTK rekeys condition (Íñigo Huguet) [2059999]
- ath11k: change to use dynamic memory for channel list of scan (Íñigo Huguet) [2059999]
- ath11k: add support for WCN6855 hw2.1 (Íñigo Huguet) [2059999]
- ath9k: switch to rate table based lookup (Íñigo Huguet) [2059999]
- iwlwifi: mvm: demote non-compliant kernel-doc header (Íñigo Huguet) [2059999]
- iwlwifi: mvm: fix a possible NULL pointer deference (Íñigo Huguet) [2059999]
- iwlwifi: mei: Fix spelling mistake "req_ownserhip" -> "req_ownership" (Íñigo Huguet) [2059999]
- iwlwifi: mei: don't rely on the size from the shared area (Íñigo Huguet) [2059999]
- iwlwifi: mei: fix linking when tracing is not enabled (Íñigo Huguet) [2059999]
- ath11k: Avoid NULL ptr access during mgmt tx cleanup (Íñigo Huguet) [2059999]
- rtlwifi: rtl8192de: Style clean-ups (Íñigo Huguet) [2059999]
- brcmfmac: Configure keep-alive packet on suspend (Íñigo Huguet) [2059999]
- ieee80211: change HE nominal packet padding value defines (Íñigo Huguet) [2059999]
- cfg80211: use ieee80211_bss_get_elem() instead of _get_ie() (Íñigo Huguet) [2059999]
- wilc1000: remove '-Wunused-but-set-variable' warning in chip_wakeup() (Íñigo Huguet) [2059999]
- iwlwifi: mvm: read the rfkill state and feed it to iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: mvm: add vendor commands needed for iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: integrate with iwlmei (Íñigo Huguet) [2059999]
- iwlwifi: mei: add debugfs hooks (Íñigo Huguet) [2059999]
- iwlwifi: mei: add the driver to allow cooperation with CSME (Íñigo Huguet) [2059999]
- mwifiex: Ensure the version string from the firmware is 0-terminated (Íñigo Huguet) [2059999]
- mwifiex: Add quirk to disable deep sleep with certain hardware revision (Íñigo Huguet) [2059999]
- mwifiex: Use a define for firmware version string length (Íñigo Huguet) [2059999]
- rtw88: add debugfs to force lowest basic rate (Íñigo Huguet) [2059999]
- rtw88: follow the AP basic rates for tx mgmt frame (Íñigo Huguet) [2059999]
- mac80211: Use memset_after() to clear tx status (Íñigo Huguet) [2059999]
- mac80211: notify non-transmitting BSS of color changes (Íñigo Huguet) [2059999]
- mac80211: minstrel_ht: remove unused SAMPLE_SWITCH_THR define (Íñigo Huguet) [2059999]
- cfg80211: allow continuous radar monitoring on offchannel chain (Íñigo Huguet) [2059999]
- cfg80211: schedule offchan_cac_abort_wk in cfg80211_radar_event (Íñigo Huguet) [2059999]
- cfg80211: delete redundant free code (Íñigo Huguet) [2059999]
- mac80211: add support for .ndo_fill_forward_path (Íñigo Huguet) [2059999]
- mac80211: Remove unused assignment statements (Íñigo Huguet) [2059999]
- cfg80211: fix possible NULL pointer dereference in cfg80211_stop_offchan_radar_detection (Íñigo Huguet) [2059999]
- ath11k: Use memset_startat() for clearing queue descriptors (Íñigo Huguet) [2059999]
- ath11k: Fix spelling mistake "detetction" -> "detection" (Íñigo Huguet) [2059999]
- Revert "ath11k: add read variant from SMBIOS for download board data" (Íñigo Huguet) [2059999]
- ath11k: add read variant from SMBIOS for download board data (Íñigo Huguet) [2059999]
- ath11k: calculate the correct NSS of peer for HE capabilities (Íñigo Huguet) [2059999]
- ath11k: change to treat alpha code na as world wide regdomain (Íñigo Huguet) [2059999]
- wilc1000: copy address before calling wilc_set_mac_address (Íñigo Huguet) [2059999]
- cfg80211: move offchan_cac_event to a dedicated work (Íñigo Huguet) [2059999]
- mac80211_hwsim: Fix spelling mistake "Droping" -> "Dropping" (Íñigo Huguet) [2059999]
- mac80211: introduce set_radar_offchan callback (Íñigo Huguet) [2059999]
- cfg80211: implement APIs for dedicated radar detection HW (Íñigo Huguet) [2059999]
- ath11k: add support for BSS color change (Íñigo Huguet) [2059999]
- ath11k: add trace log support (Íñigo Huguet) [2059999]
- ath11k: Add missing qmi_txn_cancel() (Íñigo Huguet) [2059999]
- ath11k: Disabling credit flow for WMI path (Íñigo Huguet) [2059999]
- ath11k: Increment pending_mgmt_tx count before tx send invoke (Íñigo Huguet) [2059999]
- ath11k: send proper txpower and maxregpower values to firmware (Íñigo Huguet) [2059999]
- ath11k: move peer delete after vdev stop of station for QCA6390 and WCN6855 (Íñigo Huguet) [2059999]
- ath11k: remove return for empty tx bitrate in mac_op_sta_statistics (Íñigo Huguet) [2059999]
- ath11k: enable IEEE80211_VHT_EXT_NSS_BW_CAPABLE if NSS ratio enabled (Íñigo Huguet) [2059999]
- ath11k: avoid unnecessary lock contention in tx_completion path (Íñigo Huguet) [2059999]
- ath11k: add branch predictors in dp_tx path (Íñigo Huguet) [2059999]
- ath11k: avoid while loop in ring selection of tx completion interrupt (Íñigo Huguet) [2059999]
- ath11k: remove mod operator in dst ring processing (Íñigo Huguet) [2059999]
- ath11k: allocate HAL_WBM2SW_RELEASE ring from cacheable memory (Íñigo Huguet) [2059999]
- ath11k: add branch predictors in process_rx (Íñigo Huguet) [2059999]
- ath11k: remove usage quota while processing rx packets (Íñigo Huguet) [2059999]
- ath11k: avoid active pdev check for each msdu (Íñigo Huguet) [2059999]
- ath11k: avoid additional access to ath11k_hal_srng_dst_num_free (Íñigo Huguet) [2059999]
- ath11k: modify dp_rx desc access wrapper calls inline (Íñigo Huguet) [2059999]
- ath11k: allocate dst ring descriptors from cacheable memory (Íñigo Huguet) [2059999]
- ath11k: disable unused CE8 interrupts for ipq8074 (Íñigo Huguet) [2059999]
- ath11k: avoid unnecessary BH disable lock in STA kickout event (Íñigo Huguet) [2059999]
- ath11k: enable 802.11 power save mode in station mode (Íñigo Huguet) [2059999]
- ath11k: convert ath11k_wmi_pdev_set_ps_mode() to use enum wmi_sta_ps_mode (Íñigo Huguet) [2059999]
- ath9k: use swap() to make code cleaner (Íñigo Huguet) [2059999]
- ath10k: fetch (pre-)calibration data via nvmem subsystem (Íñigo Huguet) [2059999]
- Revert "ath11k: add support for WCN6855 hw2.1" (Íñigo Huguet) [2059999]

* Thu Jun 23 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-118.rt21.118.el9]
- [rt] build kernel-rt-5.14.0-118.rt21.118.el9 [2061574]
- ixgbe: ensure IPsec VF<->PF compatibility (Ken Cox) [2037981]
- ixgbe: add improvement for MDD response functionality (Ken Cox) [2037981]
- ixgbe: add the ability for the PF to disable VF link state (Ken Cox) [2037981]
- ixgbe: xsk: change !netif_carrier_ok() handling in ixgbe_xmit_zc() (Ken Cox) [2037981]
- ixgbe: Remove non-inclusive language (Ken Cox) [2037981]
- ixgbe: respect metadata on XSK Rx to skb (Ken Cox) [2037981]
- ixgbe: don't reserve excessive XDP_PACKET_HEADROOM on XSK Rx to skb (Ken Cox) [2037981]
- ixgbe: pass bi->xdp to ixgbe_construct_skb_zc() directly (Ken Cox) [2037981]
- ixgbe: Remove useless DMA-32 fallback configuration (Ken Cox) [2037981]
- ixgbe: switch to napi_build_skb() (Ken Cox) [2037981]
- ixgbe: set X550 MDIO speed before talking to PHY (Ken Cox) [2037981]
- ixgbe: Document how to enable NBASE-T support (Ken Cox) [2037981]
- ixgbe: Use irq_update_affinity_hint() (Ken Cox) [2037981]
- ethernet: use eth_hw_addr_set() for dev->addr_len cases (Ken Cox) [2037981]
- ixgbe: let the xdpdrv work with more than 64 cpus (Ken Cox) [2037981]
- ixgbe: Fix NULL pointer dereference in ixgbe_xdp_setup (Ken Cox) [2037981]
- net: sfc: ef10: fix memory leak in efx_ef10_mtd_probe() (Íñigo Huguet) [2042841]
- net: sfc: fix memory leak due to ptp channel (Íñigo Huguet) [2042841]
- net: sfc: fix using uninitialized xdp tx_queue (Íñigo Huguet) [2042841]
- sfc: Do not free an empty page_ring (Íñigo Huguet) [2042841]
- net: sfc: add missing xdp queue reinitialization (Íñigo Huguet) [2042841]
- sfc: Avoid NULL pointer dereference on systems without numa awareness (Íñigo Huguet) [2042841]
- sfc: extend the locking on mcdi->seqno (Íñigo Huguet) [2042841]
- sfc: set affinity hints in local NUMA node only (Íñigo Huguet) [2042841]
- sfc: default config to 1 channel/core in local NUMA node only (Íñigo Huguet) [2042841]
- sfc: The size of the RX recycle ring should be more flexible (Íñigo Huguet) [2042841]
- sfc: Use swap() instead of open coding it (Íñigo Huguet) [2042841]
- ethernet/sfc: remove redundant rc variable (Íñigo Huguet) [2042841]
- x86/sgx: Free backing memory after faulting the enclave page (Vladis Dronov) [2081354]
- x86/sgx: Fix missing poison handling in reclaimer (Vladis Dronov) [2081354]
- x86/sgx: Silence softlockup detection when releasing large enclaves (Vladis Dronov) [2081354]
- selftests/sgx: Treat CC as one argument (Vladis Dronov) [2081354]
- selftests/x86: Add validity check and allow field splitting (Vladis Dronov) [2081354]
- selftests/sgx: Remove extra newlines in test output (Vladis Dronov) [2081354]
- selftests/sgx: Ensure enclave data available during debug print (Vladis Dronov) [2081354]
- selftests/sgx: Do not attempt enclave build without valid enclave (Vladis Dronov) [2081354]
- selftests/sgx: Fix NULL-pointer-dereference upon early test failure (Vladis Dronov) [2081354]
- x86/sgx: Remove .fixup usage (Vladis Dronov) [2081354]
- x86/sgx: Fix NULL pointer dereference on non-SGX systems (Vladis Dronov) [2081354]
- x86/sgx: Add an attribute for the amount of SGX memory in a NUMA node (Vladis Dronov) [2081354]
- selftests/sgx: Fix corrupted cpuid macro invocation (Vladis Dronov) [2081354]
- drivers/base/node.c: use bin_attribute to break the size limitation of cpumap ABI (Vladis Dronov) [2081354]

* Wed Jun 22 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-117.rt21.117.el9]
- [rt] build kernel-rt-5.14.0-117.rt21.117.el9 [2061574]
- powerpc/rtas: rtas_busy_delay() improvements (Gustavo Walbon) [2050890]
- scripts/pahole-flags.sh: use exit instead of return at the top level (Yauheni Kaliuta) [2098127]
- rhel config: Set DMAR_UNITS_SUPPORTED (Jerry Snitselaar) [2094984]
- iommu/vt-d: Make DMAR_UNITS_SUPPORTED a config setting (Jerry Snitselaar) [2094984]
- xfs: validate inode fork size against fork format (Andrey Albershteyn) [2089441]
- Adding CONFIG_NVME_VERBOSE_ERRORS to nvme (Gopal Tiwari) [2091823]
- nvme: add missing status values to verbose logging (Gopal Tiwari) [2091823]
- nvme: don't print verbose errors for internal passthrough requests (Gopal Tiwari) [2091823]
- nvme: add verbose error logging (Gopal Tiwari) [2091823]
- ionic: fix missing pci_release_regions() on error in ionic_probe() (Jonathan Toppins) [2050903]
- ionic: no transition while stopping (Jonathan Toppins) [2050903]
- ionic: use vmalloc include (Jonathan Toppins) [2050903]
- ionic: clean up comments and whitespace (Jonathan Toppins) [2050903]
- ionic: prefer strscpy over strlcpy (Jonathan Toppins) [2050903]
- ionic: Use vzalloc for large per-queue related buffers (Jonathan Toppins) [2050903]
- ionic: catch transition back to RUNNING with fw_generation 0 (Jonathan Toppins) [2050903]
- ionic: replace set_vf data with union (Jonathan Toppins) [2050903]
- ionic: stretch heartbeat detection (Jonathan Toppins) [2050903]
- ionic: remove the dbid_inuse bitmap (Jonathan Toppins) [2050903]
- ionic: disable napi when ionic_lif_init() fails (Jonathan Toppins) [2050903]
- ionic: Cleanups in the Tx hotpath code (Jonathan Toppins) [2050903]
- ionic: Prevent filter add/del err msgs when the device is not available (Jonathan Toppins) [2050903]
- ionic: Query FW when getting VF info via ndo_get_vf_config (Jonathan Toppins) [2050903]
- ionic: Allow flexibility for error reporting on dev commands (Jonathan Toppins) [2050903]
- ionic: Correctly print AQ errors if completions aren't received (Jonathan Toppins) [2050903]
- ionic: fix up printing of timeout error (Jonathan Toppins) [2050903]
- ionic: better handling of RESET event (Jonathan Toppins) [2050903]
- ionic: add FW_STOPPING state (Jonathan Toppins) [2050903]
- ionic: Don't send reset commands if FW isn't running (Jonathan Toppins) [2050903]
- ionic: separate function for watchdog init (Jonathan Toppins) [2050903]
- ionic: start watchdog after all is setup (Jonathan Toppins) [2050903]
- ionic: fix type complaint in ionic_dev_cmd_clean() (Jonathan Toppins) [2050903]
- [s390] s390/airq: use DMA memory for summary indicators (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: Provide target domain for EP11 cprbs to scheduling function (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: change reply buffer size offering (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: Support CPRB minor version T7 (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: handle checkstopped cards with new state (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: CEX8S exploitation support (Tobias Huschle) [2044351]
- [s390] s390/ap/zcrypt: debug feature improvements (Tobias Huschle) [2044351]
- [s390] s390/zcrypt: rework of debug feature messages (Tobias Huschle) [2044351]
- PCI: xgene: Revert "PCI: xgene: Fix IB window setup" (Myron Stowe) [2068174]
- PCI: xgene: Revert "PCI: xgene: Use inbound resources for setup" (Myron Stowe) [2068174]
- PCI: uniphier-ep: Add NX1 support (Myron Stowe) [2068174]
- PCI: uniphier-ep: Add SoC data structure (Myron Stowe) [2068174]
- dt-bindings: PCI: uniphier-ep: Add bindings for NX1 SoC (Myron Stowe) [2068174]
- PCI: rcar: Use PCI_SET_ERROR_RESPONSE after read which triggered an exception (Myron Stowe) [2068174]
- PCI: rcar: Finish transition to L1 state in rcar_pcie_config_access() (Myron Stowe) [2068174]
- PCI: qcom: Add SM8450 PCIe support (Myron Stowe) [2068174]
- PCI: qcom: Add ddrss_sf_tbu flag (Myron Stowe) [2068174]
- PCI: qcom: Remove redundancy between qcom_pcie and qcom_pcie_cfg (Myron Stowe) [2068174]
- dt-bindings: pci: qcom: Document PCIe bindings for SM8450 (Myron Stowe) [2068174]
- PCI: mvebu: Implement support for legacy INTx interrupts (Myron Stowe) [2068174]
- PCI: mvebu: Fix macro names and comments about legacy interrupts (Myron Stowe) [2068174]
- dt-bindings: PCI: mvebu: Update information about intx interrupts (Myron Stowe) [2068174]
- PCI: mvebu: Use child_ops API (Myron Stowe) [2068174]
- PCI: mvebu: Add support for Advanced Error Reporting registers on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Add support for PCI Bridge Subsystem Vendor ID on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Correctly configure x1/x4 mode (Myron Stowe) [2068174]
- dt-bindings: PCI: mvebu: Add num-lanes property (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Add support for PCI Bridge Subsystem Vendor ID capability (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Add support for PCIe extended capabilities (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Re-arrange register tests (Myron Stowe) [2068174]
- PCI: mvebu: Fix reporting Data Link Layer Link Active on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Update comment for PCI_EXP_LNKCTL register on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Update comment for PCI_EXP_LNKCAP register on emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Properly initialize vendor, device and revision of emulated bridge (Myron Stowe) [2068174]
- PCI: mvebu: Set PCI_BRIDGE_EMUL_NO_IO_FORWARD when IO is unsupported (Myron Stowe) [2068174]
- PCI: mvebu: Remove duplicate nports assignment (Myron Stowe) [2068174]
- PCI: mvebu: Add help string for CONFIG_PCI_MVEBU option (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Add support for new flag PCI_BRIDGE_EMUL_NO_IO_FORWARD (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Rename PCI_BRIDGE_EMUL_NO_PREFETCHABLE_BAR to PCI_BRIDGE_EMUL_NO_PREFMEM_FORWARD (Myron Stowe) [2068174]
- PCI: pci-bridge-emul: Make struct pci_bridge_emul_ops as const (Myron Stowe) [2068174]
- MAINTAINERS: Add Pali Rohár as pci-mvebu.c maintainer (Myron Stowe) [2068174]
- sizes.h: Add SZ_1T macro (Myron Stowe) [2068174]
- PCI: imx6: Assert i.MX8MM CLKREQ# even if no device present (Myron Stowe) [2068174]
- PCI: imx6: Invoke the PHY exit function after PHY power off (Myron Stowe) [2068174]
- PCI: imx6: Enable i.MX6QP PCIe power management support (Myron Stowe) [2068174]
- PCI: imx6: Allow to probe when dw_pcie_wait_for_link() fails (Myron Stowe) [2068174]
- PCI: fu740: Force 2.5GT/s for initial device probe (Myron Stowe) [2068174]
- PCI: fu740: Drop redundant '-gpios' from DT GPIO lookup (Myron Stowe) [2068174]
- PCI: endpoint: Fix misused goto label (Myron Stowe) [2068174]
- PCI: endpoint: Fix alignment fault error in copy tests (Myron Stowe) [2068174]
- PCI: dwc: Restore MSI Receiver mask during resume (Myron Stowe) [2068174]
- PCI: aardvark: Update comment about link going down after link-up (Myron Stowe) [2068174]
- PCI: aardvark: Drop __maybe_unused from advk_pcie_disable_phy() (Myron Stowe) [2068174]
- PCI: aardvark: Don't mask irq when mapping (Myron Stowe) [2068174]
- PCI: aardvark: Remove irq_mask_ack() callback for INTx interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Use separate INTA interrupt for emulated root bridge (Myron Stowe) [2068174]
- PCI: aardvark: Fix support for PME requester on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Add support for PME interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Optimize writing PCI_EXP_RTCTL_PMEIE and PCI_EXP_RTSTA_PME on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Fix reading PCI_EXP_RTSTA_PME bit on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Add support for ERR interrupt on emulated bridge (Myron Stowe) [2068174]
- PCI: aardvark: Enable MSI-X support (Myron Stowe) [2068174]
- PCI: aardvark: Fix setting MSI address (Myron Stowe) [2068174]
- PCI: aardvark: Add support for masking MSI interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Refactor unmasking summary MSI interrupt (Myron Stowe) [2068174]
- PCI: aardvark: Use dev_fwnode() instead of of_node_to_fwnode(dev->of_node) (Myron Stowe) [2068174]
- PCI: aardvark: Make msi_domain_info structure a static driver structure (Myron Stowe) [2068174]
- PCI: aardvark: Make MSI irq_chip structures static driver structures (Myron Stowe) [2068174]
- PCI: aardvark: Check return value of generic_handle_domain_irq() when processing INTx IRQ (Myron Stowe) [2068174]
- PCI: aardvark: Rewrite IRQ code to chained IRQ handler (Myron Stowe) [2068174]
- PCI: aardvark: Fix support for MSI interrupts (Myron Stowe) [2068174]
- PCI: aardvark: Fix reading MSI interrupt number (Myron Stowe) [2068174]
- PCI: aardvark: Replace custom PCIE_CORE_INT_* macros with PCI_INTERRUPT_* (Myron Stowe) [2068174]
- PCI/VGA: Replace full MIT license text with SPDX identifier (Myron Stowe) [2068174]
- PCI/VGA: Use unsigned format string to print lock counts (Myron Stowe) [2068174]
- PCI/VGA: Log bridge control messages when adding devices (Myron Stowe) [2068174]
- PCI/VGA: Remove empty vga_arb_device_card_gone() (Myron Stowe) [2068174]
- PCI/VGA: Move disabled VGA device detection to ADD_DEVICE path (Myron Stowe) [2068174]
- PCI/VGA: Move non-legacy VGA detection to ADD_DEVICE path (Myron Stowe) [2068174]
- PCI/VGA: Move firmware default device detection to ADD_DEVICE path (Myron Stowe) [2068174]
- PCI/VGA: Factor out default VGA device selection (Myron Stowe) [2068174]
- PCI/VGA: Factor out vga_select_framebuffer_device() (Myron Stowe) [2068174]
- PCI/VGA: Move vga_arb_integrated_gpu() earlier in file (Myron Stowe) [2068174]
- PCI/P2PDMA: Add Intel 3rd Gen Intel Xeon Scalable Processors to whitelist (Myron Stowe) [2068174]
- PCI: Avoid broken MSI on SB600 USB devices (Myron Stowe) [2068174]
- x86/PCI: Add #includes to asm/pci_x86.h (Myron Stowe) [2068174]
- PCI: ibmphp: Remove unused assignments (Myron Stowe) [2068174]
- PCI: cpqphp: Remove unused assignments (Myron Stowe) [2068174]
- PCI: fu740: Remove unused assignments (Myron Stowe) [2068174]
- PCI: kirin: Remove unused assignments (Myron Stowe) [2068174]
- PCI: Remove unused assignments (Myron Stowe) [2068174]
- PCI: Declare pci_filp_private only when HAVE_PCI_MMAP (Myron Stowe) [2068174]
- PCI/AER: Update aer-inject URL (Myron Stowe) [2068174]
- PCI: pciehp: Add Qualcomm quirk for Command Completed erratum (Myron Stowe) [2068174]
- PCI: pciehp: Clear cmd_busy bit in polling mode (Myron Stowe) [2068174]
- PCI: Reduce warnings on possible RW1C corruption (Myron Stowe) [2068174]
- PCI: Support BAR sizes up to 8TB (Myron Stowe) [2068174]
- PCI: iproc: Set all 24 bits of PCI class code (Myron Stowe) [2068174]
- PCI: Add defines for normal and subtractive PCI bridges (Myron Stowe) [2068174]
- PCI/ACPI: Replace acpi_bus_get_device() with acpi_fetch_acpi_dev() (Myron Stowe) [2068174]
- xsk: Do not write NULL in SW ring at allocation failure (Felix Maurer) [2071619]
- selftests, xsk: Fix rx_full stats test (Felix Maurer) [2071619]
- bpf, sockmap: Fix double bpf_prog_put on error case in map_link (Felix Maurer) [2071619]
- bpf, sockmap: Fix return codes from tcp_bpf_recvmsg_parser() (Felix Maurer) [2071619]
- xsk: Initialise xskb free_list_node (Felix Maurer) [2071619]
- netdevsim: Zero-initialize memory for new map's value in function nsim_bpf_map_alloc (Felix Maurer) [2071619]
- bpf, sockmap: Re-evaluate proto ops when psock is removed from sockmap (Felix Maurer) [2071619]
- bpf, sockmap: Attach map progs to psock early for feature probes (Felix Maurer) [2071619]
- selftests/bpf: Fix xdpxceiver failures for no hugepages (Felix Maurer) [2071619]
- page_pool: Revert "page_pool: disable dma mapping support..." (Felix Maurer) [2071619]
- xsk: Fix crash on double free in buffer pool (Felix Maurer) [2071619]
- bpf, sockmap: sk_skb data_end access incorrect when src_reg = dst_reg (Felix Maurer) [2071619]
- bpf: sockmap, strparser, and tls are reusing qdisc_skb_cb and colliding (Felix Maurer) [2071619]
- bpf, sockmap: Fix race in ingress receive verdict with redirect to self (Felix Maurer) [2071619]
- bpf, sockmap: Remove unhash handler for BPF sockmap usage (Felix Maurer) [2071619]
- selftests, bpf: Add one test for sockmap with strparser (Felix Maurer) [2071619]
- selftests, bpf: Fix test_txmsg_ingress_parser error (Felix Maurer) [2071619]
- skmsg: Lose offset info in sk_psock_skb_ingress (Felix Maurer) [2071619]
- xdp: Remove redundant warning (Felix Maurer) [2071619]
- page_pool: disable dma mapping support for 32-bit arch with 64-bit DMA (Felix Maurer) [2071619]
- xsk: Fix clang build error in __xp_alloc (Felix Maurer) [2071619]
- selftests: xsk: Add frame_headroom test (Felix Maurer) [2071619]
- selftests: xsk: Change interleaving of packets in unaligned mode (Felix Maurer) [2071619]
- selftests: xsk: Add single packet test (Felix Maurer) [2071619]
- selftests: xsk: Introduce pacing of traffic (Felix Maurer) [2071619]
- selftests: xsk: Fix socket creation retry (Felix Maurer) [2071619]
- selftests: xsk: Put the same buffer only once in the fill ring (Felix Maurer) [2071619]
- selftests: xsk: Fix missing initialization (Felix Maurer) [2071619]
- xsk: Optimize for aligned case (Felix Maurer) [2071619]
- xsk: Batched buffer allocation for the pool (Felix Maurer) [2071619]
- xsk: Get rid of unused entry in struct xdp_buff_xsk (Felix Maurer) [2071619]
- selftests: xsk: Add tests for 2K frame size (Felix Maurer) [2071619]
- selftests: xsk: Add tests for invalid xsk descriptors (Felix Maurer) [2071619]
- selftests: xsk: Eliminate test specific if-statement in test runner (Felix Maurer) [2071619]
- selftests: xsk: Add test for unaligned mode (Felix Maurer) [2071619]
- selftests: xsk: Introduce replacing the default packet stream (Felix Maurer) [2071619]
- selftests: xsk: Allow for invalid packets (Felix Maurer) [2071619]
- selftests: xsk: Eliminate MAX_SOCKS define (Felix Maurer) [2071619]
- selftests: xsx: Make pthreads local scope (Felix Maurer) [2071619]
- selftests: xsk: Make xdp_flags and bind_flags local (Felix Maurer) [2071619]
- selftests: xsk: Specify number of sockets to create (Felix Maurer) [2071619]
- selftests: xsk: Replace second_step global variable (Felix Maurer) [2071619]
- selftests: xsk: Introduce rx_on and tx_on in ifobject (Felix Maurer) [2071619]
- selftests: xsk: Add use_poll to ifobject (Felix Maurer) [2071619]
- selftests: xsx: Introduce test name in test spec (Felix Maurer) [2071619]
- selftests: xsk: Make frame_size configurable (Felix Maurer) [2071619]
- selftests: xsk: Move rxqsize into xsk_socket_info (Felix Maurer) [2071619]
- selftests: xsk: Move num_frames and frame_headroom to xsk_umem_info (Felix Maurer) [2071619]
- selftests: xsk: Introduce test specifications (Felix Maurer) [2071619]
- selftests: xsk: Introduce type for thread function (Felix Maurer) [2071619]
- selftests: xsk: Simplify xsk and umem arrays (Felix Maurer) [2071619]

* Tue Jun 21 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-116.rt21.116.el9]
- [rt] build kernel-rt-5.14.0-116.rt21.116.el9 [2061574]
- net/sched: act_api: fix error code in tcf_ct_flow_table_fill_tuple_ipv6() (Ivan Vecera) [2090410]
- net/sched: act_pedit: sanitize shift argument before usage (Ivan Vecera) [2090410]
- net/sched: act_pedit: really ensure the skb is writable (Ivan Vecera) [2090410]
- net/sched: cls_u32: fix possible leak in u32_init_knode() (Ivan Vecera) [2090410]
- net/sched: cls_u32: fix netns refcount changes in u32_change() (Ivan Vecera) [2090410]
- net/sched: taprio: Check if socket flags are valid (Ivan Vecera) [2090410]
- net/sched: fix initialization order when updating chain 0 head (Ivan Vecera) [2090410]
- net/sched: flower: fix parsing of ethertype following VLAN header (Ivan Vecera) [2090410]
- net/sched: act_ct: fix ref leak when switching zones (Ivan Vecera) [2090410]
- net/sched: fix incorrect vlan_push_eth dest field (Ivan Vecera) [2090410]
- net/sched: add vlan push_eth and pop_eth action to the hardware IR (Ivan Vecera) [2090410]
- flow_offload: improve extack msg for user when adding invalid filter (Ivan Vecera) [2090410]
- net/sched: act_ct: Fix flow table lookup failure with no originating ifindex (Ivan Vecera) [2090410]
- act_ct: Support GRE offload (Ivan Vecera) [2090410]
- flow_offload: reject offload for all drivers with invalid police parameters (Ivan Vecera) [2090410]
- net: flow_offload: add tc police action parameters (Ivan Vecera) [2090410]
- net: sched: avoid newline at end of message in NL_SET_ERR_MSG_MOD (Ivan Vecera) [2090410]
- net/sched: act_ct: Fix flow table lookup after ct clear or switching zones (Ivan Vecera) [2090410]
- net: sched: limit TC_ACT_REPEAT loops (Ivan Vecera) [2090410]
- net_sched: add __rcu annotation to netdev->qdisc (Ivan Vecera) [2090410]
- net/sched: act_police: more accurate MTU policing (Ivan Vecera) [2090410]
- net/sched: Enable tc skb ext allocation on chain miss only when needed (Ivan Vecera) [2090410]
- net: sched: fix use-after-free in tc_new_tfilter() (Ivan Vecera) [2090410]
- net: sched: remove qdisc_qlen_cpu() (Ivan Vecera) [2090410]
- net: sched: remove psched_tdiff_bounded() (Ivan Vecera) [2090410]
- sch_htb: Fail on unsupported parameters when offload is requested (Ivan Vecera) [2090410]
- netfilter: nft_ct: fix use after free when attaching zone template (Ivan Vecera) [2090410]
- netfilter: conntrack: remove extension register api (Ivan Vecera) [2090410]
- netfilter: conntrack: handle ->destroy hook via nat_ops instead (Ivan Vecera) [2090410]
- netfilter: conntrack: move extension sizes into core (Ivan Vecera) [2090410]
- netfilter: conntrack: make all extensions 8-byte alignned (Ivan Vecera) [2090410]
- net: sched: Clarify error message when qdisc kind is unknown (Ivan Vecera) [2090410]
- net_sched: restore "mpu xxx" handling (Ivan Vecera) [2090410]
- net: prefer nf_ct_put instead of nf_conntrack_put (Ivan Vecera) [2090410]
- netfilter: conntrack: avoid useless indirection during conntrack destruction (Ivan Vecera) [2090410]
- netfilter: make function op structures const (Ivan Vecera) [2090410]
- netfilter: core: move ip_ct_attach indirection to struct nf_ct_hook (Ivan Vecera) [2090410]
- netfilter: conntrack: convert to refcount_t api (Ivan Vecera) [2090410]
- sch_cake: revise Diffserv docs (Ivan Vecera) [2090410]
- sch_qfq: prevent shift-out-of-bounds in qfq_init_qdisc (Ivan Vecera) [2090410]
- net: openvswitch: Fill act ct extension (Ivan Vecera) [2090410]
- net/sched: act_ct: Fill offloading tuple iifidx (Ivan Vecera) [2090410]
- flow_offload: fix suspicious RCU usage when offloading tc action (Ivan Vecera) [2090410]
- net/sched: use min() macro instead of doing it manually (Ivan Vecera) [2090410]
- selftests: tc-testing: add action offload selftest for action and filter (Ivan Vecera) [2090410]
- flow_offload: validate flags of filter and actions (Ivan Vecera) [2090410]
- flow_offload: add reoffload process to update hw_count (Ivan Vecera) [2090410]
- net: sched: save full flags for tc action (Ivan Vecera) [2090410]
- flow_offload: add process to update action stats from hardware (Ivan Vecera) [2090410]
- flow_offload: rename exts stats update functions with hw (Ivan Vecera) [2090410]
- flow_offload: add skip_hw and skip_sw to control if offload the action (Ivan Vecera) [2090410]
- flow_offload: allow user to offload tc action to net device (Ivan Vecera) [2090410]
- flow_offload: add ops to tc_action_ops for flow action setup (Ivan Vecera) [2090410]
- flow_offload: rename offload functions with offload instead of flow (Ivan Vecera) [2090410]
- flow_offload: add index to flow_action_entry structure (Ivan Vecera) [2090410]
- flow_offload: reject to offload tc actions in offload drivers (Ivan Vecera) [2090410]
- flow_offload: fill flags to action structure (Ivan Vecera) [2090410]
- net/sched: act_ct: Offload only ASSURED connections (Ivan Vecera) [2090410]
- netfilter: nfnetlink_queue: silence bogus compiler warning (Ivan Vecera) [2090410]
- selftests/tc-testing: match any qdisc type (Ivan Vecera) [2090410]
- net: sched: sch_netem: Refactor code in 4-state loss generator (Ivan Vecera) [2090410]
- selftests: forwarding: Fix packet matching in mirroring selftests (Ivan Vecera) [2090410]
- cls_flower: Fix inability to match GRE/IPIP packets (Ivan Vecera) [2090410]
- sch_htb: Add extack messages for EOPNOTSUPP errors (Ivan Vecera) [2090410]
- net: sch: simplify condtion for selecting mini_Qdisc_pair buffer (Ivan Vecera) [2090410]
- net: sch: eliminate unnecessary RCU waits in mini_qdisc_pair_swap() (Ivan Vecera) [2090410]
- net: sched: gred: dynamically allocate tc_gred_qopt_offload (Ivan Vecera) [2090410]
- net: stats: Read the statistics in ___gnet_stats_copy_basic() instead of adding. (Ivan Vecera) [2090410]
- net: sched: Allow statistics reads from softirq. (Ivan Vecera) [2090410]
- net: sch_tbf: Add a graft command (Ivan Vecera) [2090410]
- net: sched: remove one pair of atomic operations (Ivan Vecera) [2090410]
- net: sched: fix logic error in qdisc_run_begin() (Ivan Vecera) [2090410]
- net: sched: Remove Qdisc::running sequence counter (Ivan Vecera) [2090410]
- net: sched: Merge Qdisc::bstats and Qdisc::cpu_bstats data types (Ivan Vecera) [2090410]
- net: sched: Use _bstats_update/set() instead of raw writes (Ivan Vecera) [2090410]
- net: sched: Protect Qdisc::bstats with u64_stats (Ivan Vecera) [2090410]
- u64_stats: Introduce u64_stats_set() (Ivan Vecera) [2090410]
- gen_stats: Move remaining users to gnet_stats_add_queue(). (Ivan Vecera) [2090410]
- mq, mqprio: Use gnet_stats_add_queue(). (Ivan Vecera) [2090410]
- gen_stats: Add gnet_stats_add_queue(). (Ivan Vecera) [2090410]
- gen_stats: Add instead Set the value in __gnet_stats_copy_basic(). (Ivan Vecera) [2090410]
- net: sched: Use struct_size() helper in kvmalloc() (Ivan Vecera) [2090410]
- net_sched: Use struct_size() and flex_array_size() helpers (Ivan Vecera) [2090410]
- net: prevent user from passing illegal stab size (Ivan Vecera) [2090410]
- net: sched: move and reuse mq_change_real_num_tx() (Ivan Vecera) [2090410]
- selftests: net: test ethtool -L vs mq (Ivan Vecera) [2090410]
- netdevsim: add ability to change channel count (Ivan Vecera) [2090410]
- net: sched: update default qdisc visibility after Tx queue cnt changes (Ivan Vecera) [2090410]
- fix array-index-out-of-bounds in taprio_change (Ivan Vecera) [2090410]
- net/sched: cls_api, reset flags on replay (Ivan Vecera) [2090410]
- tc-testing: Add control-plane selftests for sch_mq (Ivan Vecera) [2090410]
- net_sched: refactor TC action init API (Ivan Vecera) [2090410]
- tc-testing: Add control-plane selftest for skbmod SKBMOD_F_ECN option (Ivan Vecera) [2090410]
- net/sched: act_skbmod: Add SKBMOD_F_ECN option support (Ivan Vecera) [2090410]
- qdisc: add new field for qdisc_enqueue tracepoint (Ivan Vecera) [2090410]
- net/sched: Remove unnecessary if statement (Ivan Vecera) [2090410]
- iommu/amd: Enable swiotlb in all cases (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3-sva: Fix mm use-after-free (Jerry Snitselaar) [2072170]
- iommu/dma: Fix iova map result check bug (Jerry Snitselaar) [2072170]
- crypto: qat - remove dma_free_coherent() for RSA (Jerry Snitselaar) [2072170]
- iommu/amd: Do not call sleep while holding spinlock (Jerry Snitselaar) [2072170]
- iommu/amd: Remove redundant check (Jerry Snitselaar) [2072170]
- iommu/amd: Increase timeout waiting for GA log enablement (Jerry Snitselaar) [2072170]
- dma-direct: don't over-decrypt memory (Jerry Snitselaar) [2072170]
- swiotlb: max mapping size takes min align mask into account (Jerry Snitselaar) [2072170]
- dma-debug: change allocation mode from GFP_NOWAIT to GFP_ATIOMIC (Jerry Snitselaar) [2072170]
- dma-direct: don't fail on highmem CMA pages in dma_direct_alloc_pages (Jerry Snitselaar) [2072170]
- swiotlb: make swiotlb_exit a no-op if SWIOTLB_FORCE is set (Jerry Snitselaar) [2072170]
- dma-direct: use is_swiotlb_active in dma_direct_map_page (Jerry Snitselaar) [2072170]
- iommu: Make sysfs robust for non-API groups (Jerry Snitselaar) [2072170]
- iommu: arm-smmu: disable large page mappings for Nvidia arm-smmu (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Fix size calculation in arm_smmu_mm_invalidate_range() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Drop stop marker messages (Jerry Snitselaar) [2072170]
- iommu/vt-d: Calculate mask for non-aligned flushes (Jerry Snitselaar) [2072170]
- dma-direct: avoid redundant memory sync for swiotlb (Jerry Snitselaar) [2072170]
- dma-mapping: move pgprot_decrypted out of dma_pgprot (Jerry Snitselaar) [2072170]
- dma-mapping: benchmark: extract a common header file for map_benchmark definition (Jerry Snitselaar) [2072170]
- dma-debug: fix return value of __setup handlers (Jerry Snitselaar) [2072170]
- dma-mapping: remove CONFIG_DMA_REMAP (Jerry Snitselaar) [2072170]
- swiotlb: simplify array allocation (Jerry Snitselaar) [2072170]
- swiotlb: tidy up includes (Jerry Snitselaar) [2072170]
- swiotlb: simplify debugfs setup (Jerry Snitselaar) [2072170]
- swiotlb: do not zero buffer in set_memory_decrypted() (Jerry Snitselaar) [2072170]
- iommu/amd: Improve amd_iommu_v2_exit() (Jerry Snitselaar) [2072170]
- iommu/amd: Remove unused struct fault.devid (Jerry Snitselaar) [2072170]
- iommu/amd: Clean up function declarations (Jerry Snitselaar) [2072170]
- iommu/amd: Call memunmap in error path (Jerry Snitselaar) [2072170]
- iommu/amd: Improve error handling for amd_iommu_init_pci (Jerry Snitselaar) [2072170]
- iommu/vt-d: Enable ATS for the devices in SATC table (Jerry Snitselaar) [2008729]
- iommu/vt-d: Remove unused function intel_svm_capable() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Add missing "__init" for rmrr_sanity_check() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Move intel_iommu_ops to header file (Jerry Snitselaar) [2072170]
- iommu/vt-d: Fix indentation of goto labels (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unnecessary prototypes (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unnecessary includes (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove DEFER_DEVICE_DOMAIN_INFO (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove domain and devinfo mempool (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove iova_cache_get/put() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove finding domain in dmar_insert_one_dev_info() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove intel_iommu::domains (Jerry Snitselaar) [2072170]
- iommu/iova: Improve 32-bit free space estimate (Jerry Snitselaar) [2072170]
- iommu: Split struct iommu_ops (Jerry Snitselaar) [2072170]
- iommu: Remove unused argument in is_attach_deferred (Jerry Snitselaar) [2072170]
- iommu: Use right way to retrieve iommu_ops (Jerry Snitselaar) [2072170]
- iommu: Remove apply_resv_region (Jerry Snitselaar) [2072170]
- iommu: Remove aux-domain related interfaces and iommu_ops (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove aux-domain related callbacks (Jerry Snitselaar) [2072170]
- iommu: Remove guest pasid related interfaces and definitions (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove guest pasid related callbacks (Jerry Snitselaar) [2072170]
- iommu/iova: Separate out rcache init (Jerry Snitselaar) [2072170]
- iommu/arm-smmu: Account for PMU interrupts (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: fix event handling soft lockup (Jerry Snitselaar) [2072170]
- iommu/arm-smmu: Add missing pm_runtime_disable() in qcom_iommu_device_probe (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Simplify memory allocation (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Avoid open coded arithmetic in memory allocation (Jerry Snitselaar) [2072170]
- iommu/amd: Fix loop timeout issue in iommu_ga_log_enable() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Fix potential memory leak in intel_setup_irq_remapping() (Jerry Snitselaar) [2072170]
- iommu: Fix some W=1 warnings (Jerry Snitselaar) [2072170]
- iommu: Fix potential use-after-free during probe (Jerry Snitselaar) [2072170]
- swiotlb: Add CONFIG_HAS_IOMEM check around swiotlb_mem_remap() (Jerry Snitselaar) [2072170]
- swiotlb: Add swiotlb bounce buffer remap function for HV IVM (Jerry Snitselaar) [2072170]
- iommu/iova: Temporarily include dma-mapping.h from iova.h (Jerry Snitselaar) [2072170]
- iommu: Move flush queue data into iommu_dma_cookie (Jerry Snitselaar) [2072170]
- iommu/iova: Move flush queue code to iommu-dma (Jerry Snitselaar) [2072170]
- iommu/iova: Consolidate flush queue code (Jerry Snitselaar) [2072170]
- iommu/vt-d: Use put_pages_list (Jerry Snitselaar) [2072170]
- iommu/amd: Use put_pages_list (Jerry Snitselaar) [2072170]
- iommu/amd: Simplify pagetable freeing (Jerry Snitselaar) [2072170]
- iommu/iova: Squash flush_cb abstraction (Jerry Snitselaar) [2072170]
- iommu/iova: Squash entry_dtor abstraction (Jerry Snitselaar) [2072170]
- iommu/iova: Fix race between FQ timeout and teardown (Jerry Snitselaar) [2072170]
- iommu/iova: Move fast alloc size roundup into alloc_iova_fast() (Jerry Snitselaar) [2072170]
- iommu/io-pgtable-arm: Fix table descriptor paddr formatting (Jerry Snitselaar) [2072170]
- iommu: Extend mutex lock scope in iommu_probe_device() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unused dma_to_mm_pfn function (Jerry Snitselaar) [2072170]
- iommu/vt-d: Drop duplicate check in dma_pte_free_pagetable() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Use bitmap_zalloc() when applicable (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove unused macros (Jerry Snitselaar) [2072170]
- iommu/amd: Fix typo in *glues … together* in comment (Jerry Snitselaar) [2072170]
- iommu/amd: Remove useless irq affinity notifier (Jerry Snitselaar) [2072170]
- iommu/amd: X2apic mode: mask/unmask interrupts on suspend/resume (Jerry Snitselaar) [2072170]
- iommu/amd: X2apic mode: setup the INTX registers on mask/unmask (Jerry Snitselaar) [2072170]
- iommu/amd: X2apic mode: re-enable after resume (Jerry Snitselaar) [2072170]
- iommu/amd: Restore GA log/tail pointer on host resume (Jerry Snitselaar) [2072170]
- Revert "iommu/arm-smmu-v3: Decrease the queue size of evtq and priq" (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Constify arm_smmu_mmu_notifier_ops (Jerry Snitselaar) [2072170]
- iommu: arm-smmu-impl: Add SM8450 qcom iommu implementation (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-qcom: Fix TTBR0 read (Jerry Snitselaar) [2072170]
- dma-direct: add a dma_direct_use_pool helper (Jerry Snitselaar) [2072170]
- dma-direct: factor the swiotlb code out of __dma_direct_alloc_pages (Jerry Snitselaar) [2072170]
- dma-direct: drop two CONFIG_DMA_RESTRICTED_POOL conditionals (Jerry Snitselaar) [2072170]
- dma-direct: warn if there is no pool for force unencrypted allocations (Jerry Snitselaar) [2072170]
- dma-direct: fail allocations that can't be made coherent (Jerry Snitselaar) [2072170]
- dma-direct: refactor the !coherent checks in dma_direct_alloc (Jerry Snitselaar) [2072170]
- dma-direct: factor out a helper for DMA_ATTR_NO_KERNEL_MAPPING allocations (Jerry Snitselaar) [2072170]
- dma-direct: clean up the remapping checks in dma_direct_alloc (Jerry Snitselaar) [2072170]
- dma-direct: always leak memory that can't be re-encrypted (Jerry Snitselaar) [2072170]
- dma-direct: don't call dma_set_decrypted for remapped allocations (Jerry Snitselaar) [2072170]
- dma-direct: factor out dma_set_{de,en}crypted helpers (Jerry Snitselaar) [2072170]
- iommu/vt-d: Fix an unbalanced rcu_read_lock/rcu_read_unlock() (Jerry Snitselaar) [2072170]
- iommu/amd: Clarify AMD IOMMUv2 initialization messages (Jerry Snitselaar) [2072170]
- dma-mapping: use 'bitmap_zalloc()' when applicable (Jerry Snitselaar) [2072170]
- iommu/dma: Use kvcalloc() instead of kvzalloc() (Jerry Snitselaar) [2072170]
- iommu/dma: Account for min_align_mask w/swiotlb (Jerry Snitselaar) [2072170]
- swiotlb: Support aligned swiotlb buffers (Jerry Snitselaar) [2072170]
- iommu/dma: Check CONFIG_SWIOTLB more broadly (Jerry Snitselaar) [2072170]
- iommu/dma: Fold _swiotlb helpers into callers (Jerry Snitselaar) [2072170]
- iommu/dma: Skip extra sync during unmap w/swiotlb (Jerry Snitselaar) [2072170]
- iommu/dma: Fix arch_sync_dma for map (Jerry Snitselaar) [2072170]
- iommu/dma: Fix sync_sg with swiotlb (Jerry Snitselaar) [2072170]
- iommu/vt-d: Avoid duplicate removing in __domain_mapping() (Jerry Snitselaar) [2072170]
- iommu/vt-d: Convert the return type of first_pte_in_page to bool (Jerry Snitselaar) [2072170]
- iommu/vt-d: Delete dev_has_feat callback (Jerry Snitselaar) [2072170]
- iommu/vt-d: Use second level for GPA->HPA translation (Jerry Snitselaar) [2072170]
- iommu/vt-d: Check FL and SL capability sanity in scalable mode (Jerry Snitselaar) [2072170]
- iommu/vt-d: Remove duplicate identity domain flag (Jerry Snitselaar) [2072170]
- iommu/vt-d: Dump DMAR translation structure when DMA fault occurs (Jerry Snitselaar) [1880620]
- iommu/vt-d: Do not falsely log intel_iommu is unsupported kernel option (Jerry Snitselaar) [2072170]
- iommu/amd: Use report_iommu_fault() (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-qcom: Request direct mapping for modem device (Jerry Snitselaar) [2072170]
- iommu: arm-smmu-qcom: Add compatible for QCM2290 (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-qcom: Add SM6350 SMMU compatible (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Properly handle the return value of arm_smmu_cmdq_build_cmd() (Jerry Snitselaar) [2072170]
- iommu/arm-smmu-v3: Stop pre-zeroing batch commands in arm_smmu_atc_inv_master() (Jerry Snitselaar) [2072170]
- iommu/dma: Unexport IOVA cookie management (Jerry Snitselaar) [2072170]
- iommu/amd: Use struct_group() for memcpy() region (Jerry Snitselaar) [2072170]
- dma-mapping: remove bogus test for pfn_valid from dma_map_resource (Jerry Snitselaar) [2072170]
- swiotlb-xen: ensure to issue well-formed XENMEM_exchange requests (Jerry Snitselaar) [2072170]
- iova: Export alloc_iova_fast() and free_iova_fast() (Jerry Snitselaar) [2072170]
- iommu/io-pgtable: Add DART pagetable format (Jerry Snitselaar) [2072170]

* Mon Jun 20 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-115.rt21.115.el9]
- [rt] build kernel-rt-5.14.0-115.rt21.115.el9 [2061574]
- video: fbdev: hyperv_fb: Allow resolutions with size > 64 MB for Gen1 (Mohammed Gamal) [2096917]
- hv_balloon: Fix balloon_probe() and balloon_remove() error handling (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: fix typo in comment (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Remove support for Hyper-V 2008 and Hyper-V 2008R2/Win7 (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Refactor the ring-buffer iterator functions (Mohammed Gamal) [2086622]
- hv_sock: Copy packets sent by Hyper-V out of the ring buffer (Mohammed Gamal) [2086622]
- hv_sock: Check hv_pkt_iter_first_raw()'s return value (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Accept hv_sock offers in isolated guests (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Introduce {lock,unlock}_requestor() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Introduce vmbus_request_addr_match() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Introduce vmbus_sendpacket_getid() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix handling of messages with transaction ID of zero (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Add VMbus IMC device to unsupported list (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Replace smp_store_mb() with virt_store_mb() (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: Disable balloon and hot-add accordingly (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: Support status report for larger page sizes (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Prevent load re-ordering when reading ring buffer (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix potential crash on module unload (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix initialization of device object in vmbus_device_register() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Deactivate sysctl_record_panic_msg by default in isolated guests (Mohammed Gamal) [2086622]
- drivers: hv: log when enabling crash_kexec_post_notifiers (Mohammed Gamal) [2086622]
- Drivers: hv: utils: Make use of the helper macro LIST_HEAD() (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Rework use of DMA_BIT_MASK(64) (Mohammed Gamal) [2086622]
- scsi: storvsc: Add Isolation VM support for storvsc driver (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Fix memory leak in vmbus_add_channel_kobj (Mohammed Gamal) [2086622]
- Drivers: hv: Compare cpumasks and not their weights in init_vp_index() (Mohammed Gamal) [2086622]
- Drivers: hv: Rename 'alloced' to 'allocated' (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Use struct_size() helper in kmalloc() (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: account for vmbus packet header in max_pkt_size (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Initialize request offers message for Isolation VM (Mohammed Gamal) [2086622]
- Drivers: hv: Fix definition of hypercall input & output arg variables (Mohammed Gamal) [2086622]
- hv: utils: add PTP_1588_CLOCK to Kconfig to fix build (Mohammed Gamal) [2086622]
- Drivers: hv: balloon: Use VMBUS_RING_SIZE() wrapper for dm_ring_size (Mohammed Gamal) [2086622]
- Drivers: hv : vmbus: Adding NULL pointer check (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Initialize VMbus ring buffer for Isolation VM (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Add SNP support for VMbus channel initiate message (Mohammed Gamal) [2086622]
- Drivers: hv: vmbus: Mark vmbus ring buffer visible to host in Isolation VM (Mohammed Gamal) [2086622]
- x86/fpu: KVM: Set the base guest FPU uABI size to sizeof(struct kvm_xsave) (Vitaly Kuznetsov) [2092468]
- ixgbevf: clean up some inconsistent indenting (Ken Cox) [2037982]
- ixgbevf: Require large buffers for build_skb on 82599VF (Ken Cox) [2037982]
- ixgbevf: Remove useless DMA-32 fallback configuration (Ken Cox) [2037982]
- ixgbevf: switch to napi_build_skb() (Ken Cox) [2037982]
- ixgbevf: Add support for new mailbox communication between PF and VF (Ken Cox) [2037982]
- ixgbevf: Mailbox improvements (Ken Cox) [2037982]
- ixgbevf: Add legacy suffix to old API mailbox functions (Ken Cox) [2037982]
- ixgbevf: Improve error handling in mailbox (Ken Cox) [2037982]
- ixgbevf: Rename MSGTYPE to SUCCESS and FAILURE (Ken Cox) [2037982]
- net: ixgbevf: Remove redundant initialization of variable ret_val (Ken Cox) [2037982]

* Mon Jun 20 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-114.rt21.114.el9]
- [rt] build kernel-rt-5.14.0-114.rt21.114.el9 [2061574]
- redhat/configs: Move CRYPTO_USER config to match ARK layout (Vladis Dronov) [2096894]
- redhat/configs: Drop outdated CRYPTO_ECDH configs (Vladis Dronov) [2096894]
- perf: Fix sys_perf_event_open() race against self (Michael Petlan) [2087966] {CVE-2022-1729}
- block: ignore RWF_HIPRI hint for sync dio (Ming Lei) [2071243]
- [s390] s390/qdio: clarify logical vs absolute in QIB's kerneldoc (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unneeded sanity check in qdio_do_sqbs() (Mete Durlu) [2044298]
- [s390] s390/qdio: split do_QDIO() (Mete Durlu) [2044298]
- [s390] s390/qdio: split qdio_inspect_queue() (Mete Durlu) [2044298]
- [s390] s390/qdio: clarify handler logic for qdio_handle_activate_check() (Mete Durlu) [2044298]
- [s390] s390/qdio: clean up access to queue in qdio_handle_activate_check() (Mete Durlu) [2044298]
- [s390] s390/qdio: avoid allocating the qdio_irq with GFP_DMA (Mete Durlu) [2044298]
- [s390] s390/qdio: improve handling of CIWs (Mete Durlu) [2044298]
- [s390] s390/qdio: remove QDIO_SBAL_SIZE macro (Mete Durlu) [2044298]
- [s390] scsi: zfcp: fix kernel doc comments (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unused support for SLIB parameters (Mete Durlu) [2044298]
- [s390] s390/qdio: consolidate QIB code (Mete Durlu) [2044298]
- [s390] s390/qdio: use dev_info() in qdio_print_subchannel_info() (Mete Durlu) [2044298]
- [s390] s390/qdio: fine-tune the queue sync (Mete Durlu) [2044298]
- [s390] s390/qdio: clean up SIGA capability tracking (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unused sync-after-IRQ infrastructure (Mete Durlu) [2044298]
- [s390] s390/qdio: use absolute data address in ESTABLISH ccw (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unused macros (Mete Durlu) [2044298]
- [s390] s390/qdio: clarify reporting of errors to the drivers (Mete Durlu) [2044298]
- [s390] s390/qdio: remove unneeded siga-sync for Output Queue (Mete Durlu) [2044298]
- [s390] s390/qdio: remove remaining tasklet & timer code (Mete Durlu) [2044298]
- scsi: lpfc: Correct BDE DMA address assignment for GEN_REQ_WQE (Dick Kennedy) [2063879]
- scsi: lpfc: Fix split code for FLOGI on FCoE (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.3 (Dick Kennedy) [2063879]
- scsi: lpfc: Use sg_dma_address() and sg_dma_len() macros for NVMe I/O (Dick Kennedy) [2063879]
- scsi: lpfc: Alter FPIN stat accounting logic (Dick Kennedy) [2063879]
- scsi: lpfc: Rework FDMI initialization after link up (Dick Kennedy) [2063879]
- scsi: lpfc: Change VMID registration to be based on fabric parameters (Dick Kennedy) [2063879]
- scsi: lpfc: Decrement outstanding gidft_inp counter if lpfc_err_lost_link() (Dick Kennedy) [2063879]
- scsi: lpfc: Use list_for_each_entry_safe() in rscn_recovery_check() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix dmabuf ptr assignment in lpfc_ct_reject_event() (Dick Kennedy) [2063879]
- scsi: lpfc: Inhibit aborts if external loopback plug is inserted (Dick Kennedy) [2063879]
- scsi: lpfc: Fix ndlp put following a LOGO completion (Dick Kennedy) [2063879]
- scsi: lpfc: Fill in missing ndlp kref puts in error paths (Dick Kennedy) [2063879]
- scsi: lpfc: Fix element offset in __lpfc_sli_release_iocbq_s4() (Dick Kennedy) [2063879]
- scsi: lpfc: Remove redundant lpfc_sli_prep_wqe() call (Dick Kennedy) [2063879]
- scsi: lpfc: Fix additional reference counting in lpfc_bsg_rport_els() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix resource leak in lpfc_sli4_send_seq_to_ulp() (Dick Kennedy) [2063879]
- scsi: lpfc: Remove unnecessary null ndlp check in lpfc_sli_prep_wqe() (Dick Kennedy) [2063879]
- scsi: lpfc: Remove unneeded variable (Dick Kennedy) [2063879]
- scsi: lpfc: Copyright updates for 14.2.0.2 patches (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.2 (Dick Kennedy) [2063879]
- scsi: lpfc: Expand setting ELS_ID field in ELS_REQUEST64_WQE (Dick Kennedy) [2063879]
- scsi: lpfc: Update stat accounting for READ_STATUS mbox command (Dick Kennedy) [2063879]
- scsi: lpfc: Refactor cleanup of mailbox commands (Dick Kennedy) [2063879]
- scsi: lpfc: Fix field overload in lpfc_iocbq data structure (Dick Kennedy) [2063879]
- scsi: lpfc: Register for Application Services FC-4 type in Fabric topology (Dick Kennedy) [2063879]
- scsi: lpfc: Remove false FDMI NVMe FC-4 support for NPIV ports (Dick Kennedy) [2063879]
- scsi: lpfc: Revise FDMI reporting of supported port speed for trunk groups (Dick Kennedy) [2063879]
- scsi: lpfc: Fix call trace observed during I/O with CMF enabled (Dick Kennedy) [2063879]
- scsi: lpfc: Correct CRC32 calculation for congestion stats (Dick Kennedy) [2063879]
- scsi: lpfc: Move MI module parameter check to handle dynamic disable (Dick Kennedy) [2063879]
- scsi: lpfc: Remove unnecessary NULL pointer assignment for ELS_RDF path (Dick Kennedy) [2063879]
- scsi: lpfc: Transition to NPR state upon LOGO cmpl if link down or aborted (Dick Kennedy) [2063879]
- scsi: lpfc: Update fc_prli_sent outstanding only after guaranteed IOCB submit (Dick Kennedy) [2063879]
- scsi: lpfc: Protect memory leak for NPIV ports sending PLOGI_RJT (Dick Kennedy) [2063879]
- scsi: lpfc: Fix null pointer dereference after failing to issue FLOGI and PLOGI (Dick Kennedy) [2063879]
- scsi: lpfc: Clear fabric topology flag before initiating a new FLOGI (Dick Kennedy) [2063879]
- scsi: lpfc: Fix SCSI I/O completion and abort handler deadlock (Dick Kennedy) [2063879]
- scsi: lpfc: Requeue SCSI I/O to upper layer when fw reports link down (Dick Kennedy) [2063879]
- scsi: lpfc: Zero SLI4 fcp_cmnd buffer's fcpCntl0 field (Dick Kennedy) [2063879]
- scsi: lpfc: Fix diagnostic fw logging after a function reset (Dick Kennedy) [2063879]
- scsi: lpfc: Move cfg_log_verbose check before calling lpfc_dmp_dbg() (Dick Kennedy) [2063879]
- scsi: lpfc: Tweak message log categories for ELS/FDMI/NVMe rescan (Dick Kennedy) [2063879]
- scsi: lpfc: Fix locking for lpfc_sli_iocbq_lookup() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix broken SLI4 abort path (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.1 (Dick Kennedy) [2063879]
- scsi: lpfc: Fix queue failures when recovering from PCI parity error (Dick Kennedy) [2063879]
- scsi: lpfc: Fix unload hang after back to back PCI EEH faults (Dick Kennedy) [2063879]
- scsi: lpfc: Improve PCI EEH Error and Recovery Handling (Dick Kennedy) [2063879]
- scsi: lpfc: Copyright updates for 14.2.0.0 patches (Dick Kennedy) [2063879]
- scsi: lpfc: Update lpfc version to 14.2.0.0 (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor BSG paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor Abort paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor SCSI paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor CT paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor misc ELS paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor VMID paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor FDISC paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor LS_RJT paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor LS_ACC paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor the RSCN/SCR/RDF/EDC/FARPR paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor PLOGI/PRLI/ADISC/LOGO paths (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor base ELS paths and the FLOGI path (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Introduce lpfc_prep_wqe (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor fast and slow paths to native SLI4 (Dick Kennedy) [2063879]
- scsi: lpfc: SLI path split: Refactor lpfc_iocbq (Dick Kennedy) [2063879]
- scsi: lpfc: Use kcalloc() (Dick Kennedy) [2063879]
- scsi: lpfc: Fix typos in comments (Dick Kennedy) [2063879]
- scsi: lpfc: Use rport as argument for lpfc_chk_tgt_mapped() (Dick Kennedy) [2063879]
- scsi: lpfc: Use rport as argument for lpfc_send_taskmgmt() (Dick Kennedy) [2063879]
- scsi: lpfc: Use fc_block_rport() (Dick Kennedy) [2063879]
- scsi: lpfc: Drop lpfc_no_handler() (Dick Kennedy) [2063879]
- scsi: lpfc: Kill lpfc_bus_reset_handler() (Dick Kennedy) [2063879]
- scsi: lpfc: Reduce log messages seen after firmware download (Dick Kennedy) [2063879]
- scsi: lpfc: Remove NVMe support if kernel has NVME_FC disabled (Dick Kennedy) [2063879]
- scsi: lpfc: Remove redundant flush_workqueue() call (Dick Kennedy) [2063879]
- all: replace find_next{,_zero}_bit with find_first{,_zero}_bit where appropriate (Dick Kennedy) [2063879]
- scsi: lpfc: Terminate string in lpfc_debugfs_nvmeio_trc_write() (Dick Kennedy) [2063879]
- scsi: lpfc: Use irq_set_affinity() (Dick Kennedy) [2063879]
- scsi: lpfc: Add support for optional PLDV handling (Dick Kennedy) [2063879]
- scsi: lpfc: Return NULL rather than a plain 0 integer (Dick Kennedy) [2063879]
- scsi: lpfc: Fix a function name in comments (Dick Kennedy) [2063879]
- scsi: lpfc: Fix mailbox command failure during driver initialization (Dick Kennedy) [2063879]
- jbd2: fix a potential race while discarding reserved buffers after an abort (Lukas Czerner) [2079868]
- ext4: update the cached overhead value in the superblock (Lukas Czerner) [2079868]
- ext4: force overhead calculation if the s_overhead_cluster makes no sense (Lukas Czerner) [2079868]
- ext4: fix overhead calculation to account for the reserved gdt blocks (Lukas Czerner) [2079868]
- ext4: limit length to bitmap_maxbytes - blocksize in punch_hole (Lukas Czerner) [2079868]
- ext4: fix use-after-free in ext4_search_dir (Lukas Czerner) [2079868]
- ext4: fix bug_on in start_this_handle during umount filesystem (Lukas Czerner) [2079868]
- ext4: fix symlink file size not match to file content (Lukas Czerner) [2079868]
- ext4: fix fallocate to use file_modified to update permissions consistently (Lukas Czerner) [2085759]
- ext4: fix kernel doc warnings (Lukas Czerner) [2079868]
- ext4: add commit tid info in ext4_fc_commit_start/stop trace events (Lukas Czerner) [2079868]
- ext4: add commit_tid info in jbd debug log (Lukas Czerner) [2079868]
- ext4: add transaction tid info in fc_track events (Lukas Czerner) [2079868]
- ext4: convert ext4_fc_track_dentry type events to use event class (Lukas Czerner) [2079868]
- ext4: fix ext4_fc_stats trace point (Lukas Czerner) [2079868]
- ext4: add new trace event in ext4_fc_cleanup (Lukas Czerner) [2079868]
- ext4: return early for non-eligible fast_commit track events (Lukas Czerner) [2079868]
- ext4: do not call FC trace event in ext4_fc_commit() if FS does not support FC (Lukas Czerner) [2079868]
- ext4: remove unused enum EXT4_FC_COMMIT_FAILED (Lukas Czerner) [2079868]
- ext4: warn when dirtying page w/o buffers in data=journal mode (Lukas Czerner) [2079868]
- ext4: make mb_optimize_scan performance mount option work with extents (Lukas Czerner) [2079868]
- ext4: make mb_optimize_scan option work with set/unset mount cmd (Lukas Czerner) [2079868]
- ext4: stop using bio_devname (Lukas Czerner) [2079868]
- ext4: don't BUG if someone dirty pages without asking ext4 first (Lukas Czerner) [2079868]
- ext4: remove redundant assignment to variable split_flag1 (Lukas Czerner) [2079868]
- ext4: fix underflow in ext4_max_bitmap_size() (Lukas Czerner) [2079868]
- ext4: fix ext4_mb_clear_bb() kernel-doc comment (Lukas Czerner) [2079868]
- ext4: fix fs corruption when tring to remove a non-empty directory with IO error (Lukas Czerner) [2079868]
- ext4: use time_is_before_jiffies() instead of open coding it (Lukas Czerner) [2079868]
- ext4: improve fast_commit performance and scalability (Lukas Czerner) [2079868]
- ext4: add extra check in ext4_mb_mark_bb() to prevent against possible corruption (Lukas Czerner) [2079868]
- ext4: add strict range checks while freeing blocks (Lukas Czerner) [2079868]
- ext4: add ext4_sb_block_valid() refactored out of ext4_inode_block_valid() (Lukas Czerner) [2079868]
- ext4: no need to test for block bitmap bits in ext4_mb_mark_bb() (Lukas Czerner) [2079868]
- ext4: rename ext4_set_bits to mb_set_bits (Lukas Czerner) [2079868]
- ext4: use in_range() for range checking in ext4_fc_replay_check_excluded (Lukas Czerner) [2079868]
- ext4: refactor ext4_free_blocks() to pull out ext4_mb_clear_bb() (Lukas Czerner) [2079868]
- ext4: fix ext4_mb_mark_bb() with flex_bg with fast_commit (Lukas Czerner) [2079868]
- ext4: correct cluster len and clusters changed accounting in ext4_mb_mark_bb (Lukas Czerner) [2079868]
- jbd2: remove CONFIG_JBD2_DEBUG to update t_max_wait (Lukas Czerner) [2079868]
- jbd2: kill t_handle_lock transaction spinlock (Lukas Czerner) [2079868]
- fs/ext4: fix comments mentioning i_mutex (Lukas Czerner) [2079868]
- ext4: fix incorrect type issue during replay_del_range (Lukas Czerner) [2079868]
- jbd2: fix kernel-doc descriptions for jbd2_journal_shrink_{scan,count}() (Lukas Czerner) [2079868]
- jbd2: fix use-after-free of transaction_t race (Lukas Czerner) [2079868]
- jbd2: refactor wait logic for transaction updates into a common function (Lukas Czerner) [2079868]
- jbd2: cleanup unused functions declarations from jbd2.h (Lukas Czerner) [2079868]
- ext4: fix error handling in ext4_fc_record_modified_inode() (Lukas Czerner) [2079868]
- ext4: remove redundant max inline_size check in ext4_da_write_inline_data_begin() (Lukas Czerner) [2079868]
- ext4: fix error handling in ext4_restore_inline_data() (Lukas Czerner) [2079868]
- ext4: fast commit may miss file actions (Lukas Czerner) [2079868]
- ext4: fast commit may not fallback for ineligible commit (Lukas Czerner) [2079868]
- ext4: modify the logic of ext4_mb_new_blocks_simple (Lukas Czerner) [2079868]
- ext4: prevent used blocks from being allocated during fast commit replay (Lukas Czerner) [2079868]
- jbd2: export jbd2_journal_[grab|put]_journal_head (Lukas Czerner) [2079868]
- ext4: simplify ext4_sb_read_encoding (Lukas Czerner) [2079868]
- ext4: flush background discard kwork when retry allocation (Lukas Czerner) [2079868]
- ext4: get discard out of jbd2 commit kthread contex (Lukas Czerner) [2079868]
- ext4: report correct st_size for encrypted symlinks (Lukas Czerner) [2079868]
- fscrypt: add fscrypt_symlink_getattr() for computing st_size (Lukas Czerner) [2079868]

* Mon Jun 20 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-113.rt21.113.el9]
- [rt] build kernel-rt-5.14.0-113.rt21.113.el9 [2061574]
- powerpc/rtas: Keep MSR[RI] set when calling RTAS (Diego Domingos) [2087259]
- netfilter: nat: really support inet nat without l3 address (Phil Sutter) [2092430]
- netfilter: nf_tables: use kfree_rcu(ptr, rcu) to release hooks in clean_net path (Phil Sutter) [2094245]
- netfilter: nf_tables: double hook unregistration in netns path (Phil Sutter) [2094245]
- [s390] s390/dasd: Fix read inconsistency for ESE DASD devices (Mete Durlu) [2094302]
- [s390] s390/dasd: Fix read for ESE with blksize < 4k (Mete Durlu) [2094302]
- redhat/configs: enable CONFIG_SP5100_TCO for x86_64 (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Enable Family 17h+ CPUs (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Add initialization using EFCH MMIO (Sudheesh Mavila) [2078696]
- kernel/resource: Introduce request_mem_region_muxed() (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Refactor MMIO base address initialization (Sudheesh Mavila) [2078696]
- Watchdog: sp5100_tco: Move timer initialization into function (Sudheesh Mavila) [2078696]
- watchdog: sp5100_tco: Add support for get_timeleft (Sudheesh Mavila) [2078696]
- redhat/configs: enable ACPI_PCC (Mark Langsdorf) [2067294]
- ACPI: tables: Quiet ACPI table not found warning (Mark Langsdorf) [2067294]
- ACPI/IORT: Check node revision for PMCG resources (Mark Langsdorf) [2067294]
- PM: s2idle: ACPI: Fix wakeup interrupts handling (Mark Langsdorf) [2067294]
- ACPI: PM: s2idle: Cancel wakeup before dispatching EC GPE (Mark Langsdorf) [2067294]
- ACPI: PM: Revert "Only mark EC GPE for wakeup on Intel systems" (Mark Langsdorf) [2067294]
- ACPI: require CRC32 to build (Mark Langsdorf) [2067294]
- ACPI: PCC: pcc_ctx can be static (Mark Langsdorf) [2067294]
- ACPI: scan: Rename label in acpi_scan_init() (Mark Langsdorf) [2067294]
- ACPI: scan: Simplify initialization of power and sleep buttons (Mark Langsdorf) [2067294]
- ACPI: scan: Change acpi_scan_init() return value type to void (Mark Langsdorf) [2067294]
- ACPI: SPCR: check if table->serial_port.access_width is too wide (Mark Langsdorf) [2067294]
- ACPI: APD: Check for NULL pointer after calling devm_ioremap() (Mark Langsdorf) [2067294]
- ACPI: APD: Add a fmw property clk-name (Mark Langsdorf) [2067294]
- drivers: acpi: acpi_apd: Remove unused device property "is-rv" (Mark Langsdorf) [2067294]
- x86: clk: clk-fch: Add support for newer family of AMD's SOC (Mark Langsdorf) [2067294]
- ACPI: PCC: Implement OperationRegion handler for the PCC Type 3 subtype (Mark Langsdorf) [2067294]
- ACPI / x86: Skip AC and battery devices on x86 Android tablets with broken DSDTs (Mark Langsdorf) [2067294]
- ACPI / x86: Introduce an acpi_quirk_skip_acpi_ac_and_battery() helper (Mark Langsdorf) [2067294]
- ACPI: processor: thermal: avoid cpufreq_get_policy() (Mark Langsdorf) [2067294]
- ACPI / x86: Add acpi_quirk_skip_[i2c_client|serdev]_enumeration() helpers (Mark Langsdorf) [2067294]
- ACPI: scan: Create platform device for BCM4752 and LNV4752 ACPI nodes (Mark Langsdorf) [2067294]
- ACPI: battery: Add the ThinkPad "Not Charging" quirk (Mark Langsdorf) [2067294]
- acpi: Export acpi_bus_type (Mark Langsdorf) [2067294]
- ACPI: sysfs: use default_groups in kobj_type (Mark Langsdorf) [2067294]
- redhat/configs: enable ACPI_PFRUT (Mark Langsdorf) [2040058 2067294]
- ACPI: pfr_telemetry: Fix info leak in pfrt_log_ioctl() (Mark Langsdorf) [2040058 2067294]
- ACPI: pfr_update: Fix return value check in pfru_write() (Mark Langsdorf) [2040058 2067294]
- ACPI: Introduce Platform Firmware Runtime Telemetry driver (Mark Langsdorf) [2040058 2067294]
- ACPI: Introduce Platform Firmware Runtime Update device driver (Mark Langsdorf) [2040058 2067294]
- efi: Introduce EFI_FIRMWARE_MANAGEMENT_CAPSULE_HEADER and corresponding structures (Mark Langsdorf) [2040058 2067294]
- ACPICA: Update version to 20211217 (Mark Langsdorf) [2067294]
- ACPICA: iASL/NHLT table: "Specific Data" field support (Mark Langsdorf) [2067294]
- ACPICA: iASL: Add suppport for AGDI table (Mark Langsdorf) [2067294]
- ACPICA: iASL: Add TDEL table to both compiler/disassembler (Mark Langsdorf) [2067294]
- ACPICA: Fixed a couple of warnings under MSVC (Mark Langsdorf) [2067294]
- ACPICA: Change a return_ACPI_STATUS (AE_BAD_PARAMETER) (Mark Langsdorf) [2067294]
- ACPICA: Hardware: Do not flush CPU cache when entering S4 and S5 (Mark Langsdorf) [2067294]
- ACPICA: Add support for PCC Opregion special context data (Mark Langsdorf) [2067294]
- ACPICA: Fix wrong interpretation of PCC address (Mark Langsdorf) [2067294]
- ACPICA: Executer: Fix the REFCLASS_REFOF case in acpi_ex_opcode_1A_0T_1R() (Mark Langsdorf) [2067294]
- ACPICA: Utilities: Avoid deleting the same object twice in a row (Mark Langsdorf) [2067294]
- ACPICA: Fix AEST Processor generic resource substructure data field byte length (Mark Langsdorf) [2067294]
- ACPICA: iASL/Disassembler: Additional support for NHLT table (Mark Langsdorf) [2067294]
- ACPICA: Avoid subobject buffer overflow when validating RSDP signature (Mark Langsdorf) [2067294]
- ACPICA: Macros: Remove ACPI_PHYSADDR_TO_PTR (Mark Langsdorf) [2067294]
- ACPICA: Use original pointer for virtual origin tables (Mark Langsdorf) [2067294]
- ACPICA: Use original data_table_region pointer for accesses (Mark Langsdorf) [2067294]
- ACPICA: actypes.h: Expand the ACPI_ACCESS_ definitions (Mark Langsdorf) [2067294]
- ACPI: NFIT: Import GUID before use (Mark Langsdorf) [2067294]
- ACPI: NUMA: Process hotpluggable memblocks when !CONFIG_MEMORY_HOTPLUG (Mark Langsdorf) [2067294]
- ACPI: PM: Remove redundant cache flushing (Mark Langsdorf) [2067294]
- ACPI: Use acpi_fetch_acpi_dev() instead of acpi_bus_get_device() (Mark Langsdorf) [2067294]
- ACPI: tables: Add AEST to the list of known table signatures (Mark Langsdorf) [2067294]
- ACPI: delay enumeration of devices with a _DEP pointing to an INT3472 device (Mark Langsdorf) [2067294]
- ACPI: PM: Avoid CPU cache flush when entering S4 (Mark Langsdorf) [2067294]
- PM: hibernate: Allow ACPI hardware signature to be honoured (Mark Langsdorf) [2067294]
- ACPI: PMIC: xpower: Fix _TMP ACPI errors (Mark Langsdorf) [2067294]
- ACPI: PMIC: allow drivers to provide a custom lpat_raw_to_temp() function (Mark Langsdorf) [2067294]
- ACPI: PMIC: constify all struct intel_pmic_opregion_data declarations (Mark Langsdorf) [2067294]
- ACPI: EC: Mark the ec_sys write_support param as module_param_hw() (Mark Langsdorf) [2067294]
- ACPI: EC: Relocate acpi_ec_create_query() and drop acpi_ec_delete_query() (Mark Langsdorf) [2067294]
- ACPI: EC: Make the event work state machine visible (Mark Langsdorf) [2067294]
- ACPI: EC: Avoid queuing unnecessary work in acpi_ec_submit_event() (Mark Langsdorf) [2067294]
- ACPI: EC: Rename three functions (Mark Langsdorf) [2067294]
- ACPI: EC: Simplify locking in acpi_ec_event_handler() (Mark Langsdorf) [2067294]
- ACPI: EC: Rearrange the loop in acpi_ec_event_handler() (Mark Langsdorf) [2067294]
- ACPI: EC: Fold acpi_ec_check_event() into acpi_ec_event_handler() (Mark Langsdorf) [2067294]
- ACPI: EC: Pass one argument to acpi_ec_query() (Mark Langsdorf) [2067294]
- ACPI: EC: Call advance_transaction() from acpi_ec_dispatch_gpe() (Mark Langsdorf) [2067294]
- ACPI: EC: Rework flushing of EC work while suspended to idle (Mark Langsdorf) [2067294]
- ACPI / x86: Add PWM2 on the Xiaomi Mi Pad 2 to the always_present list (Mark Langsdorf) [2067294]
- ACPI / x86: Add not-present quirk for the PCI0.SDHB.BRC1 device on the GPD win (Mark Langsdorf) [2067294]
- ACPI / x86: Allow specifying acpi_device_override_status() quirks by path (Mark Langsdorf) [2067294]
- ACPI: Change acpi_device_always_present() into acpi_device_override_status() (Mark Langsdorf) [2067294]
- ACPI / x86: Drop PWM2 device on Lenovo Yoga Book from always present table (Mark Langsdorf) [2067294]
- ACPI: processor idle: Use swap() instead of open coding it (Mark Langsdorf) [2067294]
- ACPI: processor: Replace kernel.h with the necessary inclusions (Mark Langsdorf) [2067294]
- ACPI: DPTF: Update device ID in a comment (Mark Langsdorf) [2067294]
- ACPI: PM: Emit debug messages when enabling/disabling wakeup power (Mark Langsdorf) [2067294]
- ACPI: thermal: drop an always true check (Mark Langsdorf) [2067294]
- ACPI: Add a context argument for table parsing handlers (Mark Langsdorf) [2067294]
- ACPI: Teach ACPI table parsing about the CEDT header format (Mark Langsdorf) [2067294]
- ACPI: Keep sub-table parsing infrastructure available for modules (Mark Langsdorf) [2067294]
- selftests/bpf: Prevent skeleton generation race (Yauheni Kaliuta) [2069045]
- kernel.spec: disable vmlinux.h generation for s390 zfcpdump config (Yauheni Kaliuta) [2069045]
- bpf: Fix possible race in inc_misses_counter (Yauheni Kaliuta) [2069045]
- kbuild: Unify options for BTF generation for vmlinux and modules (Yauheni Kaliuta) [2069045]
- tools/resolve_btfids: Switch to new btf__type_cnt API (Yauheni Kaliuta) [2069045]
- bpf, x86: Fix "no previous prototype" warning (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add tests for restricted helpers (Yauheni Kaliuta) [2069045]
- selftests/bpf: Check map in map pruning (Yauheni Kaliuta) [2069045]
- bpf: selftest: Trigger a DCE on the whole subprog (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate bpf_objects_list (Yauheni Kaliuta) [2069045]
- scripts: documentation-file-ref-check: fix bpf selftests path (Yauheni Kaliuta) [2069045]
- libbpf: Add ability to fetch bpf_program's underlying instructions (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use cpu_number only on arches that have it (Yauheni Kaliuta) [2069045]
- libbpf: Fix skel_internal.h to set errno on loader retval < 0 (Yauheni Kaliuta) [2069045]
- bpf: Document BPF licensing. (Yauheni Kaliuta) [2069045]
- libbpf: Fix gen_loader assumption on number of programs. (Yauheni Kaliuta) [2069045]
- libbpf: Add "bool skipped" to struct bpf_map (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip all serial_test_get_branch_snapshot in vm (Yauheni Kaliuta) [2069045]
- bpf: Fix a btf decl_tag bug when tagging a function (Yauheni Kaliuta) [2069045]
- libbpf: Define BTF_KIND_* constants in btf.h to avoid compilation errors (Yauheni Kaliuta) [2069045]
- libbpf: Use probe_name for legacy kprobe (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use "__se_" prefix on architectures without syscall wrapper (Yauheni Kaliuta) [2069045]
- selftests/bpf: Extract syscall wrapper (Yauheni Kaliuta) [2069045]
- tools/resolve_btfids: Skip unresolved symbol warning for empty BTF sets (Yauheni Kaliuta) [2069045]
- libbpf: Perform map fd cleanup for gen_loader in case of error (Yauheni Kaliuta) [2069045]
- libbpf: Fix non-C89 loop variable declaration in gen_loader.c (Yauheni Kaliuta) [2069045]
- bpftool: Install libbpf headers for the bootstrap version, too (Yauheni Kaliuta) [2069045]
- tools/runqslower: Fix cross-build (Yauheni Kaliuta) [2069045]
- libbpf: Fix section counting logic (Yauheni Kaliuta) [2069045]
- libbpf: Load global data maps lazily on legacy kernels (Yauheni Kaliuta) [2069045]
- bpftool: Fix error check when calling hashmap__new() (Yauheni Kaliuta) [2069045]
- libbpf: Remove deprecation attribute from struct bpf_prog_prep_result (Yauheni Kaliuta) [2069045]
- bpftool: Fix print error when show bpf map (Yauheni Kaliuta) [2069045]
- bpf: Add missing map_get_next_key method to bloom filter map. (Yauheni Kaliuta) [2069045]
- bpf, selftests: Fix racing issue in btf_skc_cls_ingress test (Yauheni Kaliuta) [2069045]
- selftest/bpf: Add a test that reads various addresses. (Yauheni Kaliuta) [2069045]
- bpf: Fix extable address check. (Yauheni Kaliuta) [2069045]
- bpf: Fix extable fixup offset. (Yauheni Kaliuta) [2069045]
- bpf: Make 32->64 bounds propagation slightly more robust (Yauheni Kaliuta) [2069045]
- bpf: Fix signed bounds propagation after mov32 (Yauheni Kaliuta) [2069045]
- bpf, selftests: Update test case for atomic cmpxchg on r0 with pointer (Yauheni Kaliuta) [2069045]
- bpf, selftests: Add test case for atomic fetch on spilled pointer (Yauheni Kaliuta) [2069045]
- bpf: Fix kernel address leakage in atomic cmpxchg's r0 aux reg (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix OOB write in test_verifier (Yauheni Kaliuta) [2069045]
- selftests/bpf: Tests for state pruning with u32 spill/fill (Yauheni Kaliuta) [2069045]
- bpf: Fix incorrect state pruning for <8B spill/fill (Yauheni Kaliuta) [2069045]
- bpf: Add selftests to cover packet access corner cases (Yauheni Kaliuta) [2069045]
- bpf: Fix the off-by-two error in range markings (Yauheni Kaliuta) [2069045]
- treewide: Add missing includes masked by cgroup -> bpf dependency (Yauheni Kaliuta) [2069045]
- bpf: Fix bpf_check_mod_kfunc_call for built-in modules (Yauheni Kaliuta) [2069045]
- redhat/configs: Add CONFIG_DEBUG_INFO_DWARF5 (Yauheni Kaliuta) [2069045]
- bpf: Make CONFIG_DEBUG_INFO_BTF depend upon CONFIG_BPF_SYSCALL (Yauheni Kaliuta) [2069045]
- Documentation/locking/locktypes: Update migrate_disable() bits. (Yauheni Kaliuta) [2069045]
- bpf: Make sure bpf_disable_instrumentation() is safe vs preemption. (Yauheni Kaliuta) [2069045]
- libbpf: Fix lookup_and_delete_elem_flags error reporting (Yauheni Kaliuta) [2069045]
- selftests/bpf: Verifier test on refill from a smaller spill (Yauheni Kaliuta) [2069045]
- bpf: Do not reject when the stack read size is different from the tracked scalar size (Yauheni Kaliuta) [2069045]
- selftests/bpf: Make netcnt selftests serial to avoid spurious failures (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test RENAME_EXCHANGE and RENAME_NOREPLACE on bpffs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Convert test_bpffs to ASSERT macros (Yauheni Kaliuta) [2069045]
- libfs: Support RENAME_EXCHANGE in simple_rename() (Yauheni Kaliuta) [2069045]
- libfs: Move shmem_exchange to simple_rename_exchange (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate AF_XDP support (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add a testcase for 64-bit bounds propagation issue. (Yauheni Kaliuta) [2069045]
- bpf: Fix propagation of signed bounds from 64-bit min/max into 32-bit. (Yauheni Kaliuta) [2069045]
- bpf: Fix propagation of bounds from 64-bit min/max into 32-bit and var_off. (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix also no-alu32 strobemeta selftest (Yauheni Kaliuta) [2069045]
- bpf: Add missing map_delete_elem method to bloom filter map (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add bloom map success test for userspace calls (Yauheni Kaliuta) [2069045]
- bpf: Add alignment padding for "map_extra" + consolidate holes (Yauheni Kaliuta) [2069045]
- bpf: Bloom filter map naming fixups (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add test cases for struct_ops prog (Yauheni Kaliuta) [2069045]
- bpf: Add dummy BPF STRUCT_OPS for test purpose (Yauheni Kaliuta) [2069045]
- bpf: Factor out helpers for ctx access checking (Yauheni Kaliuta) [2069045]
- bpf: Factor out a helper to prepare trampoline for struct_ops prog (Yauheni Kaliuta) [2069045]
- cgroup: bpf: Move wrapper for __cgroup_bpf_*() to kernel/bpf/cgroup.c (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix strobemeta selftest regression (Yauheni Kaliuta) [2069045]
- bpf: Disallow unprivileged bpf by default (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix fclose/pclose mismatch in test_progs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix memory leak in test_ima (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix fd cleanup in sk_lookup test (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add weak/typeless ksym test for light skeleton (Yauheni Kaliuta) [2069045]
- libbpf: Use O_CLOEXEC uniformly when opening fds (Yauheni Kaliuta) [2069045]
- libbpf: Ensure that BPF syscall fds are never 0, 1, or 2 (Yauheni Kaliuta) [2069045]
- libbpf: Add weak ksym support to gen_loader (Yauheni Kaliuta) [2069045]
- libbpf: Add typeless ksym support to gen_loader (Yauheni Kaliuta) [2069045]
- bpf: Add bpf_kallsyms_lookup_name helper (Yauheni Kaliuta) [2069045]
- bpf/benchs: Add benchmarks for comparing hashmap lookups w/ vs. w/out bloom filter (Yauheni Kaliuta) [2069045]
- bpf/benchs: Add benchmark tests for bloom filter throughput + false positive (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add bloom filter map test cases (Yauheni Kaliuta) [2069045]
- libbpf: Add "map_extra" as a per-map-type extra flag (Yauheni Kaliuta) [2069045]
- bpf: Add bloom filter map implementation (Yauheni Kaliuta) [2069045]
- bpf, tests: Add module parameter test_suite to test_bpf module (Yauheni Kaliuta) [2069045]
- selftests/bpf: Adding a namespace reset for tc_redirect (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix attach_probe in parallel mode (Yauheni Kaliuta) [2069045]
- selfetests/bpf: Update vmtest.sh defaults (Yauheni Kaliuta) [2069045]
- bpf: Use u64_stats_t in struct bpf_prog_stats (Yauheni Kaliuta) [2069045]
- bpf: Fixes possible race in update_prog_stats() for 32bit arches (Yauheni Kaliuta) [2069045]
- bpf: Avoid races in __bpf_prog_run() for 32bit arches (Yauheni Kaliuta) [2069045]
- s390: introduce nospec_uses_trampoline() (Yauheni Kaliuta) [2069045]
- selftests/bpf: Guess function end for test_get_branch_snapshot (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use __BYTE_ORDER__ (Yauheni Kaliuta) [2069045]
- libbpf: Use __BYTE_ORDER__ (Yauheni Kaliuta) [2069045]
- libbpf: Fix endianness detection in BPF_CORE_READ_BITFIELD_PROBED() (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate ambiguously-named bpf_program__size() API (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate multi-instance bpf_program APIs (Yauheni Kaliuta) [2069045]
- bpftool: Switch to libbpf's hashmap for PIDs/names references (Yauheni Kaliuta) [2069045]
- bpftool: Switch to libbpf's hashmap for programs/maps in BTF listing (Yauheni Kaliuta) [2069045]
- bpftool: Switch to libbpf's hashmap for pinned paths of BPF objects (Yauheni Kaliuta) [2069045]
- bpftool: Do not expose and init hash maps for pinned path in main.c (Yauheni Kaliuta) [2069045]
- bpftool: Remove Makefile dep. on $(LIBBPF) for $(LIBBPF_INTERNAL_HDRS) (Yauheni Kaliuta) [2069045]
- selftests/bpf: Split out bpf_verif_scale selftests into multiple tests (Yauheni Kaliuta) [2069045]
- selftests/bpf: Mark tc_redirect selftest as serial (Yauheni Kaliuta) [2069045]
- bpf/selftests: remove .c suffix from prog_tests/rhskip (Yauheni Kaliuta) [2069045]
- selftests/bpf: Support multiple tests per file (Yauheni Kaliuta) [2069045]
- selftests/bpf: Normalize selftest entry points (Yauheni Kaliuta) [2069045]
- libbpf: Fix BTF header parsing checks (Yauheni Kaliuta) [2069045]
- libbpf: Fix overflow in BTF sanity checks (Yauheni Kaliuta) [2069045]
- docs/bpf: Update documentation for BTF_KIND_DECL_TAG typedef support (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add BTF_KIND_DECL_TAG typedef example in tag.c (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test deduplication for BTF_KIND_DECL_TAG typedef (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add BTF_KIND_DECL_TAG typedef unit tests (Yauheni Kaliuta) [2069045]
- bpf: Add BTF_KIND_DECL_TAG typedef support (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix flow dissector tests (Yauheni Kaliuta) [2069045]
- libbpf: Use func name when pinning programs with LIBBPF_STRICT_SEC_NAME (Yauheni Kaliuta) [2069045]
- bpftool: Avoid leaking the JSON writer prepared for program metadata (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch to new btf__type_cnt/btf__raw_data APIs (Yauheni Kaliuta) [2069045]
- bpftool: Switch to new btf__type_cnt API (Yauheni Kaliuta) [2069045]
- libbpf: Add btf__type_cnt() and btf__raw_data() APIs (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate btf__finalize_data() and move it into libbpf.c (Yauheni Kaliuta) [2069045]
- libbpf: Fix memory leak in btf__dedup() (Yauheni Kaliuta) [2069045]
- selftests/bpf: Make perf_buffer selftests work on 4.9 kernel again (Yauheni Kaliuta) [2069045]
- libbpf: Fix the use of aligned attribute (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch to ".bss"/".rodata"/".data" lookups for internal maps (Yauheni Kaliuta) [2069045]
- libbpf: Simplify look up by name of internal maps (Yauheni Kaliuta) [2069045]
- selftests/bpf: Demonstrate use of custom .rodata/.data sections (Yauheni Kaliuta) [2069045]
- libbpf: Support multiple .rodata.* and .data.* BPF maps (Yauheni Kaliuta) [2069045]
- bpftool: Improve skeleton generation for data maps without DATASEC type (Yauheni Kaliuta) [2069045]
- bpftool: Support multiple .rodata/.data internal maps in skeleton (Yauheni Kaliuta) [2069045]
- libbpf: Remove assumptions about uniqueness of .rodata/.data/.bss maps (Yauheni Kaliuta) [2069045]
- libbpf: Use Elf64-specific types explicitly for dealing with ELF (Yauheni Kaliuta) [2069045]
- libbpf: Extract ELF processing state into separate struct (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add verif_stats test (Yauheni Kaliuta) [2069045]
- bpf: Add verified_insns to bpf_prog_info and fdinfo (Yauheni Kaliuta) [2069045]
- libbpf: Fix ptr_is_aligned() usages (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test bpf_skc_to_unix_sock() helper (Yauheni Kaliuta) [2069045]
- bpf: Add bpf_skc_to_unix_sock() helper (Yauheni Kaliuta) [2069045]
- samples: bpf: Suppress readelf stderr when probing for BTF support (Yauheni Kaliuta) [2069045]
- net: bpf: Switch over to memdup_user() (Yauheni Kaliuta) [2069045]
- selftests/bpf: Some more atomic tests (Yauheni Kaliuta) [2069045]
- libbpf: Fix dumping non-aligned __int128 (Yauheni Kaliuta) [2069045]
- libbpf: Fix dumping big-endian bitfields (Yauheni Kaliuta) [2069045]
- bpftool: Remove useless #include to <perf-sys.h> from map_perf_ring.c (Yauheni Kaliuta) [2069045]
- selftests/bpf: Remove duplicated include in cgroup_helpers (Yauheni Kaliuta) [2069045]
- bpf/preload: Clean up .gitignore and "clean-files" target (Yauheni Kaliuta) [2069045]
- libbpf: Migrate internal use of bpf_program__get_prog_info_linear (Yauheni Kaliuta) [2069045]
- bpf: Silence Coverity warning for find_kfunc_desc_btf (Yauheni Kaliuta) [2069045]
- bpftool: Turn check on zlib from a phony target into a conditional error (Yauheni Kaliuta) [2069045]
- bpftool: Do not FORCE-build libbpf (Yauheni Kaliuta) [2069045]
- bpftool: Fix install for libbpf's internal header(s) (Yauheni Kaliuta) [2069045]
- libbpf: Remove Makefile warnings on out-of-sync netlink.h/if_link.h (Yauheni Kaliuta) [2069045]
- bpf: Rename BTF_KIND_TAG to BTF_KIND_DECL_TAG (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip verifier tests that fail to load with ENOTSUPP (Yauheni Kaliuta) [2069045]
- selfetest/bpf: Make some tests serial (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix pid check in fexit_sleep test (Yauheni Kaliuta) [2069045]
- selftests/bpf: Adding pid filtering for atomics test (Yauheni Kaliuta) [2069045]
- selftests/bpf: Make cgroup_v1v2 use its own port (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix race condition in enable_stats (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add per worker cgroup suffix (Yauheni Kaliuta) [2069045]
- selftests/bpf: Allow some tests to be executed in sequence (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add parallelism to test_progs (Yauheni Kaliuta) [2069045]
- bpf/selftests: Add test for writable bare tracepoint (Yauheni Kaliuta) [2069045]
- libbpf: Support detecting and attaching of writable tracepoint program (Yauheni Kaliuta) [2069045]
- bpf: Support writable context for bare tracepoint (Yauheni Kaliuta) [2069045]
- bpftool: Add install-bin target to install binary only (Yauheni Kaliuta) [2069045]
- selftests/bpf: Better clean up for runqslower in test_bpftool_build.sh (Yauheni Kaliuta) [2069045]
- samples/bpf: Do not FORCE-recompile libbpf (Yauheni Kaliuta) [2069045]
- samples/bpf: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- samples/bpf: Update .gitignore (Yauheni Kaliuta) [2069045]
- bpf: iterators: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- bpf: preload: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- tools/runqslower: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- tools/resolve_btfids: Install libbpf headers when building (Yauheni Kaliuta) [2069045]
- bpftool: Install libbpf headers instead of including the dir (Yauheni Kaliuta) [2069045]
- bpftool: Remove unused includes to <bpf/bpf_gen_internal.h> (Yauheni Kaliuta) [2069045]
- libbpf: Skip re-installing headers file if source is older than target (Yauheni Kaliuta) [2069045]
- selftests/bpf: Remove SEC("version") from test progs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip the second half of get_branch_snapshot in vm (Yauheni Kaliuta) [2069045]
- bpf, tests: Add more LD_IMM64 tests (Yauheni Kaliuta) [2069045]
- bpf, x64: Factor out emission of REX byte in more cases (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate bpf_object__unload() API since v0.6 (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch to new bpf_object__next_{map,program} APIs (Yauheni Kaliuta) [2069045]
- libbpf: Deprecate bpf_{map,program}__{prev,next} APIs since v0.7 (Yauheni Kaliuta) [2069045]
- libbpf: Add API documentation convention guidelines (Yauheni Kaliuta) [2069045]
- bpf: Use $(pound) instead of \# in Makefiles (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test new btf__add_btf() API (Yauheni Kaliuta) [2069045]
- selftests/bpf: Refactor btf_write selftest to reuse BTF generation logic (Yauheni Kaliuta) [2069045]
- libbpf: Add API that copies all BTF types from one BTF object to another (Yauheni Kaliuta) [2069045]
- bpf, x64: Save bytes for DIV by reducing reg copies (Yauheni Kaliuta) [2069045]
- bpf: Avoid retpoline for bpf_for_each_map_elem (Yauheni Kaliuta) [2069045]
- bpf: selftests: Add selftests for module kfunc support (Yauheni Kaliuta) [2069045]
- libbpf: Update gen_loader to emit BTF_KIND_FUNC relocations (Yauheni Kaliuta) [2069045]
- libbpf: Resolve invalid weak kfunc calls with imm = 0, off = 0 (Yauheni Kaliuta) [2069045]
- libbpf: Support kernel module function calls (Yauheni Kaliuta) [2069045]
- bpf: Enable TCP congestion control kfunc from modules (Yauheni Kaliuta) [2069045]
- tools: Allow specifying base BTF file in resolve_btfids (Yauheni Kaliuta) [2069045]
- bpf: btf: Introduce helpers for dynamic BTF set registration (Yauheni Kaliuta) [2069045]
- bpf: Be conservative while processing invalid kfunc calls (Yauheni Kaliuta) [2069045]
- bpf: Introduce BPF support for kernel module function calls (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use BTF-defined key/value for map definitions (Yauheni Kaliuta) [2069045]
- libbpf: Support uniform BTF-defined key/value specification across all BPF maps (Yauheni Kaliuta) [2069045]
- bpf/tests: Add test of LDX_MEM with operand aliasing (Yauheni Kaliuta) [2069045]
- bpf/tests: Add test of ALU shifts with operand register aliasing (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of BPF_ATOMIC register combinations (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of ALU register combinations (Yauheni Kaliuta) [2069045]
- bpf/tests: Minor restructuring of ALU tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Add more tests for ALU and ATOMIC register clobbering (Yauheni Kaliuta) [2069045]
- bpf/tests: Add tests to check source register zero-extension (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of BPF_ATOMIC magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add zero-extension checks in BPF_ATOMIC tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Add tests of BPF_LDX and BPF_STX with small sizes (Yauheni Kaliuta) [2069045]
- bpf, xdp, docs: Correct some English grammar and spelling (Yauheni Kaliuta) [2069045]
- selftests/bpf: Use kselftest skip code for skipped tests (Yauheni Kaliuta) [2069045]
- bpf: Do not invoke the XDP dispatcher for PROG_RUN with single repeat (Yauheni Kaliuta) [2069045]
- libbpf: Make gen_loader data aligned. (Yauheni Kaliuta) [2069045]
- bpf: selftests: Fix fd cleanup in get_branch_snapshot (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix probe_user test failure with clang build kernel (Yauheni Kaliuta) [2069045]
- bpf: Replace callers of BPF_CAST_CALL with proper function typedef (Yauheni Kaliuta) [2069045]
- bpf: Replace "want address" users of BPF_CAST_CALL with BPF_CALL_IMM (Yauheni Kaliuta) [2069045]
- bpf/tests: Add tail call limit test with external function call (Yauheni Kaliuta) [2069045]
- bpftool: Avoid using "?: " in generated code (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch sk_lookup selftests to strict SEC("sk_lookup") use (Yauheni Kaliuta) [2069045]
- libbpf: Add opt-in strict BPF program section name handling logic (Yauheni Kaliuta) [2069045]
- libbpf: Complete SEC() table unification for BPF_APROG_SEC/BPF_EAPROG_SEC (Yauheni Kaliuta) [2069045]
- libbpf: Refactor ELF section handler definitions (Yauheni Kaliuta) [2069045]
- libbpf: Reduce reliance of attach_fns on sec_def internals (Yauheni Kaliuta) [2069045]
- libbpf: Refactor internal sec_def handling to enable pluggability (Yauheni Kaliuta) [2069045]
- selftests/bpf: Normalize all the rest SEC() uses (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch SEC("classifier*") usage to a strict SEC("tc") (Yauheni Kaliuta) [2069045]
- selftests/bpf: Normalize XDP section names in selftests (Yauheni Kaliuta) [2069045]
- libbpf: Add "tc" SEC_DEF which is a better name for "classifier" (Yauheni Kaliuta) [2069045]
- bpf/tests: Add more BPF_END byte order conversion tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Expand branch conversion JIT test (Yauheni Kaliuta) [2069045]
- bpf/tests: Add JMP tests with degenerate conditional (Yauheni Kaliuta) [2069045]
- bpf/tests: Add JMP tests with small offsets (Yauheni Kaliuta) [2069045]
- bpf/tests: Add test case flag for verifier zero-extension (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive test of LD_IMM64 immediate magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add staggered JMP and JMP32 tests (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of JMP operand magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of ALU operand magnitudes (Yauheni Kaliuta) [2069045]
- bpf/tests: Add exhaustive tests of ALU shift values (Yauheni Kaliuta) [2069045]
- bpf/tests: Reduce memory footprint of test suite (Yauheni Kaliuta) [2069045]
- bpf/tests: Allow different number of runs per test case (Yauheni Kaliuta) [2069045]
- bpf: selftest: Add verifier tests for <8-byte scalar spill and refill (Yauheni Kaliuta) [2069045]
- bpf: selftest: A bpf prog that has a 32bit scalar spill (Yauheni Kaliuta) [2069045]
- bpf: Support <8-byte scalar spill and refill (Yauheni Kaliuta) [2069045]
- bpf: Check the other end of slot_type for STACK_SPILL (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix btf_dump __int128 test failure with clang build kernel (Yauheni Kaliuta) [2069045]
- libbpf: Add legacy uprobe attaching support (Yauheni Kaliuta) [2069045]
- libbpf: Refactor and simplify legacy kprobe code (Yauheni Kaliuta) [2069045]
- selftests/bpf: Adopt attach_probe selftest to work on old kernels (Yauheni Kaliuta) [2069045]
- libbpf: Fix memory leak in legacy kprobe attach logic (Yauheni Kaliuta) [2069045]
- samples: bpf: Convert ARP table network order fields into readable format (Yauheni Kaliuta) [2069045]
- samples: bpf: Convert route table network order fields into readable format (Yauheni Kaliuta) [2069045]
- libbpf: Add doc comments in libbpf.h (Yauheni Kaliuta) [2069045]
- bpf: Clarify data_len param in bpf_snprintf and bpf_seq_printf comments (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add trace_vprintk test prog (Yauheni Kaliuta) [2069045]
- selftests/bpf: Migrate prog_tests/trace_printk CHECKs to ASSERTs (Yauheni Kaliuta) [2069045]
- bpftool: Only probe trace_vprintk feature in 'full' mode (Yauheni Kaliuta) [2069045]
- libbpf: Use static const fmt string in __bpf_printk (Yauheni Kaliuta) [2069045]
- libbpf: Modify bpf_printk to choose helper based on arg count (Yauheni Kaliuta) [2069045]
- bpf: Add bpf_trace_vprintk helper (Yauheni Kaliuta) [2069045]
- selftests/bpf: Stop using bpf_program__load (Yauheni Kaliuta) [2069045]
- bpf: Merge printk and seq_printf VARARG max macros (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix a few compiler warnings (Yauheni Kaliuta) [2069045]
- libbpf: Constify all high-level program attach APIs (Yauheni Kaliuta) [2069045]
- libbpf: Schedule open_opts.attach_prog_fd deprecation since v0.7 (Yauheni Kaliuta) [2069045]
- selftests/bpf: Switch fexit_bpf2bpf selftest to set_attach_target() API (Yauheni Kaliuta) [2069045]
- libbpf: Allow skipping attach_func_name in bpf_program__set_attach_target() (Yauheni Kaliuta) [2069045]
- libbpf: Deprecated bpf_object_open_opts.relaxed_core_relocs (Yauheni Kaliuta) [2069045]
- selftests/bpf: Stop using relaxed_core_relocs which has no effect (Yauheni Kaliuta) [2069045]
- libbpf: Use pre-setup sec_def in libbpf_find_attach_btf_id() (Yauheni Kaliuta) [2069045]
- bpf: Update bpf_get_smp_processor_id() documentation (Yauheni Kaliuta) [2069045]
- libbpf: Add sphinx code documentation comments (Yauheni Kaliuta) [2069045]
- selftests/bpf: Skip btf_tag test if btf_tag attribute not supported (Yauheni Kaliuta) [2069045]
- docs/bpf: Add documentation for BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add a test with a bpf program with btf_tag attributes (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test BTF_KIND_TAG for deduplication (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add BTF_KIND_TAG unit tests (Yauheni Kaliuta) [2069045]
- selftests/bpf: Change NAME_NTH/IS_NAME_NTH for BTF_KIND_TAG format (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test libbpf API function btf__add_tag() (Yauheni Kaliuta) [2069045]
- bpftool: Add support for BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- libbpf: Add support for BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- libbpf: Rename btf_{hash,equal}_int to btf_{hash,equal}_int_tag (Yauheni Kaliuta) [2069045]
- bpf: Support for new btf kind BTF_KIND_TAG (Yauheni Kaliuta) [2069045]
- btf: Change BTF_KIND_* macros to enums (Yauheni Kaliuta) [2069045]
- selftests/bpf: Fix .gitignore to not ignore test_progs.c (Yauheni Kaliuta) [2069045]
- bpf,x64 Emit IMUL instead of MUL for x86-64 (Yauheni Kaliuta) [2069045]
- libbpf: Minimize explicit iterator of section definition array (Yauheni Kaliuta) [2069045]
- libbpf: Simplify BPF program auto-attach code (Yauheni Kaliuta) [2069045]
- libbpf: Ensure BPF prog types are set before relocations (Yauheni Kaliuta) [2069045]
- selftests/bpf: Update selftests to always provide "struct_ops" SEC (Yauheni Kaliuta) [2069045]
- libbpf: Introduce legacy kprobe events support (Yauheni Kaliuta) [2069045]
- bpf, selftests: Replicate tailcall limit test for indirect call case (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add test for bpf_get_branch_snapshot (Yauheni Kaliuta) [2069045]
- bpf: Introduce helper bpf_get_branch_snapshot (Yauheni Kaliuta) [2069045]
- selftests/bpf: Test new __sk_buff field hwtstamp (Yauheni Kaliuta) [2069045]
- bpf: Permit ingress_ifindex in bpf_prog_test_run_xattr (Yauheni Kaliuta) [2069045]
- bpf: Add hardware timestamp field to __sk_buff (Yauheni Kaliuta) [2069045]
- libbpf: Make libbpf_version.h non-auto-generated (Yauheni Kaliuta) [2069045]
- libbpf: Add LIBBPF_DEPRECATED_SINCE macro for scheduling API deprecations (Yauheni Kaliuta) [2069045]
- libbpf: Fix build with latest gcc/binutils with LTO (Yauheni Kaliuta) [2069045]
- selftests/bpf: Add checks for X__elf_bytes() skeleton helper (Yauheni Kaliuta) [2069045]
- bpftool: Provide a helper method for accessing skeleton's embedded ELF data (Yauheni Kaliuta) [2069045]
- libbpf: Change bpf_object_skeleton data field to const pointer (Yauheni Kaliuta) [2069045]
- libbpf: Don't crash on object files with no symbol tables (Yauheni Kaliuta) [2069045]
- bpf, selftests: Fix spelling mistake "tained" -> "tainted" (Yauheni Kaliuta) [2069045]
- bpf, selftests: Add test case trying to taint map value pointer (Yauheni Kaliuta) [2069045]

* Wed Jun 15 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-112.rt21.112.el9]
- [rt] build kernel-rt-5.14.0-112.rt21.112.el9 [2061574]
- redhat: configs: Update configs for vmware (Cathy Avery) [2087134]
- VMCI: Add support for ARM64 (Cathy Avery) [2079153]
- VMCI: Release notification_bitmap in error path (Cathy Avery) [2079153]
- VMCI: Check exclusive_vectors when freeing interrupt 1 (Cathy Avery) [2079153]
- VMCI: Fix some error handling paths in vmci_guest_probe_device() (Cathy Avery) [2079153]
- VMCI: No need to clear memory after a dma_alloc_coherent() call (Cathy Avery) [2079153]
- VMCI: Fix the description of vmci_check_host_caps() (Cathy Avery) [2079153]
- VMCI: dma dg: add support for DMA datagrams receive (Cathy Avery) [2079153]
- VMCI: dma dg: add support for DMA datagrams sends (Cathy Avery) [2079153]
- VMCI: dma dg: allocate send and receive buffers for DMA datagrams (Cathy Avery) [2079153]
- VMCI: dma dg: register dummy IRQ handlers for DMA datagrams (Cathy Avery) [2079153]
- VMCI: dma dg: set OS page size (Cathy Avery) [2079153]
- VMCI: dma dg: whitespace formatting change for vmci register defines (Cathy Avery) [2079153]
- VMCI: dma dg: detect DMA datagram capability (Cathy Avery) [2079153]
- VMCI: dma dg: add MMIO access to registers (Cathy Avery) [2079153]
- misc: vmw_vmci: Switch to kvfree_rcu() API (Cathy Avery) [2079153]
- VMCI: fix NULL pointer dereference when unmapping queue pair (Cathy Avery) [2079153]
- [s390] s390/dasd: prevent double format of tracks for ESE devices (Mete Durlu) [2094295]
- [s390] s390/dasd: fix data corruption for ESE devices (Mete Durlu) [2094295]
- iio: Turn off kernel configs for iios added by this patch set (Steve Best) [2071780]
- iio:dac:ad3552r: Fix an IS_ERR() vs NULL check (Steve Best) [2071780]
- iio: sx9324: Fix default precharge internal resistance register (Steve Best) [2071780]
- iio:proximity:sx9324: Fix hardware gain read/write (Steve Best) [2071780]
- iio:proximity:sx_common: Fix device property parsing on DT systems (Steve Best) [2071780]
- iio:filter:admv8818: select REGMAP_SPI for ADMV8818 (Steve Best) [2071780]
- iio: scd4x: check return of scd4x_write_and_fetch (Steve Best) [2071780]
- iio: dac: ad3552r: fix signedness bug in ad3552r_reset() (Steve Best) [2071780]
- iio: adc: xilinx-ams: Fix single channel switching sequence (Steve Best) [2071780]
- iio: adc: xilinx-ams: Fixed wrong sequencer register settings (Steve Best) [2071780]
- iio: adc: xilinx-ams: Fixed missing PS channels (Steve Best) [2071780]
- iio: accel: mma8452: use the correct logic to get mma8452_data (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: use dev_to_iio_dev() to get iio_dev struct (Steve Best) [2071780]
- iio: buffer: Fix file related error handling in IIO_BUFFER_GET_FD_IOCTL (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: wait for settling time in st_lsm6dsx_read_oneshot (Steve Best) [2071780]
- iio: adc: cpcap-adc: remove redundant assignment to variable cal_data_diff (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Make use of device properties (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Check ACPI companion directly (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Drop wrong use of ACPI_PTR() (Steve Best) [2071780]
- iio: accel: adxl355: Replace custom definitions with generic from units.h (Steve Best) [2071780]
- iio: temperature: maxim_thermocouple: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: temperature: mlx90632: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: humidity: dht11: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: frequency: adf4350: Make use of device properties (Steve Best) [2071780]
- iio: amplifiers: hmc425a: Make use of device properties (Steve Best) [2071780]
- iio: chemical: bme680: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio: dac: ad5592r: Drop leftover header inclusion (Steve Best) [2071780]
- iio: Fix error handling for PM (Steve Best) [2071780]
- iio: afe: rescale: reorder includes (Steve Best) [2071780]
- iio: afe: rescale: use s64 for temporary scale calculations (Steve Best) [2071780]
- iio: inkern: make a best effort on offset calculation (Steve Best) [2071780]
- iio: inkern: apply consumer scale when no channel scale is available (Steve Best) [2071780]
- iio: inkern: apply consumer scale on IIO_VAL_INT cases (Steve Best) [2071780]
- iio: addac: ad74413r: correct comparator gpio getters mask usage (Steve Best) [2071780]
- iio: addac: ad74413r: use ngpio size when iterating over mask (Steve Best) [2071780]
- iio: addac: ad74413r: Do not reference negative array offsets (Steve Best) [2071780]
- iio: adc: men_z188_adc: Fix a resource leak in an error handling path (Steve Best) [2071780]
- iio: humidity: hdc100x: Add ACPI HID table (Steve Best) [2071780]
- iio: pressure: dps310: Add ACPI HID table (Steve Best) [2071780]
- iio: sx9360: fix iio event generation (Steve Best) [2071780]
- iio: adc: qcom-vadc-common: Re-use generic struct u32_fract (Steve Best) [2071780]
- iio: adc: twl4030-madc: Re-use generic struct s16_fract (Steve Best) [2071780]
- iio: adc: rn5t618: Re-use generic struct u16_fract (Steve Best) [2071780]
- iio: frequency: admv1013: remove the always true condition (Steve Best) [2071780]
- iio: accel: fxls8962af: add padding to regmap for SPI (Steve Best) [2071780]
- iio:imu:adis16480: fix buffering for devices with no burst mode (Steve Best) [2071780]
- iio: adc: ad7124: fix mask used for setting AIN_BUFP & AIN_BUFM bits (Steve Best) [2071780]
- iio: adc: tsc2046: fix memory corruption by preventing array overflow (Steve Best) [2071780]
- iio: adc: tsc2046: add sanity check to avoid to big allocations (Steve Best) [2071780]
- iio: adc: tsc2046: add .read_raw support (Steve Best) [2071780]
- iio: hw_consumer: Use struct_size() helper in kzalloc() (Steve Best) [2071780]
- iio: adis: stylistic changes (Steve Best) [2071780]
- iio: sps30: Use sysfs_emit() (Steve Best) [2071780]
- iio: scd4x: Use sysfs_emit() (Steve Best) [2071780]
- iio: ms_sensors: Use sysfs_emit() (Steve Best) [2071780]
- iio: max9611: Use sysfs_emit() (Steve Best) [2071780]
- iio: max31865: Use sysfs_emit() (Steve Best) [2071780]
- iio: max31856: Use sysfs_emit() (Steve Best) [2071780]
- iio: lm3533: Use sysfs_emit() (Steve Best) [2071780]
- iio: ina2xx-adc: sysfs_emit() (Steve Best) [2071780]
- iio: as3935: Use sysfs_emit() (Steve Best) [2071780]
- iio: ad9523: Use sysfs_emit() (Steve Best) [2071780]
- iio: ad7192: Use sysfs_emit() (Steve Best) [2071780]
- iio: dmaengine-buffer: Use sysfs_emit() (Steve Best) [2071780]
- iio: adc: tsc2046: rework the trigger state machine (Steve Best) [2071780]
- iio: adc: mt8186: Add compatible node for mt8186 (Steve Best) [2071780]
- iio: st_sensors: don't always auto-enable I2C and SPI interface drivers (Steve Best) [2071780]
- iio: adc: rzg2l_adc: Fix typo (Steve Best) [2071780]
- iio:accel:dmard09: Tidy up white space around {} in id table (Steve Best) [2071780]
- iio:proximity:vl53l0x: Tidy up white space around {} in id tables (Steve Best) [2071780]
- iio:light:tsl2722: Fix inconsistent spacing before } in id table (Steve Best) [2071780]
- iio:adc:ti-adc084s021: Tidy up white space around {} (Steve Best) [2071780]
- iio:adc:hi8435: Tidy up white space around {} in id tables (Steve Best) [2071780]
- iio:adc:mt6577_auxadc: Tidy up white space around {} in id tables (Steve Best) [2071780]
- iio:frequency:admv1013: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:srf08: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:srf04: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:rfd77402: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:proximity:ping: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:light:ltr501: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:light:us5182: White space cleanup of spacing around {} in id tables (Steve Best) [2071780]
- iio:light:vcnl4035: Trivial whitespace cleanup to add space before } (Steve Best) [2071780]
- iio:light:pa12203001: Tidy up white space change to add spaces after { and before } (Steve Best) [2071780]
- iio:chemical:atlas: Trivial white space cleanup to add space before } (Steve Best) [2071780]
- iio:proximity:sx9360: Add dt-binding support (Steve Best) [2071780]
- iio:proximity:sx9360: Add sx9360 support (Steve Best) [2071780]
- iio:proximity:sx9324: Add dt_binding support (Steve Best) [2071780]
- iio:proximity:sx9324: Add SX9324 support (Steve Best) [2071780]
- iio:proximity:sx9310: Extract common Semtech sensor logic (Steve Best) [2071780]
- iio:proximity:sx9310: Add frequency in read_avail (Steve Best) [2071780]
- all: replace find_next{,_zero}_bit with find_first{,_zero}_bit where appropriate (Steve Best) [2071780]
- iio: pressure: bmp280: Use new PM macros (Steve Best) [2071780]
- iio: chemical: sunrise_co2: set val parameter only on success (Steve Best) [2071780]
- iio: frequency: admv1013: add support for ADMV1013 (Steve Best) [2071780]
- iio: adc: ti-adc081c: Partial revert of removal of ACPI IDs (Steve Best) [2071780]
- iio:addac:ad74413r: Fix uninitialized ret in a path that won't be hit. (Steve Best) [2071780]
- iio: adc: Add Xilinx AMS driver (Steve Best) [2071780]
- iio:accel:kxcjk-1013: Mark struct __maybe_unused to avoid warning. (Steve Best) [2071780]
- iio:accel:bmc150: Mark structure __maybe_unused as only needed with for pm ops. (Steve Best) [2071780]
- iio:dummy: Drop set but unused variable len. (Steve Best) [2071780]
- iio:magn:ak8975: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:imu:inv_mpu6050: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:imu:inv_icm42600: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:dac:mcp4725: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:amplifiers:hmc425a: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:adc:ti-ads1015: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:adc:rcar: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:adc:ina2xx-adc: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- iio:accel:bma180: Suppress clang W=1 warning about pointer to enum conversion. (Steve Best) [2071780]
- drivers:iio:dac: Add AD3552R driver support (Steve Best) [2071780]
- iio:filter:admv8818: add support for ADMV8818 (Steve Best) [2071780]
- iio: add filter subfolder (Steve Best) [2071780]
- iio: vz89x: Remove unnecessary cast (Steve Best) [2071780]
- iio: in2xx-adc: Remove unnecessary cast (Steve Best) [2071780]
- iio: as3935: Remove unnecessary cast (Steve Best) [2071780]
- iio: stmpe-adc: Use correctly sized arguments for bit field (Steve Best) [2071780]
- iio:adc:ti-ads8688:: remove redundant ret variable (Steve Best) [2071780]
- iio: addac: ad74413r: fix off by one in ad74413r_parse_channel_config() (Steve Best) [2071780]
- iio: adc: ad7606: Fix syntax errors in comments (Steve Best) [2071780]
- iio: iio_device_alloc(): Remove unnecessary self drvdata (Steve Best) [2071780]
- iio:adc/dac:Kconfig: Update to drop OF dependencies. (Steve Best) [2071780]
- iio:adc:ti-ads124s08: Drop dependency on OF. (Steve Best) [2071780]
- iio:adc:envelope-detector: Switch from of headers to mod_devicetable.h (Steve Best) [2071780]
- iio:adc:ti-adc12138: Switch to generic firmware properties and drop of_match_ptr (Steve Best) [2071780]
- iio:adc:mcp3911: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:adc:max9611: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:light:cm3605: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:pot:mcp41010: Switch to generic firmware properties. (Steve Best) [2071780]
- iio:dac:lpc18xx_dac: Swap from of* to mod_devicetable.h (Steve Best) [2071780]
- iio:dac:dpot-dac: Swap of.h for mod_devicetable.h (Steve Best) [2071780]
- iio:dac:ad5758: Drop unused of specific headers. (Steve Best) [2071780]
- iio:dac:ad5755: Switch to generic firmware properties and drop pdata (Steve Best) [2071780]
- iio: trigger: Fix a scheduling whilst atomic issue seen on tsc2046 (Steve Best) [2071780]
- iio: addac: add AD74413R driver (Steve Best) [2071780]
- iio: add addac subdirectory (Steve Best) [2071780]
- iio:dac:ad7293: add support for AD7293 (Steve Best) [2071780]
- iio: trigger: stm32-timer: fix MODULE_ALIAS (Steve Best) [2071780]
- iio: ltr501: Export near level property for proximity sensor (Steve Best) [2071780]
- iio:adc:axp20x: add support for NTC thermistor (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: add dts property to disable sensor-hub (Steve Best) [2071780]
- iio: test: Add test for IIO_VAL_INT_64. (Steve Best) [2071780]
- iio: test: Add check against NULL for buffer in tests. (Steve Best) [2071780]
- iio: expose shared parameter in IIO_ENUM_AVAILABLE (Steve Best) [2071780]
- iio: adc: stm32: fix null pointer on defer_probe error (Steve Best) [2071780]
- iio: buffer-dma: Use round_down() instead of rounddown() (Steve Best) [2071780]
- iio: at91-sama5d2: Fix incorrect sign extension (Steve Best) [2071780]
- iio: adc: axp20x_adc: fix charging current reporting on AXP22x (Steve Best) [2071780]
- iio: gyro: adxrs290: fix data signedness (Steve Best) [2071780]
- iio: buffer: Use dedicated variable in iio_buffers_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: ad7768-1: Call iio_trigger_notify_done() on error (Steve Best) [2071780]
- iio: itg3200: Call iio_trigger_notify_done() on error (Steve Best) [2071780]
- iio: imx8qxp-adc: fix dependency to the intended ARCH_MXC config (Steve Best) [2071780]
- iio: dln2: Check return value of devm_iio_trigger_register() (Steve Best) [2071780]
- iio: trigger: Fix reference counting (Steve Best) [2071780]
- iio: dln2-adc: Fix lockdep complaint (Steve Best) [2071780]
- iio: adc: stm32: fix a current leak by resetting pcsel before disabling vdda (Steve Best) [2071780]
- iio: mma8452: Fix trigger reference couting (Steve Best) [2071780]
- iio: stk3310: Don't return error code in interrupt handler (Steve Best) [2071780]
- iio: kxsd9: Don't return error code in trigger handler (Steve Best) [2071780]
- iio: ltr501: Don't return error code in trigger handler (Steve Best) [2071780]
- iio: accel: kxcjk-1013: Fix possible memory leak in probe and remove (Steve Best) [2071780]
- iio: light: ltr501: Added ltr303 driver support (Steve Best) [2071780]
- iio: adc: rzg2l_adc: Remove unnecessary print function dev_err() (Steve Best) [2071780]
- iio: mpl3115: Use scan_type.shift and realbit in mpl3115_read_raw (Steve Best) [2071780]
- iio: xilinx-xadc-core: Use local variable in xadc_read_raw (Steve Best) [2071780]
- iio: ti-ads1015: Remove shift variable ads1015_read_raw (Steve Best) [2071780]
- iio: mag3110: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: ti-adc12138: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: ad7266: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: stk8ba50: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: stk8312: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: sca3000: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: mma7455: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: kxcjk-1013: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: bma220: Use scan_type when processing raw data (Steve Best) [2071780]
- iio: at91-sama5d2: Use dev_to_iio_dev() in sysfs callbacks (Steve Best) [2071780]
- iio: at91-sama5d2: Fix incorrect cast to platform_device (Steve Best) [2071780]
- iio: mma8452: Use correct type for return variable in IRQ handler (Steve Best) [2071780]
- iio: lmp91000: Remove no-op trigger ops (Steve Best) [2071780]
- iio: gp2ap020a00f: Remove no-op trigger ops (Steve Best) [2071780]
- iio: atlas-sensor: Remove no-op trigger ops (Steve Best) [2071780]
- iio: as3935: Remove no-op trigger ops (Steve Best) [2071780]
- iio: afe4404: Remove no-op trigger ops (Steve Best) [2071780]
- iio: afe4403: Remove no-op trigger ops (Steve Best) [2071780]
- iio: ad_sigma_delta: Remove no-op trigger ops (Steve Best) [2071780]
- iio: sysfs-trigger: Remove no-op trigger ops (Steve Best) [2071780]
- iio: interrupt-trigger: Remove no-op trigger ops (Steve Best) [2071780]
- iio: Mark iio_device_type as const (Steve Best) [2071780]
- iio/scmi: Add reading "raw" attribute. (Steve Best) [2071780]
- iio: core: Introduce IIO_VAL_INT_64. (Steve Best) [2071780]
- iio: adc: ina2xx: Avoid double reference counting from get_task_struct/put_task_struct() (Steve Best) [2071780]
- iio: adc: ina2xx: Make use of the helper macro kthread_run() (Steve Best) [2071780]
- iio: ms5611: Simplify IO callback parameters (Steve Best) [2071780]
- iio: imx7d_adc: Don't pass IIO device to imx7d_adc_{enable,disable}() (Steve Best) [2071780]
- iio: st-sensors: Use dev_to_iio_dev() in sysfs callbacks (Steve Best) [2071780]
- iio: adc: stm32-adc: Fix of_node_put() issue in stm32-adc (Steve Best) [2071780]
- iio: xilinx-xadc: Make IRQ optional (Steve Best) [2071780]
- iio: accel: mma7660: Warn about failure to put device in stand-by in .remove() (Steve Best) [2071780]
- iio: adc: lpc18xx_adc: Reorder clk_get_rate() function call (Steve Best) [2071780]
- iio: frequency: adrf6780: Fix adrf6780_spi_{read,write}() (Steve Best) [2071780]
- iio: frequency: adrf6780: add support for ADRF6780 (Steve Best) [2071780]
- iio: chemical: scd4x: Add a scale for the co2 concentration reading (Steve Best) [2071780]
- iio: adc: adc128s052: Simplify adc128_probe() (Steve Best) [2071780]
- iio: multiplexer: iio-mux: Support settle-time-us property (Steve Best) [2071780]
- iio: buffer: Fix memory leak in iio_buffers_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: adc: stm32-adc: use generic binding for sample-time (Steve Best) [2071780]
- iio: adc: stm32-adc: add vrefint calibration support (Steve Best) [2071780]
- iio: adc: stm32-adc: add support of internal channels (Steve Best) [2071780]
- iio: adc: stm32-adc: add support of generic channels binding (Steve Best) [2071780]
- iio: adc: stm32-adc: split channel init into several routines (Steve Best) [2071780]
- iio: accel: sca3000: Use sign_extend32() instead of opencoding sign extension. (Steve Best) [2071780]
- iio: xilinx-xadc: Remove `irq` field from state struct (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: Avoid potential array overflow in st_lsm6dsx_set_odr() (Steve Best) [2071780]
- iio: light: gp2ap002: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: light: cm3605: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: ti-ads7950: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: rockchip_saradc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: qcom-pm8xxx-xoadc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: meson_saradc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: max1241: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: max1118: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: lpc18xx_adc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: imx7d_adc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: ab8500-gpadc: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: buffer: Fix uninitialized variable ret (Steve Best) [2071780]
- iio: adc: lpc18xx_adc: Convert probe to device managed version (Steve Best) [2071780]
- iio: light: ltr501: Add of_device_id table (Steve Best) [2071780]
- iio: light: ltr501: Add rudimentary regulator support (Steve Best) [2071780]
- iio: imx8qxp-adc: mark PM functions as __maybe_unused (Steve Best) [2071780]
- iio: pressure: ms5611: Make ms5611_remove() return void (Steve Best) [2071780]
- iio: potentiometer: max5487: Don't return an error in .remove() (Steve Best) [2071780]
- iio: magn: hmc5843: Make hmc5843_common_remove() return void (Steve Best) [2071780]
- iio: health: afe4403: Don't return an error in .remove() (Steve Best) [2071780]
- iio: dac: ad5686: Make ad5686_remove() return void (Steve Best) [2071780]
- iio: dac: ad5592r: Make ad5592r_remove() return void (Steve Best) [2071780]
- iio: dac: ad5446: Make ad5446_remove() return void (Steve Best) [2071780]
- iio: dac: ad5380: Make ad5380_remove() return void (Steve Best) [2071780]
- iio: accel: mma7455: Make mma7455_core_remove() return void (Steve Best) [2071780]
- iio: accel: kxsd9: Make kxsd9_common_remove() return void (Steve Best) [2071780]
- iio: accel: bmi088: Make bmi088_accel_core_remove() return void (Steve Best) [2071780]
- iio: accel: bmc150: Make bmc150_accel_core_remove() return void (Steve Best) [2071780]
- iio: accel: bma400: Make bma400_remove() return void (Steve Best) [2071780]
- drivers:iio:dac:ad5766.c: Add trigger buffer (Steve Best) [2071780]
- iio: triggered-buffer: extend support to configure output buffers (Steve Best) [2071780]
- iio: kfifo-buffer: Add output buffer support (Steve Best) [2071780]
- iio: Add output buffer support (Steve Best) [2071780]
- drivers: iio: chemical: Add support for Sensirion SCD4x CO2 sensor (Steve Best) [2071780]
- iio: light: noa1305: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: light: cm36651: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: health: afe4404: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: health: afe4403: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: st_lsm9ds0: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: st_sensors: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ti-dac7311: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: stm32-dac: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: mcp4922: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: max5821: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ds4424: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ltc1660: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: lpc18xx_dac: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: dac: ad8801: Make use of the helper function dev_err_probe() (Steve Best) [2071780]
- iio: adc: ad799x: Implement selecting external reference voltage input on AD7991, AD7995 and AD7999. (Steve Best) [2071780]
- iio: adc: max1027: fix error code in max1027_wait_eoc() (Steve Best) [2071780]
- iio: imu: adis16400: Fix buffer alignment requirements. (Steve Best) [2071780]
- iio: gyro: mpu3050: Fix alignment and size issues with buffers. (Steve Best) [2071780]
- iio: adc: ti-adc108s102: Fix alignment of buffer pushed to iio buffers. (Steve Best) [2071780]
- iio: core: Introduce iio_push_to_buffers_with_ts_unaligned() (Steve Best) [2071780]
- iio: chemical: SENSEAIR_SUNRISE_CO2 depends on I2C (Steve Best) [2071780]
- iio: adc: aspeed: Fix spelling mistake "battey" -> "battery" (Steve Best) [2071780]
- iio: adc: ad7291: convert probe to device-managed only (Steve Best) [2071780]
- iio: adc: Kconfig: add COMPILE_TEST dep for berlin2-adc (Steve Best) [2071780]
- iio: adc: berlin2-adc: convert probe to device-managed only (Steve Best) [2071780]
- iio: adc: rn5t618-adc: use devm_iio_map_array_register() function (Steve Best) [2071780]
- iio: adc: nau7802: convert probe to full device-managed (Steve Best) [2071780]
- iio: adis16460: make use of the new unmasked_drdy flag (Steve Best) [2071780]
- iio: adis16475: make use of the new unmasked_drdy flag (Steve Best) [2071780]
- iio: adis: handle devices that cannot unmask the drdy pin (Steve Best) [2071780]
- iio: adis: do not disabe IRQs in 'adis_init()' (Steve Best) [2071780]
- iio: adc: da9150-gpadc: convert probe to full-device managed (Steve Best) [2071780]
- iio: adc: axp288_adc: convert probe to full device-managed (Steve Best) [2071780]
- iio: adc: intel_mrfld_adc: convert probe to full device-managed (Steve Best) [2071780]
- iio: inkern: introduce devm_iio_map_array_register() short-hand function (Steve Best) [2071780]
- iio: adc: fsl-imx25-gcq: initialize regulators as needed (Steve Best) [2071780]
- iio: imu: st_lsm6dsx: move max_fifo_size in st_lsm6dsx_fifo_ops (Steve Best) [2071780]
- iio: adc: max1027: Don't reject external triggers when there is no IRQ (Steve Best) [2071780]
- iio: adc: max1027: Allow all kind of triggers to be used (Steve Best) [2071780]
- iio: adc: max1027: Use the EOC IRQ when populated for single reads (Steve Best) [2071780]
- iio: adc: max1027: Stop requesting a threaded IRQ (Steve Best) [2071780]
- iio: adc: max1027: Introduce an end of conversion helper (Steve Best) [2071780]
- iio: adc: max1027: Separate the IRQ handler from the read logic (Steve Best) [2071780]
- iio: adc: max1027: Prevent single channel accesses during buffer reads (Steve Best) [2071780]
- iio: adc: max1027: Create a helper to configure the channels to scan (Steve Best) [2071780]
- iio: adc: max1027: Ensure a default cnvst trigger configuration (Steve Best) [2071780]
- iio: adc: max1027: Simplify the _set_trigger_state() helper (Steve Best) [2071780]
- iio: adc: max1027: Create a helper to enable/disable the cnvst trigger (Steve Best) [2071780]
- iio: adc: max1027: Rename a helper (Steve Best) [2071780]
- iio: adc: max1027: Minimize the number of converted channels (Steve Best) [2071780]
- iio: adc: max1027: Drop useless debug messages (Steve Best) [2071780]
- iio: adc: max1027: Drop extra warning message (Steve Best) [2071780]
- iio: adc: max1027: Fix style (Steve Best) [2071780]
- iio: imx8qxp-adc: Add driver support for NXP IMX8QXP ADC (Steve Best) [2071780]
- iio: accel: fxls8962af: add wake on event (Steve Best) [2071780]
- iio: accel: fxls8962af: add threshold event handling (Steve Best) [2071780]
- iio: adc: aspeed: Get and set trimming data. (Steve Best) [2071780]
- iio: adc: aspeed: Support battery sensing. (Steve Best) [2071780]
- iio: adc: aspeed: Add compensation phase. (Steve Best) [2071780]
- iio: adc: aspeed: Add func to set sampling rate. (Steve Best) [2071780]
- iio: adc: aspeed: Fix the calculate error of clock. (Steve Best) [2071780]
- iio: adc: aspeed: Support ast2600 adc. (Steve Best) [2071780]
- iio: adc: aspeed: Use devm_add_action_or_reset. (Steve Best) [2071780]
- iio: adc: aspeed: Use model_data to set clk scaler. (Steve Best) [2071780]
- iio: adc: aspeed: Add vref config function (Steve Best) [2071780]
- iio: adc: aspeed: Restructure the model data (Steve Best) [2071780]
- iio: adc: aspeed: Keep model data to driver data. (Steve Best) [2071780]
- iio: chemical: Add Senseair Sunrise 006-0-007 driver (Steve Best) [2071780]
- iio: adc: tsc2046: fix scan interval warning (Steve Best) [2071780]
- iio: core: fix double free in iio_device_unregister_sysfs() (Steve Best) [2071780]
- iio: core: check return value when calling dev_set_name() (Steve Best) [2071780]
- iio: buffer: Fix memory leak in iio_buffer_register_legacy_sysfs_groups() (Steve Best) [2071780]
- iio: buffer: Fix double-free in iio_buffers_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: buffer: Fix memory leak in __iio_buffer_alloc_sysfs_and_mask() (Steve Best) [2071780]
- iio: buffer: check return value of kstrdup_const() (Steve Best) [2071780]
- iio: dac: ad5446: Fix ad5622_write() return value (Steve Best) [2071780]
- iio: adc: exynos: describe drivers in KConfig (Steve Best) [2071780]
- iio: adc: rockchip_saradc: Make use of the helper function devm_platform_ioremap_resource() (Steve Best) [2071780]
- iio: dac: stm32-dac: Make use of the helper function devm_platform_ioremap_resource() (Steve Best) [2071780]
- iio: accel: mma7660: Mark acpi match table as maybe unused (Steve Best) [2071780]
- iio: light: max44000: use device-managed functions in probe (Steve Best) [2071780]
- iio: gyro: adis16080: use devm_iio_device_register() in probe (Steve Best) [2071780]
- iio: dac: ad5064: convert probe to full device-managed (Steve Best) [2071780]
- iio: dac: ad7303: convert probe to full device-managed (Steve Best) [2071780]
- iio: imu: inv_mpu6050: Mark acpi match table as maybe unused (Steve Best) [2071780]
- iio: ep93xx: Make use of the helper function devm_platform_ioremap_resource() (Steve Best) [2071780]
- drivers: iio: dac: ad5766: Fix dt property name (Steve Best) [2071780]
- iio: st_pressure_spi: Add missing entries SPI to device ID table (Steve Best) [2071780]
- iio/test-format: build kunit tests without structleak plugin (Steve Best) [2071780]
- iio: light: opt3001: Fixed timeout error when 0 lux (Steve Best) [2071780]
- iio: common: cros_ec_sensors: simplify getting .driver_data (Steve Best) [2071780]
- iio: adis16480: fix devices that do not support sleep mode (Steve Best) [2071780]
- iio: mtk-auxadc: fix case IIO_CHAN_INFO_PROCESSED (Steve Best) [2071780]
- iio: adis16475: fix deadlock on frequency set (Steve Best) [2071780]
- iio: ssp_sensors: add more range checking in ssp_parse_dataframe() (Steve Best) [2071780]
- iio: ssp_sensors: fix error code in ssp_print_mcu_debug() (Steve Best) [2071780]
- iio: adc: ad7793: Fix IRQ flag (Steve Best) [2071780]
- iio: adc: ad7780: Fix IRQ flag (Steve Best) [2071780]
- iio: adc: ad7192: Add IRQ flag (Steve Best) [2071780]
- iio: adc: aspeed: set driver data when adc probe. (Steve Best) [2071780]
- iio: adc: rzg2l_adc: add missing clk_disable_unprepare() in rzg2l_adc_pm_runtime_resume() (Steve Best) [2071780]
- iio: adc: max1027: Fix the number of max1X31 channels (Steve Best) [2071780]
- iio: adc: max1027: Fix wrong shift with 12-bit devices (Steve Best) [2071780]
- iio: adc128s052: Fix the error handling path of 'adc128_probe()' (Steve Best) [2071780]
- iio: adc: rzg2l_adc: Fix -EBUSY timeout error return (Steve Best) [2071780]
- iio: accel: fxls8962af: return IRQ_HANDLED when fifo is flushed (Steve Best) [2071780]
- iio: dac: ti-dac5571: fix an error code in probe() (Steve Best) [2071780]
- iio: accel: adxl355: Add triggered buffer support (Steve Best) [2071780]
- iio: accel: adxl355: use if(ret) in place of ret < 0 (Steve Best) [2071780]
- iio: accel: Add driver support for ADXL313 (Steve Best) [2071780]
- iio: adc: aspeed: completes the bitfield declare. (Steve Best) [2071780]
- iio: adc: ti-ads8344: convert probe to device-managed (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: update copyright and authors information (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: add support for sama7g5 device (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: add helper for COR register (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: add support for separate end of conversion registers (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: convert to platform specific data structures (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: remove unused definition (Steve Best) [2071780]
- iio: adc: at91-sama5d2_adc: initialize hardware after clock is started (Steve Best) [2071780]
- iio: magnetometer: ak8975: add AK09116 support (Steve Best) [2071780]
- iio: temperature: Add MAX31865 RTD Support (Steve Best) [2071780]
- iio: adc: twl6030-gpadc: Use the defined variable to clean code (Steve Best) [2071780]
- iio: ltc2983: fail probe if no channels are given (Steve Best) [2071780]
- iio: ltc2983: add support for optional reset gpio (Steve Best) [2071780]
- iio: ad5770r: make devicetree property reading consistent (Steve Best) [2071780]
- iio: gyro: remove dead config dependencies on INPUT_MPU3050 (Steve Best) [2071780]
- iio: st_sensors: remove reference to parent device object on st_sensor_data (Steve Best) [2071780]
- iio: st_sensors: remove all driver remove functions (Steve Best) [2071780]
- iio: st_sensors: remove st_sensors_power_disable() function (Steve Best) [2071780]
- iio: st_sensors: remove st_sensors_deallocate_trigger() function (Steve Best) [2071780]
- iio: magn: st_magn: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: gyro: st_gyro: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: accel: st_accel: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: pressure: st_pressure: use devm_iio_triggered_buffer_setup() for buffer (Steve Best) [2071780]
- iio: st_sensors: disable regulators after device unregistration (Steve Best) [2071780]
- iio: adc: ad7949: use devm managed functions (Steve Best) [2071780]
- iio: adc: ad7949: add vref selection support (Steve Best) [2071780]
- iio: adc: ad7949: enable use with non 14/16-bit controllers (Steve Best) [2071780]
- iio: adc: ad7949: define and use bitfield names (Steve Best) [2071780]
- drivers/iio: Remove all strcpy() uses (Steve Best) [2071780]
- iio: accel: Add driver support for ADXL355 (Steve Best) [2071780]
- iio/drivers/hid-sensor: use HZ macros (Steve Best) [2071780]
- units: add the HZ macros (Steve Best) [2071780]
- iio/drivers/as73211: use HZ macros (Steve Best) [2071780]
- iio: adc: Add driver for Renesas RZ/G2L A/D converter (Steve Best) [2071780]
- iio: pressure: hp03: update device probe to register with devm functions (Steve Best) [2071780]
- iio: adc: rockchip_saradc: add voltage notifier so get referenced voltage once at probe (Steve Best) [2071780]
- iio: ltc2983: fix device probe (Steve Best) [2071780]
- iio: potentiometer: Add driver support for AD5110 (Steve Best) [2071780]
- iio: adc: rn5t618: Add iio map (Steve Best) [2071780]
- iio: hid-sensor-press: Add timestamp channel (Steve Best) [2071780]
- iio: accel: bmc150: Add support for BMC156 (Steve Best) [2071780]
- iio: accel: bmc150: Make it possible to configure INT2 instead of INT1 (Steve Best) [2071780]
- iio: light: cm3323: Add of_device_id table (Steve Best) [2071780]
- iio: chemical: Add driver support for sgp40 (Steve Best) [2071780]
- iio: ep93xx: Prepare clock before using it (Steve Best) [2071780]
- iio: adc: fsl-imx25-gcq: adjust irq check to match docs and simplify code (Steve Best) [2071780]
- iio: dac: max5821: convert device register to device managed function (Steve Best) [2071780]
- iio/adc: ingenic: add JZ4760B support to the sadc driver (Steve Best) [2071780]
- iio/adc: ingenic: add JZ4760 support to the sadc driver (Steve Best) [2071780]
- iio/adc: ingenic: rename has_aux2 to has_aux_md (Steve Best) [2071780]
- iio: sx9310: Support ACPI property (Steve Best) [2071780]
- PCI: hv: Remove unused hv_set_msi_entry_from_desc() (Mohammed Gamal) [2086678]
- PCI: hv: Avoid the retarget interrupt hypercall in irq_unmask() on ARM64 (Mohammed Gamal) [2086678]
- PCI: hv: Fix NUMA node assignment when kernel boots with custom NUMA topology (Mohammed Gamal) [2086678]
- net: mana: Reuse XDP dropped page (Mohammed Gamal) [2086676]
- net: mana: Add counter for XDP_TX (Mohammed Gamal) [2086676]
- net: mana: Add counter for packet dropped by XDP (Mohammed Gamal) [2086676]
- net: mana: Use struct_size() helper in mana_gd_create_dma_region() (Mohammed Gamal) [2086676]

* Tue Jun 14 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-111.rt21.111.el9]
- [rt] build kernel-rt-5.14.0-111.rt21.111.el9 [2061574]
- pinctrl: alderlake: Fix register offsets for ADL-N variant (David Arcari) [2049966]
- pinctrl: alderlake: Add Intel Alder Lake-N pin controller support (David Arcari) [2049966]
- netfilter: nf_tables: disallow non-stateful expression in sets earlier (Phil Sutter) [2092993] {CVE-2022-1966}
- block, loop: support partitions without scanning (Ming Lei) [2089698]
- scsi: fnic: Finish scsi_cmnd before dropping the spinlock (John Meneghini) [2063226]
- ipv4: do not use per netns icmp sockets (Hangbin Liu) [2089118]
- remoteproc: Fix a memory leak in an error handling path in 'rproc_handle_vdev()' (Steve Best) [2071773]
- remoteproc: imx_rproc: Change to ioremap_wc for dram (Steve Best) [2071773]
- remoteproc: qcom_q6v5_mss: Create platform device for BAM-DMUX (Steve Best) [2071773]
- remoteproc: qcom: q6v5_wpss: Add support for sc7280 WPSS (Steve Best) [2071773]
- remoteproc: k3-dsp: Add support for IPC-only mode for all K3 DSPs (Steve Best) [2071773]
- remoteproc: k3-dsp: Refactor mbox request code in start (Steve Best) [2071773]
- remoteproc: k3-r5: Add support for IPC-only mode for all R5Fs (Steve Best) [2071773]
- remoteproc: k3-r5: Refactor mbox request code in start (Steve Best) [2071773]
- remoteproc: Change rproc_shutdown() to return a status (Steve Best) [2071773]
- remoteproc: qcom: q6v5: Add interconnect path proxy vote (Steve Best) [2071773]
- remoteproc: mediatek: Support mt8186 scp (Steve Best) [2071773]
- remoteproc: qcom_q6v5_mss: Fix some leaks in q6v5_alloc_memory_region (Steve Best) [2071773]
- remoteproc: qcom_wcnss: Add missing of_node_put() in wcnss_alloc_memory_region (Steve Best) [2071773]
- remoteproc: qcom: Fix missing of_node_put in adsp_alloc_memory_region (Steve Best) [2071773]
- remoteproc: move rproc_da_to_va declaration to remoteproc.h (Steve Best) [2071773]
- remoteproc: wkup_m3: Set sysfs_read_only flag (Steve Best) [2071773]
- remoteproc: Introduce sysfs_read_only flag (Steve Best) [2071773]
- remoteproc: Fix count check in rproc_coredump_write() (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM8450 remoteproc support (Steve Best) [2071773]
- remoteproc: qcom: pas: Carry PAS metadata context (Steve Best) [2071773]
- soc: qcom: mdt_loader: Allow hash segment to be split out (Steve Best) [2071773]
- remoteproc: mtk_scp: Use dev_err_probe() where possible (Steve Best) [2071773]
- remoteproc: mtk_scp: Reorder scp_probe() sequence (Steve Best) [2071773]
- remoteproc: mtk_scp: Use devm variant of rproc_alloc() (Steve Best) [2071773]
- remoteproc: qcom: q6v5: fix service routines build errors (Steve Best) [2071773]
- remoteproc: stm32: Improve crash recovery time (Steve Best) [2071773]
- remoteproc: rcar_rproc: Remove trailing semicolon (Steve Best) [2071773]
- remoteproc: rcar_rproc: Fix pm_runtime_get_sync error check (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM6350 CDSP support (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM6350 ADSP support (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SM6350 MPSS support (Steve Best) [2071773]
- remoteproc: qcom: pas: Add missing power-domain "mxc" for CDSP (Steve Best) [2071773]
- remoteproc: imx_rproc: correct firmware reload (Steve Best) [2071773]
- remoteproc: qcom: pil_info: Don't memcpy_toio more than is provided (Steve Best) [2071773]
- remoteproc: Add Renesas rcar driver (Steve Best) [2071773]
- remoteproc: Fix remaining wrong return formatting in documentation (Steve Best) [2071773]
- remoteproc: ingenic: Request IRQ disabled (Steve Best) [2071773]
- remoteproc: k3-r5: Extend support for R5F clusters on J721S2 SoCs (Steve Best) [2071773]
- remoteproc: k3-dsp: Extend support for C71x DSPs on J721S2 SoCs (Steve Best) [2071773]
- remoteproc: coredump: Correct argument 2 type for memcpy_fromio (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix a resource leak in the remove function (Steve Best) [2071773]
- remoteproc: Use %%pe format string to print return error code (Steve Best) [2071773]
- remoteproc: Remove vdev_to_rvdev and vdev_to_rproc from remoteproc API (Steve Best) [2071773]
- remoteproc: omap_remoteproc: simplify getting .driver_data (Steve Best) [2071773]
- remoteproc: qcom_q6v5_mss: Use devm_platform_ioremap_resource_byname() to simplify code (Steve Best) [2071773]
- remoteproc: Fix spelling mistake "atleast" -> "at least" (Steve Best) [2071773]
- remoteproc: imx_dsp_rproc: mark PM functions as __maybe_unused (Steve Best) [2071773]
- remoteproc: imx_dsp_rproc: Correct the comment style of copyright (Steve Best) [2071773]
- remoteproc: imx_dsp_rproc: Add remoteproc driver for DSP on i.MX (Steve Best) [2071773]
- remoteproc: imx_rproc: Add IMX_RPROC_SCU_API method (Steve Best) [2071773]
- remoteproc: imx_rproc: Move common structure to header file (Steve Best) [2071773]
- remoteproc: meson-mx-ao-arc: fix a bit test (Steve Best) [2071773]
- remoteproc: mss: q6v5-mss: Add modem support on SC7280 (Steve Best) [2071773]
- remoteproc: qcom: pas: Add SC7280 Modem support (Steve Best) [2071773]
- remoteproc: qcom: pas: Use the same init resources for MSM8996 and MSM8998 (Steve Best) [2071773]
- remoteproc: mediatek: Support mt8195 scp (Steve Best) [2071773]
- remoteproc: meson-mx-ao-arc: Add a driver for the AO ARC remote procesor (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix rsc-table name (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix ignoring mapping vdev regions (Steve Best) [2071773]
- remoteproc: imx_rproc: Fix TCM io memory type (Steve Best) [2071773]
- remoteproc: Fix the wrong default value of is_iomem (Steve Best) [2071773]
- remoteproc: elf_loader: Fix loading segment when is_iomem true (Steve Best) [2071773]
- remoteproc: qcom: q6v5: Use qmp_send to update co-processor load state (Steve Best) [2071773]
- remoteproc: qcom: Loosen dependency on RPMSG_QCOM_SMD (Steve Best) [2071773]
- remoteproc: qcom: wcnss: Drop unused smd include (Steve Best) [2071773]
- remoteproc: q6v5_pas: Add sdm660 ADSP PIL compatible (Steve Best) [2071773]
- remoteproc: use freezable workqueue for crash notifications (Steve Best) [2071773]
- remoteproc: fix an typo in fw_elf_get_class code comments (Steve Best) [2071773]
- remoteproc: qcom: wcnss: Fix race with iris probe (Steve Best) [2071773]
- perf/x86/uncore: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/uncore: Clean up uncore_pci_ids[] (Michael Petlan) [2088832]
- perf/x86/uncore: Add Raptor Lake uncore support (Michael Petlan) [2088832]
- perf/x86/intel/uncore: Add IMC uncore support for ADL (Michael Petlan) [2088832]
- perf/x86/cstate: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/cstate: Add Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/msr: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86/msr: Add Raptor Lake CPU support (Michael Petlan) [2088832]
- perf/x86: Add new Alder Lake and Raptor Lake support (Michael Petlan) [2088832]
- perf/x86: Add Intel Raptor Lake support (Michael Petlan) [2088832]
- x86/cpu: Add new Alderlake and Raptorlake CPU model numbers (Michael Petlan) [2088832]
- turbostat: fix PC6 displaying on some systems (David Arcari) [2040079]

* Mon Jun 13 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-110.rt21.110.el9]
- [rt] build kernel-rt-5.14.0-110.rt21.110.el9 [2061574]
- [rt] lockdep: increase MAX_LOCKDEP_CHAIN_HLOCKS (Luis Claudio R. Goncalves) [2085403]
- net/core: disable NET_RX_BUSY_POLL on PREEMPT_RT (Petr Oros) [2090412]
- ACPI: sysfs: Fix BERT error region memory mapping (Aristeu Rozanski) [2026959]
- hv_utils: Add comment about max VMbus packet size in VSS driver (Mohammed Gamal) [2088365]
- x86/hyperv: fix root partition faults when writing to VP assist page MSR (Mohammed Gamal) [2088365]
- x86/coco: Explicitly declare type of confidential computing platform (Mohammed Gamal) [2088365]
- x86/hyper-v: Add hyperv Isolation VM check in the cc_platform_has() (Mohammed Gamal) [2088365]
- x86/sev: Use CC_ATTR attribute to generalize string I/O unroll (Mohammed Gamal) [2088365]
- x86/hyperv: add comment describing TSC_INVARIANT_CONTROL MSR setting bit 0 (Mohammed Gamal) [2088365]
- x86/hyperv: Fix definition of hv_ghcb_pg variable (Mohammed Gamal) [2088365]
- swiotlb: Add CONFIG_HAS_IOMEM check around swiotlb_mem_remap() (Mohammed Gamal) [2088365]
- hyper-v: Enable swiotlb bounce buffer for Isolation VM (Mohammed Gamal) [2088365]
- swiotlb: Add swiotlb bounce buffer remap function for HV IVM (Mohammed Gamal) [2088365]
- x86/hyperv: Refactor hv_msi_domain_free_irqs() (Mohammed Gamal) [2088365]
- x86/hyperv: Move required MSRs check to initial platform probing (Mohammed Gamal) [2088365]
- x86/hyperv: Fix NULL deref in set_hv_tscchange_cb() if Hyper-V setup fails (Mohammed Gamal) [2088365]
- x86/hyperv: Protect set_hv_tscchange_cb() against getting preempted (Mohammed Gamal) [2088365]
- x86/hyperv: Remove duplicate include (Mohammed Gamal) [2088365]
- x86/hyperv: Remove duplicated include in hv_init (Mohammed Gamal) [2088365]
- x86/hyperv: Add ghcb hvcall support for SNP VM (Mohammed Gamal) [2088365]
- x86/hyperv: Add Write/Read MSR registers via ghcb page (Mohammed Gamal) [2088365]
- x86/hyperv: Add new hvcall guest address host visibility support (Mohammed Gamal) [2088365]
- x86/hyperv: Initialize shared memory boundary in the Isolation VM. (Mohammed Gamal) [2088365]
- x86/hyperv: Initialize GHCB page in Isolation VM (Mohammed Gamal) [2088365]
- x86/sev: Expose sev_es_ghcb_hv_call() for use by HyperV (Mohammed Gamal) [2088365]
- x86/sev: Carve out HV call's return value verification (Mohammed Gamal) [2088365]
- x86/sev: Return an error on a returned non-zero SW_EXITINFO1[31:0] (Mohammed Gamal) [2088365]
- x86/sev: Fix noinstr for vc_ghcb_invalidate() (Mohammed Gamal) [2088365]
- topology: make core_mask include at least cluster_siblings (Mark Salter) [2047951]
- KVM: x86: Fix the intel_pt PMI handling wrongly considered from guest (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Don't rebuild page when the page is synced and no tlb flushing is required (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Verify the pmu event filter matches the correct event (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Add the helper function create_pmu_event_filter (Vitaly Kuznetsov) [2074832]
- kvm: x86/pmu: Fix the compare function used by the pmu event filter (Vitaly Kuznetsov) [2074832]
- KVM: Free new dirty bitmap if creating a new memslot fails (Vitaly Kuznetsov) [2074832]
- KVM: Initialize debugfs_dentry when a VM is created to avoid NULL deref (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Exit to userspace if vCPU has injected exception and invalid state (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Mark nested locking of vcpu->lock (Vitaly Kuznetsov) [2074832]
- kvm: x86/cpuid: Only provide CPUID leaf 0xA if host has architectural PMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Account for family 17h event renumberings in amd_pmc_perf_hw_id (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use atomic XCHG to write TDP MMU SPTEs with volatile bits (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move shadow-present check out of spte_has_volatile_bits() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Don't treat fully writable SPTEs as volatile (modulo A/D) (Vitaly Kuznetsov) [2074832]
- Revert "x86/mm: Introduce lookup_address_in_mm()" (Vitaly Kuznetsov) [2074832]
- KVM: x86: work around QEMU issue with synthetic CPUID leaves (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: fix potential races when walking host page table (Vitaly Kuznetsov) [2074832]
- Documentation: KVM: Update documentation to indicate KVM is arm64-only (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Do not create SPTEs for GFNs that exceed host.MAXPHYADDR (Vitaly Kuznetsov) [2074832]
- kvm: selftests: introduce and use more page size-related constants (Vitaly Kuznetsov) [2074832]
- kvm: selftests: do not use bitfields larger than 32-bits for PTEs (Vitaly Kuznetsov) [2074832]
- KVM: SEV: add cache flush to solve SEV cache incoherency issues (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Flush when freeing encrypted pages even on SME_COHERENT CPUs (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Simplify and harden helper to flush SEV guest page(s) (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Silence compiler warning in the kvm_page_table_test (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Update AMD PMC sample period to fix guest NMI-watchdog (Vitaly Kuznetsov) [2074832]
- x86/kvm: Preserve BSP MSR_KVM_POLL_CONTROL across suspend/resume (Vitaly Kuznetsov) [2074832]
- KVM: x86: Skip KVM_GUESTDBG_BLOCKIRQ APICv update if APICv is disabled (Vitaly Kuznetsov) [2074832]
- KVM: x86: Pend KVM_REQ_APICV_UPDATE during vCPU creation to fix a race (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Defer APICv updates while L2 is active until L1 is active (Vitaly Kuznetsov) [2074832]
- KVM: x86: Tag APICv DISABLE inhibit, not ABSENT, if APICv is disabled (Vitaly Kuznetsov) [2074832]
- KVM: Add helpers to wrap vcpu->srcu_idx and yell if it's abused (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't re-acquire SRCU lock in complete_emulated_io() (Vitaly Kuznetsov) [2074832]
- tools arch: Update arch/x86/lib/mem{cpy,set}_64.S copies used in 'perf bench mem memcpy' (Vitaly Kuznetsov) [2074832]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074832]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (Vitaly Kuznetsov) [2074832]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074832]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Add support for various modes with 16kB page size (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Check for supported page sizes (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Initialise default guest mode at test startup time (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Add support for VM_MODE_P36V48_{4K,64K} (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Introduce a variable default IPA size (Vitaly Kuznetsov) [2074832]
- KVM: selftests: arm64: Rework TCR_EL1 configuration (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Avoid writing to TSC page without an active vCPU (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Do not activate AVIC for SEV-enabled guest (Vitaly Kuznetsov) [2074832]
- selftests: kvm: add tsc_scaling_sync to .gitignore (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Don't leak GIC FD across dirty log test iterations (Vitaly Kuznetsov) [2074832]
- KVM: Don't create VM debugfs files outside of the VM directory (Vitaly Kuznetsov) [2074832]
- KVM: selftests: get-reg-list: Add KVM_REG_ARM_FW_REG(3) (Vitaly Kuznetsov) [2074832]
- KVM: avoid NULL pointer dereference in kvm_dirty_ring_push (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: remove unnecessary flush_workqueue() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Resolve nx_huge_pages when kvm.ko is loaded (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Add cond_resched() to loop in sev_clflush_pages() (Vitaly Kuznetsov) [2074832]
- KVM: x86: fix sending PV IPI (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do compare-and-exchange of gPTE via the user address (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove redundant vm_entry_controls_clearbit() call (Vitaly Kuznetsov) [2074832]
- KVM: x86: cleanup enter_rmode() (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: fix tsc scaling when the host doesn't support it (Vitaly Kuznetsov) [2074832]
- kvm: x86: SVM: remove unused defines (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: move tsc ratio definitions to svm.h (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: fix avic spec based definitions again (Vitaly Kuznetsov) [2074832]
- KVM: x86: Only do MSR filtering when access MSR by rdmsr/wrmsr (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Emulate RDPID only if it is enabled in guest (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Fix and isolate TSX-specific performance event logic (Vitaly Kuznetsov) [2074832]
- KVM: x86: mmu: trace kvm_mmu_set_spte after the new SPTE was set (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Clear reserved bits written to PerfEvtSeln MSRs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Trace all APICv inhibit changes and capture overall status (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add wrappers for setting/clearing APICv inhibits (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make APICv inhibit reasons an enum and cleanup naming (Vitaly Kuznetsov) [2074832]
- KVM: X86: Handle implicit supervisor access with SMAP (Vitaly Kuznetsov) [2074832]
- KVM: X86: Rename variable smap to not_smap in permission_fault() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Fix comments in update_permission_bitmask (Vitaly Kuznetsov) [2074832]
- KVM: X86: Change the type of access u32 to u64 (Vitaly Kuznetsov) [2074832]
- KVM: Remove dirty handling from gfn_to_pfn_cache completely (Vitaly Kuznetsov) [2074832]
- KVM: Use enum to track if cached PFN will be used in guest and/or host (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Fix kvm_cache_regs.h inclusions for is_guest_mode() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Use different raw event masks for AMD and Intel (Vitaly Kuznetsov) [2074832]
- KVM: Don't actually set a request when evicting vCPUs for GFN cache invd (Vitaly Kuznetsov) [2074832]
- KVM: avoid double put_page with gfn-to-pfn cache (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only TDP MMU leafs in zap range and mmu_notifier unmap (Vitaly Kuznetsov) [2074832]
- KVM: SVM: fix panic on out-of-bounds guest IRQ (Vitaly Kuznetsov) [2074832]
- KVM: MMU: propagate alloc_workqueue failure (Vitaly Kuznetsov) [2074832]
- KVM: x86: Forbid VMM to set SYNIC/STIMER MSRs when SynIC wasn't activated (Vitaly Kuznetsov) [2074832]
- KVM: x86: Avoid theoretical NULL pointer dereference in kvm_irq_delivery_to_apic_fast() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Check lapic_in_kernel() before attempting to set a SynIC irq (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix clang -Wimplicit-fallthrough in do_host_cpuid() (Vitaly Kuznetsov) [2074832]
- Revert "KVM: set owner of cpu and vm file operations" (Vitaly Kuznetsov) [2074832]
- KVM: Prevent module exit until all VMs are freed (Vitaly Kuznetsov) [2074832]
- KVM: use kvcalloc for array allocations (Vitaly Kuznetsov) [2074832]
- KVM: x86: Introduce KVM_CAP_DISABLE_QUIRKS2 (Vitaly Kuznetsov) [2074832]
- kvm: x86: Require const tsc for RT (Vitaly Kuznetsov) [2074832]
- KVM: x86: synthesize CPUID leaf 0x80000021h if useful (Vitaly Kuznetsov) [2074832]
- KVM: x86: add support for CPUID leaf 0x80000021 (Vitaly Kuznetsov) [2074832]
- KVM: x86: do not use KVM_X86_OP_OPTIONAL_RET0 for get_mt_mask (Vitaly Kuznetsov) [2074832]
- Revert "KVM: x86/mmu: Zap only TDP MMU leafs in kvm_zap_gfn_range()" (Vitaly Kuznetsov) [2074832]
- kvm: x86/mmu: Flush TLB before zap_gfn_range releases RCU (Vitaly Kuznetsov) [2074832]
- kvm/emulate: Fix SETcc emulation function offsets with SLS (Vitaly Kuznetsov) [2074832]
- KVM: compat: riscv: Prevent KVM_COMPAT from being selected (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add test to populate a VM with the max possible guest mem (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Define cpu_relax() helpers for s390 and x86 (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Split out helper to allocate guest mem via memfd (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Move raw KVM_SET_USER_MEMORY_REGION helper to utils (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: WARN on any attempt to atomically update REMOVED SPTE (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check for a REMOVED leaf SPTE before making the SPTE (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap defunct roots via asynchronous worker (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap roots in two passes to avoid inducing RCU stalls (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Allow yielding when zapping GFNs for defunct TDP MMU root (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap invalidated roots via asynchronous worker (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Defer TLB flush to caller when freeing TDP MMU shadow pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Do remote TLB flush before dropping RCU in TDP MMU resched (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only TDP MMU leafs in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Require mmu_lock be held for write to zap TDP MMU range (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Add dedicated helper to zap TDP MMU root shadow page (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Skip remote TLB flush when zapping all of TDP MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only the target TDP MMU shadow page in NX recovery (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Refactor low-level TDP MMU set SPTE helper to take raw values (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: WARN if old _or_ new SPTE is REMOVED in non-atomic path (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Add helpers to read/write TDP MMU SPTEs and document RCU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Drop RCU after processing each root in MMU notifier hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Batch TLB flushes from TDP MMU for MMU notifier change_spte (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check for !leaf=>leaf, not PFN change, in TDP MMU SP removal (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do not allow readers to acquire references to invalid roots (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: only perform eager page splitting on valid roots (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Require mmu_lock be held for write in unyielding root iter (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Document that zapping invalidated roots doesn't need to flush (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Formalize TDP MMU's (unintended?) deferred TLB flush logic (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fix wrong/misleading comments in TDP MMU fast zap (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check for present SPTE when clearing dirty bit in TDP MMU (Vitaly Kuznetsov) [2074832]
- selftests: kvm: add generated file to the .gitignore (Vitaly Kuznetsov) [2074832]
- KVM: x86: pull kvm->srcu read-side to kvm_arch_vcpu_ioctl_run (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Passing up the error state of mmu_alloc_shadow_roots() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Disable preemption across AVIC load/put during APICv refresh (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Exit to userspace on ENOMEM/EFAULT GHCB errors (Vitaly Kuznetsov) [2074832]
- KVM: WARN if is_unsync_root() is called on a root without a shadow page (Vitaly Kuznetsov) [2074832]
- KVM: Drop KVM_REQ_MMU_RELOAD and update vcpu-requests.rst documentation (Vitaly Kuznetsov) [2074832]
- KVM: s390: Replace KVM_REQ_MMU_RELOAD usage with arch specific request (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap only obsolete roots if a root shadow page is zapped (Vitaly Kuznetsov) [2074832]
- KVM: Drop kvm_reload_remote_mmus(), open code request in x86 users (Vitaly Kuznetsov) [2074832]
- KVM: x86: Invoke kvm_mmu_unload() directly on CR4.PCIDE change (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Move the unhandled outer privilege level logic of far return into __load_segment_descriptor() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Fix wrong privilege check for code segment in __load_segment_descriptor() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulator: Defer not-present segment check in __load_segment_descriptor() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add test to verify KVM handling of ICR (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make kvm_lapic_set_reg() a "private" xAPIC helper (Vitaly Kuznetsov) [2074832]
- KVM: x86: Treat x2APIC's ICR as a 64-bit register, not two 32-bit regs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add helpers to handle 64-bit APIC MSR read/writes (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make kvm_lapic_reg_{read,write}() static (Vitaly Kuznetsov) [2074832]
- KVM: x86: WARN if KVM emulates an IPI without clearing the BUSY flag (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't rewrite guest ICR on AVIC IPI virtualization failure (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Use common kvm_apic_write_nodecode() for AVIC write traps (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use "raw" APIC register read for handling APIC-write VM-Exit (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Handle APIC-write offset wrangling in VMX code (Vitaly Kuznetsov) [2074832]
- KVM: x86: Do not change ICR on write to APIC_SELF_IPI (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix emulation in writing cr8 (Vitaly Kuznetsov) [2074832]
- KVM: x86: flush TLB separately from MMU reset (Vitaly Kuznetsov) [2074832]
- KVM: x86: Yield to IPI target vCPU only if it is busy (Vitaly Kuznetsov) [2074832]
- x86/kvm: Don't use PV TLB/yield when mwait is advertised (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: clear MMIO cache when unloading the MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Always use current mmu's role when loading new PGD (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: load new PGD after the shadow MMU is initialized (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: look for a cached PGD when going from 32-bit to 64-bit (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do not pass vcpu to root freeing functions (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: do not consult levels when freeing roots (Vitaly Kuznetsov) [2074832]
- KVM: x86: use struct kvm_mmu_root_info for mmu->root (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: avoid NULL-pointer dereference on page freeing bugs (Vitaly Kuznetsov) [2074832]
- KVM: x86: do not deliver asynchronous page faults if CR0.PG=0 (Vitaly Kuznetsov) [2074832]
- KVM: x86: Reinitialize context if host userspace toggles EFER.LME (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Verify disabling PMU virtualization via KVM_CAP_CONFIG_PMU (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Carve out helper to create "default" VM without vCPUs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Provide per VM capability for disabling PMU virtualization (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix pointer mistmatch warning when patching RET0 static calls (Vitaly Kuznetsov) [2074832]
- KVM: Move VM's worker kthreads back to the original cgroup before exiting. (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Remove scratch 'cpu' variable that shadows an identical scratch var (Vitaly Kuznetsov) [2074832]
- kvm: vmx: Fix typos comment in __loaded_vmcs_clear() (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Make setup/unsetup under the same conditions (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: HVCALL_SEND_IPI_EX is an XMM fast hypercall (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Fix the maximum number of sparse banks for XMM fast TLB flush hypercalls (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Drop redundant 'ex' parameter from kvm_hv_flush_tlb() (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Drop redundant 'ex' parameter from kvm_hv_send_ipi() (Vitaly Kuznetsov) [2074832]
- Revert "KVM: VMX: Save HOST_CR3 in vmx_prepare_switch_to_guest()" (Vitaly Kuznetsov) [2074832]
- Revert "KVM: VMX: Save HOST_CR3 in vmx_set_host_fs_gs()" (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: disallow userspace setting of MSR_AMD64_TSC_RATIO to non default value when tsc scaling disabled (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: make apf token non-zero to fix bug (Vitaly Kuznetsov) [2074832]
- selftests: kvm: Add the uapi headers include variable (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add EXTRA_CFLAGS in top-level Makefile (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove MMU auditing (Vitaly Kuznetsov) [2074832]
- KVM: x86: allow defining return-0 static calls (Vitaly Kuznetsov) [2074832]
- KVM: x86: make several APIC virtualization callbacks optional (Vitaly Kuznetsov) [2074832]
- KVM: x86: warn on incorrectly NULL members of kvm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: x86: remove KVM_X86_OP_NULL and mark optional kvm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: x86: use static_call_cond for optional callbacks (Vitaly Kuznetsov) [2074832]
- KVM: x86: return 1 unconditionally for availability of KVM_CAP_VAPIC (Vitaly Kuznetsov) [2074832]
- selftests: KVM: allow sev_migrate_tests on machines without SEV-ES (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Allow SEV intra-host migration of VM with mirrors (Vitaly Kuznetsov) [2074832]
- x86/kvm: Don't use pv tlb/ipi/sched_yield if on 1 vCPU (Vitaly Kuznetsov) [2074832]
- x86/kvm: Fix compilation warning in non-x86_64 builds (Vitaly Kuznetsov) [2074832]
- kvm: x86: Disable KVM_HC_CLOCK_PAIRING if tsc is in always catchup mode (Vitaly Kuznetsov) [2074832]
- KVM: Fix lockdep false negative during host resume (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add KVM_CAP_ENABLE_CAP to x86 (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename AVIC helpers to use "avic" prefix instead of "svm" (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Use AMD64_RAW_EVENT_MASK for PERF_TYPE_RAW (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Don't truncate the PerfEvtSeln MSR when creating a perf event (Vitaly Kuznetsov) [2074832]
- KVM: x86: Replace memset() "optimization" with normal per-field writes (Vitaly Kuznetsov) [2074832]
- KVM: SVM: fix race between interrupt delivery and AVIC inhibition (Vitaly Kuznetsov) [2074832]
- KVM: SVM: set IRR in svm_deliver_interrupt (Vitaly Kuznetsov) [2074832]
- KVM: SVM: extract avic_ring_doorbell (Vitaly Kuznetsov) [2074832]
- selftests: kvm: Remove absent target file (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use local pointer to vcpu_vmx in vmx_vcpu_after_set_cpuid() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nSVM: Add enlightened MSR-Bitmap selftest (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nSVM: Update 'struct vmcb_control_area' definition (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nSVM: Set up MSR-Bitmap for SVM guests (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nVMX: Add enlightened MSR-Bitmap selftest (Vitaly Kuznetsov) [2074832]
- KVM: selftests: nVMX: Properly deal with 'hv_clean_fields' (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Adapt hyperv_cpuid test to the newly introduced Enlightened MSR-Bitmap (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: Implement Enlightened MSR-Bitmap feature (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: Split off common definitions for Hyper-V on KVM and KVM on Hyper-V (Vitaly Kuznetsov) [2074832]
- KVM: x86: Make kvm_hv_hypercall_enabled() static inline (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: Track whether changes in L0 require MSR bitmap for L2 to be rebuilt (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add an option to disable MANUAL_PROTECT_ENABLE and INITIALLY_SET (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Add tracepoint for splitting huge pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Split huge pages mapped by the TDP MMU during KVM_CLEAR_DIRTY_LOG (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Split huge pages mapped by the TDP MMU when dirty logging is enabled (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Separate TDP MMU shadow page allocation and initialization (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Derive page role for TDP MMU shadow pages from parent (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove redundant role overrides for TDP MMU shadow pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Refactor TDP MMU iterators to take kvm_mmu_page root (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move restore_acc_track_spte() to spte.h (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Drop new_spte local variable from restore_acc_track_spte() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unnecessary warnings from restore_acc_track_spte() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Consolidate logic to atomically install a new TDP MMU page table (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename handle_removed_tdp_mmu_page() to handle_removed_pt() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename TDP MMU functions that handle shadow pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Change tdp_mmu_{set,zap}_spte_atomic() to return 0/-EBUSY (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Automatically update iter->old_spte if cmpxchg fails (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename __rmap_write_protect() to rmap_write_protect() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename rmap_write_protect() to kvm_vcpu_write_protect_gfn() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add checks for reserved-to-zero Hyper-V hypercall fields (Vitaly Kuznetsov) [2074832]
- KVM: x86: Reject fixeds-size Hyper-V hypercalls with non-zero "var_cnt" (Vitaly Kuznetsov) [2074832]
- KVM: x86: Shove vp_bitmap handling down into sparse_set_to_vcpu_mask() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't bother reading sparse banks that end up being ignored (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add a helper to get the sparse VP_SET for IPIs and TLB flushes (Vitaly Kuznetsov) [2074832]
- KVM: x86: Refactor kvm_hv_flush_tlb() to reduce indentation (Vitaly Kuznetsov) [2074832]
- KVM: x86: Get the number of Hyper-V sparse banks from the VARHEAD field (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Consolidate comments about {Host,MMU}-writable (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename DEFAULT_SPTE_MMU_WRITEABLE to DEFAULT_SPTE_MMU_WRITABLE (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move is_writable_pte() to spte.h (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Check SPTE writable invariants when setting leaf SPTEs (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move SPTE writable invariant checks to a helper function (Vitaly Kuznetsov) [2074832]
- KVM: LAPIC: Enable timer posted-interrupt only when mwait/hlt is advertised (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Dont' send posted IRQ if vCPU == this vCPU and vCPU is IN_GUEST_MODE (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename hook implementations to conform to kvm_x86_ops' names (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename SEV implemenations to conform to kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use more verbose names for mem encrypt kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove unused MAX_INST_SIZE #define (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename svm_flush_tlb() to svm_flush_tlb_current() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Move get_cs_db_l_bits() helper to SVM (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Rename VMX functions to conform to kvm_x86_ops names (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use static_call() for copy/move encryption context ioctls() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Unexport kvm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: x86: Uninline and export hv_track_root_tdp() (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Refactor PMU refresh to avoid referencing kvm_x86_ops.pmu_ops (Vitaly Kuznetsov) [2074832]
- KVM: xen: Use static_call() for invoking kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use static_call() for .vcpu_deliver_sipi_vector() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Call vmx_get_cpl() directly in handle_dr() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Rename kvm_x86_ops pointers to align w/ preferred vendor names (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop export for .tlb_flush_current() static_call key (Vitaly Kuznetsov) [2074832]
- KVM: x86: skip host CPUID call for hypervisor leaves (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove unused "flags" of kvm_pv_kick_cpu_op() (Vitaly Kuznetsov) [2074832]
- KVM: Remove unused "kvm" of kvm_make_vcpu_request() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove unused "vcpu" of kvm_scale_tsc() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulate: Remove unused "tss_selector" of task_switch_{16, 32}() (Vitaly Kuznetsov) [2074832]
- KVM: x86/emulate: Remove unused "ctxt" of setup_syscalls_segments() (Vitaly Kuznetsov) [2074832]
- KVM: x86/ioapic: Remove unused "addr" and "length" of ioapic_read_indirect() (Vitaly Kuznetsov) [2074832]
- KVM: x86/i8259: Remove unused "addr" of elcr_ioport_{read,write}() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: improve split between svm_prepare_guest_switch and sev_es_prepare_guest_switch (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Remove unused "vcpu" of svm_check_exit_valid() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu_audit: Remove unused "level" of audit_spte_after_sync() (Vitaly Kuznetsov) [2074832]
- KVM: x86/tdp_mmu: Remove unused "kvm" of kvm_tdp_mmu_get_root() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unused "vcpu" of reset_{tdp,ept}_shadow_zero_bits_mask() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unused "kvm" of __rmap_write_protect() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove unused "kvm" of kvm_mmu_unlink_parents() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Skip APICv update if APICv is disable at the module level (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop NULL check on kvm_x86_ops.check_apicv_inhibit_reasons (Vitaly Kuznetsov) [2074832]
- KVM: x86: Unexport __kvm_request_apicv_update() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Zap _all_ roots when unmapping gfn range in TDP MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Move "invalid" check out of kvm_tdp_mmu_get_root() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use common TDP MMU zap helper for MMU notifier unmap hook (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Fix runstate updates to be atomic when preempting vCPU (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: move avic definitions from AMD's spec to svm.h (Vitaly Kuznetsov) [2074832]
- KVM: x86: lapic: don't touch irr_pending in kvm_apic_update_apicv when inhibiting it (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: deal with L1 hypervisor that intercepts interrupts but lets L2 control them (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: expose clean bit support to the guest (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM/nVMX: set nested_run_pending on VM entry which is a result of RSM (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: mark vmcb01 as dirty when restoring SMM saved state (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: fix potential NULL derefernce on nested migration (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: don't passthrough SMAP/SMEP/PKE bits in !NPT && !gCR0.PG case (Vitaly Kuznetsov) [2074832]
- Revert "svm: Add warning message for AVIC IPI invalid target" (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add vgic initialization for dirty log perf test for ARM (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Test OS lock behavior (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add OSLSR_EL1 to the list of blessed regs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use ERR_PTR_USR() to return -EFAULT as a __user pointer (Vitaly Kuznetsov) [2074832]
- KVM: x86: Report deprecated x87 features in supported CPUID (Vitaly Kuznetsov) [2074832]
- KVM: x86: use the KVM side max supported fixed counter (Vitaly Kuznetsov) [2074832]
- x86: Share definition of __is_canonical_address() (Vitaly Kuznetsov) [2074832]
- perf/x86/intel/pt: Relax address filter validation (Vitaly Kuznetsov) [2074832]
- kvm/x86: rework guest entry logic (Vitaly Kuznetsov) [2074832]
- kvm: add guest_state_{enter,exit}_irqoff() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Move delivery of non-APICv interrupt into vendor code (Vitaly Kuznetsov) [2074832]
- KVM: eventfd: Fix false positive RCU usage warning (Vitaly Kuznetsov) [2074832]
- selftests: kvm: check dynamic bits against KVM_X86_XCOMP_GUEST_SUPP (Vitaly Kuznetsov) [2074832]
- KVM: x86: add system attribute to retrieve full set of supported xsave states (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add a helper to retrieve userspace address from kvm_device_attr (Vitaly Kuznetsov) [2074832]
- selftests: kvm: move vm_xsave_req_perm call to amx_test (Vitaly Kuznetsov) [2074832]
- KVM: x86: Sync the states size with the XCR0/IA32_XSS at, any time (Vitaly Kuznetsov) [2074832]
- KVM: x86: Update vCPU's runtime CPUID on write to MSR_IA32_XSS (Vitaly Kuznetsov) [2074832]
- KVM: x86: Keep MSR_IA32_XSS unchanged for INIT (Vitaly Kuznetsov) [2074832]
- KVM: x86: Free kvm_cpuid_entry2 array on post-KVM_RUN KVM_SET_CPUID{,2} (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: WARN on any attempt to allocate shadow VMCS for vmcs02 (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Don't skip L2's VMCALL in SMM test for SVM guest (Vitaly Kuznetsov) [2074832]
- KVM: x86: Check .flags in kvm_cpuid_check_equal() too (Vitaly Kuznetsov) [2074832]
- KVM: x86: Forcibly leave nested virt when SMM state is toggled (Vitaly Kuznetsov) [2074832]
- KVM: SVM: drop unnecessary code in svm_hv_vmcb_dirty_nested_enlightenments() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: hyper-v: Enable Enlightened MSR-Bitmap support for real (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't kill SEV guest if SMAP erratum triggers in usermode (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't apply SEV+SMAP workaround on code fetch or PT access (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Inject #UD on attempted emulation for SEV guest w/o insn buffer (Vitaly Kuznetsov) [2074832]
- KVM: SVM: WARN if KVM attempts emulation on #UD or #GP for SEV guests (Vitaly Kuznetsov) [2074832]
- KVM: x86: Pass emulation type to can_emulate_instruction() (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Explicitly require DECODEASSISTS to enable SEV support (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't intercept #GP for SEV guests (Vitaly Kuznetsov) [2074832]
- Revert "KVM: SVM: avoid infinite loop on NPF from bad address" (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Never reject emulation due to SMAP errata for !SEV guests (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: skip eax alignment check for non-SVM instructions (Vitaly Kuznetsov) [2074832]
- KVM: LAPIC: Also cancel preemption timer during SET_LAPIC (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Remove vmcs_config.order (Vitaly Kuznetsov) [2074832]
- KVM/X86: Make kvm_vcpu_reload_apic_access_page() static (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Re-enable access_tracking_perf_test (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Set vmcs.PENDING_DBG.BS on #DB in STI/MOVSS blocking shadow (Vitaly Kuznetsov) [2074832]
- KVM: remove async parameter of hva_to_pfn_remapped() (Vitaly Kuznetsov) [2074832]
- x86,kvm/xen: Remove superfluous .fixup usage (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Zero host's SYSENTER_ESP iff SYSENTER is NOT used (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Fix the warning in lib/x86_64/processor.c (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Fix the warning in pmu_event_filter_test.c (Vitaly Kuznetsov) [2074832]
- kvm: selftests: Do not indent with spaces (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Nullify vcpu_(un)blocking() hooks if AVIC is disabled (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Move svm_hardware_setup() and its helpers below svm_x86_ops (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Drop AVIC's intermediate avic_set_running() helper (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Don't do full kick when handling posted interrupt wakeup (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Fold fallback path into triggering posted IRQ helper (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Pass desired vector instead of bool for triggering posted IRQ (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Don't do full kick when triggering posted interrupt "fails" (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Skip AVIC and IRTE updates when loading blocking vCPU (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Use kvm_vcpu_is_blocking() in AVIC load to handle preemption (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove unnecessary APICv/AVIC update in vCPU unblocking path (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Don't bother checking for "running" AVIC when kicking for IPIs (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Signal AVIC doorbell iff vCPU is in guest mode (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove defunct pre_block/post_block kvm_x86_ops hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Unexport LAPIC's switch_to_{hv,sw}_timer() helpers (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Move preemption timer <=> hrtimer dance to common x86 (Vitaly Kuznetsov) [2074832]
- KVM: Move x86 VMX's posted interrupt list_head to vcpu_vmx (Vitaly Kuznetsov) [2074832]
- KVM: Drop unused kvm_vcpu.pre_pcpu field (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Handle PI descriptor updates during vcpu_put/load (Vitaly Kuznetsov) [2074832]
- KVM: avoid warning on s390 in mark_page_dirty (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add a test to force emulation with a pending exception (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Reject KVM_RUN if emulation is required with pending exception (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Add test for KVM_SET_PMU_EVENT_FILTER (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Introduce x86_model() (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Export x86_family() for use outside of processor.c (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Introduce is_amd_cpu() (Vitaly Kuznetsov) [2074832]
- selftests: kvm/x86: Parameterize the CPUID vendor string check (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Use binary search to check filtered events (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Improve TLB flush comment in kvm_mmu_slot_remove_write_access() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Document and enforce MMU-writable and Host-writable invariants (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Clear MMU-writable during changed_pte notifier (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fix write-protection of PTs mapped by the TDP MMU (Vitaly Kuznetsov) [2074832]
- KVM: x86: Making the module parameter of vPMU more common (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Test KVM_SET_CPUID2 after KVM_RUN (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Rename 'get_cpuid_test' to 'cpuid_test' (Vitaly Kuznetsov) [2074832]
- KVM: x86: Partially allow KVM_SET_CPUID{,2} after KVM_RUN (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Fix available_event_types check for REF_CPU_CYCLES event (Vitaly Kuznetsov) [2074832]
- KVM: x86: Check for rmaps allocation (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Mark nested locking of kvm->lock (Vitaly Kuznetsov) [2074832]
- KVM: SVM: include CR3 in initial VMSA state for SEV-ES guests (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Provide vmread version using asm-goto-with-outputs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix wall clock writes in Xen shared_info not to mark page dirty (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Add KVM_IRQ_ROUTING_XEN_EVTCHN and event channel delivery (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Maintain valid mapping of Xen shared_info page (Vitaly Kuznetsov) [2074832]
- KVM: Reinstate gfn_to_pfn_cache with invalidation support (Vitaly Kuznetsov) [2074832]
- KVM: Warn if mark_page_dirty() is called without an active vCPU (Vitaly Kuznetsov) [2074832]
- x86/kvm: Silence per-cpu pr_info noise about KVM clocks and steal time (Vitaly Kuznetsov) [2074832]
- KVM: x86: Update vPMCs when retiring branch instructions (Vitaly Kuznetsov) [2074832]
- KVM: x86: Update vPMCs when retiring instructions (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Add pmc->intr to refactor kvm_perf_overflow{_intr}() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Reuse pmc_perf_hw_id() and drop find_fixed_event() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Refactoring find_arch_event() to pmc_perf_hw_id() (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Setup pmc->eventsel for fixed PMCs (Vitaly Kuznetsov) [2074832]
- KVM: x86: avoid out of bounds indices for fixed performance counters (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Mark VCPU_EXREG_CR3 dirty when !CR0_PG -> CR0_PG if EPT + !URG (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Reconstruct shadow page root if the guest PDPTEs is changed (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Save HOST_CR3 in vmx_set_host_fs_gs() (Vitaly Kuznetsov) [2074832]
- Revert "KVM: X86: Update mmu->pdptrs only when it is changed" (Vitaly Kuznetsov) [2074832]
- selftests: KVM: sev_migrate_tests: Add mirror command tests (Vitaly Kuznetsov) [2074832]
- selftests: KVM: sev_migrate_tests: Fix sev_ioctl() (Vitaly Kuznetsov) [2074832]
- selftests: KVM: sev_migrate_tests: Fix test_sev_mirror() (Vitaly Kuznetsov) [2074832]
- x86/mtrr: Remove the mtrr_bp_init() stub (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Wake vCPU when delivering posted IRQ even if vCPU == this vCPU (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add test to verify TRIPLE_FAULT on invalid L2 guest state (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Synthesize TRIPLE_FAULT for L2 if emulation is required (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Always clear vmx->fail on emulation_required (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Fix non-x86 compiling (Vitaly Kuznetsov) [2074832]
- KVM: x86: Always set kvm_run->if_flag (Vitaly Kuznetsov) [2074832]
- KVM: x86: remove PMU FIXED_CTR3 from msrs_to_save_all (Vitaly Kuznetsov) [2074832]
- KVM: x86: Retry page fault if MMU reload is pending and root has no sp (Vitaly Kuznetsov) [2074832]
- KVM: selftests: vmx_pmu_msrs_test: Drop tests mangling guest visible CPUIDs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop guest CPUID check for host initiated writes to MSR_IA32_PERF_CAPABILITIES (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add test to verify KVM doesn't explode on "bad" I/O (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't WARN if userspace mucks with RCX during string I/O exit (Vitaly Kuznetsov) [2074832]
- KVM: X86: Raise #GP when clearing CR0_PG in 64 bit mode (Vitaly Kuznetsov) [2074832]
- selftests: KVM: avoid failures due to reserved HyperTransport region (Vitaly Kuznetsov) [2074832]
- KVM: x86: Ignore sparse banks size for an "all CPUs", non-sparse IPI req (Vitaly Kuznetsov) [2074832]
- KVM: Add Makefile.kvm for common files, use it for x86 (Vitaly Kuznetsov) [2074832]
- KVM: Introduce CONFIG_HAVE_KVM_DIRTY_RING (Vitaly Kuznetsov) [2074832]
- KVM: x86: selftests: svm_int_ctl_test: fix intercept calculation (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Clean up PI pre/post-block WARNs (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Ensure vCPU honors event request if posting nested IRQ fails (Vitaly Kuznetsov) [2074832]
- KVM: x86: add a tracepoint for APICv/AVIC interrupt delivery (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Implement Enlightened MSR Bitmap feature (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Track whether changes in L0 require MSR bitmap for L2 to be rebuilt (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Introduce vmx_msr_bitmap_l01_changed() helper (Vitaly Kuznetsov) [2074832]
- KVM: x86: Exit to userspace if emulation prepared a completion callback (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Don't use Enlightened MSR Bitmap for L3 (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use different callback if msr access comes from the emulator (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add an emulation type to handle completion of user exits (Vitaly Kuznetsov) [2074832]
- KVM: x86: Handle 32-bit wrap of EIP for EMULTYPE_SKIP with flat code seg (Vitaly Kuznetsov) [2074832]
- KVM: Clear pv eoi pending bit only when it is set (Vitaly Kuznetsov) [2074832]
- KVM: x86: don't print when fail to read/write pv eoi memory (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove mmu parameter from load_pdptrs() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Rename gpte_is_8_bytes to has_4_byte_gpte and invert the direction (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use ept_caps_to_lpage_level() in hardware_setup() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Add parameter huge_page_level to kvm_init_shadow_ept_mmu() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Add huge_page_level to __reset_rsvds_bits_mask_ept() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove mmu->translate_gpa (Vitaly Kuznetsov) [2074832]
- KVM: X86: Add parameter struct kvm_mmu *mmu into mmu->gva_to_gpa() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Calculate quadrant when !role.gpte_is_8_bytes (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove useless code to set role.gpte_is_8_bytes when role.direct (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove unused declaration of __kvm_mmu_free_some_pages() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Fix comment in __kvm_mmu_create() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Skip allocating pae_root for vcpu->arch.guest_mmu when !tdp_enabled (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Allocate sd->save_area with __GFP_ZERO (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Rename get_max_npt_level() to get_npt_level() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Change comments about vmx_get_msr() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use kvm_set_msr_common() for MSR_IA32_TSC_ADJUST in the default way (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Save HOST_CR3 in vmx_prepare_switch_to_guest() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Update msr value after kvm_set_user_return_msr() succeeds (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Avoid to rdmsrl(MSR_IA32_SYSENTER_ESP) (Vitaly Kuznetsov) [2074832]
- KVM: X86: Update mmu->pdptrs only when it is changed (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove kvm_register_clear_available() (Vitaly Kuznetsov) [2074832]
- KVM: vmx, svm: clean up mass updates to regs_avail/regs_dirty bits (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Update vmcs.GUEST_CR3 only when the guest CR3 is dirty (Vitaly Kuznetsov) [2074832]
- KVM: X86: Mark CR3 dirty when vcpu->arch.cr3 is changed (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove references to VCPU_EXREG_CR3 (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Remove outdated comment in svm_load_mmu_pgd() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Move CR0 pdptr_bits into header file as X86_CR0_PDPTR_BITS (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Add and use X86_CR4_PDPTR_BITS when !enable_ept (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Add and use X86_CR4_TLBFLUSH_BITS when !enable_ept (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Track dirtiness of PDPTRs even if NPT is disabled (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Mark VCPU_EXREG_PDPTR available in ept_save_pdptrs() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Ensure that dirty PDPTRs are loaded (Vitaly Kuznetsov) [2074832]
- KVM: x86/svm: Add module param to control PMU virtualization (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Remove vCPU from PI wakeup list before updating PID.NV (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Move Posted Interrupt ndst computation out of write loop (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Read Posted Interrupt "control" exactly once per loop iteration (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Save/restore IRQs (instead of CLI/STI) during PI pre/post block (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Drop pointless PI.NDST update when blocking (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use boolean returns for Posted Interrupt "test" helpers (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Drop unnecessary PI logic to handle impossible conditions (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Skip Posted Interrupt updates if APICv is hard disabled (Vitaly Kuznetsov) [2074832]
- KVM: Add helpers to wake/query blocking vCPU (Vitaly Kuznetsov) [2074832]
- KVM: x86: Invoke kvm_vcpu_block() directly for non-HALTED wait states (Vitaly Kuznetsov) [2074832]
- KVM: x86: Directly block (instead of "halting") UNINITIALIZED vCPUs (Vitaly Kuznetsov) [2074832]
- KVM: Don't redo ktime_get() when calculating halt-polling stop/deadline (Vitaly Kuznetsov) [2074832]
- KVM: stats: Add stat to detect if vcpu is currently blocking (Vitaly Kuznetsov) [2074832]
- KVM: Split out a kvm_vcpu_block() helper from kvm_vcpu_halt() (Vitaly Kuznetsov) [2074832]
- KVM: Rename kvm_vcpu_block() => kvm_vcpu_halt() (Vitaly Kuznetsov) [2074832]
- KVM: Drop obsolete kvm_arch_vcpu_block_finish() (Vitaly Kuznetsov) [2074832]
- KVM: s390: Clear valid_wakeup in kvm_s390_handle_wait(), not in arch hook (Vitaly Kuznetsov) [2074832]
- KVM: x86: Tweak halt emulation helper names to free up kvm_vcpu_halt() (Vitaly Kuznetsov) [2074832]
- KVM: Don't block+unblock when halt-polling is successful (Vitaly Kuznetsov) [2074832]
- KVM: Reconcile discrepancies in halt-polling stats (Vitaly Kuznetsov) [2074832]
- KVM: Refactor and document halt-polling stats update helper (Vitaly Kuznetsov) [2074832]
- KVM: Update halt-polling stats if and only if halt-polling was attempted (Vitaly Kuznetsov) [2074832]
- KVM: Force PPC to define its own rcuwait object (Vitaly Kuznetsov) [2074832]
- KVM: s390: Ensure kvm_arch_no_poll() is read once when blocking vCPU (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Ensure target pCPU is read once when signalling AVIC doorbell (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Don't unblock vCPU w/ Posted IRQ if IRQs are disabled in guest (Vitaly Kuznetsov) [2074832]
- KVM: x86: change TLB flush indicator to bool (Vitaly Kuznetsov) [2074832]
- KVM: Avoid atomic operations when kicking the running vCPU (Vitaly Kuznetsov) [2074832]
- KVM: x86/MMU: Simplify flow of vmx_get_mt_mask (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Propagate memslot const qualifier (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove need for a vcpu from mmu_try_to_unsync_pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove need for a vcpu from kvm_slot_page_track_is_active (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use shadow page role to detect PML-unfriendly pages for L2 (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: introduce struct vmcb_ctrl_area_cached (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: split out __nested_vmcb_check_controls (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: use svm->nested.save to load vmcb12 registers and avoid TOC/TOU races (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: use vmcb_save_area_cached in nested_vmcb_valid_sregs() (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: rename nested_load_control_from_vmcb12 in nested_copy_vmcb_control_to_cache (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: introduce svm->nested.save to cache save area before checks (Vitaly Kuznetsov) [2074832]
- KVM: nSVM: move nested_vmcb_check_cr3_cr4 logic in nested_vmcb_valid_sregs (Vitaly Kuznetsov) [2074832]
- KVM: Dynamically allocate "new" memslots from the get-go (Vitaly Kuznetsov) [2074832]
- KVM: Wait 'til the bitter end to initialize the "new" memslot (Vitaly Kuznetsov) [2074832]
- KVM: Optimize overlapping memslots check (Vitaly Kuznetsov) [2074832]
- KVM: Optimize gfn lookup in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2074832]
- KVM: Call kvm_arch_flush_shadow_memslot() on the old slot in kvm_invalidate_memslot() (Vitaly Kuznetsov) [2074832]
- KVM: Keep memslots in tree-based structures instead of array-based ones (Vitaly Kuznetsov) [2074832]
- KVM: s390: Introduce kvm_s390_get_gfn_end() (Vitaly Kuznetsov) [2074832]
- KVM: s390: Add a routine for setting userspace CPU state (Vitaly Kuznetsov) [2074832]
- KVM: Use interval tree to do fast hva lookup in memslots (Vitaly Kuznetsov) [2074832]
- KVM: Resolve memslot ID via a hash table instead of via a static array (Vitaly Kuznetsov) [2074832]
- KVM: Move WARN on invalid memslot index to update_memslots() (Vitaly Kuznetsov) [2074832]
- KVM: Integrate gfn_to_memslot_approx() into search_memslots() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use nr_memslot_pages to avoid traversing the memslots array (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't call kvm_mmu_change_mmu_pages() if the count hasn't changed (Vitaly Kuznetsov) [2074832]
- KVM: Don't make a full copy of the old memslot in __kvm_set_memory_region() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't assume old/new memslots are non-NULL at memslot commit (Vitaly Kuznetsov) [2074832]
- KVM: Use prepare/commit hooks to handle generic memslot metadata updates (Vitaly Kuznetsov) [2074832]
- KVM: Stop passing kvm_userspace_memory_region to arch memslot hooks (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074832]
- KVM: s390: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074832]
- KVM: arm64: Use "new" memslot instead of userspace memory region (Vitaly Kuznetsov) [2074832]
- KVM: Let/force architectures to deal with arch specific memslot data (Vitaly Kuznetsov) [2074832]
- KVM: Use "new" memslot's address space ID instead of dedicated param (Vitaly Kuznetsov) [2074832]
- KVM: Resync only arch fields when slots_arch_lock gets reacquired (Vitaly Kuznetsov) [2074832]
- KVM: Open code kvm_delete_memslot() into its only caller (Vitaly Kuznetsov) [2074832]
- KVM: Require total number of memslot pages to fit in an unsigned long (Vitaly Kuznetsov) [2074832]
- KVM: Convert kvm_for_each_vcpu() to using xa_for_each_range() (Vitaly Kuznetsov) [2074832]
- KVM: arm64: vgic-v3: Fix vcpu index comparison (Vitaly Kuznetsov) [2074832]
- KVM: Use 'unsigned long' as kvm_for_each_vcpu()'s index (Vitaly Kuznetsov) [2074832]
- KVM: Convert the kvm->vcpus array to a xarray (Vitaly Kuznetsov) [2074832]
- KVM: s390: Use kvm_get_vcpu() instead of open-coded access (Vitaly Kuznetsov) [2074832]
- KVM: Move wiping of the kvm->vcpus array to common code (Vitaly Kuznetsov) [2074832]
- KVM: MMU: update comment on the number of page role combinations (Vitaly Kuznetsov) [2074832]
- KVM: Drop stale kvm_is_transparent_hugepage() declaration (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Retry page fault if root is invalidated by memslot update (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Set failure code in prepare_vmcs02() (Vitaly Kuznetsov) [2074832]
- KVM: ensure APICv is considered inactive if there is no APIC (Vitaly Kuznetsov) [2074832]
- KVM: x86/pmu: Fix reserved bits for AMD PerfEvtSeln register (Vitaly Kuznetsov) [2074832]
- entry: Snapshot thread flags (Vitaly Kuznetsov) [2074832]
- x86: Snapshot thread flags (Vitaly Kuznetsov) [2074832]
- thread_info: Add helpers to snapshot thread flags (Vitaly Kuznetsov) [2074832]
- KVM: fix avic_set_running for preemptable kernels (Vitaly Kuznetsov) [2074832]
- KVM: VMX: clear vmx_x86_ops.sync_pir_to_irr if APICv is disabled (Vitaly Kuznetsov) [2074832]
- KVM: SEV: accept signals in sev_lock_two_vms (Vitaly Kuznetsov) [2074832]
- KVM: SEV: do not take kvm->lock when destroying (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Prohibit migration of a VM that has mirrors (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Do COPY_ENC_CONTEXT_FROM with both VMs locked (Vitaly Kuznetsov) [2074832]
- selftests: sev_migrate_tests: add tests for KVM_CAP_VM_COPY_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: move mirror status to destination of KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: initialize regions_list of a mirror VM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: cleanup locking for KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: SEV: do not use list_replace_init on an empty list (Vitaly Kuznetsov) [2074832]
- KVM: x86: Use a stable condition around all VT-d PI paths (Vitaly Kuznetsov) [2074832]
- KVM: x86: check PIR even for vCPUs with disabled APICv (Vitaly Kuznetsov) [2074832]
- KVM: VMX: prepare sync_pir_to_irr for running with APICv disabled (Vitaly Kuznetsov) [2074832]
- KVM: selftests: page_table_test: fix calculation of guest_test_phys_mem (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Handle "default" period when selectively waking kthread (Vitaly Kuznetsov) [2074832]
- KVM: MMU: shadow nested paging does not have PKU (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Remove spurious TLB flushes in TDP MMU zap collapsible path (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Use yield-safe TDP MMU root iter in MMU notifier unmapping (Vitaly Kuznetsov) [2074832]
- KVM: X86: Use vcpu->arch.walk_mmu for kvm_mmu_invlpg() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Make sure kvm_create_max_vcpus test won't hit RLIMIT_NOFILE (Vitaly Kuznetsov) [2074832]
- KVM: x86: Forbid KVM_SET_CPUID{,2} after KVM_RUN (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Avoid KVM_SET_CPUID2 after KVM_RUN in hyperv_features test (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Emulate guest TLB flush on nested VM-Enter with new vpid12 (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Abide to KVM_REQ_TLB_FLUSH_GUEST request on nested vmentry/vmexit (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Flush current VPID (L1 vs. L2) for KVM_REQ_TLB_FLUSH_GUEST (Vitaly Kuznetsov) [2074832]
- KVM: SEV: expose KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM capability (Vitaly Kuznetsov) [2074832]
- selftests: sev_migrate_tests: free all VMs (Vitaly Kuznetsov) [2074832]
- selftests: fix check for circular KVM_CAP_VM_MOVE_ENC_CONTEXT_FROM (Vitaly Kuznetsov) [2074832]
- KVM: x86: ignore APICv if LAPIC is not enabled (Vitaly Kuznetsov) [2074832]
- KVM: downgrade two BUG_ONs to WARN_ON_ONCE (Vitaly Kuznetsov) [2074832]
- KVM: VMX: do not use uninitialized gfn_to_hva_cache (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Pass parameter flush as false in kvm_tdp_mmu_zap_collapsible_sptes() (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Skip tlb flush if it has been done in zap_gfn_range() (Vitaly Kuznetsov) [2074832]
- x86/kvm: remove unused ack_notifier callbacks (Vitaly Kuznetsov) [2074832]
- KVM: Disallow user memslot with size that exceeds "unsigned long" (Vitaly Kuznetsov) [2074832]
- KVM: Ensure local memslot copies operate on up-to-date arch-specific data (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fix TLB flush range when handling disconnected pt (Vitaly Kuznetsov) [2074832]
- KVM: x86: Cap KVM_CAP_NR_VCPUS by KVM_CAP_MAX_VCPUS (Vitaly Kuznetsov) [2074832]
- KVM: x86: Assume a 64-bit hypercall for guests with protected state (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add /x86_64/sev_migrate_tests to .gitignore (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Fix typo in and tweak name of cmd_allowed_from_miror() (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Drop a redundant setting of sev->asid during initialization (Vitaly Kuznetsov) [2074832]
- KVM: SEV: WARN if SEV-ES is marked active but SEV is not (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Set sev_info.active after initial checks in sev_guest_init() (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Disallow COPY_ENC_CONTEXT_FROM if target has created vCPUs (Vitaly Kuznetsov) [2074832]
- KVM: Kill kvm_map_gfn() / kvm_unmap_gfn() and gfn_to_pfn_cache (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Use a gfn_to_hva_cache for vmptrld (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Use kvm_read_guest_offset_cached() for nested VMCS check (Vitaly Kuznetsov) [2074832]
- KVM: x86/xen: Use sizeof_field() instead of open-coding it (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Use kvm_{read,write}_guest_cached() for shadow_vmcs12 (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: include EFER.LMA in extended mmu role (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: don't use vcpu->arch.efer when checking host state on nested state load (Vitaly Kuznetsov) [2074832]
- KVM: Fix steal time asm constraints (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix uninitialized eoi_exit_bitmap usage in vcpu_load_eoi_exitmap() (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Use perf_test_destroy_vm in memslot_modification_stress_test (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Wait for all vCPU to be created before entering guest mode (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Move vCPU thread creation and joining to common helpers (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Start at iteration 0 instead of -1 (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Sync perf_test_args to guest during VM creation (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Fill per-vCPU struct during "perf_test" VM creation (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Create VM with adjusted number of guest pages for perf tests (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Remove perf_test_args.host_page_size (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Move per-VM GPA into perf_test_args (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Use perf util's per-vCPU GPA/pages in demand paging test (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Capture per-vCPU GPA in perf_test_vcpu_args (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Use shorthand local var to access struct perf_tests_args (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Require GPA to be aligned when backed by hugepages (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Assert mmap HVA is aligned when using HugeTLB (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Expose align() helpers to tests (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Explicitly state indicies for vm_guest_mode_params array (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Add event channel upcall support to xen_shinfo_test (Vitaly Kuznetsov) [2074832]
- KVM: SEV: unify cgroup cleanup code for svm_vm_migrate_from (Vitaly Kuznetsov) [2074832]
- KVM: x86: move guest_pv_has out of user_access section (Vitaly Kuznetsov) [2074832]
- KVM: x86: Drop arbitrary KVM_SOFT_MAX_VCPUS (Vitaly Kuznetsov) [2074832]
- KVM: Move INVPCID type check from vmx and svm to the common kvm_handle_invpcid() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Add a helper function to retrieve the GPR index for INVPCID, INVVPID, and INVEPT (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Clean up x2APIC MSR handling for L2 (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Macrofy the MSR bitmap getters and setters (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Handle dynamic MSR intercept toggling (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Query current VMCS when determining if MSR bitmaps are in use (Vitaly Kuznetsov) [2074832]
- KVM: x86: Don't update vcpu->arch.pv_eoi.msr_val when a bogus value was written to MSR_KVM_PV_EOI_EN (Vitaly Kuznetsov) [2074832]
- KVM: x86: Rename kvm_lapic_enable_pv_eoi() (Vitaly Kuznetsov) [2074832]
- kvm: mmu: Use fast PF path for access tracking of huge pages when possible (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Properly dereference rcu-protected TDP MMU sptep iterator (Vitaly Kuznetsov) [2074832]
- kvm: x86: Convert return type of *is_valid_rdpmc_ecx() to bool (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix recording of guest steal time / preempted status (Vitaly Kuznetsov) [2074832]
- selftest: KVM: Add intra host migration tests (Vitaly Kuznetsov) [2074832]
- selftest: KVM: Add open sev dev helper (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Add support for SEV-ES intra host migration (Vitaly Kuznetsov) [2074832]
- KVM: SEV: Add support for SEV intra host migration (Vitaly Kuznetsov) [2074832]
- KVM: SEV: provide helpers to charge/uncharge misc_cg (Vitaly Kuznetsov) [2074832]
- KVM: generalize "bugged" VM to "dead" VM (Vitaly Kuznetsov) [2074832]
- x86/kvm: Add kexec support for SEV Live Migration. (Vitaly Kuznetsov) [2074832]
- x86/kvm: Add guest support for detecting and enabling SEV Live Migration feature. (Vitaly Kuznetsov) [2074832]
- mm: x86: Invoke hypercall when page encryption status is changed (Vitaly Kuznetsov) [2074832]
- EFI: Introduce the new AMD Memory Encryption GUID. (Vitaly Kuznetsov) [2074832]
- x86/kvm: Add AMD SEV specific Hypercall3 (Vitaly Kuznetsov) [2074832]
- KVM: x86: SGX must obey the KVM_INTERNAL_ERROR_EMULATION protocol (Vitaly Kuznetsov) [2074832]
- KVM: x86: On emulation failure, convey the exit reason, etc. to userspace (Vitaly Kuznetsov) [2074832]
- KVM: x86: Get exit_reason as part of kvm_x86_ops.get_exit_info (Vitaly Kuznetsov) [2074832]
- KVM: x86: Clarify the kvm_run.emulation_failure structure layout (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Fix nested SVM tests when built with clang (Vitaly Kuznetsov) [2074832]
- kvm: x86: Remove stale declaration of kvm_no_apic_vcpu (Vitaly Kuznetsov) [2074832]
- KVM: x86: Move SVM's APICv sanity check to common x86 (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Extract zapping of rmaps for gfn range to separate helper (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't unload MMU in kvm_vcpu_flush_tlb_guest() (Vitaly Kuznetsov) [2074832]
- KVM: X86: pair smp_wmb() of mmu_try_to_unsync_pages() with smp_rmb() (Vitaly Kuznetsov) [2074832]
- KVM: emulate: Comment on difference between RDPMC implementation and manual (Vitaly Kuznetsov) [2074832]
- KVM: x86: Add vendor name to kvm_x86_ops, use it for error messages (Vitaly Kuznetsov) [2074832]
- kvm: x86: mmu: Make NX huge page recovery period configurable (Vitaly Kuznetsov) [2074832]
- KVM: vPMU: Fill get_msr MSR_CORE_PERF_GLOBAL_OVF_CTRL w/ 0 (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Rename slot_handle_leaf to slot_handle_level_4k (Vitaly Kuznetsov) [2074832]
- KVM: VMX: RTIT_CTL_BRANCH_EN has no dependency on other CPUID bit (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Rename pt_desc.addr_range to pt_desc.num_address_ranges (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Use precomputed vmx->pt_desc.addr_range (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Restore host's MSR_IA32_RTIT_CTL when it's not zero (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: clean up prefetch/prefault/speculative naming (Vitaly Kuznetsov) [2074832]
- KVM: cleanup allocation of rmaps and page tracking data (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Introduce system counter offset test (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add helpers for vCPU device attributes (Vitaly Kuznetsov) [2074832]
- selftests: KVM: Add test for KVM_{GET,SET}_CLOCK (Vitaly Kuznetsov) [2074832]
- tools: arch: x86: pull in pvclock headers (Vitaly Kuznetsov) [2074832]
- KVM: x86: Expose TSC offset controls to userspace (Vitaly Kuznetsov) [2074832]
- KVM: x86: Refactor tsc synchronization code (Vitaly Kuznetsov) [2074832]
- kvm: x86: protect masterclock with a seqcount (Vitaly Kuznetsov) [2074832]
- KVM: x86: Report host tsc and realtime values in KVM_GET_CLOCK (Vitaly Kuznetsov) [2074832]
- KVM: x86: avoid warning with -Wbitwise-instead-of-logical (Vitaly Kuznetsov) [2074832]
- KVM: x86: only allocate gfn_track when necessary (Vitaly Kuznetsov) [2074832]
- KVM: x86: add config for non-kvm users of page tracking (Vitaly Kuznetsov) [2074832]
- nSVM: Check for reserved encodings of TLB_CONTROL in nested VMCB (Vitaly Kuznetsov) [2074832]
- kvm: use kvfree() in kvm_arch_free_vm() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Expose Predictive Store Forwarding Disable (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Avoid memslot lookup in make_spte and mmu_try_to_unsync_pages (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Avoid memslot lookup in rmap_add (Vitaly Kuznetsov) [2074832]
- KVM: MMU: pass struct kvm_page_fault to mmu_set_spte (Vitaly Kuznetsov) [2074832]
- KVM: MMU: pass kvm_mmu_page struct to make_spte (Vitaly Kuznetsov) [2074832]
- KVM: MMU: set ad_disabled in TDP MMU role (Vitaly Kuznetsov) [2074832]
- KVM: MMU: remove unnecessary argument to mmu_set_spte (Vitaly Kuznetsov) [2074832]
- KVM: MMU: clean up make_spte return value (Vitaly Kuznetsov) [2074832]
- KVM: MMU: inline set_spte in FNAME(sync_page) (Vitaly Kuznetsov) [2074832]
- KVM: MMU: inline set_spte in mmu_set_spte (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Avoid memslot lookup in page_fault_handle_page_track (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Pass the memslot around via struct kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: unify tdp_mmu_map_set_spte_atomic and tdp_mmu_set_spte_atomic_no_dirty_log (Vitaly Kuznetsov) [2074832]
- KVM: MMU: mark page dirty in make_spte (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Fold rmap_recycle into rmap_add (Vitaly Kuznetsov) [2074832]
- KVM: x86/mmu: Verify shadow walk doesn't terminate early in page faults (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change tracepoints arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change disallowed_hugepage_adjust() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change kvm_mmu_hugepage_adjust() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change fast_page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change tdp_mmu_map_handle_target_level() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change kvm_tdp_mmu_map() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change FNAME(fetch)() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change __direct_map() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change handle_abnormal_pfn() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change kvm_faultin_pfn() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change page_fault_handle_page_track() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change direct_page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: change mmu->page_fault() arguments to kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: Introduce struct kvm_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: MMU: pass unadulterated gpa to direct_page_fault (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fix potential race in KVM_GET_CLOCK (Vitaly Kuznetsov) [2074832]
- KVM: x86: extract KVM_GET_CLOCK/KVM_SET_CLOCK to separate functions (Vitaly Kuznetsov) [2074832]
- kvm: x86: abstract locking around pvclock_update_vm_gtod_copy (Vitaly Kuznetsov) [2074832]
- KVM: X86: Move PTE present check from loop body to __shadow_walk_next() (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: implement nested TSC scaling (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: add module param to control TSC scaling (Vitaly Kuznetsov) [2074832]
- KVM: x86: SVM: add module param to control LBR virtualization (Vitaly Kuznetsov) [2074832]
- KVM: x86: nSVM: don't copy pause related settings (Vitaly Kuznetsov) [2074832]
- kvm: irqfd: avoid update unmodified entries of the routing (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't check unsync if the original spte is writible (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't unsync pagetables when speculative (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove FNAME(update_pte) (Vitaly Kuznetsov) [2074832]
- KVM: X86: Zap the invalid list after remote tlb flushing (Vitaly Kuznetsov) [2074832]
- KVM: X86: Change kvm_sync_page() to return true when remote flush is needed (Vitaly Kuznetsov) [2074832]
- KVM: X86: Remove kvm_mmu_flush_or_zap() (Vitaly Kuznetsov) [2074832]
- KVM: X86: Don't flush current tlb on shadow page modification (Vitaly Kuznetsov) [2074832]
- KVM: selftests: Fix kvm_vm_free() in cr4_cpuid_sync and vmx_tsc_adjust tests (Vitaly Kuznetsov) [2074832]
- kvm: selftests: Fix spelling mistake "missmatch" -> "mismatch" (Vitaly Kuznetsov) [2074832]
- KVM: x86: Manually retrieve CPUID.0x1 when getting FMS for RESET/INIT (Vitaly Kuznetsov) [2074832]
- KVM: x86: WARN on non-zero CRs at RESET to detect improper initalization (Vitaly Kuznetsov) [2074832]
- KVM: SVM: Move RESET emulation to svm_vcpu_reset() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Move RESET emulation to vmx_vcpu_reset() (Vitaly Kuznetsov) [2074832]
- KVM: VMX: Drop explicit zeroing of MSR guest values at vCPU creation (Vitaly Kuznetsov) [2074832]
- KVM: x86: Fold fx_init() into kvm_arch_vcpu_create() (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove defunct setting of XCR0 for guest during vCPU create (Vitaly Kuznetsov) [2074832]
- KVM: x86: Remove defunct setting of CR0.ET for guests during vCPU create (Vitaly Kuznetsov) [2074832]
- KVM: x86: Simplify retrieving the page offset when loading PDTPRs (Vitaly Kuznetsov) [2074832]
- KVM: x86: Subsume nested GPA read helper into load_pdptrs() (Vitaly Kuznetsov) [2074832]
- kvm: rename KVM_MAX_VCPU_ID to KVM_MAX_VCPU_IDS (Vitaly Kuznetsov) [2074832]
- KVM: Make kvm_make_vcpus_request_mask() use pre-allocated cpu_kick_mask (Vitaly Kuznetsov) [2074832]
- KVM: Pre-allocate cpumasks for kvm_make_all_cpus_request_except() (Vitaly Kuznetsov) [2074832]
- KVM: Drop 'except' parameter from kvm_make_vcpus_request_mask() (Vitaly Kuznetsov) [2074832]
- KVM: Optimize kvm_make_vcpus_request_mask() a bit (Vitaly Kuznetsov) [2074832]
- KVM: x86: hyper-v: Avoid calling kvm_make_vcpus_request_mask() with vcpu_mask==NULL (Vitaly Kuznetsov) [2074832]
- KVM: use vma_pages() helper (Vitaly Kuznetsov) [2074832]
- KVM: nVMX: Reset vmxon_ptr upon VMXOFF emulation. (Vitaly Kuznetsov) [2074832]
- x86/kvm: Always inline to_svm() (Vitaly Kuznetsov) [2074832]
- x86/kvm: Always inline vmload() / vmsave() (Vitaly Kuznetsov) [2074832]
- x86/kvm: Always inline sev_*guest() (Vitaly Kuznetsov) [2074832]

* Fri Jun 10 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-109.rt21.109.el9]
- [rt] build kernel-rt-5.14.0-109.rt21.109.el9 [2061574]
- [s390] s390/perf: obtain sie_block from the right address (Claudio Imbrenda) [2094788]
- redhat/configs: Remove duplicates from ark/generic/s390x/zfcpdump/ (Vladis Dronov)
- redhat/configs: Move common/debug/s390x/zfcpdump/ configs to ark/debug/s390x/zfcpdump/ (Vladis Dronov)
- redhat/configs: Move common/generic/s390x/zfcpdump/ configs to ark/generic/s390x/zfcpdump/ (Vladis Dronov)
- net: Remove netif_rx_any_context() and netif_rx_ni(). (Petr Oros) [2089703]
- phonet: Use netif_rx(). (Petr Oros) [2089703]
- bluetooth: Use netif_rx(). (Petr Oros) [2089703]
- batman-adv: Use netif_rx(). (Petr Oros) [2089703]
- tipc: Use netif_rx(). (Petr Oros) [2089703]
- tun: vxlan: Use netif_rx(). (Petr Oros) [2089703]
- staging: Use netif_rx(). (Petr Oros) [2089703]
- s390: net: Use netif_rx(). (Petr Oros) [2089703]
- wireless: Use netif_rx(). (Petr Oros) [2089703]
- wireless: Marvell: Use netif_rx(). (Petr Oros) [2089703]
- wireless: brcmfmac: Use netif_rx(). (Petr Oros) [2089703]
- wireless: Atheros: Use netif_rx(). (Petr Oros) [2089703]
- slip/plip: Use netif_rx(). (Petr Oros) [2089703]
- can: Use netif_rx(). (Petr Oros) [2089703]
- net: phy: Use netif_rx(). (Petr Oros) [2089703]
- net: dev: Use netif_rx(). (Petr Oros) [2089703]
- net: bridge: Use netif_rx(). (Petr Oros) [2089703]
- net: macvlan: Use netif_rx(). (Petr Oros) [2089703]
- net: ethernet: Use netif_rx(). (Petr Oros) [2089703]
- net: dsa: Use netif_rx(). (Petr Oros) [2089703]
- net: caif: Use netif_rx(). (Petr Oros) [2089703]
- net: sgi-xp: Use netif_rx(). (Petr Oros) [2089703]
- net: xtensa: Use netif_rx(). (Petr Oros) [2089703]
- docs: networking: Use netif_rx(). (Petr Oros) [2089703]
- net: Correct wrong BH disable in hard-interrupt. (Petr Oros) [2089703]
- net: dev: Make rps_lock() disable interrupts. (Petr Oros) [2089703]
- net: dev: Makes sure netif_rx() can be invoked in any context. (Petr Oros) [2089703]
- net: dev: Remove preempt_disable() and get_cpu() in netif_rx_internal(). (Petr Oros) [2089703]
- powerpc/papr_scm: Fix buffer overflow issue with CONFIG_FORTIFY_SOURCE (Gustavo Walbon) [1873830]
- powerpc/papr_scm: Fix build failure when (Gustavo Walbon) [1873830]
- drivers/nvdimm: Fix build failure when CONFIG_PERF_EVENTS is not set (Gustavo Walbon) [1873830]
- docs: ABI: sysfs-bus-nvdimm: Document sysfs event format entries for nvdimm pmu (Gustavo Walbon) [1873830]
- powerpc/papr_scm: Add perf interface support (Gustavo Walbon) [1873830]
- drivers/nvdimm: Add perf interface to expose nvdimm performance stats (Gustavo Walbon) [1873830]
- drivers/nvdimm: Add nvdimm pmu structure (Gustavo Walbon) [1873830]
- redhat/configs: enable interconnect for NXP i.MX 8M (Steve Best) [2092404]
- x86/split_lock: Enable the split lock feature on Raptor Lake (David Arcari) [2076739]
- [s390] s390/cpumf: add new extended counter set for IBM z16 (Mete Durlu) [2047724]
- mptcp: add more offered MIBs counter (Paolo Abeni) [2089885]
- mptcp: never shrink offered window (Paolo Abeni) [2089885]
- tcp: allow MPTCP to update the announced window (Paolo Abeni) [2089885]
- mptcp: add mib for xmit window sharing (Paolo Abeni) [2089885]
- mptcp: really share subflow snd_wnd (Paolo Abeni) [2089885]
- KVM: s390: vsie/gmap: reduce gmap_rmap overhead (Thomas Huth) [2072041]
- KVM: s390x: fix SCK locking (Thomas Huth) [2072041]
- KVM: s390: Replace KVM_REQ_MMU_RELOAD usage with arch specific request (Thomas Huth) [2072041]
- KVM: s390: Clarify SIGP orders versus STOP/RESTART (Thomas Huth) [2044299]
- KVM: s390: Clear valid_wakeup in kvm_s390_handle_wait(), not in arch hook (Thomas Huth) [2072041]
- KVM: s390: Ensure kvm_arch_no_poll() is read once when blocking vCPU (Thomas Huth) [2072041]
- KVM: s390: Introduce kvm_s390_get_gfn_end() (Thomas Huth) [2072041]
- KVM: Integrate gfn_to_memslot_approx() into search_memslots() (Thomas Huth) [2072041]
- KVM: s390: Use kvm_get_vcpu() instead of open-coded access (Thomas Huth) [2072041]
- KVM: s390: add debug statement for diag 318 CPNC data (Thomas Huth) [2072041]
- KVM: s390: pv: properly handle page flags for protected guests (Thomas Huth) [2072041]
- KVM: s390: Add a routine for setting userspace CPU state (Thomas Huth) [2044299]
- openvswitch: fix OOB access in reserve_sfa_size() (Antoine Tenart) [2082155]
- net: openvswitch: don't send internal clone attribute to the userspace. (Antoine Tenart) [2082155 2085881]
- openvswitch: Add recirc_id to recirc warning (Antoine Tenart) [2082155]
- openvswitch: Fixed nd target mask field in the flow dump. (Antoine Tenart) [2082155]
- net/sched: Enable tc skb ext allocation on chain miss only when needed (Antoine Tenart) [2082155]
- openvswitch: always update flow key after nat (Antoine Tenart) [2082155]
- net: openvswitch: Remove redundant if statements (Antoine Tenart) [2082155]

* Thu Jun 09 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-108.rt21.108.el9]
- [rt] build kernel-rt-5.14.0-108.rt21.108.el9 [2061574]
- net: add netif_set_real_num_queues() for device reconfig (Ivan Vecera) [2094002]
- spmi: spmi-pmic-arb: fix irq_set_type race condition (Steve Best) [2071751]
- spmi: mediatek: Add support for MT8195 (Steve Best) [2071751]
- spmi: mediatek: Add support for MT6873/8192 (Steve Best) [2071751]
- spmi: pmic-arb: Add sid and address to error messages (Steve Best) [2071751]
- bus: Make remove callback return void (Steve Best) [2071751]
- rpmsg: core: add API to get MTU (Steve Best) [2071771]
- RISC-V: configs: Configs that had RPMSG_CHAR now get RPMSG_CTRL (Steve Best) [2071771]
- rpmsg: ctrl: Introduce new RPMSG_CREATE/RELEASE_DEV_IOCTL controls (Steve Best) [2071771]
- rpmsg: char: Introduce the "rpmsg-raw" channel (Steve Best) [2071771]
- rpmsg: char: Add possibility to use default endpoint of the rpmsg device (Steve Best) [2071771]
- rpmsg: char: Refactor rpmsg_chrdev_eptdev_create function (Steve Best) [2071771]
- rpmsg: Update rpmsg_chrdev_register_device function (Steve Best) [2071771]
- rpmsg: Move the rpmsg control device from rpmsg_char to rpmsg_ctrl (Steve Best) [2071771]
- rpmsg: Create the rpmsg class in core instead of in rpmsg char (Steve Best) [2071771]
- rpmsg: char: Export eptdev create and destroy functions (Steve Best) [2071771]
- rpmsg: char: treat rpmsg_trysend() ENOMEM as EAGAIN (Steve Best) [2071771]
- rpmsg: qcom_smd: Fix redundant channel->registered assignment (Steve Best) [2071771]
- rpmsg: use struct_size over open coded arithmetic (Steve Best) [2071771]
- rpmsg: smd: allow opening rpm_requests even if already opened (Steve Best) [2071771]
- rpmsg: qcom_smd: Promote to arch_initcall (Steve Best) [2071771]
- rpmsg: char: Fix race between the release of rpmsg_eptdev and cdev (Steve Best) [2071771]
- rpmsg: char: Fix race between the release of rpmsg_ctrldev and cdev (Steve Best) [2071771]
- rpmsg: core: Clean up resources on announce_create failure. (Steve Best) [2071771]
- rpmsg: Fix documentation return formatting (Steve Best) [2071771]
- rpmsg: char: Add pr_fmt() to prefix messages (Steve Best) [2071771]
- rpmsg: glink: Send READ_NOTIFY command in FIFO full case (Steve Best) [2071771]
- rpmsg: glink: Remove channel decouple from rpdev release (Steve Best) [2071771]
- rpmsg: glink: Remove the rpmsg dev in close_ack (Steve Best) [2071771]
- rpmsg: glink: Add TX_DATA_CONT command while sending (Steve Best) [2071771]
- rpmsg: virtio_rpmsg_bus: use dev_warn_ratelimited for msg with no recipient (Steve Best) [2071771]
- rpmsg: virtio: Remove unused including <linux/of_device.h> (Steve Best) [2071771]
- rpmsg: char: Remove useless include (Steve Best) [2071771]
- rpmsg: Change naming of mediatek rpmsg property (Steve Best) [2071771]
- rpmsg: glink: Replace strncpy() with strscpy_pad() (Steve Best) [2071771]
- bus: Make remove callback return void (Steve Best) [2071771]
- interconnect: Restore sync state by ignoring ipa-virt in provider count (Steve Best) [2071778]
- interconnect: qcom: sdx55: Drop IP0 interconnects (Steve Best) [2071778]
- interconnect: qcom: sc7180: Drop IP0 interconnects (Steve Best) [2071778]
- interconnect: qcom: msm8939: Remove snoc_mm specific regmap (Steve Best) [2071778]
- interconnect: imx: Add imx_icc_get_bw function to set initial avg and peak (Steve Best) [2071778]
- interconnect: qcom: Add QCM2290 driver support (Steve Best) [2071778]
- interconnect: icc-rpm: Support child NoC device probe (Steve Best) [2071778]
- interconnect: icc-rpm: Add QNOC type QoS support (Steve Best) [2071778]
- interconnect: icc-rpm: Define ICC device type (Steve Best) [2071778]
- interconnect: qcom: Add SM8450 interconnect provider driver (Steve Best) [2071778]
- interconnect: qcom: rpm: Prevent integer overflow in rate (Steve Best) [2071778]
- interconnect: icc-rpm: Use NOC_QOS_MODE_INVALID for qos_mode check (Steve Best) [2071778]
- interconnect: qcom: icc-rpmh: Add BCMs to commit list in pre_aggregate (Steve Best) [2071778]
- interconnect: qcom: Add MSM8996 interconnect provider driver (Steve Best) [2071778]
- interconnect: icc-rpm: Add support for bus power domain (Steve Best) [2071778]
- interconnect: qcom: Add EPSS L3 support on SC7280 (Steve Best) [2071778]
- interconnect: samsung: describe drivers in KConfig (Steve Best) [2071778]
- interconnect: qcom: drop DEFINE_QNODE macro (Steve Best) [2071778]
- interconnect: qcs404: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: msm8939: add support for AP-owned nodes (Steve Best) [2071778]
- interconnect: msm8939: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: msm8916: add support for AP-owned nodes (Steve Best) [2071778]
- interconnect: msm8916: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: icc-rpm: add support for QoS reg offset (Steve Best) [2071778]
- interconnect: sdm660: merge common code into icc-rpm (Steve Best) [2071778]
- interconnect: sdm660: drop default/unused values (Steve Best) [2071778]
- interconnect: sdm660: expand DEFINE_QNODE macros (Steve Best) [2071778]
- interconnect: icc-rpm: move bus clocks handling into qnoc_probe (Steve Best) [2071778]
- interconnect: qcom: sdm660: Add missing a2noc qos clocks (Steve Best) [2071778]
- interconnect: qcom: sdm660: Correct NOC_QOS_PRIORITY shift and mask (Steve Best) [2071778]
- interconnect: qcom: sdm660: Fix id of slv_cnoc_mnoc_cfg (Steve Best) [2071778]
- Revert "interconnect: qcom: icc-rpmh: Add BCMs to commit list in pre_aggregate" (Steve Best) [2071778]
- interconnect: qcom: osm-l3: Use driver-specific naming (Steve Best) [2071778]
- interconnect: qcom: osm-l3: Add sc8180x support (Steve Best) [2071778]
- interconnect: qcom: Add SC8180x providers (Steve Best) [2071778]
- interconnect: qcom: icc-rpmh: Add BCMs to commit list in pre_aggregate (Steve Best) [2071778]
- interconnect: Sanity check that node isn't already on list (Steve Best) [2071778]
- interconnect: qcom: icc-rpmh: Consolidate probe functions (Steve Best) [2071778]
- regulator: Turn off kernel configs for regulators added by this patch set (Steve Best) [2071777]
- regulator: qcom_smd: fix for_each_child.cocci warnings (Steve Best) [2071777]
- regulator: rohm-generic: iniline stub function (Steve Best) [2071777]
- regulator: Add regulator_err2notif() helper (Steve Best) [2071777]
- regulator: fix bullet lists of regulator_ops comment (Steve Best) [2071777]
- regulator: Minor regulator documentation fixes. (Steve Best) [2071777]
- regulator: atc260x: Fix missing active_discharge_on setting (Steve Best) [2071777]
- regulator: rtq2134: Fix missing active_discharge_on setting (Steve Best) [2071777]
- regulator: rt4831: Add active_discharge_on to fix discharge API (Steve Best) [2071777]
- regulator: rt4831: Add bypass mask to fix set_bypass API work (Steve Best) [2071777]
- regulator: qcom-rpmh: Add support for SDX65 (Steve Best) [2071777]
- regulator: rt5190a: Add support for Richtek RT5190A PMIC (Steve Best) [2071777]
- regulator: cleanup comments (Steve Best) [2071777]
- regulator: virtual: add devicetree support (Steve Best) [2071777]
- regulator: virtual: warn against production use (Steve Best) [2071777]
- regulator: virtual: use dev_err_probe() (Steve Best) [2071777]
- regulator: da9121: Remove surplus DA9141 parameters (Steve Best) [2071777]
- regulator: da9121: Fix DA914x voltage value (Steve Best) [2071777]
- regulator: core: fix false positive in regulator_late_cleanup() (Steve Best) [2071777]
- regulator: MAX20086: add gpio/consumer.h (Steve Best) [2071777]
- regulator: max20086: fix error code in max20086_parse_regulators_dt() (Steve Best) [2071777]
- regulator: Add MAX20086-MAX20089 driver (Steve Best) [2071777]
- regulator: qcom_smd: Align probe function with rpmh-regulator (Steve Best) [2071777]
- regulator: remove redundant ret variable (Steve Best) [2071777]
- regulator: qcom-labibb: OCP interrupts are not a failure while disabled (Steve Best) [2071777]
- regulator: Introduce tps68470-regulator driver (Steve Best) [2071777]
- drivers/regulator: remove redundant ret variable (Steve Best) [2071777]
- regulator: qcom-rpmh: Add support for PM8450 regulators (Steve Best) [2071777]
- regulator: da9121: Add DA914x support (Steve Best) [2071777]
- regulator: da9121: Prevent current limit change when enabled (Steve Best) [2071777]
- regulator: qcom-rpmh: Add PMG1110 regulators (Steve Best) [2071777]
- regulator: qcom_spmi: Add pm8226 regulators (Steve Best) [2071777]
- regulator: irq_helper: Provide helper for trivial IRQ notifications (Steve Best) [2071777]
- regulator: bd718x7: Use rohm generic restricted voltage setting (Steve Best) [2071777]
- regulator: rohm-regulator: add helper for restricted voltage setting (Steve Best) [2071777]
- regulator: Don't error out fixed regulator in regulator_sync_voltage() (Steve Best) [2071777]
- regulator: tps80031: Remove driver (Steve Best) [2071777]
- regulator: Fix SY7636A breakage (Steve Best) [2071777]
- regulator: uniphier: Add USB-VBUS compatible string for NX1 SoC (Steve Best) [2071777]
- regulator: qcom-rpmh: Add PM6350 regulators (Steve Best) [2071777]
- regulator: sy7636a: Remove requirement on sy7636a mfd (Steve Best) [2071777]
- regulator: tps62360: replacing legacy gpio interface for gpiod (Steve Best) [2071777]
- regulator: lp872x: Remove lp872x_dvs_state (Steve Best) [2071777]
- regulator: lp872x: replacing legacy gpio interface for gpiod (Steve Best) [2071777]
- regulator: s5m8767: do not use reset value as DVS voltage if GPIO DVS is disabled (Steve Best) [2071777]
- mfd: hi6421-spmi-pmic: Cleanup drvdata to only include regmap (Steve Best) [2071777]
- regulator: bd71815: Use defined mask values (Steve Best) [2071777]
- regulator: qcom_smd: Add PM2250 regulators (Steve Best) [2071777]
- regulator: Lower priority of logging when setting supply (Steve Best) [2071777]
- regulator: dummy: Use devm_regulator_register() (Steve Best) [2071777]
- regulator: pwm-regulator: Make use of the helper function dev_err_probe() (Steve Best) [2071777]
- regulator: fix typo in Kconfig and max8973-regulator (Steve Best) [2071777]
- regulator: max14577: Revert "regulator: max14577: Add proper module aliases strings" (Steve Best) [2071777]
- regulator: qcom-rpmh-regulator: fix pm8009-1 ldo7 resource name (Steve Best) [2071777]
- regulator: vctrl: Avoid lockdep warning in enable/disable ops (Steve Best) [2071777]
- regulator: vctrl: Use locked regulator_get_voltage in probe path (Steve Best) [2071777]
- regulator: Documentation fix for regulator error notification helper (Steve Best) [2071777]
- regulator: sy7636a: Use the regmap directly (Steve Best) [2071777]
- regulator: sy7636a: Store the epd-pwr-good GPIO locally (Steve Best) [2071777]
- regulator: sy7636a: Use the parent driver data (Steve Best) [2071777]
- regulator: sy7636a: Remove the poll_enable_time (Steve Best) [2071777]
- regulator: sy8827n: Enable REGCACHE_FLAT (Steve Best) [2071777]
- regulator: sy8824x: Enable REGCACHE_FLAT (Steve Best) [2071777]
- regulator: rtq2134: Fix coding style (Steve Best) [2071777]
- regulator: hi6421v600: rename voltage range arrays (Steve Best) [2071777]
- regulator: hi6421v600: use lowercase for ldo (Steve Best) [2071777]
- regulator: fixed: use dev_err_probe for register (Steve Best) [2071777]
- regulator: rtq2134: Add support for Richtek RTQ2134 SubPMIC (Steve Best) [2071777]
- regulator: Fix a couple of spelling mistakes in Kconfig (Steve Best) [2071777]
- regulator: rtq6752: fix reg reset behavior (Steve Best) [2071777]
- regulator: da9063: Add support for full-current mode. (Steve Best) [2071777]
- regulator: rt6245: make a const array func_base static, makes object smaller (Steve Best) [2071777]
- regulator: rtq6752: Fix the typo for reg define and author name (Steve Best) [2071777]
- regulator: Replace symbolic permissions with octal permissions (Steve Best) [2071777]
- regulator: rt6752: Add support for Richtek RTQ6752 (Steve Best) [2071777]
- regulator: rt5033: Use linear ranges to map all voltage selection (Steve Best) [2071777]
- regulator: tps65910: Silence deferred probe error (Steve Best) [2071777]
- regulator: mt6397: Remove modeset_shift from struct mt6397_regulator_info (Steve Best) [2071777]
- regulator: mt6359: Remove shift fields from struct mt6359_regulator_info (Steve Best) [2071777]
- regulator: mt6358: Remove shift fields from struct mt6358_regulator_info (Steve Best) [2071777]
- regulator: devres: unexport devm_regulator_unregister_supply_alias() (Steve Best) [2071777]
- regulator: devres: remove devm_regulator_bulk_unregister_supply_alias() (Steve Best) [2071777]
- regulator: devres: remove devm_regulator_unregister() function (Steve Best) [2071777]
- regulator: hi6421v600-regulator: add a missing dot at copyright (Steve Best) [2071777]
- scsi: scsi_dh_alua: Properly handle the ALUA transitioning state (Ewan D. Milne) [2085105]
- bnx2x: fix napi API usage sequence (Manish Chopra) [2080677]

* Wed Jun 08 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-107.rt21.107.el9]
- [rt] build kernel-rt-5.14.0-107.rt21.107.el9 [2061574]
- NFSv4: Fix free of uninitialized nfs4_label on referral lookup. (Benjamin Coddington) [2086367]
- sched/tracing: Append prev_state to tp args instead (Phil Auld) [2078906]
- sched/pelt: Fix attach_entity_load_avg() corner case (Phil Auld) [2078906]
- timers: Fix warning condition in __run_timers() (Phil Auld) [2078906]
- sched: Teach the forced-newidle balancer about CPU affinity limitation. (Phil Auld) [2078906]
- sched/core: Fix forceidle balancing (Phil Auld) [2078906]
- tick/sched: Fix non-kernel-doc comment (Phil Auld) [2078906]
- prlimit: do not grab the tasklist_lock (Phil Auld) [2078906]
- prlimit: make do_prlimit() static (Phil Auld) [2078906]
- timekeeping: Really make sure wall_to_monotonic isn't positive (Phil Auld) [2078906]
- tick/nohz: Use WARN_ON_ONCE() to prevent console saturation (Phil Auld) [2078906]
- posix-cpu-timers: Clear task::posix_cputimers_work in copy_process() (Phil Auld) [2078906]
- timers/nohz: Last resort update jiffies on nohz_full IRQ entry (Phil Auld) [2078906]
- vdpa: mlx5: synchronize driver status with CVQ (Laurent Vivier) [2059799]
- vdpa: mlx5: prevent cvq work from hogging CPU (Laurent Vivier) [2059799]
- vdpa/mlx5: Avoid processing works if workqueue was destroyed (Laurent Vivier) [2059799]
- selftests/bpf: Fix btf_dump test under new clang (Yauheni Kaliuta) [2090982]
- ahci: Add a generic 'controller2' RAID id (Tomas Henzl) [2078880]
- net/af_packet: make sure to pull mac header (Hangbin Liu) [2089566]
- net/af_packet: add VLAN support for AF_PACKET SOCK_RAW GSO (Hangbin Liu) [2089566]
- net: openvswitch: fix leak of nested actions (Eelco Chaudron) [2076588]

* Tue Jun 07 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-106.rt21.106.el9]
- [rt] build kernel-rt-5.14.0-106.rt21.106.el9 [2061574]
- [rt] configs: disable VIDEO_SAA6588 and VIDEO_SAA6752HS (Luis Claudio R. Goncalves) [2092175]
- [rt] fix preemption imbalance in __mod_memcg_lruvec_state() (Luis Claudio R. Goncalves) [2092968]
- mm, compaction: fast_find_migrateblock() should return pfn in the target zone (Rafael Aquini) [2092667]
- [s390] s390/net: sort out physical vs virtual pointers usage (Mete Durlu) [2044295]
- [s390] s390/qeth: remove check for packing mode in qeth_check_outbound_queue() (Mete Durlu) [2044295]
- [s390] s390/qeth: fine-tune .ndo_select_queue() (Mete Durlu) [2044295]
- [s390] s390/qeth: don't offer .ndo_bridge_* ops for OSA devices (Mete Durlu) [2044295]
- [s390] s390/qeth: split up L2 netdev_ops (Mete Durlu) [2044295]
- [s390] s390/qeth: simplify qeth_receive_skb() (Mete Durlu) [2044295]
- [s390] s390/lcs: add braces around empty function body (Mete Durlu) [2044295]
- [s390] s390/ctcm: add __printf format attribute to ctcm_dbf_longtext (Mete Durlu) [2044295]
- [s390] s390/ctcm: fix format string (Mete Durlu) [2044295]
- [s390] s390/qeth: allocate RX queue at probe time (Mete Durlu) [2044295]
- [s390] s390/qeth: update kerneldoc for qeth_add_hw_header() (Mete Durlu) [2044295]
- [s390] s390/qeth: fix kernel doc comments (Mete Durlu) [2044295]
- [s390] s390/qeth: add __printf format attribute to qeth_dbf_longtext (Mete Durlu) [2044295]
- [s390] s390/qeth: fix various format strings (Mete Durlu) [2044295]
- [s390] s390/qeth: don't keep track of Input Queue count (Mete Durlu) [2044295]
- [s390] s390/qeth: clarify remaining dev_kfree_skb_any() users (Mete Durlu) [2044295]
- [s390] s390/qeth: move qdio's QAOB cache into qeth (Mete Durlu) [2044295]
- [s390] s390/qeth: remove .do_ioctl() callback from driver discipline (Mete Durlu) [2044295]
- [s390] s390/qeth: improve trace entries for MAC address (un)registration (Mete Durlu) [2044295]
- [s390] s390/netiucv: remove incorrect kernel doc indicators (Mete Durlu) [2044295]
- [s390] s390/lcs: remove incorrect kernel doc indicators (Mete Durlu) [2044295]
- [s390] s390/ctcm: remove incorrect kernel doc indicators (Mete Durlu) [2044295]
- [s390] s390/qeth: clean up device_type management (Mete Durlu) [2044295]
- [s390] s390/qeth: clean up QETH_PROT_* naming (Mete Durlu) [2044295]
- Documentation/sysctl: document max_rcu_stall_to_panic (Joel Savitz) [2063060]
- Documentation: add description for net.core.gro_normal_batch (Xin Long) [2068580]
- dmaengine: idxd: make idxd_wq_enable() return 0 if wq is already enabled (Jerry Snitselaar) [2083415]
- dmaengine: idxd: Remove unnecessary synchronize_irq() before free_irq() (Jerry Snitselaar) [2083415]
- dmaengine: idxd: add missing callback function to support DMA_INTERRUPT (Jerry Snitselaar) [2083415]
- dmaengine: idxd: skip irq free when wq type is not kernel (Jerry Snitselaar) [2083415]
- dmaengine: idxd: make idxd_register/unregister_dma_channel() static (Jerry Snitselaar) [2083415]
- dmaengine: idxd: remove redudant idxd_wq_disable_cleanup() call (Jerry Snitselaar) [2083415]
- dmaengine: idxd: free irq before wq type is reset (Jerry Snitselaar) [2083415]
- dmaengine: idxd: fix lockdep warning on device driver removal (Jerry Snitselaar) [2083415]
- dmaengine: idxd: Separate user and kernel pasid enabling (Jerry Snitselaar) [2083415]
- dmaengine: idxd: refactor wq driver enable/disable operations (Jerry Snitselaar) [2083415]
- dmaengine: idxd: move wq irq enabling to after device enable (Jerry Snitselaar) [2083415]
- dmaengine: idxd: set max_xfer and max_batch for RO device (Jerry Snitselaar) [2083415]
- dmaengine: idxd: Fix the error handling path in idxd_cdev_register() (Jerry Snitselaar) [2083415]
- dmaengine: idxd: set DMA_INTERRUPT cap bit (Jerry Snitselaar) [2083415]
- dmaengine: add verification of DMA_INTERRUPT capability for dmatest (Jerry Snitselaar) [2083415]
- Dmaengine: idxd: remove trailing white space on input str for wq name (Jerry Snitselaar) [2083415]
- dmaengine: idxd: don't load pasid config until needed (Jerry Snitselaar) [2083415]
- dmaengine: idxd: fix retry value to be constant for duration of function call (Jerry Snitselaar) [2075706]
- dmaengine: idxd: match type for retries var in idxd_enqcmds() (Jerry Snitselaar) [2075706]
- NFS: LOOKUP_DIRECTORY is also ok with symlinks (Scott Mayhew) [2059729]
- NFSv4: nfs_atomic_open() can race when looking up a non-regular file (Scott Mayhew) [2059729]
- NFSv4: Handle case where the lookup of a directory fails (Scott Mayhew) [2059729]
- net: phy: Kconfig: micrel_phy: fix dependency issue (Hangbin Liu) [2066451]
- ptp: add getcrosststamp() to virtual clocks. (Hangbin Liu) [2066451]
- ptp: add gettimex64() to virtual clocks. (Hangbin Liu) [2066451]
- ptp: increase maximum adjustment of virtual clocks. (Hangbin Liu) [2066451]
- ptp: unregister virtual clocks when unregistering physical clock. (Hangbin Liu) [2066451]
- net: fix sock_timestamping_bind_phc() to release device (Hangbin Liu) [2066451]
- net: fix SOF_TIMESTAMPING_BIND_PHC to work with multiple sockets (Hangbin Liu) [2066451]
- ptp: fix code indentation issues (Hangbin Liu) [2066451]
- ptp: free 'vclock_index' in ptp_clock_release() (Hangbin Liu) [2066451]
- ptp: Fix possible memory leak in ptp_clock_register() (Hangbin Liu) [2066451]
- ptp: fix error print of ptp_kvm on X86_64 platform (Hangbin Liu) [2066451]
- ptp: Fix ptp_kvm_getcrosststamp issue for x86 ptp_kvm (Hangbin Liu) [2066451]
- ethernet: fix PTP_1588_CLOCK dependencies (Hangbin Liu) [2066451]
- drivers/char: fix unused variable warning in mem.c (Joel Savitz) [2081150]
- clk: qcom: rpmhcc: add sc8280xp support to the RPMh clock controller (Adrien Thierry) [2078618]
- dt-bindings: clock: Add sc8280xp to the RPMh clock controller binding (Adrien Thierry) [2078618]

* Sun Jun 05 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-105.rt21.105.el9]
- [rt] build kernel-rt-5.14.0-105.rt21.105.el9 [2061574]
- NFSv4.2: Fix up an invalid combination of memory allocation flags (Benjamin Coddington) [2089076]
- Documentation/sysctl: document page_lock_unfairness (Joel Savitz) [2063044]
- iommu/virtio: Fix typo in a comment (Eric Auger) [2083111]
- iommu/virtio: Support identity-mapped domains (Eric Auger) [2083111]
- iommu/virtio: Pass end address to viommu_add_mapping() (Eric Auger) [2083111]
- iommu/virtio: Sort reserved regions (Eric Auger) [2083111]
- iommu/virtio: Support bypass domains (Eric Auger) [2083111]
- iommu/virtio: Add definitions for VIRTIO_IOMMU_F_BYPASS_CONFIG (Eric Auger) [2083111]
- x86/cpu: Add new Alderlake and Raptorlake CPU model numbers (David Arcari) [2040020 2040060]
- skbuff: fix coalescing for page_pool fragment recycling (Jiri Benc) [2071618]
- af_unix: fix regression in read after shutdown (Jiri Benc) [2071618]
- tcp_bpf: Fix one concurrency problem in the tcp_bpf_send_verdict function (Jiri Benc) [2071618]
- af_unix: Rename UNIX-DGRAM to UNIX to maintain backwards compatability (Jiri Benc) [2071618]
- selftests/bpf: Use recv_timeout() instead of retries (Jiri Benc) [2071618]
- net: Implement ->sock_is_readable() for UDP and AF_UNIX (Jiri Benc) [2071618]
- skmsg: Extract and reuse sk_msg_is_readable() (Jiri Benc) [2071618]
- net: Rename ->stream_memory_read to ->sock_is_readable (Jiri Benc) [2071618]
- unix: Fix an issue in unix_shutdown causing the other end read/write failures (Jiri Benc) [2071618]
- bpf, test, cgroup: Use sk_{alloc,free} for test cases (Jiri Benc) [2071618]
- bpf, cgroup: Assign cgroup in cgroup_sk_alloc when called from interrupt (Jiri Benc) [2071618]
- bpf, selftests: Add test case for mixed cgroup v1/v2 (Jiri Benc) [2071618]
- bpf, selftests: Add cgroup v1 net_cls classid helpers (Jiri Benc) [2071618]
- bpf, cgroups: Fix cgroup v2 fallback on v1/v2 mixed mode (Jiri Benc) [2071618]
- af_unix: fix potential NULL deref in unix_dgram_connect() (Jiri Benc) [2071618]
- page_pool: use relaxed atomic for release side accounting (Jiri Benc) [2071618]
- af_unix: Fix NULL pointer bug in unix_shutdown (Jiri Benc) [2071618]
- selftests/bpf: Reduce more flakyness in sockmap_listen (Jiri Benc) [2071618]
- selftests/bpf: Adding delay in socketmap_listen to reduce flakyness (Jiri Benc) [2071618]
- selftests/bpf: Test for get_netns_cookie (Jiri Benc) [2071618]
- bpf: Allow bpf_get_netns_cookie in BPF_PROG_TYPE_SK_MSG (Jiri Benc) [2071618]
- selftests/bpf: Test for get_netns_cookie (Jiri Benc) [2071618]
- bpf: Allow bpf_get_netns_cookie in BPF_PROG_TYPE_SOCK_OPS (Jiri Benc) [2071618]
- selftest/bpf: Add new tests in sockmap for unix stream to tcp. (Jiri Benc) [2071618]
- selftest/bpf: Change udp to inet in some function names (Jiri Benc) [2071618]
- selftest/bpf: Add tests for sockmap with unix stream type. (Jiri Benc) [2071618]
- af_unix: Add unix_stream_proto for sockmap (Jiri Benc) [2071618]
- af_unix: Add read_sock for stream socket types (Jiri Benc) [2071618]
- selftest/bpf: Implement sample UNIX domain socket iterator program. (Jiri Benc) [2071618]
- bpf: af_unix: Implement BPF iterator for UNIX domain socket. (Jiri Benc) [2071618]
- net: in_irq() cleanup (Jiri Benc) [2071618]
- page_pool: add frag page recycling support in page pool (Jiri Benc) [2071618]
- page_pool: add interface to manipulate frag count in page pool (Jiri Benc) [2071618]
- page_pool: keep pp info as long as page pool owns the page (Jiri Benc) [2071618]
- bpf, unix: Check socket type in unix_bpf_update_proto() (Jiri Benc) [2071618]
- selftests/bpf: Test XDP bonding nest and unwind (Jiri Benc) [2071618]
- bonding: Fix negative jump label count on nested bonding (Jiri Benc) [2071618]
- selftests/bpf: Fix running of XDP bonding tests (Jiri Benc) [2071618]
- net, bonding: Disallow vlan+srcmac with XDP (Jiri Benc) [2071618]
- selftests/bpf: Add tests for XDP bonding (Jiri Benc) [2071618]
- selftests/bpf: Fix xdp_tx.c prog section name (Jiri Benc) [2071618]
- net, core: Allow netdev_lower_get_next_private_rcu in bh context (Jiri Benc) [2071618]
- bpf, devmap: Exclude XDP broadcast to master device (Jiri Benc) [2071618]
- net, bonding: Add XDP support to the bonding driver (Jiri Benc) [2071618]
- net, core: Add support for XDP redirection to slave device (Jiri Benc) [2071618]
- bpf: selftests: Add dctcp fallback test (Jiri Benc) [2071618]
- bpf: selftests: Add connect_to_fd_opts to network_helpers (Jiri Benc) [2071618]
- bpf: selftests: Add sk_state to bpf_tcp_helpers.h (Jiri Benc) [2071618]
- bpf: tcp: Allow bpf-tcp-cc to call bpf_(get|set)sockopt (Jiri Benc) [2071618]
- selftests/bpf: Add tests for {set|get} socket option from setsockopt BPF (Jiri Benc) [2071618]
- bpf: Add support for {set|get} socket options from setsockopt BPF (Jiri Benc) [2071618]
- bpf: selftest: Test batching and bpf_(get|set)sockopt in bpf tcp iter (Jiri Benc) [2071618]
- bpf: tcp: Support bpf_(get|set)sockopt in bpf tcp iter (Jiri Benc) [2071618]
- bpf: tcp: Bpf iter batching and lock_sock (Jiri Benc) [2071618]
- tcp: seq_file: Replace listening_hash with lhash2 (Jiri Benc) [2071618]
- tcp: seq_file: Add listening_get_first() (Jiri Benc) [2071618]
- bpf: tcp: seq_file: Remove bpf_seq_afinfo from tcp_iter_state (Jiri Benc) [2071618]
- flow_dissector: Fix out-of-bounds warnings (Jiri Benc) [2071618]
- unix_bpf: Fix a potential deadlock in unix_dgram_bpf_recvmsg() (Jiri Benc) [2071618]
- netdevsim: Add multi-queue support (Jiri Benc) [2071618]
- selftests/bpf: Add test cases for redirection between udp and unix (Jiri Benc) [2071618]
- selftests/bpf: Add a test case for unix sockmap (Jiri Benc) [2071618]
- selftests/bpf: Factor out add_to_sockmap() (Jiri Benc) [2071618]
- selftests/bpf: Factor out udp_socketpair() (Jiri Benc) [2071618]
- af_unix: Implement unix_dgram_bpf_recvmsg() (Jiri Benc) [2071618]
- af_unix: Implement ->psock_update_sk_prot() (Jiri Benc) [2071618]
- af_unix: Add a dummy ->close() for sockmap (Jiri Benc) [2071618]
- af_unix: Set TCP_ESTABLISHED for datagram sockets too (Jiri Benc) [2071618]
- af_unix: Implement ->read_sock() for sockmap (Jiri Benc) [2071618]
- sock_map: Lift socket state restriction for datagram sockets (Jiri Benc) [2071618]
- sock_map: Relax config dependency to CONFIG_NET (Jiri Benc) [2071618]
- thermal: Replace acpi_bus_get_device() (David Arcari) [2064829]
- ACPI: scan: Introduce acpi_fetch_acpi_dev() (David Arcari) [2064829]
- ACPI: DPTF: Support Raptor Lake (David Arcari) [2064829]
- thermal: int340x: Update OS policy capability handshake (David Arcari) [2064829]
- thermal: int340x: Increase bitmap size (David Arcari) [2064829]
- thermal: int340x: fix memory leak in int3400_notify() (David Arcari) [2064829]
- thermal: int340x: Check for NULL after calling kmemdup() (David Arcari) [2064829]
- thermal: int340x: Add Raptor Lake PCI device id (David Arcari) [2064829]
- thermal: int340x: Support Raptor Lake (David Arcari) [2064829]
- thermal/drivers/int340x: Fix RFIM mailbox write commands (David Arcari) [2064829]
- Bluetooth: hci_sync: Fix not processing all entries on cmd_sync_work (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Fix unbalanced unlock in set_device_flags() (Gopal Tiwari) [2066188]
- Bluetooth: Fix bt_skb_sendmmsg not allocating partial chunks (Gopal Tiwari) [2066188]
- Bluetooth: Fix not checking MGMT cmd pending queue (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix not using conn_timeout (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix hci_update_accept_list_sync (Gopal Tiwari) [2066188]
- Bluetooth: fix data races in smp_unregister(), smp_del_chan() (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Fix leaking sent_cmd skb (Gopal Tiwari) [2066188]
- Bluetooth: assign len after null check (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: fix endian bug in hci_sock_setsockopt() (Gopal Tiwari) [2066188]
- Bluetooth: L2CAP: uninitialized variables in l2cap_sock_setsockopt() (Gopal Tiwari) [2066188]
- Bluetooth: btqca: sequential validation (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for Foxconn QCA 0xe0d0 (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix broken LED quirk for legacy ROM devices (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Rework hci_inquiry_result_with_rssi_evt (Gopal Tiwari) [2066188]
- Bluetooth: btbcm: disable read tx power for MacBook Air 8,1 and 8,2 (Gopal Tiwari) [2066188]
- Bluetooth: hci_qca: Fix NULL vs IS_ERR_OR_NULL check in qca_serdev_probe (Gopal Tiwari) [2066188]
- Bluetooth: hci_bcm: Check for error irq (Gopal Tiwari) [2066188]
- Bluetooth: MGMT: Fix spelling mistake "simultanous" -> "simultaneous" (Gopal Tiwari) [2066188]
- Bluetooth: vhci: Set HCI_QUIRK_VALID_LE_STATES (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Add support for waiting specific LE subevents (Gopal Tiwari) [2066188]
- Bluetooth: MGMT: Fix LE simultaneous roles UUID if not supported (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Wait for proper events when connecting LE (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Add check simultaneous roles support (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Add hci_le_create_conn_sync (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use skb_pull_data when processing inquiry results (Gopal Tiwari) [2066188]
- Bluetooth: hci_qca: Stop IBS timer during BT OFF (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Push sync command cancellation to workqueue (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for Foxconn MT7922A (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add missing quirks and msft ext for legacy bootloader (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add two more Bluetooth parts for WCN6855 (Gopal Tiwari) [2066188]
- Bluetooth: L2CAP: Fix using wrong mode (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix not always pausing advertising when necessary (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Make use of mgmt_send_event_skb in MGMT_EV_DEVICE_CONNECTED (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Make use of mgmt_send_event_skb in MGMT_EV_DEVICE_FOUND (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Return error code when getting patch status failed (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Introduce mgmt_alloc_skb and mgmt_send_event_skb (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Handle download_firmware failure cases (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add one more Bluetooth part for WCN6855 (Gopal Tiwari) [2066188]
- Bluetooth: add quirk disabling LE Read Transmit Power (Gopal Tiwari) [2066188]
- Bluetooth: msft: Fix compilation when CONFIG_BT_MSFTEXT is not set (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Set Privacy Mode when updating the resolving list (Gopal Tiwari) [2066188]
- Bluetooth: btbcm: disable read tx power for some Macs with the T2 Security chip (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for queuing during polling interval (Gopal Tiwari) [2066188]
- Bluetooth: MGMT: Use hci_dev_test_and_{set,clear}_flag (Gopal Tiwari) [2066188]
- Bluetooth: Introduce HCI_CONN_FLAG_DEVICE_PRIVACY device flag (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Rework hci_conn_params flags (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: enable AOSP extension for MT7921 (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: enable msft opcode (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle Command Status (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle Command Complete (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle LE subevents (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Direct Advertising Report event (Gopal Tiwari) [2066188]
- Bluetooth: hci_event: Use of a function table to handle HCI events (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Extended Inquiry Result event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Advertising Report event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Inquiry Result with RSSI event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Number of Complete Packets event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Ext Advertising Report event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Inquiry Result event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse LE Metaevents (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse Command Complete event (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Use skb_pull_data to parse BR/EDR events (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: fix resume failure (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: handle runtime pm only when sdio_func is available (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Cancel sync commands for certain URB errors (Gopal Tiwari) [2066188]
- Bluetooth: Add hci_cmd_sync_cancel to public API (Gopal Tiwari) [2066188]
- Bluetooth: Reset more state when cancelling a sync command (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Cancel sync command if sending a frame failed (Gopal Tiwari) [2066188]
- Bluetooth: Send device found event on name resolve failure (Gopal Tiwari) [2066188]
- Bluetooth: Limit duration of Remote Name Resolve (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Fix definition of hci_rp_delete_stored_link_key (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Fix definition of hci_rp_read_stored_link_key (Gopal Tiwari) [2066188]
- tty: remove file from tty_ldisc_ops::ioctl and compat_ioctl (Gopal Tiwari) [2066188]
- Bluetooth: refactor malicious adv data check (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add one more Bluetooth part for the Realtek RTL8852AE (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: drop the unnecessary variable created (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: add support of processing firmware coredump and log (Gopal Tiwari) [2066188]
- Bluetooth: btusb: enable Mediatek to support AOSP extension (Gopal Tiwari) [2066188]
- Bluetooth: Attempt to clear HCI_LE_ADV on adv set terminated error event (Gopal Tiwari) [2066188]
- Bluetooth: Ignore HCI_ERROR_CANCELLED_BY_HOST on adv set terminated event (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_CONNECTABLE to use cmd_sync (Gopal Tiwari) [2066188]
- Bluetooth: hci_request: Remove bg_scan_update work (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_DISCOVERABLE to use cmd_sync (Gopal Tiwari) [2066188]
- Bluetooth: btmrvl_main: repair a non-kernel-doc comment (Gopal Tiwari) [2066188]
- Bluetooth: Don't initialize msft/aosp when using user channel (Gopal Tiwari) [2066188]
- Bluetooth: fix uninitialized variables notify_evt (Gopal Tiwari) [2066188]
- Bluetooth: stop proccessing malicious adv data (Gopal Tiwari) [2066188]
- Bluetooth: hci_h4: Fix padding calculation error within h4_recv_buf() (Gopal Tiwari) [2066188]
- Bluetooth: aosp: Support AOSP Bluetooth Quality Report (Gopal Tiwari) [2066188]
- Bluetooth: Add struct of reading AOSP vendor capabilities (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix not setting adv set duration (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Fix missing static warnings (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Rework hci_suspend_notifier (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Rework init stages (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SSP (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert adv_expire (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_ADVERTISING (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_PHY_CONFIGURATION (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_LOCAL_NAME (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_READ_LOCAL_OOB_DATA (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_LE (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_START_DISCOVERY (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_GET_CLOCK_INFO (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_SECURE_CONN (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_GET_CONN_INFO (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Enable synch'd set_bredr (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_SET_FAST_CONNECTABLE (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_OP_READ_LOCAL_OOB_EXT_DATA (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Rework background scan (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Convert MGMT_SET_POWERED (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Enable advertising when LL privacy is enabled (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 3 (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 2 (Gopal Tiwari) [2066188]
- Bluetooth: hci_sync: Make use of hci_cmd_sync_queue set 1 (Gopal Tiwari) [2066188]
- Bluetooth: Add helper for serialized HCI command execution (Gopal Tiwari) [2066188]
- Bluetooth: Fix removing adv when processing cmd complete (Gopal Tiwari) [2066188]
- bluetooth: use dev_addr_set() (Gopal Tiwari) [2066188]
- bluetooth: use eth_hw_addr_set() (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: add MT7921s Bluetooth support (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: update register CSDIOCSR operation (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: transmit packet according to status TX_EMPTY (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: use register CRPLR to read packet length (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: move interrupt service to work (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: explicitly set WHISR as write-1-clear (Gopal Tiwari) [2066188]
- Bluetooth: btmtksdio: add .set_bdaddr support (Gopal Tiwari) [2066188]
- Bluetooth: btmtksido: rely on BT_MTK module (Gopal Tiwari) [2066188]
- Bluetooth: mediatek: add BT_MTK module (Gopal Tiwari) [2066188]
- Bluetooth: hci_bcm: Remove duplicated entry in OF table (Gopal Tiwari) [2066188]
- Bluetooth: bfusb: fix division by zero in send path (Gopal Tiwari) [2066188]
- Bluetooth: cmtp: fix possible panic when cmtp_init_sockets() fails (Gopal Tiwari) [2066188]
- Bluetooth: vhci: Fix checking of msft_opcode (Gopal Tiwari) [2066188]
- Bluetooth: btsdio: Do not bind to non-removable BCM4345 and BCM43455 (Gopal Tiwari) [2066188]
- Bluetooth: virtio_bt: fix memory leak in virtbt_rx_handle() (Gopal Tiwari) [2066188]
- Bluetooth: vhci: Add support for setting msft_opcode and aosp_capable (Gopal Tiwari) [2066188]
- Bluetooth: btusb: fix memory leak in btusb_mtk_submit_wmt_recv_urb() (Gopal Tiwari) [2066188]
- Bluetooth: Fix memory leak of hci device (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix bdaddress comparison with garbage value (Gopal Tiwari) [2066188]
- Bluetooth: Fix debugfs entry leak in hci_register_dev() (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Fix application of sizeof to pointer (Gopal Tiwari) [2066188]
- Bluetooth: L2CAP: Fix not initializing sk_peer_pid (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: purge socket queues in the destruct() callback (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Fix Experimental Feature Changed event (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Fix to set the force_wakeup value (Gopal Tiwari) [2066188]
- Bluetooth: Read codec capabilities only if supported (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Fix calling hci_{suspend,resume}_dev (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of SUSPEND_DISCONNECTING (Gopal Tiwari) [2066188]
- Bluetooth: Rename driver .prevent_wake to .wakeup (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Ask ic_info to drop firmware (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for TP-Link UB500 Adapter (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: Replace use of memcpy_from_msg with bt_skb_sendmsg (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Add support for MSFT extension to rtl8821c devices (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Add force_prevent_wake entry (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Add force_suspend entry (Gopal Tiwari) [2066188]
- Bluetooth: Make use of hci_{suspend,resume}_dev on suspend notifier (Gopal Tiwari) [2066188]
- Bluetooth: btrsi: remove superfluous header files from btrsi.c (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Set VsMsftOpCode based on device table (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of experimental feature for quality reports (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of experimental feature for codec offload (Gopal Tiwari) [2066188]
- Bbluetooth: btusb: Add another Bluetooth part for Realtek 8852AE (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: enable Realtek 8822C/8852A to support AOSP extension (Gopal Tiwari) [2066188]
- Bluetooth: hci_qca: enable Qualcomm WCN399x for AOSP extension (Gopal Tiwari) [2066188]
- Bluetooth: Fix wrong opcode when LL privacy enabled (Gopal Tiwari) [2066188]
- Bluetooth: Fix Advertisement Monitor Suspend/Resume (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: directly return hci_uart_register_device() ret-val (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: Fix (runtime)suspend issues on RTL8723BS HCIs (Gopal Tiwari) [2066188]
- tty: remove file from tty_mode_ioctl (Gopal Tiwari) [2066188]
- tty: remove file from n_tty_ioctl_helper (Gopal Tiwari) [2066188]
- Bluetooth: hci_core: Move all debugfs handling to hci_debugfs.c (Gopal Tiwari) [2066188]
- Bluetooth: btmtkuart: fix a memleak in mtk_hci_wmt_sync (Gopal Tiwari) [2066188]
- Bluetooth: hci_ldisc: require CAP_NET_ADMIN to attach N_HCI ldisc (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add gpio reset way for qca btsoc in cmd_timeout (Gopal Tiwari) [2066188]
- Bluetooth: Fix passing NULL to PTR_ERR (Gopal Tiwari) [2066188]
- Bluetooth: Add bt_skb_sendmmsg helper (Gopal Tiwari) [2066188]
- Bluetooth: Add bt_skb_sendmsg helper (Gopal Tiwari) [2066188]
- Bluetooth: hci_sock: Add support for BT_{SND,RCV}BUF (Gopal Tiwari) [2066188]
- Bluetooth: SCO: Fix sco_send_frame returning skb->len (Gopal Tiwari) [2066188]
- Bluetooth: eir: Move EIR/Adv Data functions to its own file (Gopal Tiwari) [2066188]
- Bluetooth: RFCOMM: Replace use of memcpy_from_msg with bt_skb_sendmmsg (Gopal Tiwari) [2066188]
- Bluetooth: SCO: Replace use of memcpy_from_msg with bt_skb_sendmsg (Gopal Tiwari) [2066188]
- Bluetooth: hci_uart: fix GPF in h5_recv (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix incorrect out of memory check (Gopal Tiwari) [2066188]
- Bluetooth: Keep MSFT ext info throughout a hci_dev's life cycle (Gopal Tiwari) [2066188]
- Bluetooth: Allow usb to auto-suspend when SCO use non-HCI transport (Gopal Tiwari) [2066188]
- Bluetooth: Add offload feature under experimental flag (Gopal Tiwari) [2066188]
- Bluetooth: Add support for Read Local Supported Codecs V2 (Gopal Tiwari) [2066188]
- Bluetooth: Configure codec for HFP offload use case (Gopal Tiwari) [2066188]
- Bluetooth: hci_vhci: Add support for offload codecs over SCO (Gopal Tiwari) [2066188]
- Bluetooth: Add support for msbc coding format (Gopal Tiwari) [2066188]
- Bluetooth: Add support for HCI_Enhanced_Setup_Synchronous_Connection command (Gopal Tiwari) [2066188]
- Bluetooth: Allow setting of codec for HFP offload use case (Gopal Tiwari) [2066188]
- Bluetooth: Enumerate local supported codec and cache details (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Define a callback to fetch codec config data (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Define callback to fetch data_path_id (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Read supported offload use cases (Gopal Tiwari) [2066188]
- Bluetooth: Allow querying of supported offload codecs over SCO socket (Gopal Tiwari) [2066188]
- Bluetooth: call sock_hold earlier in sco_conn_del (Gopal Tiwari) [2066188]
- Bluetooth: fix init and cleanup of sco_conn.timeout_work (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for IMC Networks Mediatek Chip(MT7921) (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add the new support ID for Realtek RTL8852A (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Support public address configuration for MediaTek Chip. (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add protocol for MediaTek bluetooth devices(MT7922) (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Read boot address irrespective of controller mode (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix boot address (Gopal Tiwari) [2066188]
- Bluetooth: Fix using RPA when address has been resolved (Gopal Tiwari) [2066188]
- Bluetooth: Fix using address type from events (Gopal Tiwari) [2066188]
- Bluetooth: Fix enabling advertising for central role (Gopal Tiwari) [2066188]
- Bluetooth: sco: Fix lock_sock() blockage by memcpy_from_msg() (Gopal Tiwari) [2066188]
- Bluetooth: set quality report callback for Intel (Gopal Tiwari) [2066188]
- Bluetooth: Support the quality report events (Gopal Tiwari) [2066188]
- Bluetooth: refactor set_exp_feature with a feature table (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Disallow legacy MGMT_OP_READ_LOCAL_OOB_EXT_DATA (Gopal Tiwari) [2066188]
- Bluetooth: btintel: support link statistics telemetry events (Gopal Tiwari) [2066188]
- Bluetooth: reorganize functions from hci_sock_sendmsg() (Gopal Tiwari) [2066188]
- Bluetooth: btusb: disable Intel link statistics telemetry events (Gopal Tiwari) [2066188]
- Bluetooth: Fix return value in hci_dev_do_close() (Gopal Tiwari) [2066188]
- Bluetooth: add timeout sanity check to hci_inquiry (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Remove WAKEUP_DISABLE and add WAKEUP_AUTOSUSPEND for Realtek devices (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Pessimize compile-time bounds-check (Gopal Tiwari) [2066188]
- Bluetooth: Fix race condition in handling NOP command (Gopal Tiwari) [2066188]
- Bluetooth: btbcm: add patch ram for bluetooth (Gopal Tiwari) [2066188]
- Bluetooth: Fix handling of LE Enhanced Connection Complete (Gopal Tiwari) [2066188]
- Bluetooth: Store advertising handle so it can be re-enabled (Gopal Tiwari) [2066188]
- Bluetooth: Move shutdown callback before flushing tx and rx queue (Gopal Tiwari) [2066188]
- Bluetooth: btusb: check conditions before enabling USB ALT 3 for WBS (Gopal Tiwari) [2066188]
- Bluetooth: fix repeated calls to sco_sock_kill (Gopal Tiwari) [2066188]
- Bluetooth: schedule SCO timeouts with delayed_work (Gopal Tiwari) [2066188]
- Bluetooth: switch to lock_sock in RFCOMM (Gopal Tiwari) [2066188]
- Bluetooth: avoid circular locks in sco_sock_connect (Gopal Tiwari) [2066188]
- Bluetooth: serialize calls to sco_sock_{set,clear}_timer (Gopal Tiwari) [2066188]
- Bluetooth: switch to lock_sock in SCO (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Fix fall-through warnings (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix the legacy bootloader returns tlv based version (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Combine setting up MSFT extension (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Move hci quirks to setup routine (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Clean the exported function to static (Gopal Tiwari) [2066188]
- Bluetooth: Add support hdev to allocate private data (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Refactoring setup routine for bootloader devices (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add combined set_diag functions (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix the LED is not turning off immediately (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Fix the first HCI command not work with ROM device (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add btintel data struct (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Refactoring setup routine for legacy ROM sku (Gopal Tiwari) [2066188]
- Bluetooth: btintel: Add combined setup and shutdown functions (Gopal Tiwari) [2066188]
- Bluetooth: increase BTNAMSIZ to 21 chars to fix potential buffer overflow (Gopal Tiwari) [2066188]
- Bluetooth: Add additional Bluetooth part for Realtek 8852AE (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Support Bluetooth Reset for Mediatek Chip(MT7921) (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Record debug log for Mediatek Chip. (Gopal Tiwari) [2066188]
- Bluetooth: hci_bcm: Fix kernel doc comments (Gopal Tiwari) [2066188]
- Bluetooth: Fix not generating RPA when required (Gopal Tiwari) [2066188]
- Bluetooth: HCI: Add proper tracking for enable status of adv instances (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Enable MSFT extension for Mediatek Chip (MT7921) (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Make the CSR clone chip force-suspend workaround more generic (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Enable MSFT extension for Intel next generation controllers (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Enable MSFT extension for WCN6855 controller (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Load Broadcom firmware for Dell device 413c:8197 (Gopal Tiwari) [2066188]
- Bluetooth: btmrvl_sdio: Remove all strcpy() uses (Gopal Tiwari) [2066188]
- Bluetooth: skip invalid hci_sync_conn_complete_evt (Gopal Tiwari) [2066188]
- Bluetooth: mgmt: Fix wrong opcode in the response for add_adv cmd (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add valid le states quirk (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: Add runtime suspend (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: btrtl: Maintain flow control if wakeup is enabled (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: add WAKEUP_DISABLE flag (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for Foxconn Mediatek Chip (Gopal Tiwari) [2066188]
- Bluetooth: btrsi: use non-kernel-doc comment for copyright (Gopal Tiwari) [2066188]
- Bluetooth: btrtl: Set MSFT opcode for RTL8852 (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for LG LGSBWAC92/TWCM-K505D (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Fix a unspported condition to set available debug features (Gopal Tiwari) [2066188]
- Bluetooth: sco: prevent information leak in sco_conn_defer_accept() (Gopal Tiwari) [2066188]
- Bluetooth: btusb: Add support for IMC Networks Mediatek Chip (Gopal Tiwari) [2066188]
- Bluetooth: hci_h5: Disable the hci_suspend_notifier for btrtl devices (Gopal Tiwari) [2066188]
- Bluetooth: Bluetooth: defer cleanup of resources in hci_unregister_dev() (Gopal Tiwari) [2066188]

* Sun Jun 05 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-104.rt21.104.el9]
- [rt] build kernel-rt-5.14.0-104.rt21.104.el9 [2061574]
- bonding: fix missed rcu protection (Jonathan Toppins) [2089774]
- bonding: do not discard lowest hash bit for non layer3+4 hashing (Jonathan Toppins) [2089774]
- bonding: helper macro __ATTR_RO to make code more clear (Jonathan Toppins) [2089774]
- bonding: add new option ns_ip6_target (Jonathan Toppins) [1951971]
- bonding: add new parameter ns_targets (Jonathan Toppins) [1951971]
- bonding: add extra field for bond_opt_value (Jonathan Toppins) [1951971]
- Bonding: split bond_handle_vlan from bond_arp_send (Jonathan Toppins) [1951971]
- bonding: force carrier update when releasing slave (Jonathan Toppins) [2089774]
- bonding: fix data-races around agg_select_timer (Jonathan Toppins) [2089774]
- bonding: switch bond_net_exit() to batch mode (Jonathan Toppins) [2089774]
- bonding: pair enable_port with slave_arr_updates (Jonathan Toppins) [2089774]
- net: bonding: Add support for IPV6 ns/na to balance-alb/balance-tlb mode (Jonathan Toppins) [2089774]
- bonding: use rcu_dereference_rtnl when get bonding active slave (Jonathan Toppins) [2089774]
- net: bonding: fix bond_xmit_broadcast return value error bug (Jonathan Toppins) [2089774]
- Bonding: return HWTSTAMP_FLAG_BONDED_PHC_INDEX to notify user space (Jonathan Toppins) [2019670]
- Bonding: force user to add HWTSTAMP_FLAG_BONDED_PHC_INDEX when get/set HWTSTAMP (Jonathan Toppins) [2019670]
- bond: pass get_ts_info and SIOC[SG]HWTSTAMP ioctl to active device (Jonathan Toppins) [2019670]
- net: bonding: debug: avoid printing debug logs when bond is not notifying peers (Jonathan Toppins) [2089774]
- net: remove bond_slave_has_mac_rcu() (Jonathan Toppins) [2089774]
- Bonding: add arp_missed_max option (Jonathan Toppins) [1952053]
- net: bonding: constify and use dev_addr_set() (Jonathan Toppins) [2089774]
- bonding: remove extraneous definitions from bonding.h (Jonathan Toppins) [2089774]
- redhat: enable CONFIG_NET_ACT_CTINFO (as a module) (Davide Caratti) [2027894]
- selftests: mptcp: add subflow limits test-cases (Paolo Abeni) [2076832]
- mptcp: fix subflow accounting on close (Paolo Abeni) [2076832]
- scsi: qedi: Remove redundant flush_workqueue() calls (Nilesh Javali) [2046624]
- scsi: qedi: Fix SYSFS_FLAG_FW_SEL_BOOT formatting (Nilesh Javali) [2046624]
- scsi: qedi: Fix cmd_cleanup_cmpl counter mismatch issue (Nilesh Javali) [2046624]
- scsi: qedi: Remove set but unused 'page' variable (Nilesh Javali) [2046624]
- scsi: qedi: Fix error codes in qedi_alloc_global_queues() (Nilesh Javali) [2046624]
- scsi: qedi: Add support for fastpath doorbell recovery (Nilesh Javali) [2046624]

* Wed Jun 01 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-103.rt21.103.el9]
- [rt] build kernel-rt-5.14.0-103.rt21.103.el9 [2061574]
- ipc/mqueue: use get_tree_nodev() in mqueue_get_tree() (Waiman Long) [1924181]
- selftests/powerpc/pmu: Add interface test for mmcra register fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr3_src fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr2_fcs_fch fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr2_l2l3 field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr1_comb field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmc56 using pmc5 (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_fc56 field using pmc1 (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmcjce field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_pmccext bit (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0_cc56run field (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu/: Add interface test for mmcr0 exception bits (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macro to extract mmcr3 and mmcra fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macro to extract mmcr0/mmcr1 fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macros to extract mmcr fields (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add event_init_sampling function (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add utility functions to post process the mmap buffer (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add macros to parse event codes (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Add support for perf sampling tests (Desnes A. Nunes do Rosario) [2071110]
- selftests/powerpc/pmu: Include mmap_buffer field as part of struct event (Desnes A. Nunes do Rosario) [2071110]
- xfs: return errors in xfs_fs_sync_fs (Andrey Albershteyn) [2087995]
- vfs: make sync_filesystem return errors from ->sync_fs (Andrey Albershteyn) [2087995]
- Watchdog: sp5100_tco: Enable Family 17h+ CPUs (David Arcari) [2042590]
- Watchdog: sp5100_tco: Add initialization using EFCH MMIO (David Arcari) [2042590]
- Watchdog: sp5100_tco: Refactor MMIO base address initialization (David Arcari) [2042590]
- Watchdog: sp5100_tco: Move timer initialization into function (David Arcari) [2042590]
- i2c: piix4: Enable EFCH MMIO for Family 17h+ (David Arcari) [2042590]
- i2c: piix4: Add EFCH MMIO support for SMBus port select (David Arcari) [2042590]
- i2c: piix4: Add EFCH MMIO support to SMBus base address detect (David Arcari) [2042590]
- i2c: piix4: Add EFCH MMIO support to region request and release (David Arcari) [2042590]
- i2c: piix4: Move SMBus port selection into function (David Arcari) [2042590]
- i2c: piix4: Move SMBus controller base address detect into function (David Arcari) [2042590]
- i2c: piix4: Move port I/O region request/release code into functions (David Arcari) [2042590]
- i2c: piix4: Replace hardcoded memory map size with a #define (David Arcari) [2042590]
- kernel/resource: Introduce request_mem_region_muxed() (David Arcari) [2042590]
- [s390] RDMA/mlx5: Fix number of allocated XLT entries (Mete Durlu) [2088360]
- treewide: Replace zero-length arrays with flexible-array members (Tomas Henzl) [2049670]
- scsi: mpi3mr: Bump driver version to 8.0.0.68.0 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Update the copyright year (Tomas Henzl) [2049670]
- scsi: mpi3mr: Update MPI3 headers (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fix formatting problems in some kernel-doc comments (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fix some spelling mistakes (Tomas Henzl) [2049670]
- scsi: mpi3mr: Bump driver version to 8.0.0.61.0 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add io_uring interface support in I/O-polled mode (Tomas Henzl) [2049670]
- scsi: mpi3mr: Print cable mngnt and temp threshold events (Tomas Henzl) [2049670]
- scsi: mpi3mr: Support Prepare for Reset event (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add Event acknowledgment logic (Tomas Henzl) [2049670]
- scsi: mpi3mr: Gracefully handle online FW update operation (Tomas Henzl) [2049670]
- scsi: mpi3mr: Detect async reset that occurred in firmware (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add IOC reinit function (Tomas Henzl) [2049670]
- scsi: mpi3mr: Handle offline FW activation in graceful manner (Tomas Henzl) [2049670]
- scsi: mpi3mr: Code refactor of IOC init - part2 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Code refactor of IOC init - part1 (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fault IOC when internal command gets timeout (Tomas Henzl) [2049670]
- scsi: mpi3mr: Display IOC firmware package version (Tomas Henzl) [2049670]
- scsi: mpi3mr: Handle unaligned PLL in unmap cmnds (Tomas Henzl) [2049670]
- scsi: mpi3mr: Add support for PCIe Managed Switch SES device (Tomas Henzl) [2049670]
- scsi: mpi3mr: Fix duplicate device entries when scanning through sysfs (Tomas Henzl) [2049670]
- [s390] s390/cio: verify the driver availability for path_event call (Mete Durlu) [2058622]
- [s390] s390/hypfs: include z/VM guests with access control group set (Mete Durlu) [2058616]
- scsi: mpt3sas: Fix junk chars displayed while printing ChipName (Tomas Henzl) [2049634]
- scsi: mpt3sas: Use cached ATA Information VPD page (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix adapter replyPostRegisterIndex declaration (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix event callback log_code value handling (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix ioc->base_readl() use (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix writel() use (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix _ctl_set_task_mid() TaskMID check (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fail reset operation if config request timed out (Tomas Henzl) [2049634]
- scsi: mpt3sas: Fix use after free in _scsih_expander_node_remove() (Tomas Henzl) [2049634]
- scsi: mpt3sas: Page fault in reply q processing (Tomas Henzl) [2049634]
- scsi: mpt3sas: Convert to flexible arrays (Tomas Henzl) [2049634]
- scsi: mpt3sas: Update persistent trigger pages from sysfs interface (Tomas Henzl) [2049634]
- scsi: mpt3sas: Use irq_set_affinity_and_hint() (Tomas Henzl) [2049634]
- [s390] s390/tape: fix timer initialization in tape_std_assign() (Mete Durlu) [2085419]
- powerpc/pseries/vas: Use QoS credits from the userspace (Steve Best) [2075175]
- tracing/osnoise: Force quiescent states while tracing (Jerome Marchand) [2069708]
- tracing/osnoise: Do not unregister events twice (Jerome Marchand) [2069708]
- tracing/osnoise: Make osnoise_main to sleep for microseconds (Jerome Marchand) [2069708]
- tracing/osnoise: Properly unhook events if start_per_cpu_kthreads() fails (Jerome Marchand) [2069708]
- tracing/osnoise: Make osnoise_instances static (Jerome Marchand) [2069708]
- tracing/osnoise: Remove PREEMPT_RT ifdefs from inside functions (Jerome Marchand) [2069708]
- tracing/osnoise: Remove STACKTRACE ifdefs from inside functions (Jerome Marchand) [2069708]
- tracing/osnoise: Allow multiple instances of the same tracer (Jerome Marchand) [2069708]
- tracing/osnoise: Remove TIMERLAT ifdefs from inside functions (Jerome Marchand) [2069708]
- tracing/osnoise: Support a list of trace_array *tr (Jerome Marchand) [2069708]
- tracing/osnoise: Use start/stop_per_cpu_kthreads() on osnoise_cpus_write() (Jerome Marchand) [2069708]
- tracing/osnoise: Split workload start from the tracer start (Jerome Marchand) [2069708]
- tracing/osnoise: Improve comments about barrier need for NMI callbacks (Jerome Marchand) [2069708]
- tracing/osnoise: Do not follow tracing_cpumask (Jerome Marchand) [2069708]
- trace/timerlat: Add migrate-disabled field to the timerlat header (Jerome Marchand) [2069708]
- trace/osnoise: Add migrate-disabled field to the osnoise header (Jerome Marchand) [2069708]
- tracing/doc: Fix typos on the timerlat tracer documentation (Jerome Marchand) [2069708]
- trace/osnoise: Fix an ifdef comment (Jerome Marchand) [2069708]
- tracing: Disable "other" permission bits in the tracefs files (Jerome Marchand) [2069708]
- tracing/osnoise: Fix missed cpus_read_unlock() in start_per_cpu_kthreads() (Jerome Marchand) [2069708]
- dlm: fix plock invalid read (Alexander Aring) [2053070]
- tcp: fix potential xmit stalls caused by TCP_NOTSENT_LOWAT (Paolo Abeni) [2079411]
- tcp: ensure to use the most recently sent skb when filling the rate sample (Paolo Abeni) [2079411]
- tcp: make sure treq->af_specific is initialized (Paolo Abeni) [2079411]
- tcp: md5: incorrect tcp_header_len for incoming connections (Paolo Abeni) [2079411]
- inet: fully convert sk->sk_rx_dst to RCU rules (Paolo Abeni) [2079411]

* Wed Jun 01 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-102.rt21.102.el9]
- [rt] build kernel-rt-5.14.0-102.rt21.102.el9 [2061574]
- thunderx nic: mark device as unmaintained (Íñigo Huguet) [2060285]
- livepatch: Fix missing unlock on error in klp_enable_patch() (C. Erastus Toe) [2069362]
- livepatch: Fix kobject refcount bug on klp_init_patch_early failure path (C. Erastus Toe) [2069362]
- Documentation: livepatch: Add livepatch API page (C. Erastus Toe) [2069362]
- xfs: Fix the free logic of state in xfs_attr_node_hasname (Carlos Maiolino) [2037525]
- perf tests: Fix coresight `perf test` failure. (Michael Petlan) [2069073]
- perf unwind: Don't show unwind error messages when augmenting frame pointer stack (Michael Petlan) [2069073]
- perf test arm64: Test unwinding using fame-pointer (fp) mode (Michael Petlan) [2069073]
- perf parse-events: Move slots only with topdown (Michael Petlan) [2069073]
- libperf tests: Fix typo in perf_evlist__open() failure error messages (Michael Petlan) [2069073]
- arm64: perf: Don't register user access sysctl handler multiple times (Michael Petlan) [2069073]
- perf/x86/intel: Update the FRONTEND MSR mask on Sapphire Rapids (Michael Petlan) [2069073]
- perf/x86/intel: Don't extend the pseudo-encoding to GP counters (Michael Petlan) [2069073]
- perf vendor events: Update metrics for SkyLake Server (Michael Petlan) [2069073]
- perf parse-events: Ignore case in topdown.slots check (Michael Petlan) [2069073]
- perf evlist: Avoid iteration for empty evlist. (Michael Petlan) [2069073]
- perf parse: Fix event parser error for hybrid systems (Michael Petlan) [2069073]
- perf bench: Fix NULL check against wrong variable (Michael Petlan) [2069073]
- perf parse-events: Fix NULL check against wrong variable (Michael Petlan) [2069073]
- perf script: Fix error when printing 'weight' field (Michael Petlan) [2069073]
- perf data: Fix double free in perf_session__delete() (Michael Petlan) [2069073]
- perf evlist: Fix failed to use cpu list for uncore events (Michael Petlan) [2069073]
- perf test: Skip failing sigtrap test for arm+aarch64 (Michael Petlan) [2069073]
- perf bpf: Defer freeing string after possible strlen() on it (Michael Petlan) [2069073]
- perf test: Fix arm64 perf_event_attr tests wrt --call-graph initialization (Michael Petlan) [2069073]
- libsubcmd: Fix use-after-free for realloc(..., 0) (Michael Petlan) [2069073]
- libperf: Fix perf_cpu_map__for_each_cpu macro (Michael Petlan) [2069073]
- perf cs-etm: Fix corrupt inject files when only last branch option is enabled (Michael Petlan) [2069073]
- perf cs-etm: No-op refactor of synth opt usage (Michael Petlan) [2069073]
- libperf: Fix 32-bit build for tests uint64_t printf (Michael Petlan) [2069073]
- tools headers UAPI: Sync linux/perf_event.h with the kernel sources (Michael Petlan) [2069073]
- perf trace: Avoid early exit due SIGCHLD from non-workload processes (Michael Petlan) [2069073]
- perf ftrace: system_wide collection is not effective by default (Michael Petlan) [2069073]
- libperf: Add arm64 support to perf_mmap__read_self() (Michael Petlan) [2069073]
- perf stat: Fix display of grouped aliased events (Michael Petlan) [2069073]
- perf tools: Apply correct label to user/kernel symbols in branch mode (Michael Petlan) [2069073]
- perf bpf: Fix a typo in bpf_counter_cgroup.c (Michael Petlan) [2069073]
- perf synthetic-events: Return error if procfs isn't mounted for PID namespaces (Michael Petlan) [2069073]
- perf session: Check for NULL pointer before dereference (Michael Petlan) [2069073]
- perf annotate: Set error stream of objdump process for TUI (Michael Petlan) [2069073]
- perf tools: Add missing branch_sample_type to perf_event_attr__fprintf() (Michael Petlan) [2069073]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Michael Petlan) [2069073]
- perf beauty: Make the prctl arg regexp more strict to cope with PR_SET_VMA (Michael Petlan) [2069073]
- perf tools: Remove redundant err variable (Michael Petlan) [2069073]
- perf test: Add parse-events test for aliases with hyphens (Michael Petlan) [2069073]
- perf test: Add pmu-events test for aliases with hyphens (Michael Petlan) [2069073]
- perf parse-events: Support event alias in form foo-bar-baz (Michael Petlan) [2069073]
- perf evsel: Override attr->sample_period for non-libpfm4 events (Michael Petlan) [2069073]
- perf cpumap: Remove duplicate include in cpumap.h (Michael Petlan) [2069073]
- perf cpumap: Migrate to libperf cpumap api (Michael Petlan) [2069073]
- perf python: Fix cpu_map__item() building (Michael Petlan) [2069073]
- perf script: Fix printing 'phys_addr' failure issue (Michael Petlan) [2069073]
- perf machine: Use path__join() to compose a path instead of snprintf(dir, '/', filename) (Michael Petlan) [2069073]
- perf evlist: No need to setup affinities when disabling events for pid targets (Michael Petlan) [2069073]
- perf evlist: No need to setup affinities when enabling events for pid targets (Michael Petlan) [2069073]
- perf stat: No need to setup affinities when starting a workload (Michael Petlan) [2069073]
- perf affinity: Allow passing a NULL arg to affinity__cleanup() (Michael Petlan) [2069073]
- perf probe: Fix ppc64 'perf probe add events failed' case (Michael Petlan) [2069073]
- perf record: Disable debuginfod by default (Michael Petlan) [2069073]
- perf evlist: No need to do any affinity setup when profiling pids (Michael Petlan) [2069073]
- perf cpumap: Add is_dummy() method (Michael Petlan) [2069073]
- perf metric: Fix metric_leader (Michael Petlan) [2069073]
- perf cputopo: Fix CPU topology reading on s/390 (Michael Petlan) [2069073]
- perf metricgroup: Fix use after free in metric__new() (Michael Petlan) [2069073]
- libperf tests: Update a use of the new cpumap API (Michael Petlan) [2069073]
- perf arm: Fix off-by-one directory path (Michael Petlan) [2069073]
- perf pmu-events: Don't lower case MetricExpr (Michael Petlan) [2069073]
- perf expr: Add debug logging for literals (Michael Petlan) [2069073]
- perf tools: Probe non-deprecated sysfs path 1st (Michael Petlan) [2069073]
- perf tools: Fix SMT fallback with large core counts (Michael Petlan) [2069073]
- perf cpumap: Give CPUs their own type (Michael Petlan) [2069073]
- perf stat: Correct first_shadow_cpu to return index (Michael Petlan) [2069073]
- perf script: Fix flipped index and cpu (Michael Petlan) [2069073]
- perf c2c: Use more intention revealing iterator (Michael Petlan) [2069073]
- perf bpf: Rename 'cpu' to 'cpu_map_idx' (Michael Petlan) [2069073]
- libperf: Sync evsel documentation (Michael Petlan) [2069073]
- perf stat: Swap variable name cpu to index (Michael Petlan) [2069073]
- perf stat: Correct check_per_pkg() cpu (Michael Petlan) [2069073]
- perf test: Use perf_cpu_map__for_each_cpu() (Michael Petlan) [2069073]
- perf evsel: Rename variable cpu to index (Michael Petlan) [2069073]
- perf evsel: Reduce scope of evsel__ignore_missing_thread (Michael Petlan) [2069073]
- perf evsel: Rename CPU around get_group_fd (Michael Petlan) [2069073]
- perf stat: Correct variable name for read counter (Michael Petlan) [2069073]
- perf evsel: Pass cpu not cpu map index to synthesize (Michael Petlan) [2069073]
- perf evlist: Refactor evlist__for_each_cpu() (Michael Petlan) [2069073]
- libperf: Allow NULL in perf_cpu_map__idx() (Michael Petlan) [2069073]
- perf script: Use for each cpu to aid readability (Michael Petlan) [2069073]
- perf stat: Use perf_cpu_map__for_each_cpu() (Michael Petlan) [2069073]
- perf stat: Rename aggr_data cpu to imply it's an index (Michael Petlan) [2069073]
- perf counts: Switch name cpu to cpu_map_idx (Michael Petlan) [2069073]
- libperf: Use cpu not index for evsel mmap (Michael Petlan) [2069073]
- libperf: Switch cpu to more accurate cpu_map_idx (Michael Petlan) [2069073]
- perf evsel: Derive CPUs and threads in alloc_counts (Michael Petlan) [2069073]
- perf stat-display: Avoid use of core for CPU (Michael Petlan) [2069073]
- perf cpumap: Add CPU to aggr_cpu_id (Michael Petlan) [2069073]
- perf stat: Fix memory leak in check_per_pkg() (Michael Petlan) [2069073]
- perf cpumap: Trim the cpu_aggr_map (Michael Petlan) [2069073]
- perf cpumap: Add some comments to cpu_aggr_map (Michael Petlan) [2069073]
- perf cpumap: Move 'has' function to libperf (Michael Petlan) [2069073]
- perf cpumap: Rename cpu_map__get_X_aggr_by_cpu functions (Michael Petlan) [2069073]
- perf cpumap: Refactor cpu_map__build_map() (Michael Petlan) [2069073]
- perf cpumap: Remove cpu_map__cpu(), use libperf function (Michael Petlan) [2069073]
- perf cpumap: Remove map from function names that don't use a map (Michael Petlan) [2069073]
- perf cpumap: Document cpu__get_node() and remove redundant function (Michael Petlan) [2069073]
- perf cpumap: Rename empty functions (Michael Petlan) [2069073]
- perf cpumap: Simplify equal function name (Michael Petlan) [2069073]
- perf cpumap: Remove unused cpu_map__socket() (Michael Petlan) [2069073]
- perf cpumap: Add comments to aggr_cpu_id() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_node() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_core() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_die() (Michael Petlan) [2069073]
- perf cpumap: Remove map+index get_socket() (Michael Petlan) [2069073]
- perf cpumap: Switch cpu_map__build_map() to cpu function (Michael Petlan) [2069073]
- perf stat: Switch to cpu version of cpu_map__get() (Michael Petlan) [2069073]
- perf stat: Switch aggregation to use for_each loop (Michael Petlan) [2069073]
- perf stat: Correct aggregation CPU map (Michael Petlan) [2069073]
- perf stat: Add aggr creators that are passed a cpu (Michael Petlan) [2069073]
- libperf: Add comments to 'struct perf_cpu_map' (Michael Petlan) [2069073]
- perf evsel: Improve error message for uncore events (Michael Petlan) [2069073]
- perf script: Fix hex dump character output (Michael Petlan) [2069073]
- perf test: Enable system wide for metricgroups test (Michael Petlan) [2069073]
- perf annotate: Avoid TUI crash when navigating in the annotation of recursive functions (Michael Petlan) [2069073]
- perf arm64: Inject missing frames when using 'perf record --call-graph=fp' (Michael Petlan) [2069073]
- perf tools: Refactor SMPL_REG macro in perf_regs.h (Michael Petlan) [2069073]
- perf callchain: Enable dwarf_callchain_users on arm64 (Michael Petlan) [2069073]
- perf script: Use callchain_param_setup() instead of open coded equivalent (Michael Petlan) [2069073]
- perf machine: Add a mechanism to inject stack frames (Michael Petlan) [2069073]
- perf tools: Record ARM64 LR register automatically (Michael Petlan) [2069073]
- perf test: Use 3 digits for test numbering now we can have more tests (Michael Petlan) [2069073]
- perf arm-spe: Synthesize SPE instruction events (Michael Petlan) [2069073]
- perf test: Test 73 Sig_trap fails on s390 (Michael Petlan) [2069073]
- perf ftrace: Implement cpu and task filters in BPF (Michael Petlan) [2069073]
- perf ftrace: Add -b/--use-bpf option for latency subcommand (Michael Petlan) [2069073]
- perf ftrace: Add 'latency' subcommand (Michael Petlan) [2069073]
- perf ftrace: Move out common code from __cmd_ftrace (Michael Petlan) [2069073]
- perf ftrace: Add 'trace' subcommand (Michael Petlan) [2069073]
- perf arch: Support register names from all archs (Michael Petlan) [2069073]
- perf arm64: Rename perf_event_arm_regs for ARM64 registers (Michael Petlan) [2069073]
- perf namespaces: Add helper nsinfo__is_in_root_namespace() (Michael Petlan) [2069073]
- libperf tests: Fix a spelling mistake "Runnnig" -> "Running" (Michael Petlan) [2069073]
- perf bpf-loader: Use IS_ERR_OR_NULL() to clean code and fix check (Michael Petlan) [2069073]
- perf cs-etm: Remove duplicate and incorrect aux size checks (Michael Petlan) [2069073]
- perf vendor events: Rename arm64 arch std event files (Michael Petlan) [2069073]
- perf vendor events: For the Arm Neoverse N2 (Michael Petlan) [2069073]
- perf dlfilter: Drop unused variable (Michael Petlan) [2069073]
- perf arm-spe: Add SPE total latency as PERF_SAMPLE_WEIGHT (Michael Petlan) [2069073]
- perf bench: Use unbuffered output when pipe/tee'ing to a file (Michael Petlan) [2069073]
- perf vendor events arm64: Fix JSON indentation to 4 spaces standard (Michael Petlan) [2069073]
- perf stat: Support --cputype option for hybrid events (Michael Petlan) [2069073]
- perf tools: Drop requirement for libstdc++.so for libopencsd check (Michael Petlan) [2069073]
- perf parse-events: Architecture specific leader override (Michael Petlan) [2069073]
- perf evlist: Allow setting arbitrary leader (Michael Petlan) [2069073]
- perf metric: Reduce multiplexing with duration_time (Michael Petlan) [2069073]
- perf trace: Enable ignore_missing_thread for trace (Michael Petlan) [2069073]
- perf docs: Update link to AMD documentation (Michael Petlan) [2069073]
- perf docs: Add info on AMD raw event encoding (Michael Petlan) [2069073]
- libperf tests: Add test_stat_multiplexing test (Michael Petlan) [2069073]
- libperf: Remove scaling process from perf_mmap__read_self() (Michael Petlan) [2069073]
- libperf: Adopt perf_counts_values__scale() from tools/perf/util (Michael Petlan) [2069073]
- tools build: Enable warnings through HOSTCFLAGS (Michael Petlan) [2069073]
- perf test sigtrap: Print errno string when failing (Michael Petlan) [2069073]
- perf test sigtrap: Add basic stress test for sigtrap handling (Michael Petlan) [2069073]
- tools/perf: Add '__rel_loc' event field parsing support (Michael Petlan) [2069073]
- libtraceevent: Add __rel_loc relative location attribute support (Michael Petlan) [2069073]
- tools/perf: Stop using bpf_object__find_program_by_title API. (Michael Petlan) [2069073]
- perf: Mute libbpf API deprecations temporarily (Michael Petlan) [2069073]
- tools: fix ARRAY_SIZE defines in tools and selftests hdrs (Michael Petlan) [2069073]
- perf trace: Avoid early exit due to running SIGCHLD handler before it makes sense to (Michael Petlan) [2069073]
- perf top: Fix TUI exit screen refresh race condition (Michael Petlan) [2069073]
- perf pmu: Fix alias events list (Michael Petlan) [2069073]
- perf scripts python: intel-pt-events.py: Fix printing of switch events (Michael Petlan) [2069073]
- perf script: Fix CPU filtering of a script's switch events (Michael Petlan) [2069073]
- perf intel-pt: Fix parsing of VM time correlation arguments (Michael Petlan) [2069073]
- perf expr: Fix return value of ids__new() (Michael Petlan) [2069073]
- perf inject: Fix segfault due to perf_data__fd() without open (Michael Petlan) [2069073]
- perf inject: Fix segfault due to close without open (Michael Petlan) [2069073]
- perf expr: Fix missing check for return value of hashmap__new() (Michael Petlan) [2069073]
- perf python: Fix NULL vs IS_ERR_OR_NULL() checking (Michael Petlan) [2069073]
- perf intel-pt: Fix error timestamp setting on the decoder error path (Michael Petlan) [2069073]
- perf intel-pt: Fix missing 'instruction' events with 'q' option (Michael Petlan) [2069073]
- perf intel-pt: Fix next 'err' value, walking trace (Michael Petlan) [2069073]
- perf intel-pt: Fix state setting when receiving overflow (OVF) packet (Michael Petlan) [2069073]
- perf intel-pt: Fix intel_pt_fup_event() assumptions about setting state type (Michael Petlan) [2069073]
- perf intel-pt: Fix sync state when a PSB (synchronization) packet is found (Michael Petlan) [2069073]
- perf intel-pt: Fix some PGE (packet generation enable/control flow packets) usage (Michael Petlan) [2069073]
- perf tools: Prevent out-of-bounds access to registers (Michael Petlan) [2069073]
- perf bpf_skel: Do not use typedef to avoid error on old clang (Michael Petlan) [2069073]
- perf bpf: Fix building perf with BUILD_BPF_SKEL=1 by default in more distros (Michael Petlan) [2069073]
- perf header: Fix memory leaks when processing feature headers (Michael Petlan) [2069073]
- perf test: Reset shadow counts before loading (Michael Petlan) [2069073]
- perf test: Fix 'Simple expression parser' test on arch without CPU die topology info (Michael Petlan) [2069073]
- tools build: Remove needless libpython-version feature check that breaks test-all fast path (Michael Petlan) [2069073]
- perf tools: Fix SMT detection fast read path (Michael Petlan) [2069073]
- perf inject: Fix itrace space allowed for new attributes (Michael Petlan) [2069073]
- tools: sync uapi/linux/if_link.h header (Michael Petlan) [2069073]
- perf evsel: Fix memory leaks relating to unit (Michael Petlan) [2069073]
- perf report: Fix memory leaks around perf_tip() (Michael Petlan) [2069073]
- perf hist: Fix memory leak of a perf_hpp_fmt (Michael Petlan) [2069073]
- tools build: Fix removal of feature-sync-compare-and-swap feature detection (Michael Petlan) [2069073]
- perf inject: Fix ARM SPE handling (Michael Petlan) [2069073]
- perf test sample-parsing: Fix branch_stack entry endianness check (Michael Petlan) [2069073]
- perf tools: Set COMPAT_NEED_REALLOCARRAY for CONFIG_AUXTRACE=1 (Michael Petlan) [2069073]
- perf tests wp: Remove unused functions on s390 (Michael Petlan) [2069073]
- perf tests: Remove bash constructs from stat_all_pmu.sh (Michael Petlan) [2069073]
- perf tests: Remove bash construct from record+zstd_comp_decomp.sh (Michael Petlan) [2069073]
- perf test: Remove bash construct from stat_bpf_counters.sh test (Michael Petlan) [2069073]
- perf bench futex: Fix memory leak of perf_cpu_map__new() (Michael Petlan) [2069073]
- perf tools: Add more weak libbpf functions (Michael Petlan) [2069073]
- perf bpf: Avoid memory leak from perf_env__insert_btf() (Michael Petlan) [2069073]
- perf symbols: Factor out annotation init/exit (Michael Petlan) [2069073]
- perf symbols: Bit pack to save a byte (Michael Petlan) [2069073]
- perf symbols: Add documentation to 'struct symbol' (Michael Petlan) [2069073]
- perf test bpf: Use ARRAY_CHECK() instead of ad-hoc equivalent, addressing array_size.cocci warning (Michael Petlan) [2069073]
- perf arm-spe: Support hardware-based PID tracing (Michael Petlan) [2069073]
- perf arm-spe: Save context ID in record (Michael Petlan) [2069073]
- perf arm-spe: Update --switch-events docs in 'perf record' (Michael Petlan) [2069073]
- perf arm-spe: Track task context switch for cpu-mode events (Michael Petlan) [2069073]
- perf design.txt: Synchronize the definition of enum perf_hw_id with code (Michael Petlan) [2069073]
- perf arm-spe: Print size using consistent format (Michael Petlan) [2069073]
- perf cs-etm: Print size using consistent format (Michael Petlan) [2069073]
- perf arm-spe: Snapshot mode test (Michael Petlan) [2069073]
- perf arm-spe: Implement find_snapshot callback (Michael Petlan) [2069073]
- perf arm-spe: Add snapshot mode support (Michael Petlan) [2069073]
- perf expr: Add source_count for aggregating events (Michael Petlan) [2069073]
- perf expr: Move ID handling to its own function (Michael Petlan) [2069073]
- perf expr: Add metric literals for topology. (Michael Petlan) [2069073]
- perf expr: Add literal values starting with # (Michael Petlan) [2069073]
- perf cputopo: Match thread_siblings to topology ABI name (Michael Petlan) [2069073]
- perf cputopo: Match die_siblings to topology ABI name (Michael Petlan) [2069073]
- perf cputopo: Update to use pakage_cpus (Michael Petlan) [2069073]
- perf test: Add expr test for events with hyphens (Michael Petlan) [2069073]
- perf test: Remove skip_if_fail (Michael Petlan) [2069073]
- perf test: Remove is_supported function (Michael Petlan) [2069073]
- perf test: TSC test, remove is_supported use (Michael Petlan) [2069073]
- perf test: BP tests, remove is_supported use (Michael Petlan) [2069073]
- perf test: Remove non test case style support. (Michael Petlan) [2069073]
- perf test: Convert time to tsc test to test case. (Michael Petlan) [2069073]
- perf test: bp tests use test case (Michael Petlan) [2069073]
- perf test: Remove now unused subtest helpers (Michael Petlan) [2069073]
- perf test: Convert llvm tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert bpf tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert clang tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert watch point tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert pmu event tests to test cases. (Michael Petlan) [2069073]
- perf test: Convert pfm tests to use test cases. (Michael Petlan) [2069073]
- perf test: Add skip reason to test case. (Michael Petlan) [2069073]
- perf test: Add test case struct. (Michael Petlan) [2069073]
- perf test: Add helper functions for abstraction. (Michael Petlan) [2069073]
- perf test: Rename struct test to test_suite (Michael Petlan) [2069073]
- perf test: Move each test suite struct to its test (Michael Petlan) [2069073]
- perf test: Make each test/suite its own struct. (Michael Petlan) [2069073]
- perf test: Use macro for "suite" definitions (Michael Petlan) [2069073]
- perf test: Use macro for "suite" declarations (Michael Petlan) [2069073]
- perf beauty: Add socket level scnprintf that handles ARCH specific SOL_SOCKET (Michael Petlan) [2069073]
- perf trace: Beautify the 'level' argument of setsockopt (Michael Petlan) [2069073]
- perf trace: Beautify the 'level' argument of getsockopt (Michael Petlan) [2069073]
- perf beauty socket: Add generator for socket level (SOL_*) string table (Michael Petlan) [2069073]
- perf beauty socket: Sort the ipproto array entries (Michael Petlan) [2069073]
- perf beauty socket: Rename 'regex'  to 'ipproto_regex' (Michael Petlan) [2069073]
- perf beauty socket: Prep to receive more input header files (Michael Petlan) [2069073]
- perf beauty socket: Rename header_dir to uapi_header_dir (Michael Petlan) [2069073]
- perf beauty: Rename socket_ipproto.sh to socket.sh to hold more socket table generators (Michael Petlan) [2069073]
- perf beauty: Make all sockaddr files use a common naming scheme (Michael Petlan) [2069073]
- Add 'tools/perf/libbpf/' to ignored files (Michael Petlan) [2069073]
- perf build: Install libbpf headers locally when building (Michael Petlan) [2069073]
- perf MANIFEST: Add bpftool files to allow building with BUILD_BPF_SKEL=1 (Michael Petlan) [2069073]
- perf metric: Fix memory leaks (Michael Petlan) [2069073]
- perf parse-event: Add init and exit to parse_event_error (Michael Petlan) [2069073]
- perf parse-events: Rename parse_events_error functions (Michael Petlan) [2069073]
- perf stat: Fix memory leak on error path (Michael Petlan) [2069073]
- perf tools: Use __BYTE_ORDER__ (Michael Petlan) [2069073]
- perf inject: Add vmlinux and ignore-vmlinux arguments (Michael Petlan) [2069073]
- perf tools: Check vmlinux/kallsyms arguments in all tools (Michael Petlan) [2069073]
- perf tools: Refactor out kernel symbol argument sanity checking (Michael Petlan) [2069073]
- perf symbols: Ignore $a/$d symbols for ARM modules (Michael Petlan) [2069073]
- perf evsel: Don't set exclude_guest by default (Michael Petlan) [2069073]
- perf evsel: Fix missing exclude_{host,guest} setting (Michael Petlan) [2069073]
- perf bpf: Add missing free to bpf_event__print_bpf_prog_info() (Michael Petlan) [2069073]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2069073]
- perf clang: Fixes for more recent LLVM/clang (Michael Petlan) [2069073]
- perf bpf: Pull in bpf_program__get_prog_info_linear() (Michael Petlan) [2069073]
- perf test sample-parsing: Add endian test for struct branch_flags (Michael Petlan) [2069073]
- perf evsel: Add bitfield_swap() to handle branch_stack endian issue (Michael Petlan) [2069073]
- perf script: Support instruction latency (Michael Petlan) [2069073]
- perf script: Show binary offsets for userspace addr (Michael Petlan) [2069073]
- perf bench futex: Call the futex syscall from a function (Michael Petlan) [2069073]
- perf intel-pt: Support itrace d+o option to direct debug log to stdout (Michael Petlan) [2069073]
- perf auxtrace: Add itrace d+o option to direct debug log to stdout (Michael Petlan) [2069073]
- perf dlfilter: Add dlfilter-show-cycles (Michael Petlan) [2069073]
- perf intel-pt: Support itrace A option to approximate IPC (Michael Petlan) [2069073]
- perf auxtrace: Add itrace A option to approximate IPC (Michael Petlan) [2069073]
- perf auxtrace: Add missing Z option to ITRACE_HELP (Michael Petlan) [2069073]
- tools build: Drop needless slang include path in test-all (Michael Petlan) [2069073]
- perf tests: Improve temp file cleanup in test_arm_coresight.sh (Michael Petlan) [2069073]
- perf tests: Fix trace+probe_vfs_getname.sh /tmp cleanup (Michael Petlan) [2069073]
- perf test: Fix record+script_probe_vfs_getname.sh /tmp cleanup (Michael Petlan) [2069073]
- perf jevents: Fix some would-be warnings (Michael Petlan) [2069073]
- perf dso: Fix /proc/kcore access on 32 bit systems (Michael Petlan) [2069073]
- perf list: Display hybrid PMU events with cpu type (Michael Petlan) [2069073]
- perf session: Introduce reader EOF function (Michael Petlan) [2069073]
- perf session: Introduce reader return codes (Michael Petlan) [2069073]
- perf session: Move the event read code to a separate function (Michael Petlan) [2069073]
- perf session: Move unmap code to reader__mmap (Michael Petlan) [2069073]
- perf session: Move reader map code to a separate function (Michael Petlan) [2069073]
- perf session: Move init/release code to separate functions (Michael Petlan) [2069073]
- perf session: Introduce decompressor in reader object (Michael Petlan) [2069073]
- perf session: Move all state items to reader object (Michael Petlan) [2069073]
- perf intel-pt: Add support for PERF_RECORD_AUX_OUTPUT_HW_ID (Michael Petlan) [2069073]
- perf tools: Add support for PERF_RECORD_AUX_OUTPUT_HW_ID (Michael Petlan) [2069073]
- perf vendor events arm64: Categorise the Neoverse V1 counters (Michael Petlan) [2069073]
- perf vendor events arm64: Add new armv8 pmu events (Michael Petlan) [2069073]
- perf vendor events: Syntax corrections in Neoverse N1 json (Michael Petlan) [2069073]
- perf metric: Allow modifiers on metrics (Michael Petlan) [2069073]
- perf parse-events: Identify broken modifiers (Michael Petlan) [2069073]
- perf metric: Switch fprintf() to pr_err() (Michael Petlan) [2069073]
- perf metrics: Modify setup and deduplication (Michael Petlan) [2069073]
- perf expr: Add subset_of_ids() utility (Michael Petlan) [2069073]
- perf metric: Encode and use metric-id as qualifier (Michael Petlan) [2069073]
- perf parse-events: Allow config on kernel PMU events (Michael Petlan) [2069073]
- perf parse-events: Add new "metric-id" term (Michael Petlan) [2069073]
- perf parse-events: Add const to evsel name (Michael Petlan) [2069073]
- perf metric: Simplify metric_refs calculation (Michael Petlan) [2069073]
- perf metric: Document the internal 'struct metric' (Michael Petlan) [2069073]
- perf metric: Comment data structures (Michael Petlan) [2069073]
- perf metric: Modify resolution and recursion check (Michael Petlan) [2069073]
- perf metric: Only add a referenced metric once (Michael Petlan) [2069073]
- perf metric: Add metric new() and free() methods (Michael Petlan) [2069073]
- perf metric: Add documentation and rename a variable. (Michael Petlan) [2069073]
- perf metric: Move runtime value to the expr context (Michael Petlan) [2069073]
- perf pmu: Make pmu_event tables const. (Michael Petlan) [2069073]
- perf pmu: Make pmu_sys_event_tables const. (Michael Petlan) [2069073]
- perf pmu: Add const to pmu_events_map. (Michael Petlan) [2069073]
- tools lib: Adopt list_sort() from the kernel sources (Michael Petlan) [2069073]
- perf kmem: Improve man page for record options (Michael Petlan) [2069073]
- perf tools: Enable strict JSON parsing (Michael Petlan) [2069073]
- perf tools: Make the JSON parser more conformant when in strict mode (Michael Petlan) [2069073]
- perf vendor-events: Fix all remaining invalid JSON files (Michael Petlan) [2069073]
- perf daemon: Remove duplicate sys/file.h include (Michael Petlan) [2069073]
- perf test evlist-open-close: Use inline func to convert timeval to usec (Michael Petlan) [2069073]
- perf mmap: Introduce mmap_cpu_mask__duplicate() (Michael Petlan) [2069073]
- libperf cpumap: Use binary search in perf_cpu_map__idx() as array are sorted (Michael Petlan) [2069073]
- perf srcline: Use long-running addr2line per DSO (Michael Petlan) [2069073]
- perf metric: Avoid events for an 'if' constant result (Michael Petlan) [2069073]
- perf metric: Don't compute unused events (Michael Petlan) [2069073]
- perf expr: Propagate constants for binary operations (Michael Petlan) [2069073]
- perf expr: Merge find_ids and regular parsing (Michael Petlan) [2069073]
- perf metric: Allow metrics with no events (Michael Petlan) [2069073]
- perf metric: Add utilities to work on ids map. (Michael Petlan) [2069073]
- perf metric: Rename expr__find_other. (Michael Petlan) [2069073]
- perf expr: Move actions to the left. (Michael Petlan) [2069073]
- perf expr: Use macros for operators (Michael Petlan) [2069073]
- perf expr: Separate token declataion from type (Michael Petlan) [2069073]
- perf expr: Remove unused headers and inline d_ratio (Michael Petlan) [2069073]
- perf metric: Use NAN for missing event IDs. (Michael Petlan) [2069073]
- perf metric: Restructure struct expr_parse_ctx. (Michael Petlan) [2069073]
- perf vendor events arm64: Revise hip08 uncore events (Michael Petlan) [2069073]
- perf test: Add pmu-event test for event described as "config=" (Michael Petlan) [2069073]
- perf test: Verify more event members in pmu-events test (Michael Petlan) [2069073]
- perf jevents: Support ConfigCode (Michael Petlan) [2069073]
- perf parse-events: Set numeric term config (Michael Petlan) [2069073]
- perf tools: Add define for libtracefs version (Michael Petlan) [2069073]
- perf tools: Add define for libtraceevent version (Michael Petlan) [2069073]
- perf tools: Enable libtracefs dynamic linking (Michael Petlan) [2069073]
- perf test: Workload test of all PMUs (Michael Petlan) [2069073]
- perf test: Workload test of metric and metricgroups (Michael Petlan) [2069073]
- perf jevents: Add __maybe_unused attribute to unused function arg (Michael Petlan) [2069073]
- perf annotate: Add riscv64 support (Michael Petlan) [2069073]
- perf list: Display pmu prefix for partially supported hybrid cache events (Michael Petlan) [2069073]
- perf parse-events: Remove unnecessary #includes (Michael Petlan) [2069073]
- perf daemon: Avoid msan warnings on send_cmd (Michael Petlan) [2069073]
- perf record: Add --synth option (Michael Petlan) [2069073]
- perf tools: Allow controlling synthesizing PERF_RECORD_ metadata events during record (Michael Petlan) [2069073]
- perf parse-events: Avoid enum forward declaration. (Michael Petlan) [2069073]
- perf bpf: Deprecate bpf_map__resize() in favor of bpf_map_set_max_entries() (Michael Petlan) [2069073]
- perf annotate: Add fusion logic for AMD microarchs (Michael Petlan) [2069073]
- perf: Fix list corruption in perf_cgroup_switch() (Michael Petlan) [2069073]
- perf/x86/intel/pt: Fix crash with stop filters in single-range mode (Michael Petlan) [2069073]
- perf: uapi: Document perf_event_attr::sig_data truncation on 32 bit architectures (Michael Petlan) [2069073]
- perf: Copy perf_event_attr::sig_data on modification (Michael Petlan) [2069073]
- x86/perf: Default set FREEZE_ON_SMI for all (Michael Petlan) [2069073]
- perf/core: Fix cgroup event list management (Michael Petlan) [2069073]
- perf: Always wake the parent event (Michael Petlan) [2069073]
- x86/perf: Avoid warning for Arch LBR without XSAVE (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Add IMC uncore support for ADL (Michael Petlan) [2069073]
- perf/x86/intel/lbr: Add static_branch for LBR INFO flags (Michael Petlan) [2069073]
- perf/x86/intel/lbr: Support LBR format V7 (Michael Petlan) [2069073]
- perf/x86/rapl: fix AMD event handling (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix CAS_COUNT_WRITE issue for ICX (Michael Petlan) [2069073]
- perf/x86/intel: Add a quirk for the calculation of the number of counters on Alder Lake (Michael Petlan) [2069073]
- perf: Fix perf_event_read_local() time (Michael Petlan) [2069073]
- perf: Drop guest callback (un)register stubs (Michael Petlan) [2069073]
- KVM: arm64: Drop perf.c and fold its tiny bits of code into arm.c (Michael Petlan) [2069073]
- KVM: arm64: Hide kvm_arm_pmu_available behind CONFIG_HW_PERF_EVENTS=y (Michael Petlan) [2069073]
- KVM: arm64: Convert to the generic perf callbacks (Michael Petlan) [2069073]
- KVM: x86: Move Intel Processor Trace interrupt handler to vmx.c (Michael Petlan) [2069073]
- KVM: Move x86's perf guest info callbacks to generic KVM (Michael Petlan) [2069073]
- KVM: x86: More precisely identify NMI from guest when handling PMI (Michael Petlan) [2069073]
- KVM: x86: Drop current_vcpu for kvm_running_vcpu + kvm_arch_vcpu variable (Michael Petlan) [2069073]
- perf/core: Use static_call to optimize perf_guest_info_callbacks (Michael Petlan) [2069073]
- perf: Force architectures to opt-in to guest callbacks (Michael Petlan) [2069073]
- perf: Add wrappers for invoking guest callbacks (Michael Petlan) [2069073]
- perf/core: Rework guest callbacks to prepare for static_call support (Michael Petlan) [2069073]
- perf: Drop dead and useless guest "support" from arm, csky, nds32 and riscv (Michael Petlan) [2069073]
- perf: Stop pretending that perf can handle multiple guest callbacks (Michael Petlan) [2069073]
- KVM: x86: Register Processor Trace interrupt hook iff PT enabled in guest (Michael Petlan) [2069073]
- KVM: x86: Register perf callbacks after calling vendor's hardware_setup() (Michael Petlan) [2069073]
- perf: Protect perf_guest_cbs with RCU (Michael Petlan) [2069073]
- x86/events/amd/iommu: Remove redundant assignment to variable shift (Michael Petlan) [2069073]
- perf: Add a counter for number of user access events in context (Michael Petlan) [2069073]
- arm64: perf: Enable PMU counter userspace access for perf event (Michael Petlan) [2069073]
- arm64: perf: Add userspace counter access disable switch (Michael Petlan) [2069073]
- x86: perf: Move RDPMC event flag to a common definition (Michael Petlan) [2069073]
- perf: Ignore sigtrap for tracepoints destined for other tasks (Michael Petlan) [2069073]
- x86/perf: Fix snapshot_branch_stack warning in VM (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix IIO event constraints for Snowridge (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix IIO event constraints for Skylake Server (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix filter_tid mask for CHA events on Skylake Server (Michael Petlan) [2069073]
- perf/core: Avoid put_page() when GUP fails (Michael Petlan) [2069073]
- perf/x86/vlbr: Add c->flags to vlbr event constraints (Michael Petlan) [2069073]
- perf/x86/lbr: Reset LBR_SELECT during vlbr reset (Michael Petlan) [2069073]
- perf: Enable branch record for software events (Michael Petlan) [2069073]
- tracing/perf: Add interrupt_context_level() helper (Michael Petlan) [2069073]
- tracing: Reuse logic from perf's get_recursion_context() (Michael Petlan) [2069073]
- x86/insn: Use get_unaligned() instead of memcpy() (Michael Petlan) [2069073]
- x86/insn, tools/x86: Fix undefined behavior due to potential unaligned accesses (Michael Petlan) [2069073]
- x86/pkru: Remove useless include (Michael Petlan) [2069073]
- perf/x86/intel: Fix ICL/SPR INST_RETIRED.PREC_DIST encodings (Michael Petlan) [2069073]
- perf/core: Allow ftrace for functions in kernel/event/core.c (Michael Petlan) [2069073]
- perf/x86: Add new event for AUX output counter index (Michael Petlan) [2069073]
- perf/x86: Add compiler barrier after updating BTS (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix Intel ICX IIO event constraints (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Fix invalid unit check (Michael Petlan) [2069073]
- perf/x86/intel/uncore: Support extra IMC channel on Ice Lake server (Michael Petlan) [2069073]
- tools/power/x86/intel-speed-select: fix build failure when using -Wl,--as-needed (David Arcari) [2040063]
- Spec fixes for intel-speed-select (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: v1.12 release (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: HFI support (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: OOB daemon mode (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: v1.11 release (David Arcari) [2040063]
- tools/power/x86/intel-speed-select: Update max frequency (David Arcari) [2040063]
- Add BuildRequires libnl3-devel for intel-speed-select (David Arcari) [2040063]
- platform/x86: ISST: Fix possible circular locking dependency detected (David Arcari) [2040063]
- platform/x86: ISST: use semi-colons instead of commas (David Arcari) [2040063]
- platform/x86: intel_speed_select_if: Move to intel sub-directory (David Arcari) [2040063]
- platform/x86: ISST: Fix optimization with use of numa (David Arcari) [2040063]
- redhat/configs enable CONFIG_INTEL_HFI_THERMAL for x86 (David Arcari) [2040063]
- thermal: intel: hfi: INTEL_HFI_THERMAL depends on NET (David Arcari) [2040063]
- thermal: netlink: Fix parameter type of thermal_genl_cpu_capability_event() stub (David Arcari) [2040063]
- thermal: intel: hfi: Notify user space for HFI events (David Arcari) [2040063]
- thermal: netlink: Add a new event to notify CPU capabilities change (David Arcari) [2040063]
- thermal: intel: hfi: Enable notification interrupt (David Arcari) [2040063]
- thermal: intel: hfi: Handle CPU hotplug events (David Arcari) [2040063]
- thermal: intel: hfi: Minimally initialize the Hardware Feedback Interface (David Arcari) [2040063]
- x86/cpu: Add definitions for the Intel Hardware Feedback Interface (David Arcari) [2040063]
- x86/Documentation: Describe the Intel Hardware Feedback Interface (David Arcari) [2040063]

* Tue May 31 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-101.rt21.101.el9]
- [rt] build kernel-rt-5.14.0-101.rt21.101.el9 [2061574]
- redhat: Exclude cpufreq.h from kernel-headers (Patrick Talbert)
- tools: Add kmem_cache_alloc_lru() (Waiman Long) [2085412]
- tools: Move gfp.h and slab.h from radix-tree to lib (Waiman Long) [2085412]
- mm: workingset: replace IRQ-off check with a lockdep assert. (Waiman Long) [2079537]
- mm/memcg: disable migration instead of preemption in drain_all_stock(). (Waiman Long) [2079537]
- mm/memcg: protect memcg_stock with a local_lock_t (Waiman Long) [2079537]
- mm/memcg: opencode the inner part of obj_cgroup_uncharge_pages() in drain_obj_stock() (Waiman Long) [2079537]
- mm/memcg: protect per-CPU counter by disabling preemption on PREEMPT_RT where needed. (Waiman Long) [2079537]
- mm/memcg: disable threshold event handlers on PREEMPT_RT (Waiman Long) [2079537]
- mm/memcg: revert ("mm/memcg: optimize user context object stock access") (Waiman Long) [2079537]
- zsmalloc: replace get_cpu_var with local_lock (Waiman Long) [2079537]
- zsmalloc: replace per zpage lock with pool->migrate_lock (Waiman Long) [2079537]
- zsmalloc: remove zspage isolation for migration (Waiman Long) [2079537]
- zsmalloc: move huge compressed obj from page to zspage (Waiman Long) [2079537]
- zsmalloc: introduce obj_allocated (Waiman Long) [2079537]
- zsmalloc: decouple class actions from zspage works (Waiman Long) [2079537]
- zsmalloc: rename zs_stat_type to class_stat_type (Waiman Long) [2079537]
- zsmalloc: introduce some helper functions (Waiman Long) [2079537]
- memcg: better bounds on the memcg stats updates (Waiman Long) [2079537]
- mm: unexport {,un}lock_page_memcg (Waiman Long) [2079537]
- mm: unexport folio_memcg_{,un}lock (Waiman Long) [2079537]
- zsmalloc: Stop using slab fields in struct page (Waiman Long) [2079537]

* Fri May 27 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-100.rt21.100.el9]
- [rt] build kernel-rt-5.14.0-100.rt21.100.el9 [2061574]
- PCI: vmd: Revert 2565e5b69c44 ("PCI: vmd: Do not disable MSI-X remapping if interrupt remapping is enabled by IOMMU.") (Myron Stowe) [2084146]
- PCI: vmd: Assign VMD IRQ domain before enumeration (Myron Stowe) [2084146]
- KVM: s390: Fix lockdep issue in vm memop (Thomas Huth) [2044357]
- RHEL-only: KVM: selftests: Remove unused modes (Thomas Huth) [2073143]
- KVM: s390: selftests: Add error memop tests (Thomas Huth) [2044357]
- KVM: s390: selftests: Add more copy memop tests (Thomas Huth) [2044357]
- KVM: s390: selftests: Add named stages for memop test (Thomas Huth) [2044357]
- KVM: s390: selftests: Add macro as abstraction for MEM_OP (Thomas Huth) [2044357]
- KVM: s390: selftests: Split memop tests (Thomas Huth) [2044357]
- KVM: s390: Add missing vm MEM_OP size check (Thomas Huth) [2044357]
- KVM: s390: Clarify key argument for MEM_OP in api docs (Thomas Huth) [2044357]
- KVM: s390: Update api documentation for memop ioctl (Thomas Huth) [2044357]
- KVM: s390: Add capability for storage key extension of MEM_OP IOCTL (Thomas Huth) [2044357]
- KVM: s390: Rename existing vcpu memop functions (Thomas Huth) [2044357]
- KVM: s390: Add vm IOCTL for key checked guest absolute memory access (Thomas Huth) [2044357]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Thomas Huth) [2044357]
- KVM: s390: Add optional storage key checking to MEMOP IOCTL (Thomas Huth) [2044357]
- KVM: s390: selftests: Test TEST PROTECTION emulation (Thomas Huth) [2044357]
- KVM: s390: handle_tprot: Honor storage keys (Thomas Huth) [2044357]
- KVM: s390: Honor storage keys when accessing guest memory (Thomas Huth) [2044357]
- s390/uaccess: Add copy_from/to_user_key functions (Thomas Huth) [2044357]
- s390/uaccess: fix compile error (Thomas Huth) [2044357]
- s390/uaccess: introduce bit field for OAC specifier (Thomas Huth) [2044357]
- KVM: s390: gaccess: Cleanup access to guest pages (Thomas Huth) [2044357]
- KVM: s390: gaccess: Refactor access address range check (Thomas Huth) [2044357]
- KVM: s390: gaccess: Refactor gpa and length calculation (Thomas Huth) [2044357]
- redhat/kernel.spec.template: Specify vmlinux.h path when building samples/bpf (Jerome Marchand) [2041365]
- samples: bpf: Don't fail for a missing VMLINUX_BTF when VMLINUX_H is provided (Jerome Marchand) [2041365]
- samples: bpf: Fix xdp_sample_user.o linking with Clang (Jerome Marchand) [2041365]
- cgroup: Fix memory leak caused by missing cgroup_bpf_offline (Jerome Marchand) [2041365]
- bpf: Change value of MAX_TAIL_CALL_CNT from 32 to 33 (Jerome Marchand) [2041365]
- bpf,x86: Simplify computing label offsets (Jerome Marchand) [2041365]
- selftests/bpf: Fix test_core_reloc_mods on big-endian machines (Jerome Marchand) [2041365]
- bpf, doc: Add heading and example for extensions in cbpf (Jerome Marchand) [2041365]
- bpf: Fix a bpf_timer initialization issue (Jerome Marchand) [2041365]
- bpf: Fix crash due to incorrect copy_map_value (Jerome Marchand) [2041365]
- libbpf: Fix compilation warning due to mismatched printf format (Jerome Marchand) [2041365]
- libbpf: Fix signedness bug in btf_dump_array_data() (Jerome Marchand) [2041365]
- bpf: Fix verifier support for validation of async callbacks (Jerome Marchand) [2041365]
- samples: bpf: Fix 'unknown warning group' build warning on Clang (Jerome Marchand) [2041365]
- libbpf: Silence uninitialized warning/error in btf_dump_dump_type_data (Jerome Marchand) [2041365]
- libbpf: update index.rst reference (Jerome Marchand) [2041365]
- bpf: Forbid bpf_ktime_get_coarse_ns and bpf_timer_* in tracing progs (Jerome Marchand) [2041365]
- bpftool: Fix indent in option lists in the documentation (Jerome Marchand) [2041365]
- samples/bpf: Fix incorrect use of strlen in xdp_redirect_cpu (Jerome Marchand) [2041365]
- samples/bpf: Fix application of sizeof to pointer (Jerome Marchand) [2041365]
- samples/bpf: Fix summary per-sec stats in xdp_sample_user (Jerome Marchand) [2041365]
- bpf: Fix inner map state pruning regression. (Jerome Marchand) [2041365]
- libbpf: Fix off-by-one bug in bpf_core_apply_relo() (Jerome Marchand) [2041365]
- bpf/tests: Fix error in tail call limit tests (Jerome Marchand) [2041365]
- bpf: Fix NULL event->prog pointer access in bpf_overflow_handler (Jerome Marchand) [2041365]
- riscv, bpf: Fix potential NULL dereference (Jerome Marchand) [2041365]
- nfp: bpf: relax prog rejection for mtu check through max_pkt_offset (Jerome Marchand) [2041365]
- bpf: Fix potential race in tail call compatibility check (Jerome Marchand) [2041365]
- bpf: Move BPF_MAP_TYPE for INODE_STORAGE and TASK_STORAGE outside of CONFIG_NET (Jerome Marchand) [2041365]
- bpf: Fix error usage of map_fd and fdget() in generic_map_update_batch() (Jerome Marchand) [2041365]
- bpf: Prevent increasing bpf_jit_limit above max (Jerome Marchand) [2041365]
- bpf: Define bpf_jit_alloc_exec_limit for arm64 JIT (Jerome Marchand) [2041365]
- bpf: Define bpf_jit_alloc_exec_limit for riscv JIT (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Fix BPF_SUB when imm == 0x80000000 (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Do not emit zero extend instruction for 64-bit BPF_END (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Fix JMP32_JSET_K (Jerome Marchand) [2041365]
- powerpc/bpf ppc32: Fix ALU32 BPF_ARSH operation (Jerome Marchand) [2041365]
- powerpc/bpf: Emit stf barrier instruction sequences for BPF_NOSPEC (Jerome Marchand) [2041365]
- powerpc/security: Add a helper to query stf_barrier type (Jerome Marchand) [2041365]
- powerpc/bpf: Fix BPF_SUB when imm == 0x80000000 (Jerome Marchand) [2041365]
- powerpc/bpf: Fix BPF_MOD when imm == 1 (Jerome Marchand) [2041365]
- powerpc/bpf: Validate branch ranges (Jerome Marchand) [2041365]
- powerpc/lib: Add helper to check if offset is within conditional branch range (Jerome Marchand) [2041365]
- bpf, s390: Fix potential memory leak about jit_data (Jerome Marchand) [2041365]
- libbpf: Fix memory leak in strset (Jerome Marchand) [2041365]
- libbpf: Fix segfault in light skeleton for objects without BTF (Jerome Marchand) [2041365]
- bpf, arm: Fix register clobbering in div/mod implementation (Jerome Marchand) [2041365]
- samples/bpf: Relicense bpf_insn.h as GPL-2.0-only OR BSD-2-Clause (Jerome Marchand) [2041365]
- samples: bpf: Fix vmlinux.h generation for XDP samples (Jerome Marchand) [2041365]
- bpf, x86: Fix bpf mapping of atomic fetch implementation (Jerome Marchand) [2041365]
- libbpf: Fix segfault in static linker for objects without BTF (Jerome Marchand) [2041365]
- bpf: Exempt CAP_BPF from checks against bpf_jit_limit (Jerome Marchand) [2041365]
- perf bpf: Ignore deprecation warning when using libbpf's btf__get_from_id() (Jerome Marchand) [2041365]
- s390/bpf: Fix optimizing out zero-extensions (Jerome Marchand) [2041365]
- s390/bpf: Fix 64-bit subtraction of the -0x80000000 constant (Jerome Marchand) [2041365]
- s390/bpf: Fix branch shortening during codegen pass (Jerome Marchand) [2041365]
- bpf: Handle return value of BPF_PROG_TYPE_STRUCT_OPS prog (Jerome Marchand) [2041365]
- perf bpf: Provide a weak btf__load_from_kernel_by_id() for older libbpf versions (Jerome Marchand) [2041365]
- perf test: Fix bpf test sample mismatch reporting (Jerome Marchand) [2041365]
- selftests/bpf: Fix build of task_pt_regs test for arm64 (Jerome Marchand) [2041365]
- bpf: Relicense disassembler as GPL-2.0-only OR BSD-2-Clause (Jerome Marchand) [2041365]
- selftests/bpf: Fix potential unreleased lock (Jerome Marchand) [2041365]
- samples: bpf: Fix uninitialized variable in xdp_redirect_cpu (Jerome Marchand) [2041365]
- bpf: Fix bpf-next builds without CONFIG_BPF_EVENTS (Jerome Marchand) [2041365]
- selftests: xsk: Preface options with opt (Jerome Marchand) [2041365]
- selftests: xsk: Make enums lower case (Jerome Marchand) [2041365]
- selftests: xsk: Generate packets from specification (Jerome Marchand) [2041365]
- selftests: xsk: Simplify cleanup of ifobjects (Jerome Marchand) [2041365]
- selftests: xsk: Validate tx stats on tx thread (Jerome Marchand) [2041365]
- selftests: xsk: Disassociate umem size with packets sent (Jerome Marchand) [2041365]
- selftests: xsk: Simplify the retry code (Jerome Marchand) [2041365]
- selftests: xsk: Return correct error codes (Jerome Marchand) [2041365]
- selftests: xsk: Remove unused variables (Jerome Marchand) [2041365]
- selftests: xsk: Remove the num_tx_packets option (Jerome Marchand) [2041365]
- selftests: xsk: Remove color mode (Jerome Marchand) [2041365]
- bpf: selftests: Add bpf_task_pt_regs() selftest (Jerome Marchand) [2041365]
- bpf: Add bpf_task_pt_regs() helper (Jerome Marchand) [2041365]
- bpf: Extend bpf_base_func_proto helpers with bpf_get_current_task_btf() (Jerome Marchand) [2041365]
- bpf: Consolidate task_struct BTF_ID declarations (Jerome Marchand) [2041365]
- bpf: Add BTF_ID_LIST_GLOBAL_SINGLE macro (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map_multi to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map_multi_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_map_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_cpu to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_cpu_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_redirect_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_monitor to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Convert xdp_monitor_kern.o to XDP samples helper (Jerome Marchand) [2041365]
- samples: bpf: Add vmlinux.h generation support (Jerome Marchand) [2041365]
- samples: bpf: Add devmap_xmit tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for devmap_xmit tracepoint (Jerome Marchand) [2041365]
- samples: bpf: Add cpumap tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for cpumap tracepoints (Jerome Marchand) [2041365]
- samples: bpf: Add xdp_exception tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for xdp_exception tracepoint (Jerome Marchand) [2041365]
- samples: bpf: Add redirect tracepoint statistics support (Jerome Marchand) [2041365]
- samples: bpf: Add BPF support for redirect tracepoint (Jerome Marchand) [2041365]
- samples: bpf: Add basic infrastructure for XDP samples (Jerome Marchand) [2041365]
- tools: include: Add ethtool_drvinfo definition to UAPI header (Jerome Marchand) [2041365]
- samples: bpf: Fix a couple of warnings (Jerome Marchand) [2041365]
- bpf: Fix possible out of bound write in narrow load handling (Jerome Marchand) [2041365]
- selftests/bpf: Exit with KSFT_SKIP if no Makefile found (Jerome Marchand) [2041365]
- selftests/bpf: Add missing files required by test_bpftool.sh for installing (Jerome Marchand) [2041365]
- selftests/bpf: Add default bpftool built by selftests to PATH (Jerome Marchand) [2041365]
- selftests/bpf: Make test_doc_build.sh work from script directory (Jerome Marchand) [2041365]
- selftests/bpf: Reduce flakyness in timer_mim (Jerome Marchand) [2041365]
- bpf: Migrate cgroup_bpf to internal cgroup_bpf_attach_type enum (Jerome Marchand) [2041365]
- bpf: Use kvmalloc for map keys in syscalls (Jerome Marchand) [2041365]
- bpf: Use kvmalloc for map values in syscall (Jerome Marchand) [2041365]
- bpf: Undo off-by-one in interpreter tail call count limit (Jerome Marchand) [2041365]
- libbpf: Rename libbpf documentation index file (Jerome Marchand) [2041365]
- bpf: Remove redundant initialization of variable allow (Jerome Marchand) [2041365]
- selftests/bpf: Fix flaky send_signal test (Jerome Marchand) [2041365]
- selftests/bpf: Replace CHECK with ASSERT_* macros in send_signal.c (Jerome Marchand) [2041365]
- selftests/bpf: Support glob matching for test selector. (Jerome Marchand) [2041365]
- selftests/bpf: Also print test name in subtest status message (Jerome Marchand) [2041365]
- selftests/bpf: Correctly display subtest skip status (Jerome Marchand) [2041365]
- selftests/bpf: Skip loading bpf_testmod when using -l to list tests. (Jerome Marchand) [2041365]
- selftests/bpf: Add exponential backoff to map_delete_retriable in test_maps (Jerome Marchand) [2041365]
- selftests/bpf: Add exponential backoff to map_update_retriable in test_maps (Jerome Marchand) [2041365]
- selftests/bpf: Test btf__load_vmlinux_btf/btf__load_module_btf APIs (Jerome Marchand) [2041365]
- bpf: Reconfigure libbpf docs to remove unversioned API (Jerome Marchand) [2041365]
- selftests/bpf: Add ref_ctr_offset selftests (Jerome Marchand) [2041365]
- libbpf: Add uprobe ref counter offset support for USDT semaphores (Jerome Marchand) [2041365]
- selftests/bpf: Add bpf_cookie selftests for high-level APIs (Jerome Marchand) [2041365]
- Bselftests/bpf: Extract uprobe-related helpers into trace_helpers.{c,h} (Jerome Marchand) [2041365]
- selftests/bpf: Test low-level perf BPF link API (Jerome Marchand) [2041365]
- libbpf: Add bpf_cookie to perf_event, kprobe, uprobe, and tp attach APIs (Jerome Marchand) [2041365]
- libbpf: Add bpf_cookie support to bpf_link_create() API (Jerome Marchand) [2041365]
- libbpf: Use BPF perf link when supported by kernel (Jerome Marchand) [2041365]
- libbpf: Remove unused bpf_link's destroy operation, but add dealloc (Jerome Marchand) [2041365]
- libbpf: Re-build libbpf.so when libbpf.map changes (Jerome Marchand) [2041365]
- bpf: Add bpf_get_attach_cookie() BPF helper to access bpf_cookie value (Jerome Marchand) [2041365]
- bpf: Allow to specify user-provided bpf_cookie for BPF perf links (Jerome Marchand) [2041365]
- bpf: Implement minimal BPF perf link (Jerome Marchand) [2041365]
- bpf: Refactor perf_event_set_bpf_prog() to use struct bpf_prog input (Jerome Marchand) [2041365]
- bpf: Refactor BPF_PROG_RUN_ARRAY family of macros into functions (Jerome Marchand) [2041365]
- bpf: Refactor BPF_PROG_RUN into a function (Jerome Marchand) [2041365]
- bpf, tests: Fix spelling mistake "shoft" -> "shift" (Jerome Marchand) [2041365]
- selftest/bpf: Extend the bpf_snprintf() test for "%%c". (Jerome Marchand) [2041365]
- bpf: Support "%%c" in bpf_bprintf_prepare(). (Jerome Marchand) [2041365]
- samples/bpf: Define MAX_ENTRIES instead of a magic number in offwaketime (Jerome Marchand) [2041365]
- selftests/bpf: Verify bpf_get_netns_cookie in BPF_PROG_TYPE_CGROUP_SOCKOPT (Jerome Marchand) [2041365]
- bpf: Allow bpf_get_netns_cookie in BPF_PROG_TYPE_CGROUP_SOCKOPT (Jerome Marchand) [2041365]
- selftests/bpf: Fix test_core_autosize on big-endian machines (Jerome Marchand) [2041365]
- libbpf: Support weak typed ksyms. (Jerome Marchand) [2041365]
- bpf, tests: Add tail call test suite (Jerome Marchand) [2041365]
- bpf, tests: Add tests for BPF_CMPXCHG (Jerome Marchand) [2041365]
- bpf, tests: Add tests for atomic operations (Jerome Marchand) [2041365]
- bpf, tests: Add test for 32-bit context pointer argument passing (Jerome Marchand) [2041365]
- bpf, tests: Add branch conversion JIT test (Jerome Marchand) [2041365]
- bpf, tests: Add word-order tests for load/store of double words (Jerome Marchand) [2041365]
- bpf, tests: Add tests for ALU operations implemented with function calls (Jerome Marchand) [2041365]
- bpf, tests: Add more ALU64 BPF_MUL tests (Jerome Marchand) [2041365]
- bpf, tests: Add more BPF_LSH/RSH/ARSH tests for ALU64 (Jerome Marchand) [2041365]
- bpf, tests: Add more ALU32 tests for BPF_LSH/RSH/ARSH (Jerome Marchand) [2041365]
- bpf, tests: Add more tests of ALU32 and ALU64 bitwise operations (Jerome Marchand) [2041365]
- bpf, tests: Fix typos in test case descriptions (Jerome Marchand) [2041365]
- bpf, tests: Add BPF_MOV tests for zero and sign extension (Jerome Marchand) [2041365]
- bpf, tests: Add BPF_JMP32 test cases (Jerome Marchand) [2041365]
- samples, bpf: Add an explict comment to handle nested vlan tagging. (Jerome Marchand) [2041365]
- samples/bpf: xdpsock: Remove forward declaration of ip_fast_csum() (Jerome Marchand) [2041365]
- samples/bpf: xdpsock: Make the sample more useful outside the tree (Jerome Marchand) [2041365]
- selftests/bpf: Rename reference_tracking BPF programs (Jerome Marchand) [2041365]
- selftests/bpf: Fix bpf-iter-tcp4 test to print correctly the dest IP (Jerome Marchand) [2041365]
- selftests/bpf: Move netcnt test under test_progs (Jerome Marchand) [2041365]
- bpf, samples: Add missing mprog-disable to xdp_redirect_cpu's optstring (Jerome Marchand) [2041365]
- bpf: Fix off-by-one in tail call count limiting (Jerome Marchand) [2041365]
- tools: bpftool: Complete metrics list in "bpftool prog profile" doc (Jerome Marchand) [2041365]
- tools: bpftool: Document and add bash completion for -L, -B options (Jerome Marchand) [2041365]
- selftests/bpf: Update bpftool's consistency script for checking options (Jerome Marchand) [2041365]
- tools: bpftool: Update and synchronise option list in doc and help msg (Jerome Marchand) [2041365]
- tools: bpftool: Complete and synchronise attach or map types (Jerome Marchand) [2041365]
- selftests/bpf: Check consistency between bpftool source, doc, completion (Jerome Marchand) [2041365]
- tools: bpftool: Slightly ease bash completion updates (Jerome Marchand) [2041365]
- libbpf: Add btf__load_vmlinux_btf/btf__load_module_btf (Jerome Marchand) [2041365]
- tools: bpftool: Support dumping split BTF by id (Jerome Marchand) [2041365]
- libbpf: Add split BTF support for btf__load_from_kernel_by_id() (Jerome Marchand) [2041365]
- tools: Replace btf__get_from_id() with btf__load_from_kernel_by_id() (Jerome Marchand) [2041365]
- tools: Free BTF objects at various locations (Jerome Marchand) [2041365]
- libbpf: Rename btf__get_from_id() as btf__load_from_kernel_by_id() (Jerome Marchand) [2041365]
- libbpf: Rename btf__load() as btf__load_into_kernel() (Jerome Marchand) [2041365]
- libbpf: Return non-null error on failures in libbpf_find_prog_btf_id() (Jerome Marchand) [2041365]
- bpf: Emit better log message if bpf_iter ctx arg btf_id == 0 (Jerome Marchand) [2041365]
- tools/resolve_btfids: Emit warnings and patch zero id for missing symbols (Jerome Marchand) [2041365]
- bpf: Increase supported cgroup storage value size (Jerome Marchand) [2041365]
- libbpf: Fix race when pinning maps in parallel (Jerome Marchand) [2041365]
- libbpf: Fix comment typo (Jerome Marchand) [2041365]
- samples: bpf: Add the omitted xdp samples to .gitignore (Jerome Marchand) [2041365]
- samples: bpf: Fix tracex7 error raised on the missing argument (Jerome Marchand) [2041365]
- selftests/bpf: Use ping6 only if available in tc_redirect (Jerome Marchand) [2041365]
- libbpf: Split CO-RE logic into relo_core.c. (Jerome Marchand) [2041365]
- libbpf: Move CO-RE types into relo_core.h. (Jerome Marchand) [2041365]
- libbpf: Split bpf_core_apply_relo() into bpf_program independent helper. (Jerome Marchand) [2041365]
- libbpf: Cleanup the layering between CORE and bpf_program. (Jerome Marchand) [2041365]
- bpf/tests: Do not PASS tests without actually testing the result (Jerome Marchand) [2041365]
- bpf/tests: Fix copy-and-paste error in double word test (Jerome Marchand) [2041365]
- selftests/bpf: Document vmtest.sh dependencies (Jerome Marchand) [2041365]
- libbpf: Add bpf_map__pin_path function (Jerome Marchand) [2041365]
- libbpf: Export bpf_program__attach_kprobe_opts function (Jerome Marchand) [2041365]
- libbpf: Allow decimal offset for kprobes (Jerome Marchand) [2041365]
- libbpf: Fix func leak in attach_kprobe (Jerome Marchand) [2041365]
- selftests/bpf: Mute expected invalid map creation error msg (Jerome Marchand) [2041365]
- bpf: Remove redundant intiialization of variable stype (Jerome Marchand) [2041365]
- bpf: Fix pointer cast warning (Jerome Marchand) [2041365]
- libbpf: Propagate errors when retrieving enum value for typed data display (Jerome Marchand) [2041365]
- selftests/bpf: Add __int128-specific tests for typed data dump (Jerome Marchand) [2041365]
- libbpf: Avoid use of __int128 in typed dump display (Jerome Marchand) [2041365]
- selftests, bpf: test_tc_tunnel.sh nc: Cannot use -p and -l (Jerome Marchand) [2041365]
- bpf, selftests: Fix test_maps now that sockmap supports UDP (Jerome Marchand) [2041365]
- selftests/bpf: Check inner map deletion (Jerome Marchand) [2041365]
- libbpf: Fix removal of inner map in bpf_object__create_map (Jerome Marchand) [2041365]
- libbpf: Btf typed dump does not need to allocate dump data (Jerome Marchand) [2041365]
- libbpf: Fix compilation errors on ppc64le for btf dump typed data (Jerome Marchand) [2041365]
- libbpf: Clarify/fix unaligned data issues for btf typed dump (Jerome Marchand) [2041365]
- selftests/bpf: Add dump type data tests to btf dump tests (Jerome Marchand) [2041365]
- selftests/bpf: Add ASSERT_STRNEQ() variant for test_progs (Jerome Marchand) [2041365]
- libbpf: BTF dumper support for typed data (Jerome Marchand) [2041365]
- selftests/bpf: Switch existing selftests to using open_opts for custom BTF (Jerome Marchand) [2041365]
- libbpf: Fix the possible memory leak on error (Jerome Marchand) [2041365]
- libbpf: Introduce 'btf_custom_path' to 'bpf_obj_open_opts' (Jerome Marchand) [2041365]
- bpf: Add ambient BPF runtime context stored in current (Jerome Marchand) [2041365]
- selftests/bpf: Add test for bpf_get_func_ip in kprobe+offset probe (Jerome Marchand) [2041365]
- libbpf: Allow specification of "kprobe/function+offset" (Jerome Marchand) [2041365]
- libbpf: Add bpf_program__attach_kprobe_opts function (Jerome Marchand) [2041365]
- selftests/bpf: Add test for bpf_get_func_ip helper (Jerome Marchand) [2041365]
- bpf: Add bpf_get_func_ip helper for kprobe programs (Jerome Marchand) [2041365]
- bpf: Add bpf_get_func_ip helper for tracing programs (Jerome Marchand) [2041365]
- bpf: Enable BPF_TRAMP_F_IP_ARG for trampolines with call_get_func_ip (Jerome Marchand) [2041365]
- bpf, x86: Store caller's ip in trampoline stack (Jerome Marchand) [2041365]
- selftests/bpf: Add a test with bpf_timer in inner map. (Jerome Marchand) [2041365]
- selftests/bpf: Add bpf_timer test. (Jerome Marchand) [2041365]
- bpf: Teach stack depth check about async callbacks. (Jerome Marchand) [2041365]
- bpf: Implement verifier support for validation of async callbacks. (Jerome Marchand) [2041365]
- bpf: Relax verifier recursion check. (Jerome Marchand) [2041365]
- bpf: Remember BTF of inner maps. (Jerome Marchand) [2041365]
- bpf: Prevent pointer mismatch in bpf_timer_init. (Jerome Marchand) [2041365]
- bpf: Add map side support for bpf timers. (Jerome Marchand) [2041365]
- bpf: Introduce bpf timers. (Jerome Marchand) [2041365]
- bpf: Factor out bpf_spin_lock into helpers. (Jerome Marchand) [2041365]
- bpf: Prepare bpf_prog_put() to be called from irq context. (Jerome Marchand) [2041365]
- selftests/bpf: Remove unused variable in tc_tunnel prog (Jerome Marchand) [2041365]
- bpf: Fix potential memleak and UAF in the verifier. (Jerome Marchand) [2041365]
- bpf: Fix a typo of reuseport map in bpf.h. (Jerome Marchand) [2041365]
- bpf: Sync tools/include/uapi/linux/bpf.h (Jerome Marchand) [2041365]
- libbpf: Fix reuse of pinned map on older kernel (Jerome Marchand) [2041365]
- samples/bpf: xdp_redirect_cpu_user: Cpumap qsize set larger default (Jerome Marchand) [2041365]
- bpf: Tidy xdp attach selftests (Jerome Marchand) [2041365]
- bpf: devmap: Implement devmap prog execution for generic XDP (Jerome Marchand) [2041365]
- bpf: cpumap: Implement generic cpumap (Jerome Marchand) [2041365]
- bitops: Add non-atomic bitops for pointers (Jerome Marchand) [2041365]
- net: core: Split out code to run generic XDP prog (Jerome Marchand) [2041365]
- selftests/bpf: Add test for xdp_md context in BPF_PROG_TEST_RUN (Jerome Marchand) [2041365]
- bpf: Support specifying ingress via xdp_md context in BPF_PROG_TEST_RUN (Jerome Marchand) [2041365]
- bpf: Support input xdp_md context in BPF_PROG_TEST_RUN (Jerome Marchand) [2041365]
- bpf: Add function for XDP meta data length check (Jerome Marchand) [2041365]

* Wed May 25 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-99.rt21.99.el9]
- [rt] build kernel-rt-5.14.0-99.rt21.99.el9 [2061574]
- HID: intel-ish-hid: fix module device-id handling (Tony Camuso) [1921376]
- mod_devicetable: fix kdocs for ishtp_device_id (Tony Camuso) [1921376]
- HID: intel-ish-hid: add support for MODULE_DEVICE_TABLE() (Tony Camuso) [1921376]
- platform/x86: isthp_eclite: only load for matching devices (Tony Camuso) [1921376]
- platform/x86: Add Intel ishtp eclite driver (Tony Camuso) [1921376]
- platform/x86: Add config file for Intel ishtp eclite driver (Tony Camuso) [1921376]
- net: drop_monitor: support drop reason (Hangbin Liu) [2083432]
- drop_monitor: fix data-race in dropmon_net_event / trace_napi_poll_hit (Hangbin Liu) [2083432]
- net: __pskb_pull_tail() & pskb_carve_frag_list() drop_monitor friends (Hangbin Liu) [2083432]
- scsi: megaraid_sas: Remove unnecessary memset (Tomas Henzl) [2049680]
- scsi: megaraid_sas: Target with invalid LUN ID is deleted during scan (Tomas Henzl) [2049680]
- scsi: megasas: Clean up some inconsistent indenting (Tomas Henzl) [2049680]
- scsi: megasas: Stop using the SCSI pointer (Tomas Henzl) [2049680]
- scsi: megaraid_sas: Use irq_set_affinity_and_hint() (Tomas Henzl) [2049680]
- selftests: tc-testing: Increase timeout in tdc config file (Hangbin Liu) [2077385]
- selftests/tc-testing: Fix cannot create /sys/bus/netdevsim/new_device: Directory nonexistent (Hangbin Liu) [2077385]
- selftests/tc-testing: add missing config (Hangbin Liu) [2077385]
- selftests/tc-testing: add exit code (Hangbin Liu) [2077385]
- selftests/tc-testings: Be compatible with newer tc output (Hangbin Liu) [2077385]
- selftests: tls: add missing AES256-GCM cipher (Hangbin Liu) [2077385]
- selftests: tls: add missing AES-CCM cipher tests (Hangbin Liu) [2077385]
- selftests: tls: add tests for handling of bad records (Hangbin Liu) [2077385]
- selftests: tls: factor out cmsg send/receive (Hangbin Liu) [2077385]
- selftests: tls: add helper for creating sock pairs (Hangbin Liu) [2077385]
- selftests: netfilter: remove stray bash debug line (Hangbin Liu) [2077385]
- selftests: netfilter: check stateless nat udp checksum fixup (Hangbin Liu) [2077385]
- selftests: netfilter: fix exit value for nft_concat_range (Hangbin Liu) [2077385]
- selftests: netfilter: disable rp_filter on router (Hangbin Liu) [2077385]
- selftests: forwarding: Add a test for pedit munge SIP and DIP (Hangbin Liu) [2077385]
- selftests: forwarding: Add Q-in-VNI test for IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add a test for VxLAN symmetric routing with IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add a test for VxLAN asymmetric routing with IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add VxLAN tests with a VLAN-aware bridge for IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: Add VxLAN tests with a VLAN-unaware bridge for IPv6 (Hangbin Liu) [2077385]
- selftests: forwarding: vxlan_bridge_1q: Remove unused function (Hangbin Liu) [2077385]
- selftests: net: bridge: Parameterize ageing timeout (Hangbin Liu) [2077385]
- selftests: lib.sh: Add PING_COUNT to allow sending configurable amount of packets (Hangbin Liu) [2077385]
- selftests: net: fix array_size.cocci warning (Hangbin Liu) [2077385]
- selftests: test_vxlan_under_vrf: Fix broken test case (Hangbin Liu) [2077385]
- selftests: net: change fprintf format specifiers (Hangbin Liu) [2077385]
- selftests: pmtu.sh: Kill nettest processes launched in subshell. (Hangbin Liu) [2077385]
- selftests: pmtu.sh: Kill tcpdump processes launched by subshell. (Hangbin Liu) [2077385]
- selftests: fib offload: use sensible tos values (Hangbin Liu) [2077385]
- selftests: rtnetlink: Use more sensible tos values (Hangbin Liu) [2077385]
- selftests: fib rule: Don't echo modified sysctls (Hangbin Liu) [2077385]
- selftests: fib rule: Log test description (Hangbin Liu) [2077385]
- selftests: fib rule: Drop erroneous TABLE variable (Hangbin Liu) [2077385]
- selftests: fib rule: Make 'getmatch' and 'match' local variables (Hangbin Liu) [2077385]
- selftests/net: timestamping: Fix bind_phc check (Hangbin Liu) [2077385]
- kselftests/net: adapt the timeout to the largest runtime (Hangbin Liu) [2077385]
- kselftests/net: list all available tests in usage() (Hangbin Liu) [2077385]
- selftests: net/fcnal-test.sh: add exit code (Hangbin Liu) [2077385]
- selftests: net: remove meaningless help option (Hangbin Liu) [2077385]
- selftests: net: fib_nexthops: add test for group refcount imbalance bug (Hangbin Liu) [2077385]
- selftests/net: expand gro with two machine test (Hangbin Liu) [2077385]
- selftests/net: remove ARRAY_SIZE define from individual tests (Hangbin Liu) [2077385]
- tools: fix ARRAY_SIZE defines in tools and selftests hdrs (Hangbin Liu) [2077385]
- cpuidle: intel_idle: Drop redundant backslash at line end (Steve Best) [2072895]
- intel_idle: add core C6 optimization for SPR (Steve Best) [2072895]
- intel_idle: add 'preferred_cstates' module argument (Steve Best) [2072895]
- intel_idle: add SPR support (Steve Best) [2072895]
- intel_idle: enable interrupts before C1 on Xeons (Steve Best) [2072895]
- cpupower: Add "perf" option to print AMD P-State information (Steve Best) [2059367]
- cpupower: Add function to print AMD P-State performance capabilities (Steve Best) [2059367]
- cpupower: Move print_speed function into misc helper (Steve Best) [2059367]
- cpupower: Enable boost state support for AMD P-State module (Steve Best) [2059367]
- cpupower: Add AMD P-State sysfs definition and access helper (Steve Best) [2059367]
- cpupower: Introduce ACPI CPPC library (Steve Best) [2059367]
- cpupower: Add the function to get the sysfs value from specific table (Steve Best) [2059367]
- cpupower: Initial AMD P-State capability (Steve Best) [2059367]
- cpupower: Add the function to check AMD P-State enabled (Steve Best) [2059367]
- cpupower: Add AMD P-State capability flag (Steve Best) [2059367]
- tools/power/cpupower/{ToDo => TODO}: Rename the todo file (Steve Best) [2059367]
- tools: cpupower: fix typo in cpupower-idle-set(1) manpage (Steve Best) [2059367]
- redhat: support virtio-mem on aarch64 as tech-preview (Gavin Shan) [2044155]
- drivers/virtio: Enable virtio mem for ARM64 (Gavin Shan) [2044155]
- virtio: drop default for virtio-mem (Gavin Shan) [2044155]
- arm64/mm: avoid fixmap race condition when create pud mapping (Gavin Shan) [2044155]
- libceph: fix misleading ceph_osdc_cancel_request() comment (Jeffrey Layton) [2071641]
- libceph: fix potential use-after-free on linger ping and resends (Jeffrey Layton) [2071641]
- ceph: fix setting of xattrs on async created inodes (Jeffrey Layton) [2071641]
- ceph: fix possible NULL pointer dereference for req->r_session (Jeffrey Layton) [2071641]
- ceph: remove incorrect session state check (Jeffrey Layton) [2071641]
- ceph: get snap_rwsem read lock in handle_cap_export for ceph_add_cap (Jeffrey Layton) [2071641]
- libceph: disambiguate cluster/pool full log message (Jeffrey Layton) [2071641]
- ceph: remove reliance on bdi congestion (Jeffrey Layton) [2071641]
- ceph: fix memory leak in ceph_readdir when note_last_dentry returns error (Jeffrey Layton) [2071641]
- ceph: use tracked average r/w/m latencies to display metrics in debugfs (Jeffrey Layton) [2071641]
- ceph: include average/stdev r/w/m latency in mds metrics (Jeffrey Layton) [2071641]
- ceph: track average r/w/m latency (Jeffrey Layton) [2071641]
- ceph: use ktime_to_timespec64() rather than jiffies_to_timespec64() (Jeffrey Layton) [2071641]
- ceph: assign the ci only when the inode isn't NULL (Jeffrey Layton) [2071641]
- ceph: fix inode reference leakage in ceph_get_snapdir() (Jeffrey Layton) [2071641]
- ceph: misc fix for code style and logs (Jeffrey Layton) [2071641]
- ceph: allocate capsnap memory outside of ceph_queue_cap_snap() (Jeffrey Layton) [2071641]
- ceph: do not release the global snaprealm until unmounting (Jeffrey Layton) [2071641]
- ceph: remove incorrect and unused CEPH_INO_DOTDOT macro (Jeffrey Layton) [2071641]
- ceph: eliminate the recursion when rebuilding the snap context (Jeffrey Layton) [2071641]
- ceph: do not update snapshot context when there is no new snapshot (Jeffrey Layton) [2071641]
- ceph: zero the dir_entries memory when allocating it (Jeffrey Layton) [2071641]
- ceph: move to a dedicated slabcache for ceph_cap_snap (Jeffrey Layton) [2071641]
- ceph: add getvxattr op (Jeffrey Layton) [2071641]
- libceph: drop else branches in prepare_read_data{,_cont} (Jeffrey Layton) [2071641]
- ceph: fix comments mentioning i_mutex (Jeffrey Layton) [2071641]
- ceph: fail the request directly if handle_reply gets an ESTALE (Jeffrey Layton) [2071641]
- ceph: wake waiters after failed async create (Jeffrey Layton) [2071641]
- ceph: wait for async create reply before sending any cap messages (Jeffrey Layton) [2071641]
- ceph: eliminate req->r_wait_for_completion from ceph_mds_request (Jeffrey Layton) [2071641]
- ceph: switch netfs read ops to use rreq->inode instead of rreq->mapping->host (Jeffrey Layton) [2071641]
- libceph: optionally use bounce buffer on recv path in crc mode (Jeffrey Layton) [2071641]
- libceph: make recv path in secure mode work the same as send path (Jeffrey Layton) [2071641]
- ceph: set pool_ns in new inode layout for async creates (Jeffrey Layton) [2071641]
- ceph: properly put ceph_string reference after async create attempt (Jeffrey Layton) [2071641]
- ceph: put the requests/sessions when it fails to alloc memory (Jeffrey Layton) [2071641]
- ceph: move CEPH_SUPER_MAGIC definition to magic.h (Jeffrey Layton) [2071641]
- ceph: remove redundant Lsx caps check (Jeffrey Layton) [2071641]
- ceph: add new "nopagecache" option (Jeffrey Layton) [2071641]
- ceph: don't check for quotas on MDS stray dirs (Jeffrey Layton) [2071641]
- ceph: drop send metrics debug message (Jeffrey Layton) [2071641]
- rbd: make const pointer spaces a static const array (Jeffrey Layton) [2071641]
- ceph: Fix incorrect statfs report for small quota (Jeffrey Layton) [2071641]
- ceph: mount syntax module parameter (Jeffrey Layton) [2071641]
- ceph: record updated mon_addr on remount (Jeffrey Layton) [2071641]
- ceph: new device mount syntax (Jeffrey Layton) [2071641]
- libceph: rename parse_fsid() to ceph_parse_fsid() and export (Jeffrey Layton) [2071641]
- libceph: generalize addr/ip parsing based on delimiter (Jeffrey Layton) [2071641]
- ceph: fix up non-directory creation in SGID directories (Jeffrey Layton) [2071641]
- ceph: initialize pathlen variable in reconnect_caps_cb (Jeffrey Layton) [2071641]
- ceph: initialize i_size variable in ceph_sync_read (Jeffrey Layton) [2071641]
- ceph: fix duplicate increment of opened_inodes metric (Jeffrey Layton) [2071641]

* Tue May 24 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-98.rt21.98.el9]
- [rt] build kernel-rt-5.14.0-98.rt21.98.el9 [2061574]
- hv_balloon: rate-limit "Unhandled message" warning (Vitaly Kuznetsov) [2088401]
- scsi: qla2xxx: Fix typos in comments (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.400-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Increase max limit of ql2xnvme_queues (Nilesh Javali) [2046623]
- scsi: qla2xxx: Use correct feature type field during RFF_ID processing (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix stuck session of PRLI reject (Nilesh Javali) [2046623]
- scsi: qla2xxx: Reduce false trigger to login (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix laggy FC remote port session recovery (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix hang due to session stuck (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix N2N inconsistent PLOGI (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix crash during module load unload test (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix missed DMA unmap for NVMe ls requests (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix loss of NVMe namespaces after driver reload test (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix incorrect reporting of task management failure (Nilesh Javali) [2046623]
- scsi: qla2xxx: Use named initializers for q_dev_state (Nilesh Javali) [2046623]
- scsi: qla2xxx: Use named initializers for port_[d]state_str (Nilesh Javali) [2046623]
- scsi: qla2xxx: Stop using the SCSI pointer (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove unused qla_sess_op_cmd_list from scsi_qla_host_t (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add qla2x00_async_done() for async routines (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.300-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Check for firmware dump already collected (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add devids and conditionals for 28xx (Nilesh Javali) [2046623]
- scsi: qla2xxx: Suppress a kernel complaint in qla_create_qpair() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix T10 PI tag escape and IP guard options for 28XX adapters (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix clang warning (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix warning for missing error code (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix device reconnect in loop topology (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add ql2xnvme_queues module param to configure number of NVMe queues (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix wrong FDMI data for 64G adapter (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add retry for exec firmware (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix scheduling while atomic (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix premature hw access after PCI error (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix warning message due to adisc being flushed (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix stuck session in gpdb (Nilesh Javali) [2046623]
- scsi: qla2xxx: Implement ref count for SRB (Nilesh Javali) [2046623]
- scsi: qla2xxx: Refactor asynchronous command initialization (Nilesh Javali) [2046623]
- scsi: qla2xxx: Synchronize rport dev_loss_tmo setting (Nilesh Javali) [2046623]
- scsi: qla2xxx: Format log strings only if needed (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix off by one bug in qla_edif_app_getfcinfo() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix mailbox direction flags in qla2xxx_get_adapter_id() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.200-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix EDIF bsg (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix inconsistent check of db_flags (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Increase ELS payload (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Reduce connection thrash (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Tweak trace message (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Replace list_for_each_safe with list_for_each_entry_safe (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Flush stale events and msgs on session down (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix app start delay (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix app start fail (Nilesh Javali) [2046623]
- scsi: qla2xxx: Turn off target reset during issue_lip (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix gnl list corruption (Nilesh Javali) [2046623]
- scsi: qla2xxx: Relogin during fabric disturbance (Nilesh Javali) [2046623]
- qla2xxx: add ->map_queues support for nvme (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix unmap of already freed sgl (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix a memory leak in an error path of qla2x00_process_els() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Return -ENOMEM if kzalloc() fails (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove a declaration (Nilesh Javali) [2046623]
- scsi: target: qla2xxx: Replace enable attr with ops.enable (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix excessive messages during device logout (Nilesh Javali) [2046623]
- scsi: qla2xxx: Restore initiator in dual mode (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove redundant initialization of pointer req (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.07.100-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix use after free in eh_abort path (Nilesh Javali) [2046623]
- scsi: qla2xxx: Move heartbeat handling from DPC thread to workqueue (Nilesh Javali) [2046623]
- scsi: qla2xxx: Call process_response_queue() in Tx path (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix kernel crash when accessing port_speed sysfs file (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Use link event to wake up app (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix crash in NVMe abort path (Nilesh Javali) [2046623]
- scsi: qla2xxx: Check for firmware capability before creating QPair (Nilesh Javali) [2046623]
- scsi: qla2xxx: Display 16G only as supported speeds for 3830c card (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add support for mailbox passthru (Nilesh Javali) [2046623]
- scsi: qla2xxx: Open-code qla2xxx_eh_device_reset() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Open-code qla2xxx_eh_target_reset() (Nilesh Javali) [2046623]
- scsi: qla2xxx: Do not call fc_block_scsi_eh() during bus reset (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.06.200-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix returnvar.cocci warnings (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NVMe session down detection (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NVMe retry (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix hang on NVMe command timeouts (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NVMe | FCP personality change (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Do secure PLOGI when auth app is present (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add N2N support for EDIF (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix hang during NVMe session tear down (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix EDIF enable flag (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Reject AUTH ELS on session down (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Fix stale session (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.06.100-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: Sync queue idx with queue_pair_map idx (Nilesh Javali) [2046623]
- scsi: qla2xxx: Changes to support kdump kernel for NVMe BFS (Nilesh Javali) [2046623]
- scsi: qla2xxx: Changes to support kdump kernel (Nilesh Javali) [2046623]
- scsi: qla2xxx: Suppress unnecessary log messages during login (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix NPIV create erroneous error (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix unsafe removal from linked list (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix port type info (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add debug print of 64G link speed (Nilesh Javali) [2046623]
- scsi: qla2xxx: Show OS name and version in FDMI-1 (Nilesh Javali) [2046623]
- scsi: qla2xxx: Changes to support FCP2 Target (Nilesh Javali) [2046623]
- scsi: qla2xxx: Adjust request/response queue size for 28xx (Nilesh Javali) [2046623]
- scsi: qla2xxx: Add host attribute to trigger MPI hang (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove redundant initialization of variable num_cnt (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix use after free in debug code (Nilesh Javali) [2046623]
- scsi: qla2xxx: Fix spelling mistakes "allloc" -> "alloc" (Nilesh Javali) [2046623]
- scsi: qla2xxx: Update version to 10.02.00.107-k (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Increment command and completion counts (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add encryption to I/O path (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add doorbell notification for app (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add detection of secure device (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add authentication pass + fail bsgs (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add key update (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add extraction of auth_els from the wire (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add send, receive, and accept for auth_els (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add getfcinfo and statistic bsgs (Nilesh Javali) [2046623]
- scsi: qla2xxx: edif: Add start + stop bsgs (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove unused variable 'status' (Nilesh Javali) [2046623]
- scsi: qla2xxx: Remove redundant continue statement in a for-loop (Nilesh Javali) [2046623]
- KVM: s390: pv: make use of ultravisor AIV support (Thomas Huth) [2044300]

* Mon May 23 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-97.rt21.97.el9]
- [rt] build kernel-rt-5.14.0-97.rt21.97.el9 [2061574]
- tcp: drop the hash_32() part from the index calculation (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: increase source port perturb table to 2^16 (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: dynamically allocate the perturb table used by source ports (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: add small random increments to the source port (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: resalt the secret every 10 seconds (Guillaume Nault) [2064868] {CVE-2022-1012}
- tcp: use different parts of the port_offset for index and offset (Guillaume Nault) [2064868] {CVE-2022-1012}
- secure_seq: use the 64 bits of the siphash for port offset calculation (Guillaume Nault) [2064868] {CVE-2022-1012}
- esp: limit skb_page_frag_refill use to a single page (Sabrina Dubroca) [2082951] {CVE-2022-27666}
- esp: Fix possible buffer overflow in ESP transformation (Sabrina Dubroca) [2082951] {CVE-2022-27666}
- cifs: truncate the inode and mapping when we simulate fcollapse (Ronnie Sahlberg) [1997367]
- bpf: Fix renaming task_getsecid_subj->current_getsecid_subj. (Ondrej Mosnacek) [2083580]
- selinux: use correct type for context length (Ondrej Mosnacek) [2083580]
- selinux: drop return statement at end of void functions (Ondrej Mosnacek) [2083580]
- selinux: parse contexts for mount options early (Ondrej Mosnacek) [2083580]
- selinux: various sparse fixes (Ondrej Mosnacek) [2083580]
- selinux: try to use preparsed sid before calling parse_sid() (Ondrej Mosnacek) [2083580]
- selinux: Fix selinux_sb_mnt_opts_compat() (Ondrej Mosnacek) [2083580]
- LSM: general protection fault in legacy_parse_param (Ondrej Mosnacek) [2083580]
- selinux: fix a type cast problem in cred_init_security() (Ondrej Mosnacek) [2083580]
- selinux: drop unused macro (Ondrej Mosnacek) [2083580]
- selinux: simplify cred_init_security (Ondrej Mosnacek) [2083580]
- selinux: do not discard const qualifier in cast (Ondrej Mosnacek) [2083580]
- selinux: drop unused parameter of avtab_insert_node (Ondrej Mosnacek) [2083580]
- selinux: drop cast to same type (Ondrej Mosnacek) [2083580]
- selinux: enclose macro arguments in parenthesis (Ondrej Mosnacek) [2083580]
- selinux: declare name parameter of hash_eval const (Ondrej Mosnacek) [2083580]
- selinux: declare path parameters of _genfs_sid const (Ondrej Mosnacek) [2083580]
- selinux: check return value of sel_make_avc_files (Ondrej Mosnacek) [2083580]
- selinux: access superblock_security_struct in LSM blob way (Ondrej Mosnacek) [2083580]
- selinux: fix misuse of mutex_is_locked() (Ondrej Mosnacek) [2050966 2083580]
- selinux: minor tweaks to selinux_add_opt() (Ondrej Mosnacek) [2083580]
- selinux: fix potential memleak in selinux_add_opt() (Ondrej Mosnacek) [2083580]
- security,selinux: remove security_add_mnt_opt() (Ondrej Mosnacek) [2083580]
- selinux: Use struct_size() helper in kmalloc() (Ondrej Mosnacek) [2083580]
- lsm: security_task_getsecid_subj() -> security_current_getsecid_subj() (Ondrej Mosnacek) [2083580]
- selinux: initialize proto variable in selinux_ip_postroute_compat() (Ondrej Mosnacek) [2083580]
- selinux: fix sleeping function called from invalid context (Ondrej Mosnacek) [2083580]
- selinux: fix a sock regression in selinux_ip_postroute_compat() (Ondrej Mosnacek) [2083580]
- LSM: Avoid warnings about potentially unused hook variables (Ondrej Mosnacek) [2083580]
- selinux: fix all of the W=1 build warnings (Ondrej Mosnacek) [2083580]
- selinux: make better use of the nf_hook_state passed to the NF hooks (Ondrej Mosnacek) [2083580]
- selinux: fix race condition when computing ocontext SIDs (Ondrej Mosnacek) [2083580]
- selinux: remove unneeded ipv6 hook wrappers (Ondrej Mosnacek) [2083580]
- security: remove unneeded subdir-$(CONFIG_...) (Ondrej Mosnacek) [2083580]
- selinux: return early for possible NULL audit buffers (Ondrej Mosnacek) [2083580]
- quota: make dquot_quota_sync return errors from ->sync_fs (Lukas Czerner) [2083053]
- redhat: Enable VM kselftests (Nico Pache) [2081818]
- selftests/vm: Makefile: s/TARGETS/VMTARGETS/g (Joel Savitz) [2081818]
- redhat: Enable HMM test to be used by the kselftest test suite (Nico Pache) [2081818]
- redhat: enable CONFIG_TEST_VMALLOC for vm selftests (Nico Pache) [2081818]
- net: bridge: switchdev: check br_vlan_group() return value (Ivan Vecera) [2081601]
- net: bridge: mst: Restrict info size queries to bridge ports (Ivan Vecera) [2081601]
- net: bridge: mst: prevent NULL deref in br_mst_info_size() (Ivan Vecera) [2081601]
- selftests: forwarding: Use same VRF for port and VLAN upper (Ivan Vecera) [2081601]
- selftests: forwarding: Disable learning before link up (Ivan Vecera) [2081601]
- net: bridge: mst: Add helper to query a port's MST state (Ivan Vecera) [2081601]
- net: bridge: mst: Add helper to check if MST is enabled (Ivan Vecera) [2081601]
- net: bridge: mst: Add helper to map an MSTI to a VID set (Ivan Vecera) [2081601]
- net: bridge: mst: Notify switchdev drivers of MST state changes (Ivan Vecera) [2081601]
- net: bridge: mst: Notify switchdev drivers of VLAN MSTI migrations (Ivan Vecera) [2081601]
- net: bridge: mst: Notify switchdev drivers of MST mode changes (Ivan Vecera) [2081601]
- net: bridge: mst: Support setting and reporting MST port states (Ivan Vecera) [2081601]
- net: bridge: mst: Allow changing a VLAN's MSTI (Ivan Vecera) [2081601]
- net: bridge: mst: Multiple Spanning Tree (MST) mode (Ivan Vecera) [2081601]
- net: switchdev: remove lag_mod_cb from switchdev_handle_fdb_event_to_device (Ivan Vecera) [2081601]
- selftests: forwarding: tests of locked port feature (Ivan Vecera) [2081601]
- net: bridge: Add support for offloading of locked port flag (Ivan Vecera) [2081601]
- net: bridge: Add support for bridge port in locked mode (Ivan Vecera) [2081601]
- net: switchdev: avoid infinite recursion from LAG to bridge with port object handler (Ivan Vecera) [2081601]
- bridge: switch br_net_exit to batch mode (Ivan Vecera) [2081601]
- net: bridge: multicast: notify switchdev driver whenever MC processing gets disabled (Ivan Vecera) [2081601]
- net: switchdev: introduce switchdev_handle_port_obj_{add,del} for foreign interfaces (Ivan Vecera) [2081601]
- net: switchdev: rename switchdev_lower_dev_find to switchdev_lower_dev_find_rcu (Ivan Vecera) [2081601]
- net: bridge: switchdev: replay all VLAN groups (Ivan Vecera) [2081601]
- net: bridge: make nbp_switchdev_unsync_objs() follow reverse order of sync() (Ivan Vecera) [2081601]
- net: bridge: switchdev: differentiate new VLANs from changed ones (Ivan Vecera) [2081601]
- net: bridge: vlan: notify switchdev only when something changed (Ivan Vecera) [2081601]
- net: bridge: vlan: make __vlan_add_flags react only to PVID and UNTAGGED (Ivan Vecera) [2081601]
- net: bridge: vlan: don't notify to switchdev master VLANs without BRENTRY flag (Ivan Vecera) [2081601]
- net: bridge: vlan: check early for lack of BRENTRY flag in br_vlan_add_existing (Ivan Vecera) [2081601]
- net: bridge: vlan: check for errors from __vlan_del in __vlan_flush (Ivan Vecera) [2081601]
- net/switchdev: use struct_size over open coded arithmetic (Ivan Vecera) [2081601]
- net: bridge: vlan: fix memory leak in __allowed_ingress (Ivan Vecera) [2081601]
- net: bridge: vlan: fix single net device option dumping (Ivan Vecera) [2081601]
- net: bridge: Get SIOCGIFBR/SIOCSIFBR ioctl working in compat mode (Ivan Vecera) [2081601]
- bridge: use __set_bit in __br_vlan_set_default_pvid (Ivan Vecera) [2081601]
- net: bridge: Allow base 16 inputs in sysfs (Ivan Vecera) [2081601]
- net/bridge: replace simple_strtoul to kstrtol (Ivan Vecera) [2081601]
- net: bridge: Slightly optimize 'find_portno()' (Ivan Vecera) [2081601]
- net: bridge: switchdev: fix shim definition for br_switchdev_mdb_notify (Ivan Vecera) [2081601]
- net: bridge: switchdev: consistent function naming (Ivan Vecera) [2081601]
- net: bridge: mdb: move all switchdev logic to br_switchdev.c (Ivan Vecera) [2081601]
- net: bridge: split out the switchdev portion of br_mdb_notify (Ivan Vecera) [2081601]
- net: bridge: move br_vlan_replay to br_switchdev.c (Ivan Vecera) [2081601]
- net: bridge: provide shim definition for br_vlan_flags (Ivan Vecera) [2081601]
- net: switchdev: merge switchdev_handle_fdb_{add,del}_to_device (Ivan Vecera) [2081601]
- net: bridge: create a common function for populating switchdev FDB entries (Ivan Vecera) [2081601]
- net: bridge: move br_fdb_replay inside br_switchdev.c (Ivan Vecera) [2081601]
- net: bridge: reduce indentation level in fdb_create (Ivan Vecera) [2081601]
- net: bridge: rename br_fdb_insert to br_fdb_add_local (Ivan Vecera) [2081601]
- net: bridge: rename fdb_insert to fdb_add_local (Ivan Vecera) [2081601]
- net: bridge: remove fdb_insert forward declaration (Ivan Vecera) [2081601]
- net: bridge: remove fdb_notify forward declaration (Ivan Vecera) [2081601]
- scsi: ses: Fix unsigned comparison with less than zero (Tomas Henzl) [2065658]
- scsi: ses: Retry failed Send/Receive Diagnostic commands (Tomas Henzl) [2065658]
- redhat/configs: enable GUP_TEST in debug kernel (Joel Savitz) [2079631]

* Fri May 20 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-96.rt21.96.el9]
- [rt] build kernel-rt-5.14.0-96.rt21.96.el9 [2061574]
- Revert "redhat: disable CONFIG_USB_CHIPIDEA" (Patrick Talbert)
- soc/tegra: Add devm_tegra_core_dev_init_opp_table_common() (Patrick Talbert) [2086164]
- powerps/pseries/dma: Add support for 2M IOMMU page size (Gustavo Walbon) [2036275]
- can: ems_usb: ems_usb_start_xmit(): fix double dev_kfree_skb() in error path (Chris von Recklinghausen) [2080377] {CVE-2022-28390}
- ibmvnic: schedule failover only if vioctl fails (Diego Domingos) [2051283]
- net/ibmvnic: Cleanup workaround doing an EOI after partition migration (Diego Domingos) [2051283]
- vfio/pci: Fix vf_token mechanism when device-specific VF drivers are used (Alex Williamson) [2076304]
- s390/vfio-ap: fix kernel doc and signature of group notifier functions (Alex Williamson) [2076304]
- vfio-pci: Provide reviewers and acceptance criteria for variant drivers (Alex Williamson) [2076304]
- PCI/IOV: Fix wrong kernel-doc identifier (Alex Williamson) [2076304]
- vfio/pci: Expose vfio_pci_core_aer_err_detected() (Alex Williamson) [2076304]
- vfio: Remove migration protocol v1 documentation (Alex Williamson) [2076304]
- vfio: Extend the device migration protocol with RUNNING_P2P (Alex Williamson) [2076304]
- vfio: Define device migration protocol v2 (Alex Williamson) [2076304]
- vfio: Have the core code decode the VFIO_DEVICE_FEATURE ioctl (Alex Williamson) [2076304]
- PCI/IOV: Add pci_iov_get_pf_drvdata() to allow VF reaching the drvdata of a PF (Alex Williamson) [2076304]
- PCI/IOV: Add pci_iov_vf_id() to get VF index (Alex Williamson) [2076304]
- vfio/pci: wake-up devices around reset functions (Alex Williamson) [2076304]
- vfio/pci: fix memory leak during D3hot to D0 transition (Alex Williamson) [2076304]
- vfio/pci: Stub vfio_pci_vga_rw when !CONFIG_VFIO_PCI_VGA (Alex Williamson) [2076304]
- s390/vfio-ap: add s390dbf logging to the vfio_ap_irq_enable function (Alex Williamson) [2076304]
- s390/vfio-ap: add s390dbf logging to the handle_pqap function (Alex Williamson) [2076304]
- s390-vfio-ap: introduces s390 kernel debug feature for vfio_ap device driver (Alex Williamson) [2076304]
- vfio/iommu_type1: replace kfree with kvfree (Alex Williamson) [2076304]
- vfio/pci: Resolve sparse endian warnings in IGD support (Alex Williamson) [2076304]
- s390/vfio-ap: add status attribute to AP queue device's sysfs dir (Alex Williamson) [2076304]
- s390/cio: remove uevent suppress from cio driver (Alex Williamson) [2076304]
- vfio/pci: Fix OpRegion read (Alex Williamson) [2076304]
- vfio: remove all kernel-doc notation (Alex Williamson) [2076304]
- vfio/ccw: Convert to use vfio_register_emulated_iommu_dev() (Alex Williamson) [2076304]
- vfio/ccw: Pass vfio_ccw_private not mdev_device to various functions (Alex Williamson) [2076304]
- vfio/ccw: Use functions for alloc/free of the vfio_ccw_private (Alex Williamson) [2076304]
- vfio/ccw: Remove unneeded GFP_DMA (Alex Williamson) [2076304]
- s390/vfio-ap: s390/crypto: fix all kernel-doc warnings (Alex Williamson) [2076304]
- vfio: Use cdev_device_add() instead of device_create() (Alex Williamson) [2076304]
- vfio: Use a refcount_t instead of a kref in the vfio_group (Alex Williamson) [2076304]
- vfio: Don't leak a group reference if the group already exists (Alex Williamson) [2076304]
- vfio: Do not open code the group list search in vfio_create_group() (Alex Williamson) [2076304]
- vfio: Delete vfio_get/put_group from vfio_iommu_group_notifier() (Alex Williamson) [2076304]
- vfio/pci: Add OpRegion 2.0+ Extended VBT support. (Alex Williamson) [2076304]
- vfio/iommu_type1: remove IS_IOMMU_CAP_DOMAIN_IN_CONTAINER (Alex Williamson) [2076304]
- vfio/iommu_type1: remove the "external" domain (Alex Williamson) [2076304]
- vfio/iommu_type1: initialize pgsize_bitmap in ->open (Alex Williamson) [2076304]
- vfio/spapr_tce: reject mediated devices (Alex Williamson) [2076304]
- vfio: clean up the check for mediated device in vfio_iommu_type1 (Alex Williamson) [2076304]
- RHEL: Kludge mdev iommu_device removal (Alex Williamson) [2076304]
- vfio: move the vfio_iommu_driver_ops interface out of <linux/vfio.h> (Alex Williamson) [2076304]
- vfio: remove unused method from vfio_iommu_driver_ops (Alex Williamson) [2076304]
- vfio: simplify iommu group allocation for mediated devices (Alex Williamson) [2076304]
- vfio: remove the iommudata hack for noiommu groups (Alex Williamson) [2076304]
- vfio: refactor noiommu group creation (Alex Williamson) [2076304]
- vfio: factor out a vfio_group_find_or_alloc helper (Alex Williamson) [2076304]
- vfio: remove the iommudata check in vfio_noiommu_attach_group (Alex Williamson) [2076304]
- vfio: factor out a vfio_iommu_driver_allowed helper (Alex Williamson) [2076304]
- vfio: Move vfio_iommu_group_get() to vfio_register_group_dev() (Alex Williamson) [2076304]
- vfio/fsl-mc: Add per device reset support (Alex Williamson) [2076304]
- bus/fsl-mc: Add generic implementation for open/reset/close commands (Alex Williamson) [2076304]
- vfio/ap_ops: Add missed vfio_uninit_group_dev() (Alex Williamson) [2076304]
- vfio/pci: add missing identifier name in argument of function prototype (Alex Williamson) [2076304]
- vfio/pci: Introduce vfio_pci_core.ko (Alex Williamson) [2076304]
- vfio: Use kconfig if XX/endif blocks instead of repeating 'depends on' (Alex Williamson) [2076304]
- vfio: Use select for eventfd (Alex Williamson) [2076304]
- PCI / VFIO: Add 'override_only' support for VFIO PCI sub system (Alex Williamson) [2076304]
- PCI: Add 'override_only' field to struct pci_device_id (Alex Williamson) [2076304]
- vfio/pci: Move module parameters to vfio_pci.c (Alex Williamson) [2076304]
- vfio/pci: Move igd initialization to vfio_pci.c (Alex Williamson) [2076304]
- vfio/pci: Split the pci_driver code out of vfio_pci_core.c (Alex Williamson) [2076304]
- vfio/pci: Include vfio header in vfio_pci_core.h (Alex Williamson) [2076304]
- vfio/pci: Rename ops functions to fit core namings (Alex Williamson) [2076304]
- vfio/pci: Rename vfio_pci_device to vfio_pci_core_device (Alex Williamson) [2076304]
- vfio/pci: Rename vfio_pci_private.h to vfio_pci_core.h (Alex Williamson) [2076304]
- vfio/pci: Rename vfio_pci.c to vfio_pci_core.c (Alex Williamson) [2076304]
- vfio/ap_ops: Convert to use vfio_register_group_dev() (Alex Williamson) [2076304]
- s390/crypto: fix all kernel-doc warnings in vfio_ap_ops.c (Alex Williamson) [2076304]
- vfio/type1: Fix vfio_find_dma_valid return (Alex Williamson) [2076304]
- vfio-pci/zdev: Remove repeated verbose license text (Alex Williamson) [2076304]
- vfio: platform: reset: Convert to SPDX identifier (Alex Williamson) [2076304]
- vfio: Remove struct vfio_device_ops open/release (Alex Williamson) [2076304]
- vfio/gvt: Fix open/close when multiple device FDs are open (Alex Williamson) [2076304]
- vfio/ap,ccw: Fix open/close when multiple device FDs are open (Alex Williamson) [2076304]
- vfio/mbochs: Fix close when multiple device FDs are open (Alex Williamson) [2076304]
- vfio/pci: Reorganize VFIO_DEVICE_PCI_HOT_RESET to use the device set (Alex Williamson) [2076304]
- vfio/pci: Change vfio_pci_try_bus_reset() to use the dev_set (Alex Williamson) [2076304]
- vfio/pci: Move to the device set infrastructure (Alex Williamson) [2076304]
- vfio/platform: Use open_device() instead of open coding a refcnt scheme (Alex Williamson) [2076304]
- vfio/fsl: Move to the device set infrastructure (Alex Williamson) [2076304]
- vfio/samples: Delete useless open/close (Alex Williamson) [2076304]
- vfio: Provide better generic support for open/release vfio_device_ops (Alex Williamson) [2076304]
- vfio: Introduce a vfio_uninit_group_dev() API call (Alex Williamson) [2076304]
- vfio/mbochs: Fix missing error unwind of mbochs_used_mbytes (Alex Williamson) [2076304]
- vfio/samples: Remove module get/put (Alex Williamson) [2076304]
- vfio/mdev: don't warn if ->request is not set (Alex Williamson) [2076304]
- vfio/mdev: turn mdev_init into a subsys_initcall (Alex Williamson) [2076304]
- vfio/pci: Make vfio_pci_regops->rw() return ssize_t (Alex Williamson) [2076304]
- vfio: Use config not menuconfig for VFIO_NOIOMMU (Alex Williamson) [2076304]

* Thu May 19 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-95.rt21.95.el9]
- [rt] build kernel-rt-5.14.0-95.rt21.95.el9 [2061574]
- mm: create a new system state and fix core_kernel_text() (Patrick Talbert) [2076713]
- vmxnet3: Remove useless DMA-32 fallback configuration (Kamal Heib) [2083562]
- vmxnet3: fix minimum vectors alloc issue (Kamal Heib) [2083562]
- net: vmxnet3: remove multiple false checks in vmxnet3_ethtool.c (Kamal Heib) [2083562]
- vmxnet3: do not stop tx queues after netif_device_detach() (Kamal Heib) [2083562]
- openvswitch: Fix setting ipv6 fields causing hw csum failure (Eelco Chaudron) [2076582]

* Wed May 18 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-94.rt21.94.el9]
- [rt] build kernel-rt-5.14.0-94.rt21.94.el9 [2061574]
- md: fix NULL pointer deref with nowait but no mddev->queue (Nigel Croxon) [2079942]
- dm integrity: fix memory corruption when tag_size is less than digest size (Benjamin Marzinski) [2081778]
- selftests: mptcp: functional tests for the userspace PM type (Davide Caratti) [2079368]
- selftests: mptcp: create listeners to receive MPJs (Davide Caratti) [2079368]
- selftests: mptcp: capture netlink events (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_SUBFLOW_DESTROY (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_SUBFLOW_CREATE (Davide Caratti) [2079368]
- mptcp: netlink: allow userspace-driven subflow establishment (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_REMOVE (Davide Caratti) [2079368]
- mptcp: netlink: Add MPTCP_PM_CMD_REMOVE (Davide Caratti) [2079368]
- selftests: mptcp: support MPTCP_PM_CMD_ANNOUNCE (Davide Caratti) [2079368]
- mptcp: netlink: Add MPTCP_PM_CMD_ANNOUNCE (Davide Caratti) [2079368]
- mptcp: netlink: split mptcp_pm_parse_addr into two functions (Davide Caratti) [2079368]
- mptcp: read attributes of addr entries managed by userspace PMs (Davide Caratti) [2079368]
- mptcp: handle local addrs announced by userspace PMs (Davide Caratti) [2079368]
- mptcp: allow ADD_ADDR reissuance by userspace PMs (Davide Caratti) [2079368]
- mptcp: expose server_side attribute in MPTCP netlink events (Davide Caratti) [2079368]
- mptcp: establish subflows from either end of connection (Davide Caratti) [2079368]
- mptcp: reflect remote port (not 0) in ANNOUNCED events (Davide Caratti) [2079368]
- mptcp: store remote id from MP_JOIN SYN/ACK in local ctx (Davide Caratti) [2079368]
- selftests: mptcp: ADD_ADDR echo test with missing userspace daemon (Davide Caratti) [2079368]
- mptcp: bypass in-kernel PM restrictions for non-kernel PMs (Davide Caratti) [2079368]
- selftests: mptcp: Add tests for userspace PM type (Davide Caratti) [2079368]
- mptcp: Add a per-namespace sysctl to set the default path manager type (Davide Caratti) [2079368]
- mptcp: Make kernel path manager check for userspace-managed sockets (Davide Caratti) [2079368]
- mptcp: Bypass kernel PM when userspace PM is enabled (Davide Caratti) [2079368]
- mptcp: Add a member to mptcp_pm_data to track kernel vs userspace mode (Davide Caratti) [2079368]
- mptcp: Remove redundant assignments in path manager init (Davide Caratti) [2079368]
- selftests: mptcp: print extra msg in chk_csum_nr (Davide Caratti) [2079368]
- selftests: mptcp: check MP_FAIL response mibs (Davide Caratti) [2079368]
- mptcp: reset subflow when MP_FAIL doesn't respond (Davide Caratti) [2079368]
- mptcp: add MP_FAIL response support (Davide Caratti) [2079368]
- mptcp: use mptcp_stop_timer (Davide Caratti) [2079368]
- selftests: mptcp: add infinite map testcase (Davide Caratti) [2079368]
- selftests: mptcp: add infinite map mibs check (Davide Caratti) [2079368]
- mptcp: add mib for infinite map sending (Davide Caratti) [2079368]
- mptcp: infinite mapping receiving (Davide Caratti) [2079368]
- mptcp: infinite mapping sending (Davide Caratti) [2079368]
- mptcp: track and update contiguous data status (Davide Caratti) [2079368]
- mptcp: add the fallback check (Davide Caratti) [2079368]
- mptcp: don't send RST for single subflow (Davide Caratti) [2079368]
- selftests/mptcp: add diag listen tests (Davide Caratti) [2079368]
- mptcp: listen diag dump support (Davide Caratti) [2079368]
- mptcp: remove locking in mptcp_diag_fill_info (Davide Caratti) [2079368]
- mptcp: diag: switch to context structure (Davide Caratti) [2079368]
- mptcp: add pm_nl_pernet helpers (Davide Caratti) [2079368]
- mptcp: reset the packet scheduler on PRIO change (Davide Caratti) [2079368]
- mptcp: reset the packet scheduler on incoming MP_PRIO (Davide Caratti) [2079368]
- mptcp: optimize release_cb for the common case (Davide Caratti) [2079368]
- mptcp: send ADD_ADDR echo before create subflows (Davide Caratti) [2079368]
- mptcp: Fix crash due to tcp_tsorted_anchor was initialized before release skb (Davide Caratti) [2079368]
- selftests: mptcp: join: make it shellcheck compliant (Davide Caratti) [2079368]
- selftests: mptcp: join: avoid backquotes (Davide Caratti) [2079368]
- selftests: mptcp: join: clarify local/global vars (Davide Caratti) [2079368]
- selftests: mptcp: join: helper to filter TCP (Davide Caratti) [2079368]
- selftests: mptcp: join: list failure at the end (Davide Caratti) [2079368]
- selftests: mptcp: join: alt. to exec specific tests (Davide Caratti) [2079368]
- selftests: mptcp: join: option to execute specific tests (Davide Caratti) [2079368]
- selftests: mptcp: join: reset failing links (Davide Caratti) [2079368]
- selftests: mptcp: join: define tests groups once (Davide Caratti) [2079368]
- selftests: mptcp: drop msg argument of chk_csum_nr (Davide Caratti) [2079368]
- mptcp: add fullmesh flag check for adding address (Davide Caratti) [2079368]
- selftests: mptcp: add implicit endpoint test case (Davide Caratti) [2079368]
- mptcp: strict local address ID selection (Davide Caratti) [2079368]
- mptcp: introduce implicit endpoints (Davide Caratti) [2079368]
- mptcp: more careful RM_ADDR generation (Davide Caratti) [2079368]
- selftests: mptcp: Rename wait function (Davide Caratti) [2079368]
- selftests: mptcp: join: allow running -cCi (Davide Caratti) [2079368]
- mptcp: use MPTCP_SUBFLOW_NODATA (Davide Caratti) [2079368]
- mptcp: add tracepoint in mptcp_sendmsg_frag (Davide Caratti) [2079368]
- selftests: mptcp: update output info of chk_rm_nr (Davide Caratti) [2079368]
- selftests: mptcp: add more arguments for chk_join_nr (Davide Caratti) [2079368]
- selftests: mptcp: add invert check in check_transfer (Davide Caratti) [2079368]
- selftests: mptcp: add fastclose testcase (Davide Caratti) [2079368]
- selftests: mptcp: reuse linkfail to make given size files (Davide Caratti) [2079368]
- selftests: mptcp: add extra_args in do_transfer (Davide Caratti) [2079368]
- selftests: mptcp: add the MP_RST mibs check (Davide Caratti) [2079368]
- mptcp: add the mibs for MP_RST (Davide Caratti) [2079368]
- selftests: mptcp: add the MP_FASTCLOSE mibs check (Davide Caratti) [2079368]
- mptcp: add the mibs for MP_FASTCLOSE (Davide Caratti) [2079368]
- selftests: mptcp: adjust output alignment for more tests (Davide Caratti) [2079368]
- mptcp: Correctly set DATA_FIN timeout when number of retransmits is large (Davide Caratti) [2079368]
- selftests: mptcp: do complete cleanup at exit (Davide Caratti) [2079368]
- mptcp: accurate SIOCOUTQ for fallback socket (Davide Caratti) [2079368]
- selftests: mptcp: Add the uapi headers include variable (Davide Caratti) [2079368]
- selftests: mptcp: be more conservative with cookie MPJ limits (Davide Caratti) [2079368]
- selftests: mptcp: more robust signal race test (Davide Caratti) [2079368]
- mptcp: add mibs counter for ignored incoming options (Davide Caratti) [2079368]
- mptcp: fix race in incoming ADD_ADDR option processing (Davide Caratti) [2079368]
- mptcp: fix race in overlapping signal events (Davide Caratti) [2079368]
- selftests: mptcp: improve 'fair usage on close' stability (Davide Caratti) [2079368]
- selftests: mptcp: fix diag instability (Davide Caratti) [2079368]
- selftests: mptcp: add csum mib check for mptcp_connect (Davide Caratti) [2079368]
- selftests: mptcp: join: check for tools only if needed (Davide Caratti) [2079368]
- selftests: mptcp: join: create tmp files only if needed (Davide Caratti) [2079368]
- selftests: mptcp: join: remove unused vars (Davide Caratti) [2079368]
- selftests: mptcp: join: exit after usage() (Davide Caratti) [2079368]
- selftests: mptcp: simplify pm_nl_change_endpoint (Davide Caratti) [2079368]
- selftests: mptcp: increase timeout to 20 minutes (Davide Caratti) [2079368]
- mptcp: don't save tcp data_ready and write space callbacks (Davide Caratti) [2079368]
- mptcp: mark ops structures as ro_after_init (Davide Caratti) [2079368]
- mptcp: constify a bunch of of helpers (Davide Caratti) [2079368]
- mptcp: drop port parameter of mptcp_pm_add_addr_signal (Davide Caratti) [2079368]
- mptcp: drop unneeded type casts for hmac (Davide Caratti) [2079368]
- mptcp: drop unused sk in mptcp_get_options (Davide Caratti) [2079368]
- mptcp: mptcp_parse_option is no longer exported (Davide Caratti) [2079368]
- mptcp: add SNDTIMEO setsockopt support (Davide Caratti) [2079368]
- mptcp: netlink: process IPv6 addrs in creating listening sockets (Davide Caratti) [2079368]
- selftests: mptcp: add missing join check (Davide Caratti) [2079368]
- selftests: mptcp: set ip_mptcp in command line (Davide Caratti) [2079368]
- selftests: mptcp: add set_flags tests in pm_netlink.sh (Davide Caratti) [2079368]
- selftests: mptcp: add the id argument for set_flags (Davide Caratti) [2079368]
- selftests: mptcp: add wrapper for setting flags (Davide Caratti) [2079368]
- selftests: mptcp: add wrapper for showing addrs (Davide Caratti) [2079368]
- selftests: mptcp: add ip mptcp wrappers (Davide Caratti) [2079368]
- selftests: mptcp: add backup with port testcase (Davide Caratti) [2079368]
- selftests: mptcp: add the port argument for set_flags (Davide Caratti) [2079368]
- mptcp: allow to use port and non-signal in set_flags (Davide Caratti) [2079368]
- selftests: mptcp: add fullmesh setting tests (Davide Caratti) [2079368]
- selftests: mptcp: set fullmesh flag in pm_nl_ctl (Davide Caratti) [2079368]
- mptcp: set fullmesh flag in pm_netlink (Davide Caratti) [2079368]
- mptcp: print out reset infos of MP_RST (Davide Caratti) [2079368]
- mptcp: clarify when options can be used (Davide Caratti) [2079368]
- mptcp: reduce branching when writing MP_FAIL option (Davide Caratti) [2079368]
- mptcp: move the declarations of ssk and subflow (Davide Caratti) [2079368]
- mptcp: Use struct_group() to avoid cross-field memset() (Davide Caratti) [2079368]
- selftests: mptcp: fix ipv6 routing setup (Davide Caratti) [2079368]
- mptcp: fix removing ids bitmap setting (Davide Caratti) [2079368]
- mptcp: fix msk traversal in mptcp_nl_cmd_set_flags() (Davide Caratti) [2079368]
- mptcp: reuse __mptcp_make_csum in validate_data_csum (Davide Caratti) [2079368]
- mptcp: change the parameter of __mptcp_make_csum (Davide Caratti) [2079368]
- selftests: mptcp: more stable join tests-cases (Davide Caratti) [2079368]
- mptcp: avoid atomic bit manipulation when possible (Davide Caratti) [2079368]
- mptcp: cleanup MPJ subflow list handling (Davide Caratti) [2079368]
- selftests: mptcp: add tests for subflow creation failure (Davide Caratti) [2079368]
- mptcp: do not block subflows creation on errors (Davide Caratti) [2079368]
- mptcp: keep track of local endpoint still available for each msk (Davide Caratti) [2079368]
- mptcp: clean-up MPJ option writing (Davide Caratti) [2079368]
- selftests: mptcp: add disconnect tests (Davide Caratti) [2079368]
- mptcp: implement support for user-space disconnect (Davide Caratti) [2079368]
- mptcp: cleanup accept and poll (Davide Caratti) [2079368]
- mptcp: full disconnect implementation (Davide Caratti) [2079368]
- mptcp: implement fastclose xmit path (Davide Caratti) [2079368]
- mptcp: keep snd_una updated for fallback socket (Davide Caratti) [2079368]
- SO_ZEROCOPY should return -EOPNOTSUPP rather than -ENOTSUPP (Hangbin Liu) [2081920]
- net: fix up skbs delta_truesize in UDP GRO frag_list (Hangbin Liu) [2081920]
- net: preserve skb_end_offset() in skb_unclone_keeptruesize() (Hangbin Liu) [2081920]
- net: add skb_set_end_offset() helper (Hangbin Liu) [2081920]
- net-timestamp: convert sk->sk_tskey to atomic_t (Hangbin Liu) [2081920]
- net: initialize init_net earlier (Hangbin Liu) [2081920]
- net: gro: avoid re-computing truesize twice on recycle (Hangbin Liu) [2081920]
- rtnetlink: make sure to refresh master_dev/m_ops in __rtnl_newlink() (Hangbin Liu) [2081920]
- net-procfs: show net devices bound packet types (Hangbin Liu) [2081920]
- net: fix information leakage in /proc/net/ptype (Hangbin Liu) [2081920]
- netns: add schedule point in ops_exit_list() (Hangbin Liu) [2081920]
- lwtunnel: Validate RTA_ENCAP_TYPE attribute length (Hangbin Liu) [2081920]
- net: Fix double 0x prefix print in SKB dump (Hangbin Liu) [2081920]
- net, neigh: clear whole pneigh_entry at alloc time (Hangbin Liu) [2081920]
- net: annotate data-races on txq->xmit_lock_owner (Hangbin Liu) [2081920]
- net: multicast: calculate csum of looped-back and forwarded packets (Hangbin Liu) [2081920]
- rtnetlink: fix if_nlmsg_stats_size() under estimation (Hangbin Liu) [2081920]
- pktgen: remove unused variable (Hangbin Liu) [2081920]
- netfilter: nft_socket: only do sk lookups when indev is available (Florian Westphal) [2080138]
- netfilter: nf_conntrack_tcp: re-init for syn packets only (Florian Westphal) [2080138]
- netfilter: conntrack: fix udp offload timeout sysctl (Florian Westphal) [2080138]
- netfilter: nft_set_rbtree: overlap detection with element re-addition after deletion (Florian Westphal) [2080138]
- ipvs: correctly print the memory size of ip_vs_conn_tab (Florian Westphal) [2080138]
- netfilter: nft_socket: make cgroup match work in input too (Florian Westphal) [2080138]
- netfilter: nf_conntrack_tcp: preserve liberal flag in tcp options (Florian Westphal) [2080138]
- netfilter: conntrack: Add and use nf_ct_set_auto_assign_helper_warned() (Florian Westphal) [2080138]
- netfilter: flowtable: Fix QinQ and pppoe support for inet table (Florian Westphal) [2080138]
- netfilter: fix use-after-free in __nf_register_net_hook() (Florian Westphal) [2080138]
- netfilter: nf_tables: prefer kfree_rcu(ptr, rcu) variant (Florian Westphal) [2080138]
- netfilter: nf_tables: fix memory leak during stateful obj update (Florian Westphal) [2080138]
- netfilter: nft_synproxy: unregister hooks on init error path (Florian Westphal) [2080138]
- netfilter: xt_socket: fix a typo in socket_mt_destroy() (Florian Westphal) [2080138]
- netfilter: ctnetlink: disable helper autoassign (Florian Westphal) [2080138]
- netfilter: nft_payload: don't allow th access for fragments (Florian Westphal) [2080138]
- netfilter: nf_tables: convert pktinfo->tprot_set to flags field (Florian Westphal) [2080138]
- random: document crng_fast_key_erasure() destination possibility (Prarit Bhargava) [2079030]
- wireguard: device: clear keys on VM fork (Prarit Bhargava) [2079030]
- random: Add hook to override device reads and getrandom(2) (Herbert Xu) [2079030]
- selftests/bpf: fix selftest after random: Urandom_read tracepoint removal (Prarit Bhargava) [2079030]
- arm64: random: implement arch_get_random_int/_long based on RNDR (Prarit Bhargava) [2079030]
- random: use memmove instead of memcpy for remaining 32 bytes (Prarit Bhargava) [2079030]
- random: make random_get_entropy() return an unsigned long (Prarit Bhargava) [2079030]
- random: allow partial reads if later user copies fail (Prarit Bhargava) [2079030]
- random: check for signals every PAGE_SIZE chunk of /dev/[u]random (Prarit Bhargava) [2079030]
- random: check for signal_pending() outside of need_resched() check (Prarit Bhargava) [2079030]
- random: do not allow user to keep crng key around on stack (Prarit Bhargava) [2079030]
- random: opportunistically initialize on /dev/urandom reads (Prarit Bhargava) [2079030]
- random: do not split fast init input in add_hwgenerator_randomness() (Prarit Bhargava) [2079030]
- random: mix build-time latent entropy into pool at init (Prarit Bhargava) [2079030]
- random: re-add removed comment about get_random_{u32,u64} reseeding (Prarit Bhargava) [2079030]
- random: treat bootloader trust toggle the same way as cpu trust toggle (Prarit Bhargava) [2079030]
- random: skip fast_init if hwrng provides large chunk of entropy (Prarit Bhargava) [2079030]
- Revert "random: block in /dev/urandom" (Prarit Bhargava) [2079030]
- random: check for signal and try earlier when generating entropy (Prarit Bhargava) [2079030]
- random: reseed more often immediately after booting (Prarit Bhargava) [2079030]
- random: make consistent usage of crng_ready() (Prarit Bhargava) [2079030]
- random: use SipHash as interrupt entropy accumulator (Prarit Bhargava) [2079030]
- random: provide notifier for VM fork (Prarit Bhargava) [2079030]
- random: replace custom notifier chain with standard one (Prarit Bhargava) [2079030]
- random: do not export add_vmfork_randomness() unless needed (Prarit Bhargava) [2079030]
- random: add mechanism for VM forks to reinitialize crng (Prarit Bhargava) [2079030]
- random: don't let 644 read-only sysctls be written to (Prarit Bhargava) [2079030]
- random: give sysctl_random_min_urandom_seed a more sensible value (Prarit Bhargava) [2079030]
- random: block in /dev/urandom (Prarit Bhargava) [2079030]
- random: do crng pre-init loading in worker rather than irq (Prarit Bhargava) [2079030]
- random: unify cycles_t and jiffies usage and types (Prarit Bhargava) [2079030]
- random: cleanup UUID handling (Prarit Bhargava) [2079030]
- random: only wake up writers after zap if threshold was passed (Prarit Bhargava) [2079030]
- random: round-robin registers as ulong, not u32 (Prarit Bhargava) [2079030]
- random: clear fast pool, crng, and batches in cpuhp bring up (Prarit Bhargava) [2079030]
- random: check for crng_init == 0 in add_device_randomness() (Prarit Bhargava) [2079030]
- random: unify early init crng load accounting (Prarit Bhargava) [2079030]
- random: do not take pool spinlock at boot (Prarit Bhargava) [2079030]
- random: defer fast pool mixing to worker (Prarit Bhargava) [2079030]
- random: rewrite header introductory comment (Prarit Bhargava) [2079030]
- random: group sysctl functions (Prarit Bhargava) [2079030]
- random: group userspace read/write functions (Prarit Bhargava) [2079030]
- random: group entropy collection functions (Prarit Bhargava) [2079030]
- random: group entropy extraction functions (Prarit Bhargava) [2079030]
- random: group crng functions (Prarit Bhargava) [2079030]
- random: group initialization wait functions (Prarit Bhargava) [2079030]
- random: remove whitespace and reorder includes (Prarit Bhargava) [2079030]
- random: introduce drain_entropy() helper to declutter crng_reseed() (Prarit Bhargava) [2079030]
- random: deobfuscate irq u32/u64 contributions (Prarit Bhargava) [2079030]
- random: add proper SPDX header (Prarit Bhargava) [2079030]
- random: remove unused tracepoints (Prarit Bhargava) [2079030]
- random: remove ifdef'd out interrupt bench (Prarit Bhargava) [2079030]
- random: tie batched entropy generation to base_crng generation (Prarit Bhargava) [2079030]
- random: fix locking for crng_init in crng_reseed() (Prarit Bhargava) [2079030]
- random: zero buffer after reading entropy from userspace (Prarit Bhargava) [2079030]
- random: remove outdated INT_MAX >> 6 check in urandom_read() (Prarit Bhargava) [2079030]
- random: make more consistent use of integer types (Prarit Bhargava) [2079030]
- random: use hash function for crng_slow_load() (Prarit Bhargava) [2079030]
- random: use simpler fast key erasure flow on per-cpu keys (Prarit Bhargava) [2079030]
- random: absorb fast pool into input pool after fast load (Prarit Bhargava) [2079030]
- random: do not xor RDRAND when writing into /dev/random (Prarit Bhargava) [2079030]
- random: ensure early RDSEED goes through mixer on init (Prarit Bhargava) [2079030]
- random: inline leaves of rand_initialize() (Prarit Bhargava) [2079030]
- random: get rid of secondary crngs (Prarit Bhargava) [2079030]
- random: use RDSEED instead of RDRAND in entropy extraction (Prarit Bhargava) [2079030]
- random: fix locking in crng_fast_load() (Prarit Bhargava) [2079030]
- random: remove batched entropy locking (Prarit Bhargava) [2079030]
- random: remove use_input_pool parameter from crng_reseed() (Prarit Bhargava) [2079030]
- random: make credit_entropy_bits() always safe (Prarit Bhargava) [2079030]
- random: always wake up entropy writers after extraction (Prarit Bhargava) [2079030]
- random: use linear min-entropy accumulation crediting (Prarit Bhargava) [2079030]
- random: simplify entropy debiting (Prarit Bhargava) [2079030]
- random: use computational hash for entropy extraction (Prarit Bhargava) [2079030]
- random: only call crng_finalize_init() for primary_crng (Prarit Bhargava) [2079030]
- random: access primary_pool directly rather than through pointer (Prarit Bhargava) [2079030]
- random: wake up /dev/random writers after zap (Prarit Bhargava) [2079030]
- random: continually use hwgenerator randomness (Prarit Bhargava) [2079030]
- random: move the random sysctl declarations to its own file (Prarit Bhargava) [2079030]
- sysctl: add a new register_sysctl_init() interface (Prarit Bhargava) [2079030]
- random: simplify arithmetic function flow in account() (Prarit Bhargava) [2079030]
- random: selectively clang-format where it makes sense (Prarit Bhargava) [2079030]
- random: access input_pool_data directly rather than through pointer (Prarit Bhargava) [2079030]
- random: cleanup fractional entropy shift constants (Prarit Bhargava) [2079030]
- random: prepend remaining pool constants with POOL_ (Prarit Bhargava) [2079030]
- random: de-duplicate INPUT_POOL constants (Prarit Bhargava) [2079030]
- random: remove unused OUTPUT_POOL constants (Prarit Bhargava) [2079030]
- random: rather than entropy_store abstraction, use global (Prarit Bhargava) [2079030]
- random: remove unused extract_entropy() reserved argument (Prarit Bhargava) [2079030]
- random: remove incomplete last_data logic (Prarit Bhargava) [2079030]
- random: cleanup integer types (Prarit Bhargava) [2079030]
- random: cleanup poolinfo abstraction (Prarit Bhargava) [2079030]
- random: fix typo in comments (Prarit Bhargava) [2079030]
- random: don't reset crng_init_cnt on urandom_read() (Prarit Bhargava) [2079030]
- random: avoid superfluous call to RDRAND in CRNG extraction (Prarit Bhargava) [2079030]
- random: early initialization of ChaCha constants (Prarit Bhargava) [2079030]
- random: use IS_ENABLED(CONFIG_NUMA) instead of ifdefs (Prarit Bhargava) [2079030]
- random: harmonize "crng init done" messages (Prarit Bhargava) [2079030]
- random: mix bootloader randomness into pool (Prarit Bhargava) [2079030]
- random: do not throw away excess input to crng_fast_load (Prarit Bhargava) [2079030]
- random: do not re-init if crng_reseed completes before primary init (Prarit Bhargava) [2079030]
- random: fix crash on multiple early calls to add_bootloader_randomness() (Prarit Bhargava) [2079030]
- random: do not sign extend bytes for rotation when mixing (Prarit Bhargava) [2079030]
- random: use BLAKE2s instead of SHA1 in extraction (Prarit Bhargava) [2079030]
- random: fix data race on crng init time (Prarit Bhargava) [2079030]
- random: fix data race on crng_node_pool (Prarit Bhargava) [2079030]
- random: remove unused irq_flags argument from add_interrupt_randomness() (Prarit Bhargava) [2079030]
- random: document add_hwgenerator_randomness() with other input functions (Prarit Bhargava) [2079030]
- lib/crypto: add prompts back to crypto libraries (Prarit Bhargava) [2079030]
- lib/crypto: blake2s: avoid indirect calls to compression function for Clang CFI (Prarit Bhargava) [2079030]
- lib/crypto: blake2s: include as built-in (Prarit Bhargava) [2079030]
- crypto: drbg - ignore jitterentropy errors if not in FIPS mode (Prarit Bhargava) [2079030]
- crypto: drbg - reseed 'nopr' drbgs periodically from get_random_bytes() (Prarit Bhargava) [2079030]
- crypto: drbg - make drbg_prepare_hrng() handle jent instantiation errors (Prarit Bhargava) [2079030]
- crypto: drbg - make reseeding from get_random_bytes() synchronous (Prarit Bhargava) [2079030]
- crypto: drbg - move dynamic ->reseed_threshold adjustments to __drbg_seed() (Prarit Bhargava) [2079030]
- crypto: drbg - track whether DRBG was seeded with !rng_is_initialized() (Prarit Bhargava) [2079030]
- crypto: drbg - prepare for more fine-grained tracking of seeding state (Prarit Bhargava) [2079030]
- crypto: drbg - Fix unused value warning in drbg_healthcheck_sanity() (Prarit Bhargava) [2079030]
- Revert "random: Add hook to override device reads and getrandom(2)" (Prarit Bhargava) [2079030]
- locking/lockdep: Iterate lock_classes directly when reading lockdep files (Waiman Long) [2076713]
- lockdep: Correct lock_classes index mapping (Waiman Long) [2076713]
- locking: Enable RT_MUTEXES by default on PREEMPT_RT. (Waiman Long) [2076713]
- locking/local_lock: Make the empty local_lock_*() function a macro. (Waiman Long) [2076713]
- atomics: Fix atomic64_{read_acquire,set_release} fallbacks (Waiman Long) [2076713]
- locking/rwlocks: introduce write_lock_nested (Waiman Long) [2076713]
- locking: Add missing __sched attributes (Waiman Long) [2076713]
- locking/lockdep: Avoid potential access of invalid memory in lock_class (Waiman Long) [2076713]
- locking/rtmutex: Fix incorrect condition in rtmutex_spin_on_owner() (Waiman Long) [2076713]
- locking: Mark racy reads of owner->on_cpu (Waiman Long) [2076713]
- locking: Make owner_on_cpu() into <linux/sched.h> (Waiman Long) [2076713]
- locking: Allow to include asm/spinlock_types.h from linux/spinlock_types_raw.h (Waiman Long) [2076713]
- x86/mm: Include spinlock_t definition in pgtable. (Waiman Long) [2076713]
- lockdep/selftests: Adapt ww-tests for PREEMPT_RT (Waiman Long) [2076713]
- lockdep/selftests: Skip the softirq related tests on PREEMPT_RT (Waiman Long) [2076713]
- lockdep/selftests: Unbalanced migrate_disable() & rcu_read_lock(). (Waiman Long) [2076713]
- lockdep/selftests: Avoid using local_lock_{acquire|release}(). (Waiman Long) [2076713]
- lockdep: Remove softirq accounting on PREEMPT_RT. (Waiman Long) [2076713]
- locking/rtmutex: Add rt_mutex_lock_nest_lock() and rt_mutex_lock_killable(). (Waiman Long) [2076713]
- locking/rtmutex: Squash self-deadlock check for ww_rt_mutex. (Waiman Long) [2076713]
- kallsyms: remove arch specific text and data check (Waiman Long) [2076713]
- mm: make generic arch_is_kernel_initmem_freed() do what it says (Waiman Long) [2076713]
- locking: Remove spin_lock_flags() etc (Waiman Long) [2076713]
- locking/rwsem: Fix comments about reader optimistic lock stealing conditions (Waiman Long) [2076713]
- locking/rwsem: Disable preemption for spinning region (Waiman Long) [2076713]
- locking: Remove rcu_read_{,un}lock() for preempt_{dis,en}able() (Waiman Long) [2076713]
- rtmutex: Wake up the waiters lockless while dropping the read lock. (Waiman Long) [2076713]
- rtmutex: Check explicit for TASK_RTLOCK_WAIT. (Waiman Long) [2076713]
- locking/rwbase: Optimize rwbase_read_trylock (Waiman Long) [2076713]
- lockdep: Let lock_is_held_type() detect recursive read as read (Waiman Long) [2076713]
- locking/lockdep: Cleanup the repeated declaration (Waiman Long) [2076713]
- lockdep: Improve comments in wait-type checks (Waiman Long) [2076713]
- locking/lockdep: Avoid RCU-induced noinstr fail (Waiman Long) [2076713]
- rcu-tasks: Set ->percpu_enqueue_shift to zero upon contention (Waiman Long) [2076713]
- rcu-tasks: Use order_base_2() instead of ilog2() (Waiman Long) [2076713]
- rcutorture: Enable limited callback-flooding tests of SRCU (Waiman Long) [2076713]
- torture: Change KVM environment variable to RCUTORTURE (Waiman Long) [2076713]
- rcu: Add per-CPU rcuc task dumps to RCU CPU stall warnings (Waiman Long) [2076713]
- rcu: Replace cpumask_weight with cpumask_empty where appropriate (Waiman Long) [2076713]
- rcu: Don't deboost before reporting expedited quiescent state (Waiman Long) [2076713]
- torture: Make kvm-find-errors.sh notice missing vmlinux file (Waiman Long) [2076713]
- rcu: Remove __read_mostly annotations from rcu_scheduler_active externs (Waiman Long) [2076713]
- rcu: Uninline multi-use function: finish_rcuwait() (Waiman Long) [2076713]
- rcutorture: make use of the helper function kthread_run_on_cpu() (Waiman Long) [2076713]
- kthread: add the helper function kthread_run_on_cpu() (Waiman Long) [2076713]
- rcu: Update documentation regarding kthread_prio cmdline parameter (Waiman Long) [2076713]
- rcu: Elevate priority of offloaded callback threads (Waiman Long) [2076713]
- rcu: Make priority of grace-period thread consistent (Waiman Long) [2076713]
- rcu: Move kthread_prio bounds-check to a separate function (Waiman Long) [2076713]
- rcu: Mark writes to the rcu_segcblist structure's ->flags field (Waiman Long) [2076713]
- torture: Wake up kthreads after storing task_struct pointer (Waiman Long) [2076713]
- rcutorture: Fix rcu_fwd_mutex deadlock (Waiman Long) [2076713]
- rcu: Create per-cpu rcuc kthreads only when rcutree.use_softirq=0 (Waiman Long) [2076713]
- torture: Print only one summary line per run (Waiman Long) [2076713]
- kasan: Record work creation stack trace with interrupts enabled (Waiman Long) [2076713]
- torture: Make kvm-remote.sh try multiple times to download tarball (Waiman Long) [2076713]
- rcu: Inline __call_rcu() into call_rcu() (Waiman Long) [2076713]
- torture: Compress KCSAN as well as KASAN vmlinux files (Waiman Long) [2076713]
- rcutorture: Add end-of-test check to rcu_torture_fwd_prog() loop (Waiman Long) [2076713]
- rcutorture: Make rcu_fwd_cb_nodelay be a counter (Waiman Long) [2076713]
- rcutorture: Increase visibility of forward-progress hangs (Waiman Long) [2076713]
- torture: Distinguish kthread stopping and being asked to stop (Waiman Long) [2076713]
- rcu: Make rcu_barrier() no longer block CPU-hotplug operations (Waiman Long) [2076713]
- rcu: Rework rcu_barrier() and callback-migration logic (Waiman Long) [2076713]
- rcu: Mark ->expmask access in synchronize_rcu_expedited_wait() (Waiman Long) [2076713]
- rcu: Mark accesses to boost_starttime (Waiman Long) [2076713]
- rcu: Remove unused rcu_state.boost (Waiman Long) [2076713]
- rcu/exp: Fix check for idle context in rcu_exp_handler (Waiman Long) [2076713]
- rcu/nocb: Handle concurrent nocb kthreads creation (Waiman Long) [2076713]
- rcu: Refactor rcu_barrier() empty-list handling (Waiman Long) [2076713]
- rcu: Create and use an rcu_rdp_cpu_online() (Waiman Long) [2076713]
- rcu: Add mutex for rcu boost kthread spawning and affinity setting (Waiman Long) [2076713]
- rcutorture: Print message before invoking ->cb_barrier() (Waiman Long) [2076713]
- torture: Indicate which torture.sh runs' bugs are all KCSAN reports (Waiman Long) [2076713]
- torture: Make kvm.sh summaries note runs having only KCSAN reports (Waiman Long) [2076713]
- torture: Output per-failed-run summary lines from torture.sh (Waiman Long) [2076713]
- torture: Allow four-digit repetition numbers for --configs parameter (Waiman Long) [2076713]
- torture: Drop trailing ^M from console output (Waiman Long) [2076713]
- MAINTAINERS:  Add Frederic and Neeraj to their RCU files (Waiman Long) [2076713]
- rcu: Fix description of kvfree_rcu() (Waiman Long) [2076713]
- scftorture: Warn on individual scf_torture_init() error conditions (Waiman Long) [2076713]
- refscale: Warn on individual ref_scale_init() error conditions (Waiman Long) [2076713]
- torture: Make kvm-remote.sh print size of downloaded tarball (Waiman Long) [2076713]
- torture: Allot 1G of memory for scftorture runs (Waiman Long) [2076713]
- tools/rcu: Add an extract-stall script (Waiman Long) [2076713]
- scftorture: Count reschedule IPIs (Waiman Long) [2076713]
- scftorture: Shut down if nonsensical arguments given (Waiman Long) [2076713]
- scftorture: Allow zero weight to exclude an smp_call_function*() category (Waiman Long) [2076713]
- rcu: Kill rnp->ofl_seq and use only rcu_state.ofl_lock for exclusion (Waiman Long) [2076713]
- scsi: target: tcmu: Fix possible page UAF (Maurizio Lombardi) [2076591]
- scsi: target: pscsi: Remove struct pscsi_plugin_task (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Make cmd_ring_size changeable via configfs (Maurizio Lombardi) [2076591]
- scsi: target: iscsi: Make sure the np under each tpg is unique (Maurizio Lombardi) [2076591]
- scsi: target: configfs: Delete unnecessary checks for NULL (Maurizio Lombardi) [2076591]
- scsi: target: core: Use RCU helpers for INQUIRY t10_alua_tg_pt_gp (Maurizio Lombardi) [2076591]
- scsi: target: core: Remove from tmr_list during LUN unlink (Maurizio Lombardi) [2076591]
- scsi: target: core: Stop using bdevname() (Maurizio Lombardi) [2076591]
- scsi: target: Perform ALUA group changes in one step (Maurizio Lombardi) [2076591]
- scsi: target: Replace lun_tg_pt_gp_lock with rcu in I/O path (Maurizio Lombardi) [2076591]
- scsi: target: Fix alua_tg_pt_gps_count tracking (Maurizio Lombardi) [2076591]
- scsi: target: Fix ordered tag handling (Maurizio Lombardi) [2076591]
- scsi: target: Fix ordered CMD_T_SENT handling (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Allocate zeroed pages for data area (Maurizio Lombardi) [2076591]
- scsi: target: cxgbit: Enable Delayed ACK (Maurizio Lombardi) [2076591]
- scsi: target: cxgbit: Increase max DataSegmentLength (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Use struct_size() helper in kmalloc() (Maurizio Lombardi) [2076591]
- scsi: target: sbp: Replace enable attr with ops.enable (Maurizio Lombardi) [2076591]
- scsi: target: iscsi: Replace tpg enable attr with ops.enable (Maurizio Lombardi) [2076591]
- scsi: target: core: Add common tpg/enable attribute (Maurizio Lombardi) [2076591]
- scsi: target: core: Make logs less verbose (Maurizio Lombardi) [2076591]
- scsi: target: Remove unused function arguments (Maurizio Lombardi) [2076591]
- scsi: target: Fix spelling mistake "CONFLIFT" -> "CONFLICT" (Maurizio Lombardi) [2076591]
- scsi: target: Fix sense key for invalid EXTENDED COPY request (Maurizio Lombardi) [2076591]
- scsi: target: Allows backend drivers to fail with specific sense codes (Maurizio Lombardi) [2076591]
- scsi: target: pscsi: Fix possible null-pointer dereference in pscsi_complete_cmd() (Maurizio Lombardi) [2076591]
- scsi: target: core: Drop unnecessary se_cmd ASC/ASCQ members (Maurizio Lombardi) [2076591]
- scsi: target: sbp: Drop incorrect ASC/ASCQ usage (Maurizio Lombardi) [2076591]
- scsi: target: core: Avoid using lun_tg_pt_gp after unlock (Maurizio Lombardi) [2076591]
- scsi: target: tcmu: Add new feature KEEP_BUF (Maurizio Lombardi) [2076591]
- scsi: target: Remove redundant assignment to variable ret (Maurizio Lombardi) [2076591]
- arch/arm64: Fix topology initialization for core scheduling (Phil Auld) [1992993]
- ntb_hw_amd: Add NTB PCI ID for new gen CPU (Sudheesh Mavila) [2037289]
- s390/unwind: recover kretprobe modified return address in stacktrace (Joe Lawrence) [2069373]
- powerpc: Fix STACKTRACE=n build (Joe Lawrence) [2069373]
- arm64: Mark start_backtrace() notrace and NOKPROBE_SYMBOL (Joe Lawrence) [2069373]
- arm64: Make some stacktrace functions private (Joe Lawrence) [2069373]
- arm64: Make dump_backtrace() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make profile_pc() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make return_address() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make __get_wchan() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Make perf_callchain_kernel() use arch_stack_walk() (Joe Lawrence) [2069373]
- arm64: Mark __switch_to() as __sched (Joe Lawrence) [2069373]
- arm64: Add comment for stack_info::kr_cur (Joe Lawrence) [2069373]
- arch: Make ARCH_STACKWALK independent of STACKTRACE (Joe Lawrence) [2069373]
- arm64: ftrace: use HAVE_FUNCTION_GRAPH_RET_ADDR_PTR (Joe Lawrence) [2069373]
- stacktrace: move filter_irq_stacks() to kernel/stacktrace.c (Joe Lawrence) [2069373]
- kprobes: Add a test case for stacktrace from kretprobe handler (Joe Lawrence) [2069373]
- ARM: Recover kretprobe modified return address in stacktrace (Joe Lawrence) [2069373]
- ARM: kprobes: Make a frame pointer on __kretprobe_trampoline (Joe Lawrence) [2069373]
- ARM: clang: Do not rely on lr register for stacktrace (Joe Lawrence) [2069373]
- arm64: Recover kretprobe modified return address in stacktrace (Joe Lawrence) [2069373]
- arm64: kprobes: Make a frame pointer on __kretprobe_trampoline (Joe Lawrence) [2069373]
- arm64: kprobes: Record frame pointer with kretprobe instance (Joe Lawrence) [2069373]
- x86/unwind: Compile kretprobe fixup code only if CONFIG_KRETPROBES=y (Joe Lawrence) [2069373]
- kprobes: convert tests to kunit (Joe Lawrence) [2069373]
- x86/kprobes: Fixup return address in generic trampoline handler (Joe Lawrence) [2069373]
- tracing: Show kretprobe unknown indicator only for kretprobe_trampoline (Joe Lawrence) [2069373]
- x86/unwind: Recover kretprobe trampoline entry (Joe Lawrence) [2069373]
- x86/kprobes: Push a fake return address at kretprobe_trampoline (Joe Lawrence) [2069373]
- kprobes: Enable stacktrace from pt_regs in kretprobe handler (Joe Lawrence) [2069373]
- arm: kprobes: Make space for instruction pointer on stack (Joe Lawrence) [2069373]
- ia64: Add instruction_pointer_set() API (Joe Lawrence) [2069373]
- ARC: Add instruction_pointer_set() API (Joe Lawrence) [2069373]
- x86/kprobes: Add UNWIND_HINT_FUNC on kretprobe_trampoline() (Joe Lawrence) [2069373]
- objtool: Ignore unwind hints for ignored functions (Joe Lawrence) [2069373]
- objtool: Add frame-pointer-specific function ignore (Joe Lawrence) [2069373]
- kprobes: Add kretprobe_find_ret_addr() for searching return address (Joe Lawrence) [2069373]
- kprobes: treewide: Make it harder to refer kretprobe_trampoline directly (Joe Lawrence) [2069373]
- kprobes: treewide: Remove trampoline_address from kretprobe_trampoline_handler() (Joe Lawrence) [2069373]
- kprobes: treewide: Replace arch_deref_entry_point() with dereference_symbol_descriptor() (Joe Lawrence) [2069373]
- ia64: kprobes: Fix to pass correct trampoline address to the handler (Joe Lawrence) [2069373]
- kprobes: Use bool type for functions which returns boolean value (Joe Lawrence) [2069373]
- kprobes: treewide: Use 'kprobe_opcode_t *' for the code address in get_optimized_kprobe() (Joe Lawrence) [2069373]
- kprobes: Add assertions for required lock (Joe Lawrence) [2069373]
- kprobes: Use IS_ENABLED() instead of kprobes_built_in() (Joe Lawrence) [2069373]
- kprobes: Fix coding style issues (Joe Lawrence) [2069373]
- kprobes: treewide: Cleanup the error messages for kprobes (Joe Lawrence) [2069373]
- kprobes: Make arch_check_ftrace_location static (Joe Lawrence) [2069373]
- csky: ftrace: Drop duplicate implementation of arch_check_ftrace_location() (Joe Lawrence) [2069373]
- kprobe: Simplify prepare_kprobe() by dropping redundant version (Joe Lawrence) [2069373]
- kprobes: Use helper to parse boolean input from userspace (Joe Lawrence) [2069373]
- kprobes: Do not use local variable when creating debugfs file (Joe Lawrence) [2069373]
- Revert "netfilter: conntrack: tag conntracks picked up in local out hook" (Florian Westphal) [2061850]
- Revert "netfilter: nat: force port remap to prevent shadowing well-known ports" (Florian Westphal) [2061850]
- arm64: enable CONFIG_MEMORY_HOTREMOVE (Baoquan He) [2062054]
- Revert "rtmutex: Add a special case for ww-mutex handling." (Fernando Pacheco)
- Revert "random: Make it work on rt" (Fernando Pacheco)

* Tue May 17 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-93.rt21.93.el9]
- [rt] build kernel-rt-5.14.0-93.rt21.93.el9 [2061574]
- NFSv4 only print the label when its queried (Benjamin Coddington) [2057327]
- nvme: expose cntrltype and dctype through sysfs (John Meneghini) [2045550]
- nvme: send uevent on connection up (John Meneghini) [2045550]
- xfs: punch out data fork delalloc blocks on COW writeback failure (Andrey Albershteyn) [2039058]
- macvlan: Fix leaking skb in source mode with nodst option (Davide Caratti) [2079415]
- net: macvlan: fix potential UAF problem for lowerdev (Davide Caratti) [2079415]
- net: ipvtap: fix template string argument of device_create() call (Davide Caratti) [2079415]
- net: macvtap: fix template string argument of device_create() call (Davide Caratti) [2079415]
- redhat/configs: Set CONFIG_EFI_DISABLE_RUNTIME Kconfig symbol (Javier Martinez Canillas) [2070196]
- efi: Allow to enable EFI runtime services by default on RT (Javier Martinez Canillas) [2070196]
- arm64: Restore forced disabling of KPTI on ThunderX (Mark Salter) [2043737]
- devlink: Clarifies max_macs generic devlink param (Petr Oros) [2073210]
- devlink: Add new "event_eq_size" generic device param (Petr Oros) [2073210]
- devlink: Add new "io_eq_size" generic device param (Petr Oros) [2073210]
- devlink: Simplify devlink resources unregister call (Petr Oros) [2073210]
- devlink: Remove misleading internal_flags from health reporter dump (Petr Oros) [2073210]
- devlink: fix flexible_array.cocci warning (Petr Oros) [2073210]
- devlink: Add 'enable_iwarp' generic device param (Petr Oros) [2073210]
- eth: fwnode: remove the addr len from mac helpers (Íñigo Huguet) [2069566]
- eth: fwnode: change the return type of mac address helpers (Íñigo Huguet) [2069566]
- device property: move mac addr helpers to eth.c (Íñigo Huguet) [2069566]

* Mon May 16 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-92.rt21.92.el9]
- [rt] build kernel-rt-5.14.0-92.rt21.92.el9 [2061574]
- RDMA/hfi1: Fix use-after-free bug for mm struct (Kamal Heib) [2056772]
- RDMA/siw: Fix a condition race issue in MPA request processing (Kamal Heib) [2056772]
- RDMA/irdma: Fix possible crash due to NULL netdev in notifier (Kamal Heib) [2056772]
- RDMA/irdma: Reduce iWARP QP destroy time (Kamal Heib) [2056772]
- RDMA/irdma: Flush iWARP QP if modified to ERR from RTR state (Kamal Heib) [2056772]
- RDMA/irdma: Fix deadlock in irdma_cleanup_cm_core() (Kamal Heib) [2056772]
- IB/rdmavt: add lock to call to rvt_error_qp to prevent a race condition (Kamal Heib) [2056772]
- IB/cm: Cancel mad on the DREQ event when the state is MRA_REP_RCVD (Kamal Heib) [2056772]
- RDMA/nldev: Prevent underflow in nldev_stat_set_counter_dynamic_doit() (Kamal Heib) [2056772]
- IB/iser: Fix error flow in case of registration failure (Kamal Heib) [2056772]
- IB/iser: Generalize map/unmap dma tasks (Kamal Heib) [2056772]
- IB/iser: Use iser_fr_desc as registration context (Kamal Heib) [2056772]
- IB/iser: Remove iser_reg_data_sg helper function (Kamal Heib) [2056772]
- RDMA/irdma: Add support for address handle re-use (Kamal Heib) [2056772]
- Revert "RDMA/core: Fix ib_qp_usecnt_dec() called when error" (Kamal Heib) [2056772]
- RDMA/irdma: Prevent some integer underflows (Kamal Heib) [2056772]
- RDMA/core: Fix ib_qp_usecnt_dec() called when error (Kamal Heib) [2056772]
- IB/hfi1: Allow larger MTU without AIP (Kamal Heib) [2056772]
- RDMA/core: Remove unnecessary statements (Kamal Heib) [2056772]
- RDMA/irdma: Remove incorrect masking of PD (Kamal Heib) [2056772]
- RDMA/irdma: Fix Passthrough mode in VM (Kamal Heib) [2056772]
- RDMA/irdma: Fix netdev notifications for vlan's (Kamal Heib) [2056772]
- RDMA/irdma: Make irdma_create_mg_ctx return a void (Kamal Heib) [2056772]
- RDMA/irdma: Move union irdma_sockaddr to header file (Kamal Heib) [2056772]
- RDMA/irdma: Remove the unnecessary variable saddr (Kamal Heib) [2056772]
- RDMA/irdma: Use net_type to check network type (Kamal Heib) [2056772]
- RDMA/irdma: Remove excess error variables (Kamal Heib) [2056772]
- RDMA/irdma: Propagate error codes (Kamal Heib) [2056772]
- RDMA/irdma: Remove enum irdma_status_code (Kamal Heib) [2056772]
- RDMA/ib_srp: Add more documentation (Kamal Heib) [2056772]
- IB/cma: Allow XRC INI QPs to set their local ACK timeout (Kamal Heib) [2056772]
- RDMA/hfi: Replace cpumask_weight with cpumask_empty where appropriate (Kamal Heib) [2056772]
- RDMA/irdma: Refactor DCB bits in prep for DSCP support (Kamal Heib) [2056772]
- RDMA/opa: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/iser: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/ipoib: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/usnic: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/hfi1: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/core: Delete useless module.h include (Kamal Heib) [2056772]
- RDMA/core: Set MR type in ib_reg_user_mr (Kamal Heib) [2056772]
- RDMA/pvrdma: Remove useless DMA-32 fallback configuration (Kamal Heib) [2056772]
- redhat: disable CONFIG_USB_CHIPIDEA (Patrick Talbert)

* Mon May 16 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-91.rt21.91.el9]
- [rt] build kernel-rt-5.14.0-91.rt21.91.el9 [2061574]
- redhat/configs: Enable CONFIG_AMD_HSMP for x86_64 (John Allen) [2072235]
- platform/x86: Add AMD system management interface (John Allen) [2072235]
- scsi: core: Fix sbitmap depth in scsi_realloc_sdev_budget_map() (Ewan D. Milne) [2071832]
- lib/sbitmap: allocate sb->map via kvzalloc_node (Ewan D. Milne) [2071832]
- scsi: core: sd: Add silence_suspend flag to suppress some PM messages (Ewan D. Milne) [2071832]
- scsi: scsi_transport_fc: Fix FPIN Link Integrity statistics counters (Ewan D. Milne) [2071832]
- scsi: core: Put LLD module refcnt after SCSI device is released (Ewan D. Milne) [2071832]
- sd: delay calling free_opal_dev (Ewan D. Milne) [2071832]
- sd: call sd_zbc_release_disk before releasing the scsi_device reference (Ewan D. Milne) [2071832]
- sd: rename the scsi_disk.dev field (Ewan D. Milne) [2071832]
- scsi: don't use disk->private_data to find the scsi_driver (Ewan D. Milne) [2071832]
- scsi: core: Reallocate device's budget map on queue depth change (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_mode_select() interface (Ewan D. Milne) [2071832]
- scsi: sr: Don't use GFP_DMA (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_device_max_queue_depth() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix buffer size of REPORT ZONES command (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Clean up sd_zbc_parse_report() setting of wp (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Simplify zone full condition check (Ewan D. Milne) [2071832]
- scsi: core: Show SCMD_LAST in text form (Ewan D. Milne) [2071832]
- scsi: core: Declare 'scsi_scan_type' static (Ewan D. Milne) [2071832]
- scsi: core: Suppress a kernel-doc warning (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Zero clear zones at reset write pointer (Ewan D. Milne) [2071832]
- scsi: core: sysfs: Fix setting device state to SDEV_RUNNING (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Sanity check block descriptor length in resp_mode_select() (Ewan D. Milne) [2071832]
- scsi: core: Use eh_timeout for START STOP UNIT (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix type in min_t to avoid stack OOB (Ewan D. Milne) [2071832]
- scsi: core: Simplify control flow in scmd_eh_abort_handler() (Ewan D. Milne) [2071832]
- scsi: core: Avoid leaving shost->last_reset with stale value if EH does not run (Ewan D. Milne) [2071832]
- scsi: core: sysfs: Fix hang when device state is set via sysfs (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Don't call kcalloc() if size arg is zero (Ewan D. Milne) [2071832]
- scsi: core: Remove command size deduction from scsi_setup_scsi_cmnd() (Ewan D. Milne) [2071832]
- scsi: scsi_ioctl: Validate command size (Ewan D. Milne) [2071832]
- scsi: sr: Remove duplicate assignment (Ewan D. Milne) [2071832]
- scsi: sd: add concurrent positioning ranges support (Ewan D. Milne) [2071832]
- scsi: scsi_transport_sas: Add 22.5 Gbps link rate definitions (Ewan D. Milne) [2071832]
- scsi: sr: Add error handling support for add_disk() (Ewan D. Milne) [2071832]
- scsi: sd: Add error handling support for add_disk() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix out-of-bound read in resp_report_tgtpgs() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Fix out-of-bound read in resp_readcap16() (Ewan D. Milne) [2071832]
- scsi: sd: Print write through due to no caching mode page as warning (Ewan D. Milne) [2071832]
- scsi: sd: Fix crashes in sd_resume_runtime() (Ewan D. Milne) [2071832]
- scsi: core: pm: Only runtime resume if necessary (Ewan D. Milne) [2071832]
- scsi: sd: Rename sd_resume() into sd_resume_system() (Ewan D. Milne) [2071832]
- scsi: core: pm: Rely on the device driver core for async power management (Ewan D. Milne) [2071832]
- scsi: core: Fix spelling in a source code comment (Ewan D. Milne) [2071832]
- scsi: sd: Fix sd_do_mode_sense() buffer length handling (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_mode_select() buffer length handling (Ewan D. Milne) [2071832]
- scsi: core: Fix scsi_mode_sense() buffer length handling (Ewan D. Milne) [2071832]
- scsi: core: Delete scsi_{get,free}_host_dev() (Ewan D. Milne) [2071832]
- scsi: core: Remove 'current_tag' (Ewan D. Milne) [2071832]
- scsi: acornscsi: Remove tagged queuing vestiges (Ewan D. Milne) [2071832]
- scsi: fas216: Kill scmd->tag (Ewan D. Milne) [2071832]
- scsi: core: Remove include <scsi/scsi_host.h> from scsi_cmnd.h (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Support disks with more than 2**32 logical blocks (Ewan D. Milne) [2071832]
- scsi: sd: Make sd_spinup_disk() less noisy (Ewan D. Milne) [2071832]
- scsi: sr: Fix spelling mistake "does'nt" -> "doesn't" (Ewan D. Milne) [2071832]
- scsi: sd_zbc: Ensure buffer size is aligned to SECTOR_SIZE (Ewan D. Milne) [2071832]
- scsi: sd: Free scsi_disk device via put_device() (Ewan D. Milne) [2071832]
- scsi: sd: Do not exit sd_spinup_disk() quietly (Ewan D. Milne) [2071832]
- scsi: core: Remove scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: ibmvfc: Stop using scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: fnic: Stop setting scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: fnic: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: wd719: Stop using scsi_cmnd.tag (Ewan D. Milne) [2071832]
- scsi: core: Add helper to return number of logical blocks in a request (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: scsi_transport_spi: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: scsi_transport_fc: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: sr: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: sd: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: core: Use scsi_cmd_to_rq() instead of scsi_cmnd.request (Ewan D. Milne) [2071832]
- scsi: core: Introduce the scsi_cmd_to_rq() function (Ewan D. Milne) [2071832]
- scsi: core: Add BLIST_IGN_MEDIA_CHANGE for Ultra HS-SD/MMC USB card readers (Ewan D. Milne) [2071832]
- scsi: sd: REQUEST SENSE for BLIST_IGN_MEDIA_CHANGE devices in runtime_resume() (Ewan D. Milne) [2071832]
- scsi: core: Add new flag BLIST_IGN_MEDIA_CHANGE (Ewan D. Milne) [2071832]
- scsi: core: Make scsi_get_lba() return the LBA (Ewan D. Milne) [2071832]
- scsi: core: Introduce scsi_get_sector() (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Improve RDPROTECT/WRPROTECT handling (Ewan D. Milne) [2071832]
- scsi: scsi_debug: Remove dump_sector() (Ewan D. Milne) [2071832]
- scsi: core: Add scsi_prot_ref_tag() helper (Ewan D. Milne) [2071832]
- genirq/affinity: Consider that CPUs on nodes can be unbalanced (Ming Lei) [2074315]
- Revert "ata: ahci: mvebu: Make SATA PHY optional for Armada 3720" (Tomas Henzl) [2042790]
- ata: pata_pxa: Use platform_get_irq() to get the interrupt (Tomas Henzl) [2042790]
- ata: Drop commas after OF match table sentinels (Tomas Henzl) [2042790]
- ata: ahci: Rename board_ahci_mobile (Tomas Henzl) [2042790]
- ata: pata_hpt37x: merge transfer mode setting methods (Tomas Henzl) [2042790]
- ata: libata-sff: use *switch* statement in ata_sff_dev_classify() (Tomas Henzl) [2042790]
- ata: add/use ata_taskfile::{error|status} fields (Tomas Henzl) [2042790]
- ata: Kconfig: fix sata gemini compile test condition (Tomas Henzl) [2042790]
- ata: libata-scsi: use *switch* statements to check SCSI command codes (Tomas Henzl) [2042790]
- ata: libata-sff: refactor ata_sff_altstatus() (Tomas Henzl) [2042790]
- ata: libata-sff: refactor ata_sff_set_devctl() (Tomas Henzl) [2042790]
- ata: libata-sff: make ata_resources_present() return 'bool' (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: disable fast interrupts in prereset() method (Tomas Henzl) [2042790]
- ata: pata_hpt37x: disable fast interrupts in prereset() method (Tomas Henzl) [2042790]
- ata: pata_hpt366: disable fast interrupts in prereset() method (Tomas Henzl) [2042790]
- ata: pata_mpc52xx: use GFP_KERNEL (Tomas Henzl) [2042790]
- ata: sata_rcar: drop unused #define's (Tomas Henzl) [2042790]
- ata: pata_hpt366: check channel enable bits (Tomas Henzl) [2042790]
- ata: sata_rcar: make sata_rcar_ata_devchk() return 'bool' (Tomas Henzl) [2042790]
- ata: pata_samsung_cf: make pata_s3c_devchk() return 'bool' (Tomas Henzl) [2042790]
- ata: libata-sff: make ata_devchk() return 'bool' (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: drop unused 'struct hpt_chip' (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: drop unused HPT_PCI_FAST (Tomas Henzl) [2042790]
- ata: pata_artop: use *switch* in atp8xx_fixup() (Tomas Henzl) [2042790]
- ata: pata_artop: use *switch* in artop_init_one() (Tomas Henzl) [2042790]
- pata_hpt3x2n: fix writing to wrong register in hpt3x2n_bmdma_stop() (Tomas Henzl) [2042790]
- pata_hpt3x2n: check channel enable bits (Tomas Henzl) [2042790]
- ata: libata: make ata_host_suspend() *void* (Tomas Henzl) [2042790]
- ata: libata: ata_{sff|std}_prereset() always return 0 (Tomas Henzl) [2042790]
- ata: ahci: Skip 200 ms debounce delay for Marvell 88SE9235 (Tomas Henzl) [2042790]
- ata: libata-acpi: kill ata_acpi_on_suspend() (Tomas Henzl) [2042790]
- ata: libata-scsi: Simplify scsi_XX_lba_len() (Tomas Henzl) [2042790]
- ata: libata-scsi: Simplify ata_scsi_mode_select_xlat() (Tomas Henzl) [2042790]
- ata: libata-scsi: Cleanup ata_get_xlat_func() (Tomas Henzl) [2042790]
- ata: pata_pdc202xx_old: make static read-only array pio_timing const (Tomas Henzl) [2042790]
- ata: pata_atiixp: make static read-only arrays const (Tomas Henzl) [2042790]
- ata: pata_platform: Make use of platform_get_mem_or_io() (Tomas Henzl) [2042790]
- ata: pata_hpt37x: disable primary channel on HPT371 (Tomas Henzl) [2042790]
- ata: pata_hpt37x: fix PCI clock detection (Tomas Henzl) [2042790]
- ata: libata-core: Disable TRIM on M88V29 (Tomas Henzl) [2042790]
- ata: sata_fsl: fix sscanf() and sysfs_emit() format strings (Tomas Henzl) [2042790]
- ata: libata-core: Fix ata_dev_config_cpr() (Tomas Henzl) [2042790]
- ata: libata-core: Introduce ATA_HORKAGE_NO_LOG_DIR horkage (Tomas Henzl) [2042790]
- ata: pata_platform: Fix a NULL pointer dereference in __pata_platform_probe() (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: fix call to trace_ata_bmdma_stop() (Tomas Henzl) [2042790]
- ata: pata_ali: remove redundant return statement (Tomas Henzl) [2042790]
- ata: ahci: Add support for AMD A85 FCH (Hudson D4) (Tomas Henzl) [2042790]
- ata: libata: Rename link flag ATA_LFLAG_NO_DB_DELAY (Tomas Henzl) [2042790]
- ata: libata-scsi: simplify __ata_scsi_queuecmd() (Tomas Henzl) [2042790]
- ata: pata_of_platform: Use platform_get_irq_optional() to get the interrupt (Tomas Henzl) [2042790]
- ata: pata_samsung_cf: add compile test support (Tomas Henzl) [2042790]
- ata: pata_pxa: add compile test support (Tomas Henzl) [2042790]
- ata: pata_imx: add compile test support (Tomas Henzl) [2042790]
- ata: pata_ftide010: add compile test support (Tomas Henzl) [2042790]
- ata: pata_cs5535: add compile test support (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: remove redundant val variable (Tomas Henzl) [2042790]
- ata: fix read_id() ata port operation interface (Tomas Henzl) [2042790]
- ata: ahci_xgene: use correct type for port mmio address (Tomas Henzl) [2042790]
- ata: sata_fsl: fix cmdhdr_tbl_entry and prde struct definitions (Tomas Henzl) [2042790]
- ata: sata_fsl: fix scsi host initialization (Tomas Henzl) [2042790]
- ata: pata_bk3710: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_seattle: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_xgene: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_tegra: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_sunxi: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_mvebu: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_mtk: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_dm816: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_da850: add compile test support (Tomas Henzl) [2042790]
- ata: ahci_brcm: add compile test support (Tomas Henzl) [2042790]
- ata: sata_fsl: add compile test support (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Remove debug compile options (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: remove 'check_status' argument (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: drop DEBUG_NCQ (Tomas Henzl) [2042790]
- ata: libata-scsi: rework ata_dump_status to avoid using pr_cont() (Tomas Henzl) [2042790]
- ata: pata_hpt366: convert pr_warn() calls (Tomas Henzl) [2042790]
- ata: sata_gemini: convert pr_err() calls (Tomas Henzl) [2042790]
- ata: pata_hpt3x2n: convert pr_XXX() calls (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: Replace pr_XXX() calls with structured logging (Tomas Henzl) [2042790]
- ata: pata_hpt37x: convert pr_XXX() calls (Tomas Henzl) [2042790]
- ata: sata_mv: convert remaining printk() to structured logging (Tomas Henzl) [2042790]
- ata: sata_sx4: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_sil680: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_serverworks: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_rz1000: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_marvell: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_it821x: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cypress: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cs5536: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cs5520: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cmd64x: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_cmd640: convert printk() calls (Tomas Henzl) [2042790]
- ata: pata_atp867x: convert printk() calls (Tomas Henzl) [2042790]
- ata: libata: remove debug compilation switches (Tomas Henzl) [2042790]
- ata: libata: remove 'new' ata message handling (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_drv() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_info() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_probe() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_warn() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_malloc() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_ctl() (Tomas Henzl) [2042790]
- ata: libata: drop ata_msg_error() and ata_msg_intr() (Tomas Henzl) [2042790]
- ata: sata_sx4: add module parameter 'dimm_test' (Tomas Henzl) [2042790]
- ata: sata_sx4: Drop pointless VPRINTK() calls and convert the remaining ones (Tomas Henzl) [2042790]
- ata: sata_sil: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_fsl: convert VPRINTK() calls to ata_port_dbg() (Tomas Henzl) [2042790]
- ata: sata_nv: drop pointless VPRINTK() calls and convert remaining ones (Tomas Henzl) [2042790]
- ata: sata_mv: Drop pointless VPRINTK() call and convert the remaining one (Tomas Henzl) [2042790]
- ata: sata_inic162x: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_rcar: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_qstor: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: sata_promise: Drop pointless VPRINTK() calls and convert the remaining ones (Tomas Henzl) [2042790]
- ata: pata_via: Drop pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: Drop pointless VPRINTK() calls and convert the remaining one (Tomas Henzl) [2042790]
- ata: pdc_adma: Drop pointless VPRINTK() calls and remove disabled NCQ debugging (Tomas Henzl) [2042790]
- ata: ahci: Drop pointless VPRINTK() calls and convert the remaining ones (Tomas Henzl) [2042790]
- ata: libata: remove pointless VPRINTK() calls (Tomas Henzl) [2042790]
- ata: pata_pdc2027x: Replace PDPRINTK() with standard ata logging (Tomas Henzl) [2042790]
- ata: sata_qstor: replace DPRINTK() with dev_dbg() (Tomas Henzl) [2042790]
- ata: sata_rcar: replace DPRINTK() with ata_port_dbg() (Tomas Henzl) [2042790]
- ata: sata_fsl: move DPRINTK to ata debugging (Tomas Henzl) [2042790]
- ata: pdc_adma: Remove DPRINTK call (Tomas Henzl) [2042790]
- ata: pata_octeon_cf: remove DPRINTK() macro in interrupt context (Tomas Henzl) [2042790]
- ata: sata_mv: replace DPRINTK with dynamic debugging (Tomas Henzl) [2042790]
- ata: sata_mv: kill 'port' argument in mv_dump_all_regs() (Tomas Henzl) [2042790]
- ata: libata: move DPRINTK to ata debugging (Tomas Henzl) [2042790]
- ata: libata: revamp ata_get_cmd_descript() (Tomas Henzl) [2042790]
- ata: libata: move ata_{port,link,dev}_dbg to standard pr_XXX() macros (Tomas Henzl) [2042790]
- ata: libata: add tracepoints for ATA error handling (Tomas Henzl) [2042790]
- ata: libata-scsi: drop DPRINTK calls for cdb translation (Tomas Henzl) [2042790]
- ata: libata-sff: tracepoints for HSM state machine (Tomas Henzl) [2042790]
- ata: libata: tracepoints for bus-master DMA (Tomas Henzl) [2042790]
- ata: libata: add qc_prep tracepoint (Tomas Henzl) [2042790]
- ata: libata: add reset tracepoints (Tomas Henzl) [2042790]
- ata: libata: sanitize ATA_HORKAGE_DUMP_ID (Tomas Henzl) [2042790]
- ata: libata: move ata_dump_id() to dynamic debugging (Tomas Henzl) [2042790]
- ata: libata: Add ata_port_classify() helper (Tomas Henzl) [2042790]
- ata: libata: whitespace cleanup (Tomas Henzl) [2042790]
- ata: libata: remove pointless debugging messages (Tomas Henzl) [2042790]
- ata: libata: use min() to make code cleaner (Tomas Henzl) [2042790]
- ata: libahci_platform: Get rid of dup message when IRQ can't be retrieved (Tomas Henzl) [2042790]
- ata: libahci_platform: Remove bogus 32-bit DMA mask attempt (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Remove unused forward declaration (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Use temporary variable for struct device (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: Use devm_platform_*ioremap_resource() APIs (Tomas Henzl) [2042790]
- ata: sata_fsl: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: ahci: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: libata-scsi: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: libata-sata: use sysfs_emit() (Tomas Henzl) [2042790]
- ata: sata_fsl: Use struct_group() for memcpy() region (Tomas Henzl) [2042790]
- ata: pata_ali: no need to initialise statics to 0 (Tomas Henzl) [2042790]
- libata: if T_LENGTH is zero, dma direction should be DMA_NONE (Tomas Henzl) [2042790]
- libata: add horkage for ASMedia 1092 (Tomas Henzl) [2042790]
- ata: ahci_ceva: Fix id array access in ceva_ahci_read_id() (Tomas Henzl) [2042790]
- ata: replace snprintf in show functions with sysfs_emit (Tomas Henzl) [2042790]
- sata_fsl: fix warning in remove_proc_entry when rmmod sata_fsl (Tomas Henzl) [2042790]
- sata_fsl: fix UAF in sata_fsl_port_stop when rmmod sata_fsl (Tomas Henzl) [2042790]
- pata_falcon: Avoid type warnings from sparse (Tomas Henzl) [2042790]
- ata: libahci: Adjust behavior when StorageD3Enable _DSD is set (Tomas Henzl) [2042790]
- ata: ahci: Add Green Sardine vendor ID as board_ahci_mobile (Tomas Henzl) [2042790]
- ata: libata: add missing ata_identify_page_supported() calls (Tomas Henzl) [2042790]
- ata: libata: improve ata_read_log_page() error message (Tomas Henzl) [2042790]
- libata: add horkage for missing Identify Device log (Tomas Henzl) [2042790]
- ata: sata_highbank: Remove unnecessary print function dev_err() (Tomas Henzl) [2042790]
- libata: fix read log timeout value (Tomas Henzl) [2042790]
- pata_radisys: fix checking of DMA state (Tomas Henzl) [2042790]
- pata_optidma: fix checking of DMA state (Tomas Henzl) [2042790]
- pata_amd: fix checking of DMA state (Tomas Henzl) [2042790]
- pata_ali: fix checking of DMA state (Tomas Henzl) [2042790]
- libata-scsi: fix checking of DMA state (Tomas Henzl) [2042790]
- libata: fix checking of DMA state (Tomas Henzl) [2042790]
- Add AHCI support for ASM1062+JBM575 cards (Tomas Henzl) [2042790]
- ahci: remove duplicated PCI device IDs (Tomas Henzl) [2042790]
- libata: support concurrent positioning ranges log (Tomas Henzl) [2042790]
- ata: sata_mv: Fix the error handling of mv_chip_id() (Tomas Henzl) [2042790]
- ata: ahci_platform: fix null-ptr-deref in ahci_platform_enable_regulators() (Tomas Henzl) [2042790]
- pata_legacy: fix a couple uninitialized variable bugs (Tomas Henzl) [2042790]
- libata: Add ATA_HORKAGE_NO_NCQ_ON_ATI for Samsung 860 and 870 SSD. (Tomas Henzl) [2042790]
- libata: add ATA_HORKAGE_NO_NCQ_TRIM for Samsung 860 and 870 SSDs (Tomas Henzl) [2042790]
- pata: ixp4xx: Rewrite to use device tree (Tomas Henzl) [2042790]
- pata: ixp4xx: Refer to cmd and ctl rather than csN (Tomas Henzl) [2042790]
- pata: ixp4xx: Use IS_ENABLED() to determine endianness (Tomas Henzl) [2042790]
- pata: ixp4xx: Use local dev variable (Tomas Henzl) [2042790]
- include:libata: fix boolreturn.cocci warnings (Tomas Henzl) [2042790]
- libata: Introduce ncq_prio_supported sysfs sttribute (Tomas Henzl) [2042790]
- libata: print feature list on device scan (Tomas Henzl) [2042790]
- libata: fix ata_read_log_page() warning (Tomas Henzl) [2042790]
- libata: cleanup NCQ priority handling (Tomas Henzl) [2042790]
- libata: cleanup ata_dev_configure() (Tomas Henzl) [2042790]
- libata: cleanup device sleep capability detection (Tomas Henzl) [2042790]
- libata: simplify ata_scsi_rbuf_fill() (Tomas Henzl) [2042790]
- libata: fix ata_host_start() (Tomas Henzl) [2042790]
- ata: sata_dwc_460ex: No need to call phy_exit() befre phy_init() (Tomas Henzl) [2042790]
- redhat/configs: aarch64: Enable NXP i.MX8M SoCs (Mark Salter) [2069626]
- scsi: qedf: Stop using the SCSI pointer (Nilesh Javali) [2046632]
- scsi: qedf: Change context reset messages to ratelimited (Nilesh Javali) [2046632]
- scsi: qedf: Fix refcount issue when LOGO is received during TMF (Nilesh Javali) [2046632]
- scsi: qedf: Add stag_work to all the vports (Nilesh Javali) [2046632]
- scsi: qedf: Fix potential dereference of NULL pointer (Nilesh Javali) [2046632]
- scsi: qedf: Fix error codes in qedf_alloc_global_queues() (Nilesh Javali) [2046632]

* Fri May 13 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-90.rt21.90.el9]
- [rt] build kernel-rt-5.14.0-90.rt21.90.el9 [2061574]
- platform/x86/intel: Fix 'rmmod pmt_telemetry' panic (David Arcari) [2080320]
- net: mpls: Fix notifications when deleting a device (Guillaume Nault) [2081758]
- nvme-pci: disable namespace identifiers for Qemu controllers (Gopal Tiwari) [2079310]
- nvme-pci: disable namespace identifiers for the MAXIO MAP1002/1202 (Gopal Tiwari) [2079310]
- nvme: add a quirk to disable namespace identifiers (Gopal Tiwari) [2079310]
- nvme-multipath: fix hang when disk goes live over reconnect (Gopal Tiwari) [2079310]
- nvme-pci: add quirks for Samsung X5 SSDs (Gopal Tiwari) [2079310]
- nvme-pci: expose use_threaded_interrupts read-only in sysfs (Gopal Tiwari) [2079310]
- selftest: net: Test IPv4 PMTU exceptions with DSCP and ECN (Guillaume Nault) [2081383]
- ipv4: Fix route lookups when handling ICMP redirects and PMTU updates (Guillaume Nault) [2081383]
- ipv4: fix data races in fib_alias_hw_flags_set (Guillaume Nault) [2081383]
- ipv4: remove sparse error in ip_neigh_gw4() (Guillaume Nault) [2081383]
- ipv4: tcp: send zero IPID in SYNACK messages (Guillaume Nault) [2081383]
- ipv4: raw: lock the socket in raw_bind() (Guillaume Nault) [2081383]
- ipv4: update fib_info_cnt under spinlock protection (Guillaume Nault) [2081383]
- inet: frags: annotate races around fqdir->dead and fqdir->high_thresh (Guillaume Nault) [2081383]
- net: nexthop: fix null pointer dereference when IPv6 is not enabled (Guillaume Nault) [2081383]
- net: dcb: disable softirqs in dcbnl_flush_dev() (Xin Long) [2080477]
- doc/ip-sysctl: add bc_forwarding (Xin Long) [2080477]
- l3mdev: l3mdev_master_upper_ifindex_by_index_rcu should be using netdev_master_upper_dev_get_rcu (Xin Long) [2080477]
- net/packet: fix packet_sock xmit return value checking (Xin Long) [2080477]
- net: handle ARPHRD_PIMREG in dev_is_mac_header_xmit() (Xin Long) [2080477]
- net/packet: fix slab-out-of-bounds access in packet_recvmsg() (Xin Long) [2080477]
- net: dcb: flush lingering app table entries for unregistered devices (Xin Long) [2080477]
- veth: fix races around rq->rx_notify_masked (Xin Long) [2080477]
- net: fix a memleak when uncloning an skb dst and its metadata (Xin Long) [2080477]
- net: do not keep the dst cache when uncloning an skb dst and its metadata (Xin Long) [2080477]
- af_packet: fix data-race in packet_setsockopt / packet_setsockopt (Xin Long) [2080477]
- ipv4: remove sparse error in ip_neigh_gw4() (Xin Long) [2080477]
- af_unix: annote lockless accesses to unix_tot_inflight & gc_in_progress (Xin Long) [2080477]
- veth: Do not record rx queue hint in veth_xmit (Xin Long) [2080477]
- veth: ensure skb entering GRO are not cloned. (Xin Long) [2080477]
- ip_gre, ip6_gre: Fix race condition on o_seqno in collect_md mode (Guillaume Nault) [2081047]
- ip6_gre: Make o_seqno start from 0 in native mode (Guillaume Nault) [2081047]
- ip_gre: Make o_seqno start from 0 in native mode (Guillaume Nault) [2081047]
- ip6_gre: Fix skb_under_panic in __gre6_xmit() (Guillaume Nault) [2081047]
- ip6_gre: Avoid updating tunnel->tun_hlen in __gre6_xmit() (Guillaume Nault) [2081047]
- ipv6_tunnel: Rate limit warning messages (Guillaume Nault) [2081047]
- bareudp: use ipv6_mod_enabled to check if IPv6 enabled (Guillaume Nault) [2080891]
- tipc: fix the timer expires after interval 100ms (Xin Long) [2080364]
- tipc: fix incorrect order of state message data sanity check (Xin Long) [2080364]
- tipc: fix kernel panic when enabling bearer (Xin Long) [2080364]
- tipc: Fix end of loop tests for list_for_each_entry() (Xin Long) [2080364]
- tipc: fix wrong notification node addresses (Xin Long) [2080364]
- tipc: fix wrong publisher node address in link publications (Xin Long) [2080364]
- tipc: fix a bit overflow in tipc_crypto_key_rcv() (Xin Long) [2080364]
- tipc: rate limit warning for received illegal binding update (Xin Long) [2080364]
- net: tipc: remove unused static inlines (Xin Long) [2080364]
- sctp: Initialize daddr on peeled off socket (Xin Long) [2079979]
- sctp: count singleton chunks in assoc user stats (Xin Long) [2079979]
- sctp: fix kernel-infoleak for SCTP sockets (Xin Long) [2079979]
- scsi: target: Allow changing dbroot if there are no registered devices (Maurizio Lombardi) [2075759]
- xfs: check sb_meta_uuid for dabuf buffer recovery (Dave Chinner) [2069776]

* Thu May 12 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-89.rt21.89.el9]
- [rt] build kernel-rt-5.14.0-89.rt21.89.el9 [2061574]
- nixge: fix mac address error handling again (Ivan Vecera) [2081256]
- ethernet: fix up ps3_gelic_net.c for "ethernet: use  eth_hw_addr_set()" (Ivan Vecera) [2081256]
- ethernet: ehea: add missing cast (Ivan Vecera) [2081256]
- ethernet: use eth_hw_addr_set() - casts (Ivan Vecera) [2081256]
- fddi: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- ethernet: s2io: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- ethernet: chelsio: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- net: usb: use eth_hw_addr_set() instead of ether_addr_copy() (Ivan Vecera) [2081256]
- ethernet: use eth_hw_addr_set() instead of ether_addr_copy() (Ivan Vecera) [2081256]
- net: use eth_hw_addr_set() instead of ether_addr_copy() (Ivan Vecera) [2081256]
- net: usb: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- ethernet: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- net: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- arch: use eth_hw_addr_set() (Ivan Vecera) [2081256]
- net: cipso: fix warnings in netlbl_cipsov4_add_std (Guillaume Nault) [2079246]
- wireguard: device: check for metadata_dst with skb_valid_dst() (Hangbin Liu) [2076974]
- wireguard: socket: ignore v6 endpoints when ipv6 is disabled (Hangbin Liu) [2076974]
- wireguard: socket: free skb in send6 when ipv6 is disabled (Hangbin Liu) [2076974]
- wireguard: queueing: use CFI-safe ptr_ring cleanup function (Hangbin Liu) [2076974]
- wireguard: main: rename 'mod_init' & 'mod_exit' functions to be module-specific (Hangbin Liu) [2076974]
- fork: Use IS_ENABLED() in account_kernel_stack() (Phil Auld) [2076594]
- fork: Only cache the VMAP stack in finish_task_switch() (Phil Auld) [2076594]
- fork: Move task stack accounting to do_exit() (Phil Auld) [2076594]
- fork: Move memcg_charge_kernel_stack() into CONFIG_VMAP_STACK (Phil Auld) [2076594]
- fork: Don't assign the stack pointer in dup_task_struct() (Phil Auld) [2076594]
- fork, IA64: Provide alloc_thread_stack_node() for IA64 (Phil Auld) [2076594]
- fork: Duplicate task_struct before stack allocation (Phil Auld) [2076594]
- fork: Redo ifdefs around task stack handling (Phil Auld) [2076594]
- sched/tracing: Report TASK_RTLOCK_WAIT tasks as TASK_UNINTERRUPTIBLE (Phil Auld) [2076594]
- locking/rt: Take RCU nesting into account for __might_resched() (Phil Auld) [2076594]
- sched: Make cond_resched_lock() variants RT aware (Phil Auld) [2076594]
- sched: Make RCU nest depth distinct in __might_resched() (Phil Auld) [2076594]
- sched: Make might_sleep() output less confusing (Phil Auld) [2076594]
- sched: Cleanup might_sleep() printks (Phil Auld) [2076594]
- sched: Remove preempt_offset argument from __might_sleep() (Phil Auld) [2076594]
- sched: Make cond_resched_*lock() variants consistent vs. might_sleep() (Phil Auld) [2076594]
- sched: Clean up the might_sleep() underscore zoo (Phil Auld) [2076594]
- sched/deadline,rt: Remove unused parameter from pick_next_[rt|dl]_entity() (Phil Auld) [2065219]
- sched/deadline,rt: Remove unused functions for !CONFIG_SMP (Phil Auld) [2065219]
- sched/deadline: Use __node_2_[pdl|dle]() and rb_first_cached() consistently (Phil Auld) [2065219]
- sched/deadline: Merge dl_task_can_attach() and dl_cpu_busy() (Phil Auld) [2065219]
- sched/deadline: Move bandwidth mgmt and reclaim functions into sched class source file (Phil Auld) [2065219]
- sched/deadline: Remove unused def_dl_bandwidth (Phil Auld) [2065219]
- sched/headers: ARM needs asm/paravirt_api_clock.h too (Phil Auld) [2069275]
- sched/headers: Only include <linux/entry-common.h> when CONFIG_GENERIC_ENTRY=y (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/sched.h dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/build_utility.c dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/build_policy.c dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/fair.c dependencies (Phil Auld) [2069275]
- sched/headers: Reorganize, clean up and optimize kernel/sched/core.c dependencies (Phil Auld) [2069275]
- sched/headers: Standardize kernel/sched/sched.h header dependencies (Phil Auld) [2069275]
- sched/headers: Introduce kernel/sched/build_policy.c and build multiple .c files there (Phil Auld) [2069275]
- sched/headers: Introduce kernel/sched/build_utility.c and build multiple .c files there (Phil Auld) [2069275]
- sched/headers: Make the <linux/sched/deadline.h> header build standalone (Phil Auld) [2069275]
- sched/headers: Fix comment typo in kernel/sched/cpudeadline.c (Phil Auld) [2069275]
- sched/headers: Add initial new headers as identity mappings (Phil Auld) [2069275]
- sched/headers: sched/clock: Mark all functions 'notrace', remove CC_FLAGS_FTRACE build asymmetry (Phil Auld) [2069275]
- sched/headers: Add header guard to kernel/sched/stats.h and kernel/sched/autogroup.h (Phil Auld) [2069275]
- sched/headers: Add header guard to kernel/sched/sched.h (Phil Auld) [2069275]
- sched/headers: Fix header to build standalone: <linux/sched_clock.h> (Phil Auld) [2069275]

* Thu May 12 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-88.rt21.88.el9]
- [rt] build kernel-rt-5.14.0-88.rt21.88.el9 [2061574]
- vrf: fix packet sniffing for traffic originating from ip tunnels (Antoine Tenart) [2082589]
- vrf: don't run conntrack on vrf with !dflt qdisc (Antoine Tenart) [2082589]
- vrf: run conntrack only in context of lower/physdev for locally generated packets (Antoine Tenart) [2082589]
- netfilter: conntrack: skip confirmation and nat hooks in postrouting for vrf (Antoine Tenart) [2082589]
- vrf: Revert "Reset skb conntrack connection..." (Antoine Tenart) [2082589]
- selftests: netfilter: add a vrf+conntrack testcase (Antoine Tenart) [2082589]
- ABI: configfs-usb-gadget-uac2: fix a broken table (Torez Smith) [2061784]
- usb: gadget: Fix use-after-free bug by not setting udc->dev.driver (Torez Smith) [2061784]
- usb: usbtmc: Fix bug in pipe direction for control transfers (Torez Smith) [2061784]
- partially Revert "usb: musb: Set the DT node on the child device" (Torez Smith) [2061784]
- usb: gadget: rndis: prevent integer overflow in rndis_set_response() (Torez Smith) [2061784]
- xen/usb: don't use gnttab_end_foreign_access() in xenhcd_gnttab_done() (Torez Smith) [2061784]
- usb: gadget: rndis: add spinlock for rndis response list (Torez Smith) [2061784]
- usb: dwc3: gadget: Let the interrupt handler disable bottom halves. (Torez Smith) [2061784]
- USB: gadget: validate endpoint index for xilinx udc (Torez Smith) [2061784]
- dt-bindings: update Roger Quadros email (Torez Smith) [2061784]
- USB: serial: option: add Telit LE910R1 compositions (Torez Smith) [2061784]
- USB: serial: option: add support for DW5829e (Torez Smith) [2061784]
- Revert "USB: serial: ch341: add new Product ID for CH341A" (Torez Smith) [2061784]
- usb: dwc2: drd: fix soft connect when gadget is unconfigured (Torez Smith) [2061784]
- usb: dwc3: pci: Fix Bay Trail phy GPIO mappings (Torez Smith) [2061784]
- tps6598x: clear int mask on probe failure (Torez Smith) [2061784]
- xhci: Prevent futile URB re-submissions due to incorrect return value. (Torez Smith) [2061784]
- xhci: re-initialize the HC during resume if HCE was set (Torez Smith) [2061784]
- usb: dwc3: pci: Add "snps,dis_u2_susphy_quirk" for Intel Bay Trail (Torez Smith) [2061784]
- usb: dwc3: pci: add support for the Intel Raptor Lake-S (Torez Smith) [2061784]
- Revert "usb: dwc2: drd: fix soft connect when gadget is unconfigured" (Torez Smith) [2061784]
- usb: dwc2: drd: fix soft connect when gadget is unconfigured (Torez Smith) [2061784]
- usb: gadget: rndis: check size of RNDIS_MSG_SET command (Torez Smith) [2061784]
- USB: gadget: validate interface OS descriptor requests (Torez Smith) [2061784]
- usb: core: Unregister device on component_add() failure (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: add compatible "intel,socfpga-agilex-hsotg" (Torez Smith) [2061784]
- usb: dwc3: gadget: Prevent core from processing stale TRBs (Torez Smith) [2061784]
- USB: serial: cp210x: add CPI Bulk Coin Recycler id (Torez Smith) [2061784]
- USB: serial: cp210x: add NCR Retail IO box id (Torez Smith) [2061784]
- USB: serial: ftdi_sio: add support for Brainboxes US-159/235/320 (Torez Smith) [2061784]
- usb: gadget: f_uac2: Define specific wTerminalType (Torez Smith) [2061784]
- usb: gadget: udc: renesas_usb3: Fix host to USB_ROLE_NONE transition (Torez Smith) [2061784]
- usb: usb251xb: add boost-up property support (Torez Smith) [2061784]
- usb: raw-gadget: fix handling of dual-direction-capable endpoints (Torez Smith) [2061784]
- usb: ulpi: Call of_node_put correctly (Torez Smith) [2061784]
- usb: ulpi: Move of_node_put to ulpi_dev_release (Torez Smith) [2061784]
- USB: serial: option: add ZTE MF286D modem (Torez Smith) [2061784]
- USB: serial: ch341: add support for GW Instek USB2.0-Serial devices (Torez Smith) [2061784]
- usb: f_fs: Fix use-after-free for epfile (Torez Smith) [2061784]
- usb: dwc3: xilinx: fix uninitialized return value (Torez Smith) [2061784]
- usb: cdnsp: Fix segmentation fault in cdns_lost_power function (Torez Smith) [2061784]
- usb: dwc2: gadget: don't try to disable ep0 in dwc2_hsotg_suspend (Torez Smith) [2061784]
- usb: gadget: at91_udc: fix incorrect print type (Torez Smith) [2061784]
- usb: dwc3: xilinx: Fix error handling when getting USB3 PHY (Torez Smith) [2061784]
- usb: dwc3: xilinx: Skip resets and USB3 register settings for USB2.0 mode (Torez Smith) [2061784]
- usb: xhci-plat: fix crash when suspend if remote wake enable (Torez Smith) [2061784]
- usb: common: ulpi: Fix crash in ulpi_match() (Torez Smith) [2061784]
- usb: gadget: f_sourcesink: Fix isoc transfer for USB_SPEED_SUPER_PLUS (Torez Smith) [2061784]
- ucsi_ccg: Check DEV_INT bit only when starting CCG4 (Torez Smith) [2061784]
- USB: core: Fix hang in usb_kill_urb by adding memory barriers (Torez Smith) [2061784]
- usb-storage: Add unusual-devs entry for VL817 USB-SATA bridge (Torez Smith) [2061784]
- usb: typec: tcpm: Do not disconnect when receiving VSAFE0V (Torez Smith) [2061784]
- usb: typec: tcpm: Do not disconnect while receiving VBUS off (Torez Smith) [2061784]
- usb: typec: Don't try to register component master without components (Torez Smith) [2061784]
- usb: typec: Only attempt to link USB ports if there is fwnode (Torez Smith) [2061784]
- usb: typec: tcpci: don't touch CC line if it's Vconn source (Torez Smith) [2061784]
- usb: roles: fix include/linux/usb/role.h compile issue (Torez Smith) [2061784]
- usb: gadget: u_audio: Subdevice 0 for capture ctls (Torez Smith) [2061784]
- usb: gadget: u_audio: fix calculations for small bInterval (Torez Smith) [2061784]
- usb: dwc2: gadget: initialize max_speed from params (Torez Smith) [2061784]
- usb: dwc2: do not gate off the hardware if it does not support clock gating (Torez Smith) [2061784]
- usb: dwc3: qcom: Fix NULL vs IS_ERR checking in dwc3_qcom_probe (Torez Smith) [2061784]
- headers/deps: USB: Optimize <linux/usb/ch9.h> dependencies, remove <linux/device.h> (Torez Smith) [2061784]
- USB: common: debug: add needed kernel.h include (Torez Smith) [2061784]
- headers/prep: Fix non-standard header section: drivers/usb/host/ohci-tmio.c (Torez Smith) [2061784]
- headers/prep: Fix non-standard header section: drivers/usb/cdns3/core.h (Torez Smith) [2061784]
- headers/prep: usb: gadget: Fix namespace collision (Torez Smith) [2061784]
- USB: core: Fix bug in resuming hub's handling of wakeup requests (Torez Smith) [2061784]
- USB: Fix "slab-out-of-bounds Write" bug in usb_hcd_poll_rh_status (Torez Smith) [2061784]
- usb: dwc3: dwc3-qcom: Add missing platform_device_put() in dwc3_qcom_acpi_register_core (Torez Smith) [2061784]
- usb: gadget: clear related members when goto fail (Torez Smith) [2061784]
- usb: gadget: don't release an existing dev->buf (Torez Smith) [2061784]
- usb: dwc2: Simplify a bitmap declaration (Torez Smith) [2061784]
- usb: Remove usb_for_each_port() (Torez Smith) [2061784]
- usb: typec: port-mapper: Convert to the component framework (Torez Smith) [2061784]
- usb: Link the ports to the connectors they are attached to (Torez Smith) [2061784]
- acpi: Store CRC-32 hash of the _PLD in struct acpi_device (Torez Smith) [2061784]
- docs: ABI: fixed req_number desc in UAC1 (Torez Smith) [2061784]
- usb-storage: Remove redundant assignments (Torez Smith) [2061784]
- thunderbolt: Add module parameter for CLx disabling (Torez Smith) [2061784]
- thunderbolt: Enable CL0s for Intel Titan Ridge (Torez Smith) [2061784]
- thunderbolt: Rename Intel TB_VSE_CAP_IECS capability (Torez Smith) [2061784]
- thunderbolt: Implement TMU time disruption for Intel Titan Ridge (Torez Smith) [2061784]
- thunderbolt: Move usb4_switch_wait_for_bit() to switch.c (Torez Smith) [2061784]
- thunderbolt: Add CL0s support for USB4 routers (Torez Smith) [2061784]
- thunderbolt: Add TMU uni-directional mode (Torez Smith) [2061784]
- usb: typec: ucsi: Only check the contract if there is a connection (Torez Smith) [2061784]
- xhci: Fresco FL1100 controller should not have BROKEN_MSI quirk set. (Torez Smith) [2061784]
- tty: tty_io: Switch to vmalloc() fallback in case of TTY_NO_WRITE_SPLIT (Torez Smith) [2061784]
- usb: mtu3: set interval of FS intr and isoc endpoint (Torez Smith) [2061784]
- usb: mtu3: fix list_head check warning (Torez Smith) [2061784]
- usb: mtu3: add memory barrier before set GPD's HWO (Torez Smith) [2061784]
- usb: mtu3: fix interval value for intr and isoc (Torez Smith) [2061784]
- usb: gadget: f_fs: Clear ffs_eventfd in ffs_data_clear. (Torez Smith) [2061784]
- usb: musb: dsps: Use platform_get_irq_byname() to get the interrupt (Torez Smith) [2061784]
- usb: cdns3: Use platform_get_irq_byname() to get the interrupt (Torez Smith) [2061784]
- usb: isp1760: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: dwc3: Drop unneeded calls to platform_get_resource_byname() (Torez Smith) [2061784]
- usb: renesas_usbhs: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: host: fotg210: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- xhci: use max() to make code cleaner (Torez Smith) [2061784]
- Revert "usb: host: ehci-sh: propagate errors from platform_get_irq()" (Torez Smith) [2061784]
- usb: misc: ehset: Rework test mode entry (Torez Smith) [2061784]
- usb: core: Export usb_device_match_id (Torez Smith) [2061784]
- usb: musb: Set the DT node on the child device (Torez Smith) [2061784]
- usb: musb: Drop unneeded resource copying (Torez Smith) [2061784]
- usb: host: ohci-omap: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: host: ehci-sh: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: gadget: udc: pxa25x: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: gadget: udc: bcm63xx: propagate errors from platform_get_irq() (Torez Smith) [2061784]
- usb: ftdi-elan: fix memory leak on device disconnect (Torez Smith) [2061784]
- usb: hub: Add delay for SuperSpeed hub resume to let links transit to U0 (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: Add SM6350 compatible (Torez Smith) [2061784]
- usb: dwc2: drd: restore role and overrides upon resume (Torez Smith) [2061784]
- usb: dwc2: drd: add role-switch-default-node support (Torez Smith) [2061784]
- dt-bindings: usb: document role-switch-default-mode property in dwc2 (Torez Smith) [2061784]
- usb: chipidea: Set the DT node on the child device (Torez Smith) [2061784]
- usb: uhci: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: ohci-s3c2410: Use platform_get_irq() to get the interrupt (Torez Smith) [2061784]
- usb: ohci-spear: Remove direct access to platform_device resource list (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: add binding for SM8450 (Torez Smith) [2061784]
- Revert "usb: early: convert to readl_poll_timeout_atomic()" (Torez Smith) [2061784]
- dt-bindings: usb: Convert BDC to YAML (Torez Smith) [2061784]
- usb: hub: make wait_for_connected() take an int instead of a pointer to int (Torez Smith) [2061784]
- usb: chipidea: tegra: Add runtime PM and OPP support (Torez Smith) [2061784]
- usb: hub: avoid warm port reset during USB3 disconnect (Torez Smith) [2061784]
- usb: host: xen-hcd: add missing unlock in error path (Torez Smith) [2061784]
- dt-bindings: usb: dwc3-xilinx: Convert USB DWC3 bindings (Torez Smith) [2061784]
- usb: dwc2: platform: adopt dev_err_probe() to silent probe defer (Torez Smith) [2061784]
- usb: typec: tcpm: fix tcpm unregister port but leave a pending timer (Torez Smith) [2061784]
- usb: cdnsp: Fix lack of spin_lock_irqsave/spin_lock_restore (Torez Smith) [2061784]
- USB: NO_LPM quirk Lenovo USB-C to Ethernet Adapher(RTL8153-04) (Torez Smith) [2061784]
- usb: dwc2: fix STM ID/VBUS detection startup delay in dwc2_driver_probe (Torez Smith) [2061784]
- USB: gadget: bRequestType is a bitfield, not a enum (Torez Smith) [2061784]
- thunderbolt: Check return value of kmemdup() in icm_handle_event() (Torez Smith) [2061784]
- dt-bindings: usb: Add missing properties used in examples (Torez Smith) [2061784]
- media: drivers:usb:remove unneeded variable (Torez Smith) [2061784]
- media: b2c2-flexcop-usb: fix some whitespace coding style (Torez Smith) [2061784]
- media: Revert "media: uvcvideo: Set unique vdev name based in type" (Torez Smith) [2061784]
- media: dw2102: Fix use after free (Torez Smith) [2061784]
- USB: serial: option: add Telit FN990 compositions (Torez Smith) [2061784]
- USB: serial: cp210x: fix CP2105 GPIO registration (Torez Smith) [2061784]
- usb: cdnsp: Fix incorrect status for control request (Torez Smith) [2061784]
- usb: cdnsp: Fix issue in cdnsp_log_ep trace event (Torez Smith) [2061784]
- usb: cdnsp: Fix incorrect calling of cdnsp_died function (Torez Smith) [2061784]
- usb: xhci-mtk: fix list_del warning when enable list debug (Torez Smith) [2061784]
- usb: gadget: u_ether: fix race in setting MAC address in setup phase (Torez Smith) [2061784]
- dt-bindings: usb: tegra-xudc: Document interconnects and iommus properties (Torez Smith) [2061784]
- usb: core: hcd: change sizeof(vaddr) to sizeof(unsigned long) (Torez Smith) [2061784]
- usb: aspeed-vhub: support test mode feature (Torez Smith) [2061784]
- usb: aspeed-vhub: fix ep0 OUT ack received wrong length issue (Torez Smith) [2061784]
- usb: aspeed-vhub: add qualifier descriptor (Torez Smith) [2061784]
- Add CONFIG_USB_XEN_HCD to configs (Torez Smith) [2061784]
- usb: Introduce Xen pvUSB frontend (xen hcd) (Torez Smith) [2061784]
- usb: dwc3: gadget: Support Multi-Stream Transfer (Torez Smith) [2061784]
- usb: core: config: using bit mask instead of individual bits (Torez Smith) [2061784]
- usb: core: config: fix validation of wMaxPacketValue entries (Torez Smith) [2061784]
- USB: gadget: zero allocate endpoint 0 buffers (Torez Smith) [2061784]
- USB: gadget: detect too-big endpoint 0 requests (Torez Smith) [2061784]
- xhci: avoid race between disable slot command and host runtime suspend (Torez Smith) [2061784]
- xhci: Remove CONFIG_USB_DEFAULT_PERSIST to prevent xHCI from runtime suspending (Torez Smith) [2061784]
- Revert "usb: dwc3: dwc3-qcom: Enable tx-fifo-resize property by default" (Torez Smith) [2061784]
- thunderbolt: Do not dereference fwnode in struct device (Torez Smith) [2061784]
- thunderbolt: Add debug logging of DisplayPort resource allocation (Torez Smith) [2061784]
- thunderbolt: Do not program path HopIDs for USB4 routers (Torez Smith) [2061784]
- thunderbolt: Do not allow subtracting more NFC credits than configured (Torez Smith) [2061784]
- thunderbolt: Runtime resume USB4 port when retimers are scanned (Torez Smith) [2061784]
- thunderbolt: Tear down existing tunnels when resuming from hibernate (Torez Smith) [2061784]
- thunderbolt: Runtime PM activate both ends of the device link (Torez Smith) [2061784]
- thunderbolt: xdomain: Avoid potential stack OOB read (Torez Smith) [2061784]
- media: m920x: don't use stack on USB reads (Torez Smith) [2061784]
- media: siano: remove duplicate USB device IDs (Torez Smith) [2061784]
- media: replace setting of bytesused with vb2_set_plane_payload (Torez Smith) [2061784]
- media: uvcvideo: Avoid returning invalid controls (Torez Smith) [2061784]
- media: uvcvideo: Avoid invalid memory access (Torez Smith) [2061784]
- media: uvcvideo: Increase UVC_CTRL_CONTROL_TIMEOUT to 5 seconds. (Torez Smith) [2061784]
- media: uvcvideo: Set the colorspace as sRGB if undefined (Torez Smith) [2061784]
- media: uvcvideo: fix division by zero at stream start (Torez Smith) [2061784]
- media: uvcvideo: Fix memory leak of object map on error exit path (Torez Smith) [2061784]
- usb: core: Fix file path that does not exist (Torez Smith) [2061784]
- treewide: Add missing includes masked by cgroup -> bpf dependency (Torez Smith) [2061784]
- usb: cdnsp: Fix a NULL pointer dereference in cdnsp_endpoint_init() (Torez Smith) [2061784]
- usb: cdns3: gadget: fix new urb never complete if ep cancel previous requests (Torez Smith) [2061784]
- usb: typec: tcpm: Wait in SNK_DEBOUNCED until disconnect (Torez Smith) [2061784]
- USB: NO_LPM quirk Lenovo Powered USB-C Travel Hub (Torez Smith) [2061784]
- xhci: Fix commad ring abort, write all 64 bits to CRCR register. (Torez Smith) [2061784]
- usb: bdc: fix error handling code in bdc_resume (Torez Smith) [2061784]
- usb: uhci: add aspeed ast2600 uhci support (Torez Smith) [2061784]
- usb: dwc3: gadget: Skip reading GEVNTSIZn (Torez Smith) [2061784]
- usb: dwc3: gadget: Ignore Update Transfer cmd params (Torez Smith) [2061784]
- usb: dwc3: gadget: Skip checking Update Transfer status (Torez Smith) [2061784]
- media: pvrusb2: fix inconsistent indenting (Torez Smith) [2061784]
- media: au0828-i2c: drop a duplicated function (Torez Smith) [2061784]
- media: lmedm04: don't ignore errors when setting a filter (Torez Smith) [2061784]
- USB: serial: option: add Fibocom FM101-GL variants (Torez Smith) [2061784]
- usb: dwc2: gadget: use existing helper (Torez Smith) [2061784]
- usb: gadget: configfs: use to_usb_function_instance() in cfg (un)link func (Torez Smith) [2061784]
- usb: gadget: configfs: use to_config_usb_cfg() in os_desc_link() (Torez Smith) [2061784]
- usb: gadget: configfs: remove os_desc_attr_release() (Torez Smith) [2061784]
- usb: gadget: configfs: simplify os_desc_item_to_gadget_info() helper (Torez Smith) [2061784]
- usb: xilinx: Add suspend resume support (Torez Smith) [2061784]
- usb: typec: tipd: Fix initialization sequence for cd321x (Torez Smith) [2061784]
- usb: typec: tipd: Fix typo in cd321x_switch_power_state (Torez Smith) [2061784]
- usb: hub: Fix locking issues with address0_mutex (Torez Smith) [2061784]
- USB: serial: pl2303: fix GC type detection (Torez Smith) [2061784]
- USB: serial: option: add Telit LE910S1 0x9200 composition (Torez Smith) [2061784]
- media: dib0700: Only touch one bit when start/stop an adapter (Torez Smith) [2061784]
- media: dib0700: cleanup start/stop streaming logic (Torez Smith) [2061784]
- media: dib0700: fix undefined behavior in tuner shutdown (Torez Smith) [2061784]
- media: stk1160: fix control-message timeouts (Torez Smith) [2061784]
- media: s2255: fix control-message timeouts (Torez Smith) [2061784]
- media: pvrusb2: fix control-message timeouts (Torez Smith) [2061784]
- media: em28xx: fix control-message timeouts (Torez Smith) [2061784]
- media: cpia2: fix control-message timeouts (Torez Smith) [2061784]
- media: flexcop-usb: fix control-message timeouts (Torez Smith) [2061784]
- usb: chipidea: ci_hdrc_imx: fix potential error pointer dereference in probe (Torez Smith) [2061784]
- usb: hub: Fix usb enumeration issue due to address0 race (Torez Smith) [2061784]
- usb: typec: fusb302: Fix masking of comparator and bc_lvl interrupts (Torez Smith) [2061784]
- usb: dwc3: leave default DMA for PCI devices (Torez Smith) [2061784]
- usb: dwc2: hcd_queue: Fix use of floating point literal (Torez Smith) [2061784]
- usb: dwc3: gadget: Fix null pointer exception (Torez Smith) [2061784]
- usb: gadget: udc-xilinx: Fix an error handling path in 'xudc_probe()' (Torez Smith) [2061784]
- usb: xhci: tegra: Check padctrl interrupt presence in device tree (Torez Smith) [2061784]
- usb: dwc2: gadget: Fix ISOC flow for elapsed frames (Torez Smith) [2061784]
- usb: dwc3: gadget: Check for L1/L2/U3 for Start Transfer (Torez Smith) [2061784]
- usb: dwc3: gadget: Ignore NoStream after End Transfer (Torez Smith) [2061784]
- usb: dwc3: core: Revise GHWPARAMS9 offset (Torez Smith) [2061784]
- usb: typec: ucsi: Expose number of alternate modes in partner (Torez Smith) [2061784]
- usb: xhci-mtk: fix random remote wakeup (Torez Smith) [2061784]
- usb: xhci-mtk: remove unnecessary error check (Torez Smith) [2061784]
- Docs: usb: update writesize, copy_from_user, usb_fill_bulk_urb, usb_submit_urb (Torez Smith) [2061784]
- Docs: usb: update comment and code near increment usage count (Torez Smith) [2061784]
- Docs: usb: update err() to pr_err() and replace __FILE__ (Torez Smith) [2061784]
- usb: gadget: at91_udc: Convert to GPIO descriptors (Torez Smith) [2061784]
- usb: gadget: composite: Show warning if function driver's descriptors are incomplete. (Torez Smith) [2061784]
- usb: gadget: f_midi: allow resetting index option (Torez Smith) [2061784]
- usb: Remove redundant 'flush_workqueue()' calls (Torez Smith) [2061784]
- usb: gadget: f_fs: Use stream_open() for endpoint files (Torez Smith) [2061784]
- USB: ehci_brcm_hub_control: Improve port index sanitizing (Torez Smith) [2061784]
- usb: dwc3: meson-g12a: fix shared reset control use (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: add binding for IPQ4019 and IPQ8064 (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: document the port when usb-role-switch is used (Torez Smith) [2061784]
- usb: cdnsp: Remove unneeded semicolon after `}' (Torez Smith) [2061784]
- media: em28xx: fix memory leak in em28xx_init_dev (Torez Smith) [2061784]
- media: gspca: Make use of the helper macro kthread_run() (Torez Smith) [2061784]
- dt-bindings: treewide: Update @st.com email address to @foss.st.com (Torez Smith) [2061784]
- xhci: Fix USB 3.1 enumeration issues by increasing roothub power-on-good delay (Torez Smith) [2061784]
- Revert "usb: core: hcd: Add support for deferring roothub registration" (Torez Smith) [2061784]
- Revert "xhci: Set HCD flag to defer primary roothub registration" (Torez Smith) [2061784]
- usb: gadget: Mark USB_FSL_QE broken on 64-bit (Torez Smith) [2061784]
- usb: gadget: f_mass_storage: Disable eps during disconnect (Torez Smith) [2061784]
- usb: gadget: udc: core: Revise comments for USB ep enable/disable (Torez Smith) [2061784]
- usb: mtu3: enable wake-up interrupt after runtime_suspend called (Torez Smith) [2061784]
- usb: xhci-mtk: enable wake-up interrupt after runtime_suspend called (Torez Smith) [2061784]
- USB: serial: keyspan: fix memleak on probe errors (Torez Smith) [2061784]
- USB: serial: cp210x: use usb_control_msg_recv() and usb_control_msg_send() (Torez Smith) [2061784]
- USB: serial: ch314: use usb_control_msg_recv() (Torez Smith) [2061784]
- USB: iowarrior: fix control-message timeouts (Torez Smith) [2061784]
- Documentation: USB: fix example bulk-message timeout (Torez Smith) [2061784]
- usb: remove res2 argument from gadget code completions (Torez Smith) [2061784]
- usb: dwc2: stm32mp15: set otg_rev (Torez Smith) [2061784]
- usb: dwc2: add otg_rev and otg_caps information for gadget driver (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: adopt otg properties defined in usb-drd.yaml (Torez Smith) [2061784]
- dt-bindings: usb: dwc2: Add reference to usb-drd.yaml (Torez Smith) [2061784]
- usb: gadget: uvc: implement dwPresentationTime and scrSourceClock (Torez Smith) [2061784]
- usb: gadget: uvc: use on returned header len in video_encode_isoc_sg (Torez Smith) [2061784]
- usb:gadget: f_uac1: fixed sync playback (Torez Smith) [2061784]
- Docs: usb: remove :c:func: for usb_register and usb_deregister (Torez Smith) [2061784]
- Docs: usb: update struct usb_driver (Torez Smith) [2061784]
- usb: gadget: configfs: change config attributes file operation (Torez Smith) [2061784]
- usb: gadget: configfs: add cfg_to_gadget_info() helper (Torez Smith) [2061784]
- usb: dwc3: Align DWC3_EP_* flag macros (Torez Smith) [2061784]
- usb: dwc3: gadget: Skip resizing EP's TX FIFO if already resized (Torez Smith) [2061784]
- USB: chipidea: fix interrupt deadlock (Torez Smith) [2061784]
- usb: musb: Balance list entry in musb_gadget_queue (Torez Smith) [2061784]
- usb: musb: sunxi: Don't print error on MUSB_ULPI_BUSCONTROL access (Torez Smith) [2061784]
- usb: gadget: uvc: ensure the vdev is unset (Torez Smith) [2061784]
- usb: gadget: uvc: only pump video data if necessary (Torez Smith) [2061784]
- usb: gadget: uvc: only schedule stream in streaming state (Torez Smith) [2061784]
- usb: gadget: uvc: test if ep->desc is valid on ep_queue (Torez Smith) [2061784]
- usb: gadget: uvc: rename function to be more consistent (Torez Smith) [2061784]
- usb: gadget: uvc: consistently use define for headerlen (Torez Smith) [2061784]
- usb: max-3421: Use driver data instead of maintaining a list of bound devices (Torez Smith) [2061784]
- usb: dwc2: drd: reset current session before setting the new one (Torez Smith) [2061784]
- usb: dwc2: drd: fix dwc2_drd_role_sw_set when clock could be disabled (Torez Smith) [2061784]
- usb: dwc2: drd: fix dwc2_force_mode call in dwc2_ovr_init (Torez Smith) [2061784]
- usb: ohci: disable start-of-frame interrupt in ohci_rh_suspend (Torez Smith) [2061784]
- usb: host: ehci: Make use of dma_pool_zalloc() instead of dma_pool_alloc/memset() (Torez Smith) [2061784]
- usb: host: fotg210: Make use of dma_pool_zalloc() instead of dma_pool_alloc/memset() (Torez Smith) [2061784]
- usb: dwc3: gadget: Change to dev_dbg() when queuing to inactive gadget/ep (Torez Smith) [2061784]
- usb: gadget: u_ether: use eth_hw_addr_set() (Torez Smith) [2061784]
- usb: typec: tipd: Enable event interrupts by default (Torez Smith) [2061784]
- media: gspca/gl860-mi1320/ov9655: avoid -Wstring-concatenation warning (Torez Smith) [2061784]
- usb: typec: STUSB160X should select REGMAP_I2C (Torez Smith) [2061784]
- usb-storage: Add compatibility quirk flags for iODD 2531/2541 (Torez Smith) [2061784]
- scsi: usb: Switch to attribute groups (Torez Smith) [2061784]
- net: remove single-byte netdev->dev_addr writes (Torez Smith) [2061784]
- usb: musb: dsps: Fix the probe error path (Torez Smith) [2061784]
- usb: gadget: avoid unusual inline assembly (Torez Smith) [2061784]
- usb: musb: select GENERIC_PHY instead of depending on it (Torez Smith) [2061784]
- usb: host: ohci-tmio: check return value after calling platform_get_resource() (Torez Smith) [2061784]
- usb: gadget: u_audio.c: Adding Playback Pitch ctl for sync playback (Torez Smith) [2061784]
- usb: gadget: hid: fix error code in do_config() (Torez Smith) [2061784]
- xhci: Enable trust tx length quirk for Fresco FL11 USB controller (Torez Smith) [2061784]
- xhci: Fix command ring pointer corruption while aborting a command (Torez Smith) [2061784]
- USB: xhci: dbc: fix tty registration race (Torez Smith) [2061784]
- xhci: add quirk for host controllers that don't update endpoint DCS (Torez Smith) [2061784]
- xhci: guard accesses to ep_state in xhci_endpoint_reset() (Torez Smith) [2061784]
- USB: gadget: udc: Remove some dead code (Torez Smith) [2061784]
- usb: gadget: storage: add support for media larger than 2T (Torez Smith) [2061784]
- usb: chipidea: udc: make controller hardware endpoint primed (Torez Smith) [2061784]
- dt-binding: usb: xilinx: Add clocking node (Torez Smith) [2061784]
- media: usb: dvd-usb: fix uninit-value bug in dibusb_read_eeprom_byte() (Torez Smith) [2061784]
- USB: serial: qcserial: add EM9191 QDL support (Torez Smith) [2061784]
- Revert "usb: misc: ehset: Workaround for "special" hubs" (Torez Smith) [2061784]
- USB: serial: option: add Quectel EC200S-CN module support (Torez Smith) [2061784]
- USB: serial: option: add prod. id for Quectel EG91 (Torez Smith) [2061784]
- USB: serial: option: add Telit LE910Cx composition 0x1204 (Torez Smith) [2061784]
- thunderbolt: build kunit tests without structleak plugin (Torez Smith) [2061784]
- usb: core: config: Change sizeof(struct ...) to sizeof(*...) (Torez Smith) [2061784]
- ARM: omap1: move omap15xx local bus handling to usb.c (Torez Smith) [2061784]
- USB: cdc-acm: fix break reporting (Torez Smith) [2061784]
- USB: cdc-acm: fix racy tty buffer accesses (Torez Smith) [2061784]
- usb: gadget: f_uac2: fixed EP-IN wMaxPacketSize (Torez Smith) [2061784]
- usb: cdc-wdm: Fix check for WWAN (Torez Smith) [2061784]
- usb: chipidea: ci_hdrc_imx: Also search for 'phys' phandle (Torez Smith) [2061784]
- usb: typec: tcpm: handle SRC_STARTUP state if cc changes (Torez Smith) [2061784]
- usb: typec: tcpci: don't handle vSafe0V event if it's not enabled (Torez Smith) [2061784]
- usb: typec: tipd: Remove dependency on "connector" child fwnode (Torez Smith) [2061784]
- Partially revert "usb: Kconfig: using select for USB_COMMON dependency" (Torez Smith) [2061784]
- usb: dwc3: gadget: Revert "set gadgets parent to the right controller" (Torez Smith) [2061784]
- usb: xhci: tegra: mark PM functions as __maybe_unused (Torez Smith) [2061784]
- usb: gadget: udc: core: Print error code in usb_gadget_probe_driver() (Torez Smith) [2061784]
- usb: gadget: udc: core: Use pr_fmt() to prefix messages (Torez Smith) [2061784]
- usb: gadget: uvc: fix multiple opens (Torez Smith) [2061784]
- usb: cdc-wdm: Constify static struct wwan_port_ops (Torez Smith) [2061784]
- usb: usb-skeleton: Update min() to min_t() (Torez Smith) [2061784]
- dt-bindings: usb: dwc3: Fix usb-phy check (Torez Smith) [2061784]
- dt-bindings: usb: Convert SMSC USB3503 binding to a schema (Torez Smith) [2061784]
- usb: exynos: describe driver in KConfig (Torez Smith) [2061784]
- usb: gadget: udc-xilinx: Add clock support (Torez Smith) [2061784]
- usb: xhci-mtk: use xhci_dbg() to print log (Torez Smith) [2061784]
- USB: EHCI: Improve port index sanitizing (Torez Smith) [2061784]
- USB: phy: tahvo:remove unnecessary debug log (Torez Smith) [2061784]
- usb: atm: Use struct_size() helper (Torez Smith) [2061784]
- usb: phy: tegra: Support OTG mode programming (Torez Smith) [2061784]
- usb: host: oxu210hp: Fix a function name in comments (Torez Smith) [2061784]
- usb: host: fotg210: Fix a function name in comments (Torez Smith) [2061784]
- usb: ehci: Fix a function name in comments (Torez Smith) [2061784]
- usb: typec: tipd: Remove FIXME about testing with I2C_FUNC_I2C (Torez Smith) [2061784]
- usb: typec: tipd: Switch CD321X power state to S0 (Torez Smith) [2061784]
- usb: typec: tipd: Add support for Apple CD321X (Torez Smith) [2061784]
- usb: typec: tipd: Add short-circuit for no irqs (Torez Smith) [2061784]
- usb: typec: tipd: Split interrupt handler (Torez Smith) [2061784]
- dt-bindings: usb: tps6598x: Add Apple CD321x compatible (Torez Smith) [2061784]
- usb: typec: ucsi: Better fix for missing unplug events issue (Torez Smith) [2061784]
- usb: typec: ucsi: Read the PDOs in separate work (Torez Smith) [2061784]
- usb: typec: ucsi: Check the partner alt modes always if there is PD contract (Torez Smith) [2061784]
- usb: typec: ucsi: acpi: Reduce the command completion timeout (Torez Smith) [2061784]
- usb: typec: ucsi: Add polling mechanism for partner tasks like alt mode checking (Torez Smith) [2061784]
- usb: typec: ucsi: Don't stop alt mode registration on busy condition (Torez Smith) [2061784]
- usb: typec: ucsi: Always cancel the command if PPM reports BUSY condition (Torez Smith) [2061784]
- usb: typec: tcpci: Fix spelling mistake "resolbed" -> "resolved" (Torez Smith) [2061784]
- usb: misc: ehset: Workaround for "special" hubs (Torez Smith) [2061784]
- media: em28xx: Don't use ops->suspend if it is NULL (Torez Smith) [2061784]
- scsi: target: usb: Replace enable attr with ops.enable (Torez Smith) [2061784]
- media: mxl111sf: change mutex_init() location (Torez Smith) [2061784]
- media: tm6000: Avoid card name truncation (Torez Smith) [2061784]
- media: usb: stkwebcam: Update the reference count of the usb device structure (Torez Smith) [2061784]
- media: gspca: Limit frame size to sizeimage. (Torez Smith) [2061784]
- media: usb: airspy: clean the freed pointer and counter (Torez Smith) [2061784]
- media: pvrusb2: Replaced simple_strtol() with kstrtoint() (Torez Smith) [2061784]
- media: uvcvideo: Don't spam the log in uvc_ctrl_restore_values() (Torez Smith) [2061784]
- media: uvcvideo: Set error_idx during ctrl_commit errors (Torez Smith) [2061784]
- media: uvcvideo: Check controls flags before accessing them (Torez Smith) [2061784]
- media: uvcvideo: Use control names from framework (Torez Smith) [2061784]
- media: uvcvideo: Increase the size of UVC_METADATA_BUF_SIZE (Torez Smith) [2061784]
- media: uvcvideo: Set unique vdev name based in type (Torez Smith) [2061784]
- media: uvcvideo: Use dev->name for querycap() (Torez Smith) [2061784]
- media: uvcvideo: Add support for V4L2_CTRL_TYPE_CTRL_CLASS (Torez Smith) [2061784]
- media: uvcvideo: refactor __uvc_ctrl_add_mapping (Torez Smith) [2061784]
- media: uvcvideo: Return -EIO for control errors (Torez Smith) [2061784]
- media: uvcvideo: Set capability in s_param (Torez Smith) [2061784]
- media: uvcvideo: Remove s_ctrl and g_ctrl (Torez Smith) [2061784]
- media: uvcvideo: Remove unused including <linux/version.h> (Torez Smith) [2061784]
- media: uvcvideo: Do not check for V4L2_CTRL_WHICH_DEF_VAL (Torez Smith) [2061784]
- media: pvrusb2: Do not check for V4L2_CTRL_WHICH_DEF_VAL (Torez Smith) [2061784]
- media: m5602_ov7660: remove the repeated declaration (Torez Smith) [2061784]
- media: dvb-usb: fix ununit-value in az6027_rc_query (Torez Smith) [2061784]
- media: ttusb-dec: avoid release of non-acquired mutex (Torez Smith) [2061784]
- media: gspca/sn9c20x: Add ability to control built-in webcam LEDs (Torez Smith) [2061784]
- media: em28xx: add missing em28xx_close_extension (Torez Smith) [2061784]
- thunderbolt: Fix -Wrestrict warning (Torez Smith) [2061784]
- USB: serial: option: add device id for Foxconn T99W265 (Torez Smith) [2061784]
- USB: serial: cp210x: add ID for GW Instek GDM-834x Digital Multimeter (Torez Smith) [2061784]
- USB: serial: cp210x: add part-number debug printk (Torez Smith) [2061784]
- USB: serial: cp210x: fix dropped characters with CP2102 (Torez Smith) [2061784]
- USB: serial: kl5kusb105: drop line-status helper (Torez Smith) [2061784]
- USB: serial: kl5kusb105: simplify line-status handling (Torez Smith) [2061784]
- USB: serial: kl5kusb105: clean up line-status handling (Torez Smith) [2061784]
- usb: musb: tusb6010: uninitialized data in tusb_fifo_write_unaligned() (Torez Smith) [2061784]
- usb-storage: Add quirk for ScanLogic SL11R-IDE older than 2.6c (Torez Smith) [2061784]
- Re-enable UAS for LaCie Rugged USB3-FW with fk quirk (Torez Smith) [2061784]
- usb: dwc3: gadget: Avoid starting DWC3 gadget during UDC unbind (Torez Smith) [2061784]
- usb: core: hcd: fix messages in usb_hcd_request_irqs() (Torez Smith) [2061784]
- usb: host: ehci-mv: drop duplicated MODULE_ALIAS (Torez Smith) [2061784]
- usb: typec: tipd: Remove WARN_ON in tps6598x_block_read (Torez Smith) [2061784]
- usb: typec: tipd: Add an additional overflow check (Torez Smith) [2061784]
- usb: typec: tipd: Don't read/write more bytes than required (Torez Smith) [2061784]
- usb: musb: tusb6010: check return value after calling platform_get_resource() (Torez Smith) [2061784]
- USB: cdc-acm: remove duplicate USB device ID (Torez Smith) [2061784]
- USB: serial: kl5kusb105: use usb_control_msg_recv() and usb_control_msg_send() (Torez Smith) [2061784]
- USB: serial: keyspan_pda: use usb_control_msg_recv() (Torez Smith) [2061784]
- USB: serial: ftdi_sio: use usb_control_msg_recv() (Torez Smith) [2061784]
- USB: serial: f81232: use usb_control_msg_recv() and usb_control_msg_send() (Torez Smith) [2061784]
- USB: serial: allow hung up ports to be suspended (Torez Smith) [2061784]
- USB: serial: clean up core error labels (Torez Smith) [2061784]
- USB: serial: option: remove duplicate USB device ID (Torez Smith) [2061784]
- USB: serial: mos7840: remove duplicated 0xac24 device ID (Torez Smith) [2061784]
- USB: core: Make do_proc_control() and do_proc_bulk() killable (Torez Smith) [2061784]
- usb: musb: mediatek: Expose role-switch control to userspace (Torez Smith) [2061784]
- usb: gadget: f_uac2: Populate SS descriptors' wBytesPerInterval (Torez Smith) [2061784]
- usb: gadget: f_uac2: Add missing companion descriptor for feedback EP (Torez Smith) [2061784]
- usb: dwc2: gadget: Fix ISOC transfer complete handling for DDMA (Torez Smith) [2061784]
- usb: core: hcd: Modularize HCD stop configuration in usb_stop_hcd() (Torez Smith) [2061784]
- xhci: Set HCD flag to defer primary roothub registration (Torez Smith) [2061784]
- usb: core: hcd: Add support for deferring roothub registration (Torez Smith) [2061784]
- usb: dwc2: gadget: Fix ISOC flow for BDMA and Slave (Torez Smith) [2061784]
- usb: dwc3: core: balance phy init and exit (Torez Smith) [2061784]
- Revert "USB: bcma: Add a check for devm_gpiod_get" (Torez Smith) [2061784]
- usb: ehci: Simplify platform driver registration (Torez Smith) [2061784]
- USB: cdc-acm: fix minor-number release (Torez Smith) [2061784]
- usb: dwc2: check return value after calling platform_get_resource() (Torez Smith) [2061784]
- usb: cdns3: fix race condition before setting doorbell (Torez Smith) [2061784]
- usb: gadget: r8a66597: fix a loop in set_feature() (Torez Smith) [2061784]
- usb: gadget: u_audio: EP-OUT bInterval in fback frequency (Torez Smith) [2061784]
- usb: testusb: Fix for showing the connection speed (Torez Smith) [2061784]
- usb: gadget: fix for a typo that conveys logically-inverted information. (Torez Smith) [2061784]
- usb: gadget: goku_udc: Fix mask and set operation on variable master (Torez Smith) [2061784]
- USB: host: ehci-atmel: Add support for HSIC phy (Torez Smith) [2061784]
- dt-bindings: usb: atmel: add USB PHY type property (Torez Smith) [2061784]
- usb: ehci: handshake CMD_RUN instead of STS_HALT (Torez Smith) [2061784]
- usb: gadget: f_uac2: clean up some inconsistent indenting (Torez Smith) [2061784]
- dt-bindings: usb: qcom,dwc3: add binding for IPQ6018 (Torez Smith) [2061784]
- usb: dwc3: reference clock period configuration (Torez Smith) [2061784]
- dt-bindings: usb: dwc3: add reference clock period (Torez Smith) [2061784]
- usb: ohci: Prefer struct_size over open coded arithmetic (Torez Smith) [2061784]
- usb: typec: hd3ss3220: Use regmap_write_bits() (Torez Smith) [2061784]
- dt-binding: usb: xilinx: Convert binding to YAML (Torez Smith) [2061784]
- USB: serial: option: add Telit LN920 compositions (Torez Smith) [2061784]
- thunderbolt: test: split up test cases in tb_test_credit_alloc_all (Torez Smith) [2061784]
- USB: serial: pl2303: fix GL type detection (Torez Smith) [2061784]
- usb: isp1760: otg control register access (Torez Smith) [2061784]
- usb: isp1760: use the right irq status bit (Torez Smith) [2061784]
- usb: isp1760: write to status and address register (Torez Smith) [2061784]
- usb: isp1760: fix qtd fill length (Torez Smith) [2061784]
- usb: isp1760: fix memory pool initialization (Torez Smith) [2061784]
- usb: typec: tcpm: Fix spelling mistake "atleast" -> "at least" (Torez Smith) [2061784]
- usb: dwc2: Fix spelling mistake "was't" -> "wasn't" (Torez Smith) [2061784]
- usb: renesas_usbhs: Fix spelling mistake "faile" -> "failed" (Torez Smith) [2061784]
- usb: host: xhci-rcar: Don't reload firmware after the completion (Torez Smith) [2061784]
- usb: xhci-mtk: allow bandwidth table rollover (Torez Smith) [2061784]
- usb: mtu3: fix random remote wakeup (Torez Smith) [2061784]
- usb: mtu3: return successful suspend status (Torez Smith) [2061784]
- usb: xhci-mtk: Do not use xhci's virt_dev in drop_endpoint (Torez Smith) [2061784]
- usb: xhci-mtk: modify the SOF/ITP interval for mt8195 (Torez Smith) [2061784]
- usb: xhci-mtk: add a member of num_esit (Torez Smith) [2061784]
- usb: xhci-mtk: check boundary before check tt (Torez Smith) [2061784]
- usb: xhci-mtk: update fs bus bandwidth by bw_budget_table (Torez Smith) [2061784]
- usb: xhci-mtk: fix issue of out-of-bounds array access (Torez Smith) [2061784]
- usb: xhci-mtk: support option to disable usb2 ports (Torez Smith) [2061784]
- usb: xhci-mtk: fix use-after-free of mtk->hcd (Torez Smith) [2061784]
- dt-bindings: usb: mtk-xhci: add compatible for mt8195 (Torez Smith) [2061784]
- dt-bindings: usb: mtk-xhci: add optional property to disable usb2 ports (Torez Smith) [2061784]
- usb: bdc: Fix a resource leak in the error handling path of 'bdc_probe()' (Torez Smith) [2061784]
- usb: bdc: Fix an error handling path in 'bdc_probe()' when no suitable DMA config is available (Torez Smith) [2061784]
- Revert "usb: xhci-mtk: relax TT periodic bandwidth allocation" (Torez Smith) [2061784]
- usb: isp1760: clean never read udc_enabled warning (Torez Smith) [2061784]
- usb: isp1760: do not shift in uninitialized slot (Torez Smith) [2061784]
- usb: isp1760: do not reset retval (Torez Smith) [2061784]
- usb: isp1760: check maxpacketsize before using it (Torez Smith) [2061784]
- usb: isp1760: ignore return value for bus change pattern (Torez Smith) [2061784]
- usb: gadget: Add description for module parameter (Torez Smith) [2061784]
- usbip:vhci_hcd USB port can get stuck in the disabled state (Torez Smith) [2061784]
- usbip: clean up code in vhci_device_unlink_cleanup (Torez Smith) [2061784]
- usbip: give back URBs for unsent unlink requests during cleanup (Torez Smith) [2061784]
- usb: gadget: aspeed: Remove repeated verbose license text (Torez Smith) [2061784]
- usb: gadget: mass_storage: Remove repeated verbose license text (Torez Smith) [2061784]
- usb: musb: musb_dsps: request_irq() after initializing musb (Torez Smith) [2061784]
- usb: dwc3: pci: add support for AMD's newer generation platform. (Torez Smith) [2061784]
- usb: dwc3: imx8mp: request irq after initializing dwc3 (Torez Smith) [2061784]
- usb: ehci-orion: Handle errors of clk_prepare_enable() in probe (Torez Smith) [2061784]
- xhci: Add bus number to some debug messages (Torez Smith) [2061784]
- xhci: Add additional dynamic debug to follow URBs in cancel and error cases. (Torez Smith) [2061784]
- Revert "USB: xhci: fix U1/U2 handling for hardware with XHCI_INTEL_HOST quirk set" (Torez Smith) [2061784]
- xhci: Fix failure to give back some cached cancelled URBs. (Torez Smith) [2061784]
- xhci: fix even more unsafe memory usage in xhci tracing (Torez Smith) [2061784]
- xhci: fix unsafe memory usage in xhci tracing (Torez Smith) [2061784]
- USB: serial: replace symbolic permissions by octal permissions (Torez Smith) [2061784]
- usb: gadget: f_hid: optional SETUP/SET_REPORT mode (Torez Smith) [2061784]
- usb: chipidea: host: fix port index underflow and UBSAN complains (Torez Smith) [2061784]
- usb: typec: altmodes/displayport: Notify drm subsys of hotplug events (Torez Smith) [2061784]
- usb: typec: altmodes/displayport: Make dp_altmode_notify() more generic (Torez Smith) [2061784]
- drm/connector: Add support for out-of-band hotplug notification (v3) (Torez Smith) [2061784]
- drm/connector: Add drm_connector_find_by_fwnode() function (v3) (Torez Smith) [2061784]
- drm/connector: Add a fwnode pointer to drm_connector and register with ACPI (v2) (Torez Smith) [2061784]
- drm/connector: Give connector sysfs devices there own device_type (Torez Smith) [2061784]
- USB: EHCI: Add alias for Broadcom INSNREG (Torez Smith) [2061784]
- USB: EHCI: Add register array bounds to HCS ports (Torez Smith) [2061784]
- usb: gadget: mv_u3d: request_irq() after initializing UDC (Torez Smith) [2061784]
- usb: gadget: f_uac1: fixing inconsistent indenting (Torez Smith) [2061784]
- usb: remove reference to deleted config STB03xxx (Torez Smith) [2061784]
- usb: host: remove line for obsolete config USB_HWA_HCD (Torez Smith) [2061784]
- usb: host: remove dead EHCI support for on-chip PMC MSP71xx USB controller (Torez Smith) [2061784]
- usb: dwc3: Decouple USB 2.0 L1 & L2 events (Torez Smith) [2061784]
- usb: phy: tahvo: add IRQ check (Torez Smith) [2061784]
- usb: host: ohci-tmio: add IRQ check (Torez Smith) [2061784]
- dt-bindings: usb: mtk-musb: add MT7623 compatible (Torez Smith) [2061784]
- usb: gadget: remove unnecessary AND operation when get ep maxp (Torez Smith) [2061784]
- usb: gadget: bdc: remove unnecessary AND operation when get ep maxp (Torez Smith) [2061784]
- usb: gadget: udc: renesas_usb3: Fix soc_device_match() abuse (Torez Smith) [2061784]
- usb: typec: tcpm: Support non-PD mode (Torez Smith) [2061784]
- usb: gadget: tegra-xudc: fix the wrong mult value for HS isoc or intr (Torez Smith) [2061784]
- usb: cdnsp: fix the wrong mult value for HS isoc or intr (Torez Smith) [2061784]
- usb: mtu3: fix the wrong HS mult value (Torez Smith) [2061784]
- usb: mtu3: use @mult for HS isoc or intr (Torez Smith) [2061784]
- usb: mtu3: restore HS function when set SS/SSP (Torez Smith) [2061784]
- usb: phy: twl6030: add IRQ checks (Torez Smith) [2061784]
- usb: phy: fsl-usb: add IRQ check (Torez Smith) [2061784]
- usb: misc: brcmstb-usb-pinmap: add IRQ check (Torez Smith) [2061784]
- usb: gadget: udc: s3c2410: add IRQ check (Torez Smith) [2061784]
- usb: gadget: udc: at91: add IRQ check (Torez Smith) [2061784]
- usb: dwc3: qcom: add IRQ check (Torez Smith) [2061784]
- usb: dwc3: meson-g12a: add IRQ check (Torez Smith) [2061784]
- usb: dwc2: gadget: implement udc_set_speed() (Torez Smith) [2061784]
- usb: xhci-mtk: relax TT periodic bandwidth allocation (Torez Smith) [2061784]
- dt-bindings: usb: renesas,usbhs: Document RZ/G2L bindings (Torez Smith) [2061784]
- docs: usb: fix malformed table (Torez Smith) [2061784]
- usb: gadget: f_uac2: remove redundant assignments to pointer i_feature (Torez Smith) [2061784]
- usb: misc: adutux: use swap() (Torez Smith) [2061784]
- usb: gadget: remove useless cast (Torez Smith) [2061784]
- usb: gadget: Fix inconsistent indent (Torez Smith) [2061784]
- media: em28xx-input: fix refcount bug in em28xx_usb_disconnect (Torez Smith) [2061784]
- thunderbolt: Add authorized value to the KOBJ_CHANGE uevent (Torez Smith) [2061784]
- USB: serial: cp210x: determine fw version for CP2105 and CP2108 (Torez Smith) [2061784]
- USB: serial: cp210x: clean up type detection (Torez Smith) [2061784]
- USB: serial: cp210x: clean up set-chars request (Torez Smith) [2061784]
- USB: serial: cp210x: clean up control-request timeout (Torez Smith) [2061784]
- USB: serial: cp210x: fix flow-control error handling (Torez Smith) [2061784]
- USB: serial: cp210x: fix control-characters error handling (Torez Smith) [2061784]
- USB: serial: io_edgeport: drop unused descriptor helper (Torez Smith) [2061784]
- usb: gadget: pxa25x_udc: Constify static struct pxa25x_ep_ops (Torez Smith) [2061784]
- drivers: usb: dwc3-qcom: Add sdm660 compatible (Torez Smith) [2061784]
- usb: isp1760: rework cache initialization error handling (Torez Smith) [2061784]
- usb: isp1760: do not sleep in field register poll (Torez Smith) [2061784]
- usb: isp1760: remove debug message as error (Torez Smith) [2061784]
- dt-bindings: usb: ohci: Add Allwinner A83t compatible (Torez Smith) [2061784]
- dt-bindings: usb: ehci: Add Allwinner A83t compatible (Torez Smith) [2061784]
- usb: gadget: uvc: decrease the interrupt load to a quarter (Torez Smith) [2061784]
- usb: gadget: uvc: add scatter gather support (Torez Smith) [2061784]
- usb: gadget: uvc: set v4l2_dev->dev in f_uvc (Torez Smith) [2061784]
- usb: gadget: uvc: make uvc_num_requests depend on gadget speed (Torez Smith) [2061784]
- usb: dwc3: gadget: set gadgets parent to the right controller (Torez Smith) [2061784]
- usb: mtu3: support suspend/resume for dual-role mode (Torez Smith) [2061784]
- usb: mtu3: support suspend/resume for device mode (Torez Smith) [2061784]
- usb: mtu3: add helper to power on/down device (Torez Smith) [2061784]
- usb: mtu3: support runtime PM for host mode (Torez Smith) [2061784]
- usb: mtu3: add new helpers for host suspend/resume (Torez Smith) [2061784]
- usb: mtu3: support option to disable usb2 ports (Torez Smith) [2061784]
- usb: mtu3: support property role-switch-default-mode (Torez Smith) [2061784]
- usb: dwc3: drd: use helper to get role-switch-default-mode (Torez Smith) [2061784]
- usb: common: add helper to get role-switch-default-mode (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: add wakeup interrupt (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: add support property role-switch-default-mode (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: add optional property to disable usb2 ports (Torez Smith) [2061784]
- dt-bindings: usb: mtu3: remove support VBUS detection of extcon (Torez Smith) [2061784]
- media: stkwebcam: fix memory leak in stk_camera_probe (Torez Smith) [2061784]
- media: go7007: remove redundant initialization (Torez Smith) [2061784]
- media: go7007: fix memory leak in go7007_usb_probe (Torez Smith) [2061784]
- media: dvb-usb: Fix error handling in dvb_usb_i2c_init (Torez Smith) [2061784]
- media: dvb-usb: fix uninit-value in vp702x_read_mac_addr (Torez Smith) [2061784]
- media: dvb-usb: fix uninit-value in dvb_usb_adapter_dvb_init (Torez Smith) [2061784]
- usb: dwc3: dwc3-qcom: Fix typo in the dwc3 vbus override API (Torez Smith) [2061784]
- usb: gadget: f_uac1: add volume and mute support (Torez Smith) [2061784]
- usb: gadget: f_uac2: add volume and mute support (Torez Smith) [2061784]
- usb: gadget: u_audio: add bi-directional volume and mute support (Torez Smith) [2061784]
- usb: audio-v2: add ability to define feature unit descriptor (Torez Smith) [2061784]
- dt-bindings: usb: generic-ohci: Document dr_mode property (Torez Smith) [2061784]
- dt-bindings: usb: generic-ehci: Document dr_mode property (Torez Smith) [2061784]
- usb: dwc2: gadget: Add endpoint wedge support (Torez Smith) [2061784]
- usb: gadget: composite: Allow bMaxPower=0 if self-powered (Torez Smith) [2061784]
- usb: isp1301-omap: Fix the GPIO include (Torez Smith) [2061784]
- usb: renesas-xhci: Remove renesas_xhci_pci_exit() (Torez Smith) [2061784]
- usb: xhci-renesas: Minor coding style cleanup (Torez Smith) [2061784]
- usb: host: ohci-spear: simplify calling usb_add_hcd() (Torez Smith) [2061784]
- USB: EHCI: ehci-mv: improve error handling in mv_ehci_enable() (Torez Smith) [2061784]
- usb: gadget: u_ether: fix a potential null pointer dereference (Torez Smith) [2061784]
- usb: gadget: f_ncm: ncm_wrap_ntb - move var definitions into if statement (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove spurious if statement (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove check for NULL skb_tx_data in timer function (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove spurious boolean timer_stopping (Torez Smith) [2061784]
- usb: gadget: f_ncm: remove timer_force_tx field (Torez Smith) [2061784]
- usb: host: fotg210: fix the actual_length of an iso packet (Torez Smith) [2061784]
- usb: host: fotg210: fix the endpoint's transactional opportunities calculation (Torez Smith) [2061784]
- Revert "usb: host: fotg210: Use dma_pool_zalloc" (Torez Smith) [2061784]
- media: usb: dvb-usb-v2: af9035: let subdrv autoselect enable si2168 and si2157 (Torez Smith) [2061784]
- media: usb: dvb-usb-v2: af9035: report if i2c client isn't bound (Torez Smith) [2061784]
- dt-bindings: usb: dwc3: Update dwc3 TX fifo properties (Torez Smith) [2061784]
- usb: dwc3: dwc3-qcom: Enable tx-fifo-resize property by default (Torez Smith) [2061784]
- usb: dwc3: Resize TX FIFOs to meet EP bursting requirements (Torez Smith) [2061784]
- usb: gadget: configfs: Check USB configuration before adding (Torez Smith) [2061784]
- usb: gadget: udc: core: Introduce check_config to verify USB configuration (Torez Smith) [2061784]
- media: drivers/media/usb/gspca: fix typo Fliker -> Flicker (Torez Smith) [2061784]
- media: uvc: don't do DMA on stack (Torez Smith) [2061784]
- media: gspca: Drop default m (Torez Smith) [2061784]
- media: dvbsky: add support for MyGica T230C2_LITE and T230A (Torez Smith) [2061784]
- oom_kill.c: futex: delay the OOM reaper to allow time for proper futex cleanup (Nico Pache) [1951330]
- scsi: mpt3sas: Fix mpt3sas_check_same_4gb_region() kdoc comment (Tomas Henzl) [2068044]
- scsi: mpt3sas: Fix incorrect 4GB boundary check (Tomas Henzl) [2068044]
- scsi: mpt3sas: Remove scsi_dma_map() error messages (Tomas Henzl) [2068044]
- qed: fix ethtool register dump (Manish Chopra) [2040279]
- qede: confirm skb is allocated before using (Manish Chopra) [2040279]
- qed: remove unnecessary memset in qed_init_fw_funcs (Manish Chopra) [2040279]
- qed: return status of qed_iov_get_link (Manish Chopra) [2040279]
- net: qlogic: check the return value of dma_alloc_coherent() in qed_vf_hw_prepare() (Manish Chopra) [2040279]
- qed: validate and restrict untrusted VFs vlan promisc mode (Manish Chopra) [2040279]
- qed: display VF trust config (Manish Chopra) [2040279]
- qed: prevent a fw assert during device shutdown (Manish Chopra) [2040279]
- qed: use msleep() in qed_mcp_cmd() and add qed_mcp_cmd_nosleep() for udelay. (Manish Chopra) [2040279]
- qed: Use dma_set_mask_and_coherent() and simplify code (Manish Chopra) [2040279]
- qed*: esl priv flag support through ethtool (Manish Chopra) [2040279]
- qed*: enhance tx timeout debug info (Manish Chopra) [2040279]
- qede: validate non LSO skb length (Manish Chopra) [2040279]
- qed: Enhance rammod debug prints to provide pretty details (Manish Chopra) [2040279]
- net: qed: fix the array may be out of bound (Manish Chopra) [2040279]
- qed: Use the bitmap API to simplify some functions (Manish Chopra) [2040279]
- RDMA/qed: Use helper function to set GUIDs (Manish Chopra) [2040279]
- RDMA/qedr: Fix NULL deref for query_qp on the GSI QP (Manish Chopra) [2040279]
- net: qed_dev: fix check of true !rc expression (Manish Chopra) [2040279]
- net: qed_ptp: fix check of true !rc expression (Manish Chopra) [2040279]
- RDMA/qedr: Remove unsupported qedr_resize_cq callback (Manish Chopra) [2040279]
- qed: Change the TCP common variable - "iscsi_ooo" (Manish Chopra) [2040279]
- qed: Optimize the ll2 ooo flow (Manish Chopra) [2040279]
- net: qed_debug: fix check of false (grc_param < 0) expression (Manish Chopra) [2040279]
- qed: Fix missing error code in qed_slowpath_start() (Manish Chopra) [2040279]
- qed: Fix compilation for CONFIG_QED_SRIOV undefined scenario (Manish Chopra) [2040279]
- qed: Initialize debug string array (Manish Chopra) [2040279]
- qed: Fix spelling mistake "ctx_bsaed" -> "ctx_based" (Manish Chopra) [2040279]
- qed: fix ll2 establishment during load of RDMA driver (Manish Chopra) [2040279]
- qed: Update the TCP active termination 2 MSL timer ("TIME_WAIT") (Manish Chopra) [2040279]
- qed: Update TCP silly-window-syndrome timeout for iwarp, scsi (Manish Chopra) [2040279]
- qed: Update debug related changes (Manish Chopra) [2040279]
- qed: Add '_GTT' suffix to the IRO RAM macros (Manish Chopra) [2040279]
- qed: Update FW init functions to support FW 8.59.1.0 (Manish Chopra) [2040279]
- qed: Use enum as per FW 8.59.1.0 in qed_iro_hsi.h (Manish Chopra) [2040279]
- qed: Update qed_hsi.h for fw 8.59.1.0 (Manish Chopra) [2040279]
- qed: Update qed_mfw_hsi.h for FW ver 8.59.1.0 (Manish Chopra) [2040279]
- qed: Update common_hsi for FW ver 8.59.1.0 (Manish Chopra) [2040279]
- qed: Split huge qed_hsi.h header file (Manish Chopra) [2040279]
- qed: Remove e4_ and _e4 from FW HSI (Manish Chopra) [2040279]
- qed: Fix kernel-doc warnings (Manish Chopra) [2040279]
- qed: rdma - don't wait for resources under hw error recovery flow (Manish Chopra) [2040279]
- qed: Improve the stack space of filter_config() (Manish Chopra) [2040279]
- qed: Handle management FW error (Manish Chopra) [2040279]
- qed: Enable automatic recovery on error condition. (Manish Chopra) [2040279]
- RDMA/qedr: Move variables reset to qedr_set_common_qp_params() (Manish Chopra) [2040279]
- qed: Remove duplicated include of kernel.h (Manish Chopra) [2040279]
- qed: Remove redundant prints from the iWARP SYN handling (Manish Chopra) [2040279]
- qed: Skip DORQ attention handling during recovery (Manish Chopra) [2040279]
- qed: Avoid db_recovery during recovery (Manish Chopra) [2040279]
- RDMA/qedr: Improve error logs for rdma_alloc_tid error return (Manish Chopra) [2040279]
- RDMA/qed: Use accurate error num in qed_cxt_dynamic_ilt_alloc (Manish Chopra) [2040279]
- qede: Remove the qede module version (Manish Chopra) [2040279]
- qed: Remove the qed module version (Manish Chopra) [2040279]
- net: qed: remove unneeded return variables (Manish Chopra) [2040279]
- sched/isolation: Split housekeeping cpumask per isolation features (Phil Auld) [2065222]
- sched/isolation: Fix housekeeping_mask memory leak (Phil Auld) [2065222]
- sched/isolation: Consolidate error handling (Phil Auld) [2065222]
- sched/isolation: Consolidate check for housekeeping minimum service (Phil Auld) [2065222]
- sched/isolation: Use single feature type while referring to housekeeping cpumask (Phil Auld) [2065222]
- net: Decouple HK_FLAG_WQ and HK_FLAG_DOMAIN cpumask fetch (Phil Auld) [2065222]
- workqueue: Decouple HK_FLAG_WQ and HK_FLAG_DOMAIN cpumask fetch (Phil Auld) [2065222]
- pci: Decouple HK_FLAG_WQ and HK_FLAG_DOMAIN cpumask fetch (Phil Auld) [2065222]
- mailbox: pcc: Avoid using the uninitialized variable 'dev' (Mark Langsdorf) [1998271]
- mailbox: pcc: Handle all PCC subtypes correctly in pcc_mbox_irq (Mark Langsdorf) [1998271]
- i2c: xgene-slimpro: Fix wrong pointer passed to PTR_ERR() (Mark Langsdorf) [1998271]
- ACPI: Make acpi_node_get_parent() local (Mark Langsdorf) [1998271]
- ACPI: Get acpi_device's parent from the parent field (Mark Langsdorf) [1998271]
- ACPI: Drop ACPI_USE_BUILTIN_STDARG ifdef from acgcc.h (Mark Langsdorf) [1998271]
- ACPI: PM: Fix device wakeup power reference counting error (Mark Langsdorf) [1998271]
- ACPI: video: use platform backlight driver on Xiaomi Mi Pad 2 (Mark Langsdorf) [1998271]
- ACPI: video: Drop dmi_system_id.ident settings from video_detect_dmi_table[] (Mark Langsdorf) [1998271]
- ACPI: PMIC: Fix intel_pmic_regs_handler() read accesses (Mark Langsdorf) [1998271]
- ACPI: EC: Remove initialization of static variables to false (Mark Langsdorf) [1998271]
- ACPI: EC: Use ec_no_wakeup on HP ZHAN 66 Pro (Mark Langsdorf) [1998271]
- ACPI: Add a convenience function to tell a device is in D0 state (Mark Langsdorf) [1998271]
- ACPI: scan: Obtain device's desired enumeration power state (Mark Langsdorf) [1998271]
- perf: qcom_l2_pmu: ACPI: Use ACPI_COMPANION() directly (Mark Langsdorf) [1998271]
- ACPI/PCC: Add maintainer for PCC mailbox driver (Mark Langsdorf) [1998271]
- mailbox: pcc: Move bulk of PCCT parsing into pcc_mbox_probe (Mark Langsdorf) [1998271]
- mailbox: pcc: Add support for PCCT extended PCC subspaces(type 3/4) (Mark Langsdorf) [1998271]
- mailbox: pcc: Drop handling invalid bit-width in {read,write}_register (Mark Langsdorf) [1998271]
- mailbox: pcc: Avoid accessing PCCT table in pcc_send_data and pcc_mbox_irq (Mark Langsdorf) [1998271]
- mailbox: pcc: Add PCC register bundle and associated accessor functions (Mark Langsdorf) [1998271]
- mailbox: pcc: Rename doorbell ack to platform interrupt ack register (Mark Langsdorf) [1998271]
- mailbox: pcc: Use PCC mailbox channel pointer instead of standard (Mark Langsdorf) [1998271]
- mailbox: pcc: Add pcc_mbox_chan structure to hold shared memory region info (Mark Langsdorf) [1998271]
- mailbox: pcc: Consolidate subspace doorbell register parsing (Mark Langsdorf) [1998271]
- mailbox: pcc: Consolidate subspace interrupt information parsing (Mark Langsdorf) [1998271]
- mailbox: pcc: Refactor all PCC channel information into a structure (Mark Langsdorf) [1998271]
- mailbox: pcc: Fix kernel doc warnings (Mark Langsdorf) [1998271]
- ACPI: APEI: mark apei_hest_parse() static (Mark Langsdorf) [1998271]
- ACPI: APEI: EINJ: Relax platform response timeout to 1 second (Mark Langsdorf) [1998271]
- ACPI: resources: Add one more Medion model in IRQ override quirk (Mark Langsdorf) [1998271]
- ACPI: AC: Quirk GK45 to skip reading _PSR (Mark Langsdorf) [1998271]
- ACPI: PM: sleep: Do not set suspend_ops unnecessarily (Mark Langsdorf) [1998271]
- ACPI: PRM: Handle memory allocation and memory remap failure (Mark Langsdorf) [1998271]
- ACPI: PRM: Remove unnecessary blank lines (Mark Langsdorf) [1998271]
- ACPI: PM: Turn off wakeup power resources on _DSW/_PSW errors (Mark Langsdorf) [1998271]
- ACPI: PM: Fix sharing of wakeup power resources (Mark Langsdorf) [1998271]
- ACPI: PM: Turn off unused wakeup power resources (Mark Langsdorf) [1998271]
- ACPI: PM: Check states of power resources during initialization (Mark Langsdorf) [1998271]
- hwmon: (acpi_power_meter) Use acpi_bus_get_acpi_device() (Mark Langsdorf) [1998271]
- ACPI: replace snprintf() in "show" functions with sysfs_emit() (Mark Langsdorf) [1998271]
- ACPI: LPSS: Use ACPI_COMPANION() directly (Mark Langsdorf) [1998271]
- ACPI: battery: Accept charges over the design capacity as full (Mark Langsdorf) [1998271]
- ACPICA: Update version to 20210930 (Mark Langsdorf) [1998271]
- ACPICA: iASL table disassembler: Added disassembly support for the NHLT ACPI table (Mark Langsdorf) [1998271]
- ACPICA: ACPI 6.4 SRAT: add Generic Port Affinity type (Mark Langsdorf) [1998271]
- ACPICA: Add support for Windows 2020 _OSI string (Mark Langsdorf) [1998271]
- ACPICA: Avoid evaluating methods too early during system resume (Mark Langsdorf) [1998271]
- ACPI: glue: Look for ACPI bus type only if ACPI companion is not known (Mark Langsdorf) [1998271]
- ACPI: glue: Drop cleanup callback from struct acpi_bus_type (Mark Langsdorf) [1998271]
- ACPI: processor: idle: Avoid falling back to C3 type C-states (Mark Langsdorf) [1998271]
- ACPI: processor idle: Allow playing dead in C3 state (Mark Langsdorf) [1998271]
- ACPI: Kconfig: Fix a typo in Kconfig (Mark Langsdorf) [1998271]
- ACPI: PNP: remove duplicated BRI0A49 and BDP3336 entries (Mark Langsdorf) [1998271]
- ACPI: resources: Add DMI-based legacy IRQ override quirk (Mark Langsdorf) [1998271]
- ACPICA: Add support for MADT online enabled bit (Mark Langsdorf) [1998271]
- ACPI: PM: Do not turn off power resources in unknown state (Mark Langsdorf) [1998269]
- acpi/arm64: fix next_platform_timer() section mismatch error (Mark Langsdorf) [1998269]
- ACPI: PM: Include alternate AMDI0005 id in special behaviour (Mark Langsdorf) [1998269]
- ACPI: NFIT: Use fallback node id when numa info in NFIT table is incorrect (Mark Langsdorf) [1998269]
- ACPICA: Update the list of maintainers (Mark Langsdorf) [1998269]
- MAINTAINERS: Change Rafael's e-mail address (Mark Langsdorf) [1998269]
- ACPI: PRM: Find PRMT table before parsing it (Mark Langsdorf) [1998269]
- ACPI: scan: Remove unneeded header linux/nls.h (Mark Langsdorf) [1998269]
- ACPI: PM: s2idle: Run both AMD and Microsoft methods if both are supported (Mark Langsdorf) [1998269]
- ACPI: power: Drop name from struct acpi_power_resource (Mark Langsdorf) [1998269]
- ACPI: power: Use acpi_handle_debug() to print debug messages (Mark Langsdorf) [1998269]
- ACPI: button: Add DMI quirk for Lenovo Yoga 9 (14INTL5) (Mark Langsdorf) [1998269]
- ACPI: SPCR: Add support for the new 16550-compatible Serial Port Subtype (Mark Langsdorf) [1998269]
- ACPI: platform-profile: call sysfs_notify() from platform_profile_store() (Mark Langsdorf) [1998269]
- ACPICA: Update version to 20210730 (Mark Langsdorf) [1998269]
- ACPICA: Add method name "_DIS" For use with aslmethod.c (Mark Langsdorf) [1998269]
- ACPICA: iASL: Fix for WPBT table with no command-line arguments (Mark Langsdorf) [1998269]
- ACPICA: Headers: Add new DBG2 Serial Port Subtypes (Mark Langsdorf) [1998269]
- ACPICA: Macros should not use a trailing semicolon (Mark Langsdorf) [1998269]
- ACPICA: Fix an if statement (add parens) (Mark Langsdorf) [1998269]
- ACPICA: iASL: Add support for the AEST table (data compiler) (Mark Langsdorf) [1998269]
- clk: fractional-divider: Introduce POWER_OF_TWO_PS flag (Mark Langsdorf) [1998269]
- ACPI: DPTF: Add new PCH FIVR methods (Mark Langsdorf) [1998269]
- clk: x86: Rename clk-lpt to more specific clk-lpss-atom (Mark Langsdorf) [1998269]
- ACPI: configfs: Make get_header() to return error pointer (Mark Langsdorf) [1998269]
- ACPI: configfs: Use sysfs_emit() in "show" functions (Mark Langsdorf) [1998269]
- ACPI: Add LoongArch support for ACPI_PROCESSOR/ACPI_NUMA (Mark Langsdorf) [1998269]
- ACPI / PMIC: XPower: optimize MIPI PMIQ sequence I2C-bus accesses (Mark Langsdorf) [1998269]
- ACPI / PMIC: XPower: optimize I2C-bus accesses (Mark Langsdorf) [1998269]

* Tue May 10 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-87.rt21.87.el9]
- [rt] build kernel-rt-5.14.0-87.rt21.87.el9 [2061574]
- redhat: Fix unset config items for kfence on RT (Fernando Pacheco)
- perf tools: Add external commands to list-cmds (Michael Petlan) [2065179]
- perf docs: Add perf-iostat link to manpages (Michael Petlan) [2065179]
- net: make use of helper netif_is_bridge_master() (Ivan Vecera) [2081260]
- xfrm: enforce validity of offload input flags (Sabrina Dubroca) [2080384]
- xfrm: Don't accidentally set RTO_ONLINK in decode_session4() (Sabrina Dubroca) [2080384]
- net/xfrm: IPsec tunnel mode fix inner_ipproto setting in sec_path (Sabrina Dubroca) [2080384]
- xfrm: fix a small bug in xfrm_sa_len() (Sabrina Dubroca) [2080384]
- xfrm: fix policy lookup for ipv6 gre packets (Sabrina Dubroca) [2080384]
- net/tls: fix slab-out-of-bounds bug in decrypt_internal (Sabrina Dubroca) [2080356]
- tls: cap the output scatter list to something reasonable (Sabrina Dubroca) [2080356]
- net/tls: Fix authentication failure in CCM mode (Sabrina Dubroca) [2080356]
- tls: fix replacing proto_ops (Sabrina Dubroca) [2080356]
- tls: splice_read: fix accessing pre-processed records (Sabrina Dubroca) [2080356]
- tls: splice_read: fix record type check (Sabrina Dubroca) [2080356]
- net: macsec: Verify that send_sci is on when setting Tx sci explicitly (Sabrina Dubroca) [2080352]
- net: macsec: Fix offload support for NETDEV_UNREGISTER event (Sabrina Dubroca) [2080352]
- sctp: check asoc strreset_chunk in sctp_generate_reconf_event (Xin Long) [2069957]
- udf: Restore i_lenAlloc when inode expansion fails (Carlos Maiolino) [2054658] {CVE-2022-0617}
- udf: Fix NULL ptr deref when converting from inline format (Carlos Maiolino) [2054658] {CVE-2022-0617}
- cifs: destage any unwritten data to the server before calling copychunk_write (Ronnie Sahlberg) [1997373]
- i40e: xsk: Move tmp desc array from driver to pool (Ivan Vecera) [2078894]
- printk: use atomic updates for klogd work (Prarit Bhargava) [2078897]
- genirq: Provide generic_handle_irq_safe() (Prarit Bhargava) [2078897]
- printk: Remove printk.h inclusion in percpu.h (Prarit Bhargava) [2078897]
- efi: Allow efi=runtime (Prarit Bhargava) [2078897]
- efi: Disable runtime services on RT (Prarit Bhargava) [2078897]
- x86/softirq: Disable softirq stacks on PREEMPT_RT (Prarit Bhargava) [2078897]
- genirq: Disable irqfixup/poll on PREEMPT_RT. (Prarit Bhargava) [2078897]
- genirq: Move prio assignment into the newly created thread (Prarit Bhargava) [2078897]
- cpufreq: intel_pstate: Use firmware default EPP (Steve Best) [2072886]
- cpufreq: intel_pstate: Update cpuinfo.max_freq on HWP_CAP changes (Steve Best) [2072886]
- cpufreq: intel_pstate: Update EPP for AlderLake mobile (Steve Best) [2072886]
- cpufreq: intel_pstate: Drop redundant intel_pstate_get_hwp_cap() call (Steve Best) [2072886]
- cpufreq: intel_pstate: ITMT support for overclocked system (Steve Best) [2072886]
- cpufreq: intel_pstate: Fix active mode offline/online EPP handling (Steve Best) [2072886]
- cpufreq: intel_pstate: Add Ice Lake server to out-of-band IDs (Steve Best) [2072886]
- drivers/base/memory: clarify adding and removing of memory blocks (David Hildenbrand) [2077436]
- drivers/base/memory: determine and store zone for single-zone memory blocks (David Hildenbrand) [2077436]
- drivers/base/node: rename link_mem_sections() to register_memory_block_under_node() (David Hildenbrand) [2077436]
- drivers/base/node: consolidate node device subsystem initialization in node_dev_init() (David Hildenbrand) [2077436]
- powerpc/kernel: Add __init attribute to eligible functions (David Hildenbrand) [2077436]
- drivers/base/memory: add memory block to memory group after registration succeeded (David Hildenbrand) [2077436]
- af_key: add __GFP_ZERO flag for compose_sadb_supported in function pfkey_register (Xin Long) [2075183]
- proc/vmcore: fix vmcore_alloc_buf() kernel-doc comment (Baoquan He) [2051908]
- proc/vmcore: fix possible deadlock on concurrent mmap and read (Baoquan He) [2051908]
- proc/vmcore: don't fake reading zeroes on surprise vmcore_cb unregistration (Baoquan He) [2051908]
- enable DAMON configs (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: update for schemes statistics (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/reclaim: document statistics parameters (Chris von Recklinghausen) [2004230]
- mm/damon: hide kernel pointer from tracepoint event (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: hide kernel pointer from damon_va_three_regions() failure log (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: use pr_debug() for damon_va_three_regions() failure logging (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: remove an unnecessary variable (Chris von Recklinghausen) [2004230]
- mm/damon: move the implementation of damon_insert_region to damon.h (Chris von Recklinghausen) [2004230]
- mm/damon: add access checking for hugetlb pages (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support all DAMOS stats (Chris von Recklinghausen) [2004230]
- mm/damon/reclaim: provide reclamation statistics (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: account how many times quota limit has exceeded (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: account scheme actions that successfully applied (Chris von Recklinghausen) [2004230]
- mm/damon: remove a mistakenly added comment for a future feature (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: update for kdamond_pid and (mk|rm)_contexts (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: mention tracepoint at the beginning (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: remove redundant information (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/usage: update for scheme quotas and watermarks (Chris von Recklinghausen) [2004230]
- mm/damon: convert macro functions to static inline functions (Chris von Recklinghausen) [2004230]
- mm/damon: modify damon_rand() macro to static inline function (Chris von Recklinghausen) [2004230]
- mm/damon: move damon_rand() definition into damon.h (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: add the validity judgment of thresholds (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: remove swap_ranges() and replace it with swap() (Chris von Recklinghausen) [2004230]
- mm/damon: remove some unneeded function definitions in damon.h (Chris von Recklinghausen) [2004230]
- mm/damon/core: use abs() instead of diff_of() (Chris von Recklinghausen) [2004230]
- mm/damon: add 'age' of region tracepoint support (Chris von Recklinghausen) [2004230]
- mm/damon: unified access_check function naming rules (Chris von Recklinghausen) [2004230]
- docs/vm: add vmalloced-kernel-stacks document (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: fix 'struct pid' leaks in 'dbgfs_target_ids_write()' (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: protect targets destructions with kdamond_lock (Chris von Recklinghausen) [2004230]
- selftests/damon: test debugfs file reads/writes with huge count (Chris von Recklinghausen) [2004230]
- selftests/damon: test DAMON enabling with empty target_ids case (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr-test: remove unnecessary variables (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: remove an unnecessary warning message (Chris von Recklinghausen) [2004230]
- mm/damon/core: remove unnecessary error messages (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: remove an unnecessary error message (Chris von Recklinghausen) [2004230]
- mm/damon/core: use better timer mechanisms selection threshold (Chris von Recklinghausen) [2004230]
- mm/damon/core: fix fake load reports due to uninterruptible sleeps (Chris von Recklinghausen) [2004230]
- timers: implement usleep_idle_range() (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: fix missed use of damon_dbgfs_lock (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: use '__GFP_NOWARN' for user-specified size buffer allocation (Chris von Recklinghausen) [2004230]
- mm/damon: remove return value from before_terminate callback (Chris von Recklinghausen) [2004230]
- mm/damon: fix a few spelling mistakes in comments and a pr_debug message (Chris von Recklinghausen) [2004230]
- mm/damon: simplify stop mechanism (Chris von Recklinghausen) [2004230]
- include/linux/delay.h: replace kernel.h with the necessary inclusions (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/pagemap: wordsmith page flags descriptions (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/start: simplify the content (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/start: fix a wrong link (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon/start: fix wrong example commands (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: add adaptive_targets list check before enable monitor_on (Chris von Recklinghausen) [2004230]
- mm/damon: remove unnecessary variable initialization (Chris von Recklinghausen) [2004230]
- Documentation/admin-guide/mm/damon: add a document for DAMON_RECLAIM (Chris von Recklinghausen) [2004230]
- mm/damon: introduce DAMON-based Reclamation (DAMON_RECLAIM) (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support watermarks (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: activate schemes based on a watermarks mechanism (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support prioritization weights (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr,paddr: support pageout prioritization (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: prioritize regions within the quotas (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support quotas of schemes (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: implement time quota (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: skip already charged targets and regions (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: implement size quota for schemes application speed control (Chris von Recklinghausen) [2004230]
- mm/damon/paddr: support the pageout scheme (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: remove unnecessary variables (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: constify static mm_walk_ops (Chris von Recklinghausen) [2004230]
- Docs/DAMON: document physical memory monitoring support (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support physical memory monitoring (Chris von Recklinghausen) [2004230]
- mm/damon: implement primitives for physical address space monitoring (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: separate commonly usable functions (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs-test: add a unit test case for 'init_regions' (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon: document 'init_regions' feature (Chris von Recklinghausen) [2004230]
- Docs/admin-guide/mm/damon: document DAMON-based Operation Schemes (Chris von Recklinghausen) [2004230]
- docs/vm/damon: remove broken reference (Chris von Recklinghausen) [2004230]
- Documentation/vm: move user guides to admin-guide/mm/ (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: allow users to set initial monitoring target regions (Chris von Recklinghausen) [2004230]
- mm/damon/schemes: implement statistics feature (Chris von Recklinghausen) [2004230]
- mm/damon/dbgfs: support DAMON-based Operation Schemes (Chris von Recklinghausen) [2004230]
- mm/damon/vaddr: support DAMON-based Operation Schemes (Chris von Recklinghausen) [2004230]
- mm/damon/core: implement DAMON-based Operation Schemes (DAMOS) (Chris von Recklinghausen) [2004230]
- mm/damon/core: account age of target regions (Chris von Recklinghausen) [2004230]
- mm/damon/core: nullify pointer ctx->kdamond with a NULL (Chris von Recklinghausen) [2004230]
- mm/damon: needn't hold kdamond_lock to print pid of kdamond (Chris von Recklinghausen) [2004230]
- mm/damon: remove unnecessary do_exit() from kdamond (Chris von Recklinghausen) [2004230]
- mm/damon/core: print kdamond start log in debug mode only (Chris von Recklinghausen) [2004230]
- mm/damon: grammar s/works/work/ (Chris von Recklinghausen) [2004230]
- drm/msm: Fix missing include files in msm_gem_shrinker.c (Chris von Recklinghausen) [2004230]
- NFSv4.2: Fix missing removal of SLAB_ACCOUNT on kmem_cache allocation (Waiman Long) [2013413]
- slab: remove __alloc_size attribute from __kmalloc_track_caller (Waiman Long) [2013413]
- mm: memcontrol: rename memcg_cache_id to memcg_kmem_id (Waiman Long) [2013413]
- mm: list_lru: rename list_lru_per_memcg to list_lru_memcg (Waiman Long) [2013413]
- mm: memcontrol: fix cannot alloc the maximum memcg ID (Waiman Long) [2013413]
- mm: memcontrol: reuse memory cgroup ID for kmem ID (Waiman Long) [2013413]
- mm: list_lru: replace linear array with xarray (Waiman Long) [2013413]
- mm: list_lru: rename memcg_drain_all_list_lrus to memcg_reparent_list_lrus (Waiman Long) [2013413]
- mm: list_lru: allocate list_lru_one only when needed (Waiman Long) [2013413]
- mm: memcontrol: move memcg_online_kmem() to mem_cgroup_css_online() (Waiman Long) [2013413]
- xarray: use kmem_cache_alloc_lru to allocate xa_node (Waiman Long) [2013413]
- mm: dcache: use kmem_cache_alloc_lru() to allocate dentry (Waiman Long) [2013413]
- fs: allocate inode by using alloc_inode_sb() (Waiman Long) [2013413]
- fs: introduce alloc_inode_sb() to allocate filesystems specific inode (Waiman Long) [2013413]
- mm: introduce kmem_cache_alloc_lru (Waiman Long) [2013413]
- mm: list_lru: transpose the array of per-node per-memcg lru lists (Waiman Long) [2013413]
- memcg: add per-memcg total kernel memory stat (Waiman Long) [2013413]
- memcg: add per-memcg vmalloc stat (Waiman Long) [2013413]
- mm: list_lru: only add memcg-aware lrus to the global lru list (Waiman Long) [2013413]
- mm: list_lru: fix the return value of list_lru_count_one() (Waiman Long) [2013413]
- mm: list_lru: remove holding lru lock (Waiman Long) [2013413]
- memcg, kmem: further deprecate kmem.limit_in_bytes (Waiman Long) [2013413]
- mm/list_lru.c: prefer struct_size over open coded arithmetic (Waiman Long) [2013413]
- slab: add __alloc_size attributes for better bounds checking (Waiman Long) [2013413]
- slab: clean up function prototypes (Waiman Long) [2013413]
- Compiler Attributes: add __alloc_size() for better bounds checking (Waiman Long) [2013413]
- Redhat: enable Kfence on production servers (Nico Pache) [2072662]
- kfence, x86: only define helpers if !MODULE (Nico Pache) [2072662]
- kfence: default to dynamic branch instead of static keys mode (Nico Pache) [2072662]
- kfence: test: try to avoid test_gfpzero trigger rcu_stall (Nico Pache) [2072662]
- kunit: fix UAF when run kfence test case test_gfpzero (Nico Pache) [2072662]
- kfence: alloc kfence_pool after system startup (Nico Pache) [2072662]
- kfence: allow re-enabling KFENCE after system startup (Nico Pache) [2072662]
- mm/kfence: remove unnecessary CONFIG_KFENCE option (Nico Pache) [2072662]
- kfence: make test case compatible with run time set sample interval (Nico Pache) [2072662]
- kfence: always use static branches to guard kfence_alloc() (Nico Pache) [2072662]
- kfence: shorten critical sections of alloc/free (Nico Pache) [2072662]
- kfence: test: use kunit_skip() to skip tests (Nico Pache) [2072662]
- kfence: limit currently covered allocations when pool nearly full (Nico Pache) [2072662]
- kfence: move saving stack trace of allocations into __kfence_alloc() (Nico Pache) [2072662]
- kfence: count unexpectedly skipped allocations (Nico Pache) [2072662]
- kfence: add function to mask address bits (Nico Pache) [2072662]
- cifs: verify that tcon is valid before dereference in cifs_kill_sb (Ronnie Sahlberg) [2048823]
- cifs: release cached dentries only if mount is complete (Ronnie Sahlberg) [2048823]
- cifs: we do not need a spinlock around the tree access during umount (Ronnie Sahlberg) [2048823]
- cifs: fix handlecache and multiuser (Ronnie Sahlberg) [2048823]
- cifs: fix workstation_name for multiuser mounts (Ronnie Sahlberg) [2048823]
- cifs: free ntlmsspblob allocated in negotiate (Ronnie Sahlberg) [2048823]
- cifs: fix ntlmssp auth when there is no key exchange (Ronnie Sahlberg) [2048823]
- cifs: send workstation name during ntlmssp session setup (Ronnie Sahlberg) [2048823]
- cifs: Fix crash on unload of cifs_arc4.ko (Ronnie Sahlberg) [2048823]
- Documentation, arch: Remove leftovers from CIFS_WEAK_PW_HASH (Ronnie Sahlberg) [2048823]
- cifs: fix the cifs_reconnect path for DFS (Ronnie Sahlberg) [2048823]
- cifs: sanitize multiple delimiters in prepath (Ronnie Sahlberg) [2048823]
- cifs: ignore resource_id while getting fscache super cookie (Ronnie Sahlberg) [2048823]
- cifs: avoid use of dstaddr as key for fscache client cookie (Ronnie Sahlberg) [2048823]
- cifs: add server conn_id to fscache client cookie (Ronnie Sahlberg) [2048823]
- cifs: wait for tcon resource_id before getting fscache super (Ronnie Sahlberg) [2048823]
- cifs: fix missed refcounting of ipc tcon (Ronnie Sahlberg) [2048823]
- cifs: update internal version number (Ronnie Sahlberg) [2048823]
- smb2: clarify rc initialization in smb2_reconnect (Ronnie Sahlberg) [2048823]
- cifs: populate server_hostname for extra channels (Ronnie Sahlberg) [2048823]
- cifs: nosharesock should be set on new server (Ronnie Sahlberg) [2048823]
- cifs: introduce cifs_ses_mark_for_reconnect() helper (Ronnie Sahlberg) [2048823]
- cifs: protect srv_count with cifs_tcp_ses_lock (Ronnie Sahlberg) [2048823]
- cifs: move debug print out of spinlock (Ronnie Sahlberg) [2048823]
- cifs: do not duplicate fscache cookie for secondary channels (Ronnie Sahlberg) [2048823]
- cifs: connect individual channel servers to primary channel server (Ronnie Sahlberg) [2048823]
- cifs: protect session channel fields with chan_lock (Ronnie Sahlberg) [2048823]
- cifs: do not negotiate session if session already exists (Ronnie Sahlberg) [2048823]
- smb3: do not setup the fscache_super_cookie until fsinfo initialized (Ronnie Sahlberg) [2048823]
- cifs: fix potential use-after-free bugs (Ronnie Sahlberg) [2048823]
- cifs: fix memory leak of smb3_fs_context_dup::server_hostname (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB311_posix_mkdir (Ronnie Sahlberg) [2048823]
- cifs: release lock earlier in dequeue_mid error case (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB2_tcon (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB2_open (Ronnie Sahlberg) [2048823]
- smb3: add additional null check in SMB2_ioctl (Ronnie Sahlberg) [2048823]
- smb3: remove trivial dfs compile warning (Ronnie Sahlberg) [2048823]
- cifs: support nested dfs links over reconnect (Ronnie Sahlberg) [2048823]
- smb3: do not error on fsync when readonly (Ronnie Sahlberg) [2048823]
- cifs: for compound requests, use open handle if possible (Ronnie Sahlberg) [2048823]
- cifs: set a minimum of 120s for next dns resolution (Ronnie Sahlberg) [2048823]
- cifs: split out dfs code from cifs_reconnect() (Ronnie Sahlberg) [2048823]
- cifs: convert list_for_each to entry variant (Ronnie Sahlberg) [2048823]
- cifs: introduce new helper for cifs_reconnect() (Ronnie Sahlberg) [2048823]
- cifs: fix print of hdr_flags in dfscache_proc_show() (Ronnie Sahlberg) [2048823]
- cifs: nosharesock should not share socket with future sessions (Ronnie Sahlberg) [2048823]
- smb3: add dynamic trace points for socket connection (Ronnie Sahlberg) [2048823]
- cifs: Move SMB2_Create definitions to the shared area (Ronnie Sahlberg) [2048823]
- cifs: Move more definitions into the shared area (Ronnie Sahlberg) [2048823]
- cifs: move NEGOTIATE_PROTOCOL definitions out into the common area (Ronnie Sahlberg) [2048823]
- cifs: Create a new shared file holding smb2 pdu definitions (Ronnie Sahlberg) [2048823]
- cifs: add mount parameter tcpnodelay (Ronnie Sahlberg) [2048823]
- cifs: To match file servers, make sure the server hostname matches (Ronnie Sahlberg) [2048823]
- cifs: fix incorrect check for null pointer in header_assemble (Ronnie Sahlberg) [2048823]
- smb3: correct server pointer dereferencing check to be more consistent (Ronnie Sahlberg) [2048823]
- smb3: correct smb3 ACL security descriptor (Ronnie Sahlberg) [2048823]
- cifs: Clear modified attribute bit from inode flags (Ronnie Sahlberg) [2048823]
- cifs: Deal with some warnings from W=1 (Ronnie Sahlberg) [2048823]
- cifs: fix a sign extension bug (Ronnie Sahlberg) [2048823]
- cifs: Not to defer close on file when lock is set (Ronnie Sahlberg) [2048823]
- cifs: Fix soft lockup during fsstress (Ronnie Sahlberg) [2048823]
- cifs: Deferred close performance improvements (Ronnie Sahlberg) [2048823]
- cifs: fix incorrect kernel doc comments (Ronnie Sahlberg) [2048823]
- cifs: remove pathname for file from SPDX header (Ronnie Sahlberg) [2048823]
- cifs: properly invalidate cached root handle when closing it (Ronnie Sahlberg) [2048823]
- cifs: move SMB FSCTL definitions to common code (Ronnie Sahlberg) [2048823]
- cifs: rename cifs_common to smbfs_common (Ronnie Sahlberg) [2048823]
- cifs: cifs_md4 convert to SPDX identifier (Ronnie Sahlberg) [2048823]
- cifs: create a MD4 module and switch cifs.ko to use it (Ronnie Sahlberg) [2048823]
- cifs: fork arc4 and create a separate module for it for cifs and other users (Ronnie Sahlberg) [2048823]
- cifs: remove support for NTLM and weaker authentication algorithms (Ronnie Sahlberg) [2048823]
- cifs: update FSCTL definitions (Ronnie Sahlberg) [2048823]
- cifs: Do not leak EDEADLK to dgetents64 for STATUS_USER_SESSION_DELETED (Ronnie Sahlberg) [2048823]
- cifs: enable fscache usage even for files opened as rw (Ronnie Sahlberg) [2048823]
- smb3: fix posix extensions mount option (Ronnie Sahlberg) [2048823]
- cifs: fix wrong release in sess_alloc_buffer() failed path (Ronnie Sahlberg) [2048823]
- CIFS: Fix a potencially linear read overflow (Ronnie Sahlberg) [2048823]

* Fri May 06 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-86.rt21.86.el9]
- [rt] build kernel-rt-5.14.0-86.rt21.86.el9 [2061574]
- configs: enable LOGITECH_FF (Benjamin Tissoires) [2070018]
- veth: Ensure eth header is in skb's linear part (Guillaume Nault) [2040238]
- virtchnl: Add support for new VLAN capabilities (Ivan Vecera) [2078776]
- virtchnl: Use the BIT() macro for capability/offload flags (Ivan Vecera) [2078776]
- virtchnl: Remove unused VIRTCHNL_VF_OFFLOAD_RSVD define (Ivan Vecera) [2078776]
- skbuff: introduce skb_pull_data (Ivan Vecera) [2078759]
- redhat/configs: Add CONFIG_PERF_EVENTS_AMD_UNCORE (Michael Petlan) [2069070]
- perf callchain: Fix compilation on powerpc with gcc11+ (Michael Petlan) [2069070]
- perf script: Check session->header.env.arch before using it (Michael Petlan) [2069070]
- perf build: Suppress 'rm dlfilter' build message (Michael Petlan) [2069070]
- libperf tests: Fix test_stat_cpu (Michael Petlan) [2069070]
- libperf test evsel: Fix build error on !x86 architectures (Michael Petlan) [2069070]
- perf report: Output non-zero offset for decompressed records (Michael Petlan) [2069070]
- perf build: Fix plugin static linking with libopencsd on ARM and ARM64 (Michael Petlan) [2069070]
- perf build: Add missing -lstdc++ when linking with libopencsd (Michael Petlan) [2069070]
- perf jevents: Free the sys_event_tables list after processing entries (Michael Petlan) [2069070]
- perf iostat: Fix Segmentation fault from NULL 'struct perf_counts_values *' (Michael Petlan) [2069070]
- perf iostat: Use system-wide mode if the target cpu_list is unspecified (Michael Petlan) [2069070]
- perf config: Refine error message to eliminate confusion (Michael Petlan) [2069070]
- perf doc: Fix typos all over the place (Michael Petlan) [2069070]
- perf arm: Fix off-by-one directory paths. (Michael Petlan) [2069070]
- perf vendor events powerpc: Fix spelling mistake "icach" -> "icache" (Michael Petlan) [2069070]
- perf tests: Fix flaky test 'Object code reading' (Michael Petlan) [2069070]
- perf test: Fix DWARF unwind for optimized builds. (Michael Petlan) [2069070]
- perf bpf: Ignore deprecation warning when using libbpf's btf__get_from_id() (Michael Petlan) [2069070]
- libperf evsel: Make use of FD robust. (Michael Petlan) [2069070]
- perf machine: Initialize srcline string member in add_location struct (Michael Petlan) [2069070]
- perf script: Fix ip display when type != attr->type (Michael Petlan) [2069070]
- perf annotate: Fix fused instr logic for assembly functions (Michael Petlan) [2069070]
- perf tools: Add an option to build without libbfd (Michael Petlan) [2069070]
- perf tools: Allow build-id with trailing zeros (Michael Petlan) [2069070]
- perf tools: Fix hybrid config terms list corruption (Michael Petlan) [2069070]
- perf tools: Factor out copy_config_terms() and free_config_terms() (Michael Petlan) [2069070]
- perf tools: Fix perf_event_attr__fprintf() missing/dupl. fields (Michael Petlan) [2069070]
- perf tools: Ignore Documentation dependency file (Michael Petlan) [2069070]
- perf bpf: Provide a weak btf__load_from_kernel_by_id() for older libbpf versions (Michael Petlan) [2069070]
- perf beauty: Cover more flags in the  move_mount syscall argument beautifier (Michael Petlan) [2069070]
- perf report: Add support to print a textual representation of IBS raw sample data (Michael Petlan) [2069070]
- perf report: Add tools/arch/x86/include/asm/amd-ibs.h (Michael Petlan) [2069070]
- perf env: Add perf_env__cpuid, perf_env__{nr_}pmu_mappings (Michael Petlan) [2069070]
- perf symbol: Look for ImageBase in PE file to compute .text offset (Michael Petlan) [2069070]
- perf scripts python: Fix passing arguments to stackcollapse report (Michael Petlan) [2069070]
- perf test: Fix bpf test sample mismatch reporting (Michael Petlan) [2069070]
- perf beauty: Update copy of linux/socket.h with the kernel sources (Michael Petlan) [2069070]
- perf tests: Add test for PMU aliases (Michael Petlan) [2069070]
- perf pmu: Add PMU alias support (Michael Petlan) [2069070]
- perf session: Report collisions in AUX records (Michael Petlan) [2069070]
- perf script python: Allow reporting the [un]throttle PERF_RECORD_ meta event (Michael Petlan) [2069070]
- perf build: Report failure for testing feature libopencsd (Michael Petlan) [2069070]
- perf cs-etm: Show a warning for an unknown magic number (Michael Petlan) [2069070]
- perf cs-etm: Print the decoder name (Michael Petlan) [2069070]
- perf cs-etm: Create ETE decoder (Michael Petlan) [2069070]
- perf cs-etm: Update OpenCSD decoder for ETE (Michael Petlan) [2069070]
- perf cs-etm: Fix typo (Michael Petlan) [2069070]
- perf cs-etm: Save TRCDEVARCH register (Michael Petlan) [2069070]
- perf cs-etm: Refactor out ETMv4 header saving (Michael Petlan) [2069070]
- perf cs-etm: Initialise architecture based on TRCIDR1 (Michael Petlan) [2069070]
- perf cs-etm: Refactor initialisation of decoder params. (Michael Petlan) [2069070]
- tools build: Fix feature detect clean for out of source builds (Michael Petlan) [2069070]
- perf evlist: Add evlist__for_each_entry_from() macro (Michael Petlan) [2069070]
- perf evsel: Handle precise_ip fallback in evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Move bpf_counter__install_pe() to success path in evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Move test_attr__open() to success path in evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Move ignore_missing_thread() to fallback code (Michael Petlan) [2069070]
- perf evsel: Separate rlimit increase from evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Separate missing feature detection from evsel__open_cpu() (Michael Petlan) [2069070]
- perf evsel: Add evsel__prepare_open() (Michael Petlan) [2069070]
- perf evsel: Separate missing feature disabling from evsel__open_cpu (Michael Petlan) [2069070]
- perf evsel: Save open flags in evsel in prepare_open() (Michael Petlan) [2069070]
- perf evsel: Separate open preparation from open itself (Michael Petlan) [2069070]
- perf evsel: Remove retry_sample_id goto label (Michael Petlan) [2069070]
- perf mmap: Add missing bitops.h header (Michael Petlan) [2069070]
- libperf cpumap: Take into advantage it is sorted to optimize perf_cpu_map__max() (Michael Petlan) [2069070]
- libsubcmd: add OPT_UINTEGER_OPTARG option type (Michael Petlan) [2069070]
- perf tools: Fix LLVM download hint link (Michael Petlan) [2069070]
- perf tools: Fix LLVM test failure when running in verbose mode (Michael Petlan) [2069070]
- perf tools: Refactor LLVM test warning for missing binary (Michael Petlan) [2069070]
- perf auxtrace arm: Support compat_auxtrace_mmap__{read_head|write_tail} (Michael Petlan) [2069070]
- perf auxtrace: Add compat_auxtrace_mmap__{read_head|write_tail} (Michael Petlan) [2069070]
- perf bpf: Fix memory leaks relating to BTF. (Michael Petlan) [2069070]
- perf data: Correct -h output (Michael Petlan) [2069070]
- perf header: Fix spelling mistake "cant'" -> "can't" (Michael Petlan) [2069070]
- perf dlfilters: Fix build on environments with a --sysroot gcc arg (Michael Petlan) [2069070]
- perf record: Fix wrong comm in system-wide mode with delay (Michael Petlan) [2069070]
- perf stat: Do not allow --for-each-cgroup without cpu (Michael Petlan) [2069070]
- perf bench evlist-open-close: Use PRIu64 with u64 to fix build on 32-bit architectures (Michael Petlan) [2069070]
- perf tests: Fix *probe_vfs_getname.sh test failures (Michael Petlan) [2069070]
- perf bench inject-buildid: Handle writen() errors (Michael Petlan) [2069070]
- perf unwind: Do not overwrite FEATURE_CHECK_LDFLAGS-libunwind-{x86,aarch64} (Michael Petlan) [2069070]
- perf config: Fix caching and memory leak in perf_home_perfconfig() (Michael Petlan) [2069070]
- perf tools: Fixup get_current_dir_name() compilation (Michael Petlan) [2069070]
- libperf tests: Fix verbose printing (Michael Petlan) [2069070]
- perf tools: Add missing newline at the end of header file (Michael Petlan) [2069070]
- perf tests dlfilter: Free desc and long_desc in check_filter_desc (Michael Petlan) [2069070]
- tools: Add sparse context/locking annotations in compiler-types.h (Michael Petlan) [2069070]
- perf test: Do not compare overheads in the zstd comp test (Michael Petlan) [2069070]
- perf tools: Enable on a list of CPUs for hybrid (Michael Petlan) [2069070]
- perf tools: Create hybrid flag in target (Michael Petlan) [2069070]
- libperf: Add perf_cpu_map__default_new() (Michael Petlan) [2069070]
- perf test: Make --skip work on shell tests (Michael Petlan) [2069070]
- perf tests: Add dlfilter test (Michael Petlan) [2069070]
- perf build: Move perf_dlfilters.h in the source tree (Michael Petlan) [2069070]
- perf dlfilter: Amend documentation wrt library dependencies (Michael Petlan) [2069070]
- perf script: Fix --list-dlfilters documentation (Michael Petlan) [2069070]
- perf script: Fix unnecessary machine_resolve() (Michael Petlan) [2069070]
- perf script: Fix documented const'ness of perf_dlfilter_fns (Michael Petlan) [2069070]
- perf vendor events: Update metrics for SkyLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update uncore event list for SkyLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update core event list for SkyLake Server (Michael Petlan) [2069070]
- perf vendor events: Update metrics for CascadeLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update uncore event list for CascadeLake Server (Michael Petlan) [2069070]
- perf vendor events intel: Update core event list for CascadeLake Server (Michael Petlan) [2069070]
- perf test: Add pmu-events sys event support (Michael Petlan) [2069070]
- perf jevents: Print SoC name per system event table (Michael Petlan) [2069070]
- perf pmu: Make pmu_add_sys_aliases() public (Michael Petlan) [2069070]
- perf test: Add more pmu-events uncore aliases (Michael Petlan) [2069070]
- perf test: Re-add pmu-event uncore PMU alias test (Michael Petlan) [2069070]
- perf pmu: Check .is_uncore field in pmu_add_cpu_aliases_map() (Michael Petlan) [2069070]
- perf test: Test pmu-events core aliases separately (Michael Petlan) [2069070]
- perf test: Factor out pmu-events alias comparison (Michael Petlan) [2069070]
- perf test: Declare pmu-events test events separately (Michael Petlan) [2069070]
- perf jevents: Relocate test events to cpu folder (Michael Petlan) [2069070]
- perf test: Factor out pmu-events event comparison (Michael Petlan) [2069070]
- perf jevents: Make build dependency on test JSONs (Michael Petlan) [2069070]
- perf bench: Add benchmark for evlist open/close operations (Michael Petlan) [2069070]
- perf docs: Fix accidental em-dashes (Michael Petlan) [2069070]
- perf env: Track kernel 64-bit mode in environment (Michael Petlan) [2069070]
- tools: Remove feature-sync-compare-and-swap feature detection (Michael Petlan) [2069070]
- perf: Cleanup for HAVE_SYNC_COMPARE_AND_SWAP_SUPPORT (Michael Petlan) [2069070]
- perf auxtrace: Remove auxtrace_mmap__read_snapshot_head() (Michael Petlan) [2069070]
- perf auxtrace: Drop legacy __sync functions (Michael Petlan) [2069070]
- perf auxtrace: Use WRITE_ONCE() for updating aux_tail (Michael Petlan) [2069070]
- perf script python: Fix unintended underline (Michael Petlan) [2069070]
- perf cs-etm: Add warnings for missing DSOs (Michael Petlan) [2069070]
- perf vendor events: Add metrics for Icelake Server (Michael Petlan) [2069070]
- perf bench futex, requeue: Add --pi parameter (Michael Petlan) [2069070]
- perf bench futex, requeue: Robustify futex_wait() handling (Michael Petlan) [2069070]
- perf bench futex, requeue: Add --broadcast option (Michael Petlan) [2069070]
- perf bench futex: Add --mlockall parameter (Michael Petlan) [2069070]
- perf bench futex: Remove bogus backslash from comment (Michael Petlan) [2069070]
- perf bench futex: Group test parameters cleanup (Michael Petlan) [2069070]
- perf cs-etm: Improve Coresight zero timestamp warning (Michael Petlan) [2069070]
- perf tools: Add flag for tracking warnings of missing DSOs (Michael Petlan) [2069070]
- perf annotate: Add disassembly warnings for annotate --stdio (Michael Petlan) [2069070]
- perf annotate: Re-add annotate_warned functionality (Michael Petlan) [2069070]
- perf tools: Add WARN_ONCE equivalent for UI warnings (Michael Petlan) [2069070]
- perf tools: Add pipe_test.sh to verify pipe operations (Michael Petlan) [2069070]
- perf inject: Fix output from a file to a pipe (Michael Petlan) [2069070]
- perf inject: Fix output from a pipe to a file (Michael Petlan) [2069070]
- perf tools: Pass a fd to perf_file_header__read_pipe() (Michael Petlan) [2069070]
- perf tools: Remove repipe argument from perf_session__new() (Michael Petlan) [2069070]
- perf vendor events intel: Add basic metrics for Elkhartlake (Michael Petlan) [2069070]
- perf vendor events intel: Add core event list for Elkhartlake (Michael Petlan) [2069070]
- perf vendor events: Add metrics for Tigerlake (Michael Petlan) [2069070]
- perf vendor events intel: Add core event list for Tigerlake (Michael Petlan) [2069070]
- perf annotate: Add error log in symbol__annotate() (Michael Petlan) [2069070]
- perf env: Normalize aarch64.* and arm64.* to arm64 in normalize_arch() (Michael Petlan) [2069070]
- perf beauty: Reuse the generic arch errno switch (Michael Petlan) [2069070]
- perf doc: Reorganize ARTICLES variables. (Michael Petlan) [2069070]
- perf doc: Remove howto-index.sh related references. (Michael Petlan) [2069070]
- perf doc: Remove cmd-list.perl references (Michael Petlan) [2069070]
- perf doc: Add info pages to all target. (Michael Petlan) [2069070]
- perf doc: Remove references to user-manual (Michael Petlan) [2069070]
- perf doc: Fix doc.dep (Michael Petlan) [2069070]
- perf doc: Fix perfman.info build (Michael Petlan) [2069070]
- perf cs-etm: Pass unformatted flag to decoder (Michael Petlan) [2069070]
- perf cs-etm: Use existing decoder instead of resetting it (Michael Petlan) [2069070]
- perf cs-etm: Suppress printing when resetting decoder (Michael Petlan) [2069070]
- perf cs-etm: Only setup queues when they are modified (Michael Petlan) [2069070]
- perf cs-etm: Split setup and timestamp search functions (Michael Petlan) [2069070]
- perf cs-etm: Refactor initialisation of kernel start address (Michael Petlan) [2069070]
- perf trace: Update cmd string table to decode sys_bpf first arg (Michael Petlan) [2069070]
- perf/x86/msr: Add Sapphire Rapids CPU support (Michael Petlan) [2069070]
- perf/core: fix userpage->time_enabled of inactive events (Michael Petlan) [2069070]
- perf/x86/intel: Update event constraints for ICX (Michael Petlan) [2069070]
- perf/x86: Reset destroy callback on event init failure (Michael Petlan) [2069070]
- events: Reuse value read using READ_ONCE instead of re-reading it (Michael Petlan) [2069070]
- perf/x86/amd/ibs: Add bitfield definitions in new <asm/amd-ibs.h> header (Michael Petlan) [2069070]
- perf/amd/uncore: Allow the driver to be built as a module (Michael Petlan) [2069070]
- perf/amd/uncore: Clean up header use, use <linux/ include paths instead of <asm/ (Michael Petlan) [2069070]
- perf/amd/uncore: Simplify code, use free_percpu()'s built-in check for NULL (Michael Petlan) [2069070]
- perf/x86: Remove unused assignment to pointer 'e' (Michael Petlan) [2069070]
- perf/x86/intel/uncore: Fix IIO cleanup mapping procedure for SNR/ICX (Michael Petlan) [2069070]
- cifs: fix NULL ptr dereference in smb2_ioctl_query_info() (Ronnie Sahlberg) [2074302]
- cifs: prevent bad output lengths in smb2_ioctl_query_info() (Ronnie Sahlberg) [2074302]
- ping: remove pr_err from ping_lookup (Xin Long) [2054023]
- ping: fix the dif and sdif check in ping_lookup (Xin Long) [2054023]
- ping: fix the sk_bound_dev_if match in ping_lookup (Xin Long) [2054023]
- redhat: configs: add CONFIG_INTEL_IDXD_COMPAT (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Remove useless DMA-32 fallback configuration (Jerry Snitselaar) [2072168]
- dmaengine: idxd: restore traffic class defaults after wq reset (Jerry Snitselaar) [2046470]
- dmaengine: idxd: deprecate token sysfs attributes for read buffers (Jerry Snitselaar) [2040044]
- dmaengine: idxd: change bandwidth token to read buffers (Jerry Snitselaar) [2040044]
- dmaengine: idxd: fix wq settings post wq disable (Jerry Snitselaar) [2040046]
- dmaengine: idxd: change MSIX allocation based on per wq activation (Jerry Snitselaar) [2040496]
- dmaengine: idxd: fix descriptor flushing locking (Jerry Snitselaar) [2040496]
- dmaengine: idxd: embed irq_entry in idxd_wq struct (Jerry Snitselaar) [2040496]
- dmaengine: idxd: fix missed completion on abort path (Jerry Snitselaar) [2040041]
- dmaengine: idxd: fix calling wq quiesce inside spinlock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: add knob for enqcmds retries (Jerry Snitselaar) [2040048]
- dmaengine: idxd: set defaults for wq configs (Jerry Snitselaar) [2040048]
- dmaengine: idxd: handle interrupt handle revoked event (Jerry Snitselaar) [2040052]
- dmaengine: idxd: handle invalid interrupt handle descriptors (Jerry Snitselaar) [2040052]
- dmaengine: idxd: create locked version of idxd_quiesce() call (Jerry Snitselaar) [2040052]
- dmaengine: idxd: add helper for per interrupt handle drain (Jerry Snitselaar) [2040052]
- dmaengine: idxd: move interrupt handle assignment (Jerry Snitselaar) [2040052]
- dmaengine: idxd: int handle management refactoring (Jerry Snitselaar) [2040052]
- dmaengine: idxd: rework descriptor free path on failure (Jerry Snitselaar) [2040052]
- dmaengine: idxd: fix resource leak on dmaengine driver disable (Jerry Snitselaar) [2040041]
- dmaengine: idxd: cleanup completion record allocation (Jerry Snitselaar) [2040041]
- dmaengine: idxd: reconfig device after device reset command (Jerry Snitselaar) [2040041]
- dmaengine: idxd: add halt interrupt support (Jerry Snitselaar) [2040048]
- dmaengine: idxd: Use list_move_tail instead of list_del/list_add_tail (Jerry Snitselaar) [2072168]
- dmanegine: idxd: fix resource free ordering on driver removal (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove kernel wq type set when load configuration (Jerry Snitselaar) [2072168]
- dmaengine: idxd: remove gen cap field per spec 1.2 update (Jerry Snitselaar) [2040041]
- dmaengine: idxd: check GENCAP config support for gencfg register (Jerry Snitselaar) [2040041]
- dmaengine: idxd: move out percpu_ref_exit() to ensure it's outside submission (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove interrupt disable for dev_lock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove interrupt disable for cmd_lock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: fix setting up priv mode for dwq (Jerry Snitselaar) [2040041]
- dmaengine: idxd: set descriptor allocation size to threshold for swq (Jerry Snitselaar) [2040041]
- dmaengine: idxd: make submit failure path consistent on desc freeing (Jerry Snitselaar) [2040041]
- dmaengine: idxd: remove interrupt flag for completion list spinlock (Jerry Snitselaar) [2040041]
- dmaengine: idxd: make I/O interrupt handler one shot (Jerry Snitselaar) [2040041]
- dmaengine: idxd: clear block on fault flag when clear wq (Jerry Snitselaar) [2040041]
- dmaengine: idxd: add capability check for 'block on fault' attribute (Jerry Snitselaar) [2040041]
- dmaengine: idxd: Remove unused status variable in irq_process_work_list() (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Fix a possible NULL pointer dereference (Jerry Snitselaar) [2072168]
- dmaengine: idxd: fix abort status check (Jerry Snitselaar) [2040041]
- dmanegine: idxd: add software command status (Jerry Snitselaar) [2040048]
- dmaengine: idxd: rotate portal address for better performance (Jerry Snitselaar) [2040048]
- dmaengine: idxd: fix wq slot allocation index check (Jerry Snitselaar) [2040041]
- dmaengine: idxd: fix uninit var for alt_drv (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Set defaults for GRPCFG traffic class (Jerry Snitselaar) [2040048]
- dmaengine: idxd: remove fault processing code (Jerry Snitselaar) [2040041]
- dmaengine: idxd: move dsa_drv support to compatible mode (Jerry Snitselaar) [1971962]
- dmaengine: dsa: move dsa_bus_type out of idxd driver to standalone (Jerry Snitselaar) [1971962]
- dmaengine: idxd: create user driver for wq 'device' (Jerry Snitselaar) [1971962]
- dmaengine: idxd: create dmaengine driver for wq 'device' (Jerry Snitselaar) [1971962]
- dmaengine: idxd: create idxd_device sub-driver (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add type to driver in order to allow device matching (Jerry Snitselaar) [1971962]
- dmanegine: idxd: open code the dsa_drv registration (Jerry Snitselaar) [1971962]
- dmaengine: idxd: idxd: move remove() bits for idxd 'struct device' to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: move probe() bits for idxd 'struct device' to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: fix bus_probe() and bus_remove() for dsa_bus (Jerry Snitselaar) [1971962]
- dmaengine: idxd: remove iax_bus_type prototype (Jerry Snitselaar) [1971962]
- dmaengine: idxd: remove bus shutdown (Jerry Snitselaar) [1971962]
- dmaengine: idxd: move wq_disable() to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: move wq_enable() to device.c (Jerry Snitselaar) [1971962]
- dmaengine: idxd: remove IDXD_DEV_CONF_READY (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add 'struct idxd_dev' as wrapper for conf_dev (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add driver name (Jerry Snitselaar) [1971962]
- dmaengine: idxd: add driver register helper (Jerry Snitselaar) [1971962]
- dmaengine: idxd: assign MSIX vectors to each WQ rather than roundrobin (Jerry Snitselaar) [2072168]
- dmaengine: idxd: add missing percpu ref put on failure (Jerry Snitselaar) [2072168]
- dmaengine: idxd: have command status always set (Jerry Snitselaar) [1973884]
- dmanegine: idxd: cleanup all device related bits after disabling device (Jerry Snitselaar) [2072168]
- dmaengine: idxd: Simplify code and axe the use of a deprecated API (Jerry Snitselaar) [2072168]
- x86/fpu/xstate: Consolidate size calculations (Jerry Snitselaar) [2004573]
- x86/fpu/xstate: Handle supervisor states in XSTATE permissions (Jerry Snitselaar) [2004573]
- x86/fpu/xsave: Handle compacted offsets correctly with supervisor states (Jerry Snitselaar) [2004573]
- x86/fpu: Cache xfeature flags from CPUID (Jerry Snitselaar) [2004573]
- x86/fpu/xsave: Initialize offset/size cache early (Jerry Snitselaar) [2004573]
- x86/fpu: Remove unused supervisor only offsets (Jerry Snitselaar) [2004573]
- Documentation/x86: Update documentation for SVA (Shared Virtual Addressing) (Jerry Snitselaar) [2004573]
- tools/objtool: Check for use of the ENQCMD instruction in the kernel (Jerry Snitselaar) [2004573]
- x86/cpufeatures: Re-enable ENQCMD (Jerry Snitselaar) [2004573]
- x86/traps: Demand-populate PASID MSR via #GP (Jerry Snitselaar) [2004573]
- sched: Define and initialize a flag to identify valid PASID in the task (Jerry Snitselaar) [2004573]
- x86/fpu: Clear PASID when copying fpstate (Jerry Snitselaar) [2004573]
- iommu/sva: Assign a PASID to mm on PASID allocation and free it on mm exit (Jerry Snitselaar) [2004573]
- kernel/fork: Initialize mm's PASID (Jerry Snitselaar) [2004573]
- iommu/ioasid: Introduce a helper to check for valid PASIDs (Jerry Snitselaar) [2004573]
- mm: Change CONFIG option for mm->pasid field (Jerry Snitselaar) [2004573]
- iommu/sva: Rename CONFIG_IOMMU_SVA_LIB to CONFIG_IOMMU_SVA (Jerry Snitselaar) [2004573]
- stddef: Introduce DECLARE_FLEX_ARRAY() helper (Josef Oskera) [2069567]
- iommu/vt-d: Use correctly sized arguments for bit field (Jerry Snitselaar) [2068207]
- redhat: configs: Enable CONFIG_INTEL_IOMMU_DEBUGFS (Jerry Snitselaar) [2068207]

* Wed May 04 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-85.rt21.85.el9]
- [rt] build kernel-rt-5.14.0-85.rt21.85.el9 [2061574]
- net: mana: Remove unnecessary check of cqe_type in mana_process_rx_cqe() (Mohammed Gamal) [2064198]
- net: mana: Add handling of CQE_RX_TRUNCATED (Mohammed Gamal) [2064198]
- ipv6: make ip6_rt_gc_expire an atomic_t (Hangbin Liu) [2077372]
- ipv6: fix panic when forwarding a pkt with no in6 dev (Hangbin Liu) [2077372]
- ipv6: Fix stats accounting in ip6_pkt_drop (Hangbin Liu) [2077372]
- net: ipv6: ensure we call ipv6_mc_down() at most once (Hangbin Liu) [2077372]
- ipv6: fix data-race in fib6_info_hw_flags_set / fib6_purge_rt (Hangbin Liu) [2077372]
- ipv6: per-netns exclusive flowlabel checks (Hangbin Liu) [2077372]
- ipv6: mcast: use rcu-safe version of ipv6_get_lladdr() (Hangbin Liu) [2077372]
- ipmr,ip6mr: acquire RTNL before calling ip[6]mr_free_table() on failure path (Hangbin Liu) [2077372]
- ipv6: annotate accesses to fn->fn_sernum (Hangbin Liu) [2077372]
- redhat/configs: enable CONFIG_RANDOMIZE_KSTACK_OFFSET_DEFAULT (Joel Savitz) [2026319]
- net: annotate accesses to dev->gso_max_segs (Ivan Vecera) [2073465]
- net: annotate accesses to dev->gso_max_size (Ivan Vecera) [2073465]
- PCI/VGA: Move vgaarb to drivers/pci (Karol Herbst) [2072020]
- vgaarb: don't pass a cookie to vga_client_register (Karol Herbst) [2072020]
- vgaarb: remove the unused irq_set_state argument to vga_client_register (Karol Herbst) [2072020]
- vgaarb: provide a vga_client_unregister wrapper (Karol Herbst) [2072020]
- vgaarb: cleanup vgaarb.h (Karol Herbst) [2072020]
- vgaarb: move the kerneldoc for vga_set_legacy_decoding to vgaarb.c (Karol Herbst) [2072020]
- vgaarb: remove vga_conflicts (Karol Herbst) [2072020]
- vgaarb: remove VGA_DEFAULT_DEVICE (Karol Herbst) [2072020]
- agp/intel-gtt: reduce intel-gtt dependencies more (Karol Herbst) [2072020]
- agp/intel-gtt: Replace kernel.h with the necessary inclusions (Karol Herbst) [2072020]
- component: Add common helper for compare/release functions (Karol Herbst) [2072020]
- lib/string_helpers: Consolidate string helpers implementation (Karol Herbst) [2072020]
- include/linux/string_helpers.h: add linux/string.h for strlen() (Karol Herbst) [2072020]
- linux/container_of.h: switch to static_assert (Karol Herbst) [2072020]
- kernel.h: split out container_of() and typeof_member() macros (Karol Herbst) [2072020]
- x86/kvmclock: Fix Hyper-V Isolated VM's boot issue when vCPUs > 64 (Karol Herbst) [2072020]
- x86/kvm: Don't waste memory if kvmclock is disabled (Karol Herbst) [2072020]
- treewide: Replace the use of mem_encrypt_active() with cc_platform_has() (Karol Herbst) [2072020]
- x86/sev: Replace occurrences of sev_es_active() with cc_platform_has() (Karol Herbst) [2072020]
- x86/sev: Replace occurrences of sev_active() with cc_platform_has() (Karol Herbst) [2072020]
- x86/sme: Replace occurrences of sme_active() with cc_platform_has() (Karol Herbst) [2072020]
- powerpc/pseries/svm: Add a powerpc version of cc_platform_has() (Karol Herbst) [2072020]
- x86/sev: Add an x86 version of cc_platform_has() (Karol Herbst) [2072020]
- arch/cc: Introduce a function to check for confidential computing features (Karol Herbst) [2072020]
- x86/ioremap: Selectively build arch override encryption functions (Karol Herbst) [2072020]
- lib: devres: Add managed arch_io_reserve_memtype_wc() (Karol Herbst) [2072020]
- lib: devres: Add managed arch_phys_wc_add() (Karol Herbst) [2072020]
- mm/vmscan: add sync_shrinkers function v3 (Karol Herbst) [2072020]
- kernel/locking: Use a pointer in ww_mutex_trylock(). (Karol Herbst) [2072020]
- locking/ww-mutex: Fix uninitialized use of ret in test_aa() (Karol Herbst) [2072020]
- kernel/locking: Add context to ww_mutex_trylock() (Karol Herbst) [2072020]
- samples/bpf: Fix build error due to -isystem removal (Karol Herbst) [2072020]
- isystem: delete global -isystem compile option (Karol Herbst) [2072020]
- uapi/linux/stddef.h: Add include guards (Karol Herbst) [2072020]
- stddef: Introduce struct_group() helper macro (Karol Herbst) [2072020]
- isystem: trim/fixup stdarg.h and other headers (Karol Herbst) [2072020]
- ACPI: tools: fix compilation error (Karol Herbst) [2072020]
- isystem: ship and use stdarg.h (Karol Herbst) [2072020]
- locking/lockdep: Provide lockdep_assert{,_once}() helpers (Karol Herbst) [2072020]

* Tue May 03 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-84.rt21.84.el9]
- [rt] build kernel-rt-5.14.0-84.rt21.84.el9 [2061574]
- sctp: use the correct skb for security_sctp_assoc_request (Ondrej Mosnacek) [2078856]
- security: implement sctp_assoc_established hook in selinux (Ondrej Mosnacek) [2078856]
- security: add sctp_assoc_established hook (Ondrej Mosnacek) [2078856]
- security: call security_sctp_assoc_request in sctp_sf_do_5_1D_ce (Ondrej Mosnacek) [2078856]
- security: pass asoc to sctp_assoc_request and sctp_sk_clone (Ondrej Mosnacek) [2078856]
- string.h: Introduce memset_startat() for wiping trailing members and padding (Íñigo Huguet) [2077839]
- string.h: Introduce memset_after() for wiping trailing members/padding (Íñigo Huguet) [2077839]
- net_tstamp: define new flag HWTSTAMP_FLAG_BONDED_PHC_INDEX (Petr Oros) [2073458]
- net_tstamp: add new flag HWTSTAMP_FLAG_BONDED_PHC_INDEX (Petr Oros) [2073458]
- bnx2x: truncate value to original sizing (Manish Chopra) [2040283]
- bnx2x: use correct format characters (Manish Chopra) [2040283]
- bnx2x: fix built-in kernel driver load failure (Manish Chopra) [2040283]
- bnx2x: fix driver load from initrd (Manish Chopra) [2040283]
- bnx2x: Replace one-element array with flexible-array member (Manish Chopra) [2040283]
- bnx2x: Remove useless DMA-32 fallback configuration (Manish Chopra) [2040283]
- bnx2x: Invalidate fastpath HSI version for VFs (Manish Chopra) [2040283]
- bnx2x: Utilize firmware 7.13.21.0 (Manish Chopra) [2040283]
- bnx2x: constify static inline stub for dev_addr (Manish Chopra) [2040283]
- net: bnx2x: fix variable dereferenced before check (Manish Chopra) [2040283]
- ethernet: bnx2x: use eth_hw_addr_set() (Manish Chopra) [2040283]
- cacheflush.h: Add forward declaration for struct folio (Aristeu Rozanski) [2019485]
- mm/swap: fix confusing comment in folio_mark_accessed (Aristeu Rozanski) [2019485]
- mm: page->mapping folio->mapping should have the same offset (Aristeu Rozanski) [2019485]
- mm: delete unsafe BUG from page_cache_add_speculative() (Aristeu Rozanski) [2019485]
- mm: Add functions to zero portions of a folio (Aristeu Rozanski) [2019485]
- fs: Rename AS_THP_SUPPORT and mapping_thp_support (Aristeu Rozanski) [2019485]
- fs: Remove FS_THP_SUPPORT (Aristeu Rozanski) [2019485]
- mm: Remove folio_test_single (Aristeu Rozanski) [2019485]
- mm: Rename folio_test_multi to folio_test_large (Aristeu Rozanski) [2019485]
- Add linux/cacheflush.h (Aristeu Rozanski) [2019485]
- folio: Add a function to get the host inode for a folio (Aristeu Rozanski) [2019485]
- folio: Add a function to change the private data attached to a folio (Aristeu Rozanski) [2019485]
- mm: fix mismerge of folio page flag manipulators (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_write_one (Aristeu Rozanski) [2019485]
- mm/filemap: Add FGP_STABLE (Aristeu Rozanski) [2019485]
- mm/filemap: Add filemap_get_folio (Aristeu Rozanski) [2019485]
- mm/filemap: Convert mapping_get_entry to return a folio (Aristeu Rozanski) [2019485]
- mm/filemap: Add filemap_add_folio() (Aristeu Rozanski) [2019485]
- mm/filemap: Add filemap_alloc_folio (Aristeu Rozanski) [2019485]
- mm/page_alloc: Add folio allocation functions (Aristeu Rozanski) [2019485]
- mm/lru: Add folio_add_lru() (Aristeu Rozanski) [2019485]
- mm/lru: Convert __pagevec_lru_add_fn to take a folio (Aristeu Rozanski) [2019485]
- mm: Add folio_evictable() (Aristeu Rozanski) [2019485]
- mm/workingset: Convert workingset_refault() to take a folio (Aristeu Rozanski) [2019485]
- mm/filemap: Add readahead_folio() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_mkwrite_check_truncate() (Aristeu Rozanski) [2019485]
- mm/filemap: Add i_blocks_per_folio() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_redirty_for_writepage() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_account_redirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_clear_dirty_for_io() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_cancel_dirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_account_cleaned() (Aristeu Rozanski) [2019485]
- mm/writeback: Add filemap_dirty_folio() (Aristeu Rozanski) [2019485]
- mm/writeback: Convert tracing writeback_page_template to folios (Aristeu Rozanski) [2019485]
- mm/writeback: Add __folio_mark_dirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_mark_dirty() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_start_writeback() (Aristeu Rozanski) [2019485]
- mm/writeback: Add __folio_end_writeback() (Aristeu Rozanski) [2019485]
- mm/writeback: Change __wb_writeout_inc() to __wb_writeout_add() (Aristeu Rozanski) [2019485]
- flex_proportions: Allow N events instead of 1 (Aristeu Rozanski) [2019485]
- mm/writeback: Rename __add_wb_stat() to wb_stat_mod() (Aristeu Rozanski) [2019485]
- mm/migrate: Add folio_migrate_copy() (Aristeu Rozanski) [2019485]
- mm/migrate: Add folio_migrate_flags() (Aristeu Rozanski) [2019485]
- mm/migrate: Add folio_migrate_mapping() (Aristeu Rozanski) [2019485]
- mm/rmap: Add folio_mkclean() (Aristeu Rozanski) [2019485]
- mm/swap: Add folio_mark_accessed() (Aristeu Rozanski) [2019485]
- mm/swap: Add folio_activate() (Aristeu Rozanski) [2019485]
- mm: Add folio_young and folio_idle (Aristeu Rozanski) [2019485]
- mm: Add arch_make_folio_accessible() (Aristeu Rozanski) [2019485]
- mm: Add kmap_local_folio() (Aristeu Rozanski) [2019485]
- mm: Add flush_dcache_folio() (Aristeu Rozanski) [2019485]
- mm: Add folio_raw_mapping() (Aristeu Rozanski) [2019485]
- mm: Add folio_pfn() (Aristeu Rozanski) [2019485]
- mm/workingset: Convert workingset_activation to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_lruvec_relock_irq() and folio_lruvec_relock_irqsave() (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_lruvec_lock() and similar functions (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_lruvec() (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_move_account() to use a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_memcg_lock() and folio_memcg_unlock() (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_track_foreign_dirty_slowpath() to folio (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_migrate() to take folios (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_uncharge() to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Convert uncharge_page() to uncharge_folio() (Aristeu Rozanski) [2019485]
- mm/memcg: Convert mem_cgroup_charge() to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Convert commit_charge() to take a folio (Aristeu Rozanski) [2019485]
- mm/memcg: Add folio_memcg() and related functions (Aristeu Rozanski) [2019485]
- mm/memcg: Convert memcg_check_events to take a node ID (Aristeu Rozanski) [2019485]
- mm/memcg: Remove soft_limit_tree_node() (Aristeu Rozanski) [2019485]
- mm/memcg: Use the node id in mem_cgroup_update_tree() (Aristeu Rozanski) [2019485]
- mm/memcg: Remove 'page' parameter to mem_cgroup_charge_statistics() (Aristeu Rozanski) [2019485]
- mm: Add folio_nid() (Aristeu Rozanski) [2019485]
- mm: Add folio_mapped() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio private_2 functions (Aristeu Rozanski) [2019485]
- mm/filemap: Convert page wait queues to be folios (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_wake_bit() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_wait_bit() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_wait_stable() (Aristeu Rozanski) [2019485]
- mm/writeback: Add folio_wait_writeback() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_end_writeback() (Aristeu Rozanski) [2019485]
- mm/swap: Add folio_rotate_reclaimable() (Aristeu Rozanski) [2019485]
- mm/filemap: Add __folio_lock_or_retry() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_wait_locked() (Aristeu Rozanski) [2019485]
- mm/filemap: Add __folio_lock_async() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_lock_killable() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_lock() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_unlock() (Aristeu Rozanski) [2019485]
- mm/util: Add folio_mapping() and folio_file_mapping() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_pos() and folio_file_pos() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_next_index() (Aristeu Rozanski) [2019485]
- mm/filemap: Add folio_index(), folio_file_page() and folio_contains() (Aristeu Rozanski) [2019485]
- mm: Handle per-folio private data (Aristeu Rozanski) [2019485]
- mm/lru: Add folio LRU functions (Aristeu Rozanski) [2019485]
- mm: Add folio flag manipulation functions (Aristeu Rozanski) [2019485]
- mm: Add folio_try_get_rcu() (Aristeu Rozanski) [2019485]
- mm: Add folio_get() (Aristeu Rozanski) [2019485]
- mm: Add folio_put() (Aristeu Rozanski) [2019485]
- mm: Add folio reference count functions (Aristeu Rozanski) [2019485]
- mm/debug: Add VM_BUG_ON_FOLIO() and VM_WARN_ON_ONCE_FOLIO() (Aristeu Rozanski) [2019485]
- mm/vmstat: Add functions to account folio statistics (Aristeu Rozanski) [2019485]
- mm: Add folio_pgdat(), folio_zone() and folio_zonenum() (Aristeu Rozanski) [2019485]
- mm: Introduce struct folio (Aristeu Rozanski) [2019485]
- mm: Convert get_page_unless_zero() to return bool (Aristeu Rozanski) [2019485]
- scripts: check_extable: fix typo in user error message (Aristeu Rozanski) [2019485]
- PCI: vmd: Prevent recursive locking on interrupt allocation (Myron Stowe) [2066898]
- PCI: Mark all AMD Navi10 and Navi14 GPU ATS as broken (Myron Stowe) [2066898]
- PCI: mvebu: Fix device enumeration regression (Myron Stowe) [2066898]
- PCI: kirin: Add dev struct for of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: j721e: Initialize pcie->cdns_pcie before using it (Myron Stowe) [2066898]
- PCI/sysfs: Find shadow ROM before static attribute initialization (Myron Stowe) [2066898]
- x86/gpu: Reserve stolen memory for first integrated Intel GPU (Myron Stowe) [2066898]
- PCI: spear13xx: Avoid invalid address space conversions (Myron Stowe) [2066898]
- PCI: hisi: Avoid invalid address space conversions (Myron Stowe) [2066898]
- PCI: xilinx-cpm: Rename xilinx_cpm_pcie_port to xilinx_cpm_pcie (Myron Stowe) [2066898]
- PCI: xilinx: Rename xilinx_pcie_port to xilinx_pcie (Myron Stowe) [2066898]
- PCI: xgene: Rename xgene_pcie_port to xgene_pcie (Myron Stowe) [2066898]
- PCI: uniphier: Rename uniphier_pcie_priv to uniphier_pcie (Myron Stowe) [2066898]
- PCI: tegra194: Rename tegra_pcie_dw to tegra194_pcie (Myron Stowe) [2066898]
- PCI: rcar-gen2: Rename rcar_pci_priv to rcar_pci (Myron Stowe) [2066898]
- PCI: microchip: Rename mc_port to mc_pcie (Myron Stowe) [2066898]
- PCI: mediatek-gen3: Rename mtk_pcie_port to mtk_gen3_pcie (Myron Stowe) [2066898]
- PCI: ls-gen4: Rename ls_pcie_g4 to ls_g4_pcie (Myron Stowe) [2066898]
- PCI: iproc: Rename iproc_pcie_pltfm_ to iproc_pltfm_pcie_ (Myron Stowe) [2066898]
- PCI: iproc: Rename iproc_pcie_bcma_ to iproc_bcma_pcie_ (Myron Stowe) [2066898]
- PCI: intel-gw: Rename intel_pcie_port to intel_pcie (Myron Stowe) [2066898]
- PCI: j721e: Drop redundant struct device * (Myron Stowe) [2066898]
- PCI: j721e: Drop pointless of_device_get_match_data() cast (Myron Stowe) [2066898]
- PCI: kirin: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: keystone: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: dra7xx: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: designware-plat: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: cadence: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: artpec6: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: altera: Prefer of_device_get_match_data() (Myron Stowe) [2066898]
- PCI: xgene: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: hv: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: keystone: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: Use PCI_ERROR_RESPONSE to identify config read errors (Myron Stowe) [2066898]
- PCI: cpqphp: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI/PME: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI/DPC: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI: pciehp: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI: vmd: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI/ERR: Use PCI_POSSIBLE_ERROR() to check config reads (Myron Stowe) [2066898]
- PCI: rockchip-host: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: rcar-host: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: altera: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: mvebu: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: aardvark: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: kirin: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: histb: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: exynos: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: mediatek: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: iproc: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: thunder: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: Drop error data fabrication when config read fails (Myron Stowe) [2066898]
- PCI: Use PCI_SET_ERROR_RESPONSE() for disconnected devices (Myron Stowe) [2066898]
- PCI: Set error response data when config read fails (Myron Stowe) [2066898]
- PCI: Add PCI_ERROR_RESPONSE and related definitions (Myron Stowe) [2066898]
- misc: pci_endpoint_test: Terminate statement with semicolon (Myron Stowe) [2066898]
- PCI: Correct misspelled words (Myron Stowe) [2066898]
- PCI: Change capability register offsets to hex (Myron Stowe) [2066898]
- PCI: Sort Intel Device IDs by value (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Set PCI_STATUS_CAP_LIST for PCIe device (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Correctly set PCIe capabilities (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Fix definitions of reserved bits (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Properly mark reserved PCIe bits in PCI config space (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Make expansion ROM Base Address register read-only (Myron Stowe) [2066898]
- PCI: xilinx-nwl: Simplify code and fix a memory leak (Myron Stowe) [2066898]
- PCI: xgene: Fix IB window setup (Myron Stowe) [2066898]
- PCI: xgene-msi: Use bitmap_zalloc() when applicable (Myron Stowe) [2066898]
- PCI: vmd: Add DID 8086:A77F for all Intel Raptor Lake SKU's (Myron Stowe) [2066898]
- PCI: vmd: Honor ACPI _OSC on PCIe features (Myron Stowe) [2066898]
- PCI: vmd: Clean up domain before enumeration (Myron Stowe) [2066898]
- PCI: qcom-ep: Constify static dw_pcie_ep_ops (Myron Stowe) [2066898]
- PCI: qcom: Use __be16 type to store return value from cpu_to_be16() (Myron Stowe) [2066898]
- PCI: mvebu: Add support for compiling driver as module (Myron Stowe) [2066898]
- bus: mvebu-mbus: Export symbols for public API window functions (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for DEVCAP2, DEVCTL2 and LNKCTL2 registers on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for PCI_EXP_RTSTA on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for PCI_EXP_DEVCTL on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for PCI_BRIDGE_CTL_BUS_RESET on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Fix configuring secondary bus of PCIe Root Port via emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Set PCI Bridge Class Code to PCI Bridge (Myron Stowe) [2066898]
- PCI: mvebu: Setup PCIe controller to Root Complex mode (Myron Stowe) [2066898]
- PCI: mvebu: Propagate errors when updating PCI_IO_BASE and PCI_MEM_BASE registers (Myron Stowe) [2066898]
- PCI: mvebu: Do not modify PCI IO type bits in conf_write (Myron Stowe) [2066898]
- PCI: mvebu: Fix support for bus mastering and PCI_COMMAND on emulated bridge (Myron Stowe) [2066898]
- PCI: mvebu: Disallow mapping interrupts on emulated bridges (Myron Stowe) [2066898]
- PCI: mvebu: Handle invalid size of read config request (Myron Stowe) [2066898]
- PCI: mvebu: Check that PCI bridge specified in DT has function number zero (Myron Stowe) [2066898]
- PCI: mvebu: Check for errors from pci_bridge_emul_init() call (Myron Stowe) [2066898]
- PCI: mvebu: Check for valid ports (Myron Stowe) [2066898]
- arm: ioremap: Remove unused ARM-specific function pci_ioremap_io() (Myron Stowe) [2066898]
- arm: ioremap: Replace pci_ioremap_io() usage by pci_remap_iospace() (Myron Stowe) [2066898]
- PCI: mvebu: Remove custom mvebu_pci_host_probe() function (Myron Stowe) [2066898]
- PCI: mvebu: Replace pci_ioremap_io() usage by devm_pci_remap_iospace() (Myron Stowe) [2066898]
- arm: ioremap: Implement standard PCI function pci_remap_iospace() (Myron Stowe) [2066898]
- PCI: mt7621: Allow COMPILE_TEST for all arches (Myron Stowe) [2066898]
- PCI: Let pcibios_root_bridge_prepare() access bridge->windows (Myron Stowe) [2066898]
- PCI: mediatek-gen3: Disable DVFSRC voltage request (Myron Stowe) [2066898]
- PCI: mediatek: Assert PERST# for 100ms for power and clock to stabilize (Myron Stowe) [2066898]
-     PCI: keystone: Use phandle argument from "ti,syscon-pcie-id"/"ti,syscon-pcie-mode" (Myron Stowe) [2066898]
- dt-bindings: PCI: ti,am65: Fix "ti,syscon-pcie-id"/"ti,syscon-pcie-mode" to take argument (Myron Stowe) [2066898]
- PCI: endpoint: Return -EINVAL when interrupts num is smaller than 1 (Myron Stowe) [2066898]
- PCI: layerscape: Change to use the DWC common link-up check function (Myron Stowe) [2066898]
- PCI: imx: Add the imx8mm pcie support (Myron Stowe) [2066898]
- PCI: qcom-ep: Remove surplus dev_err() when using platform_get_irq_byname() (Myron Stowe) [2066898]
- PCI: dwc: Do not remap invalid res (Myron Stowe) [2066898]
- PCI: brcmstb: Do not turn off WOL regulators on suspend (Myron Stowe) [2066898]
- PCI: brcmstb: Add control of subdevice voltage regulators (Myron Stowe) [2066898]
- PCI: brcmstb: Add mechanism to turn on subdev regulators (Myron Stowe) [2066898]
- PCI: brcmstb: Split brcm_pcie_setup() into two funcs (Myron Stowe) [2066898]
- dt-bindings: PCI: Add bindings for Brcmstb EP voltage regulators (Myron Stowe) [2066898]
- dt-bindings: PCI: Correct brcmstb interrupts, interrupt-map. (Myron Stowe) [2066898]
- PCI: brcmstb: Fix function return value handling (Myron Stowe) [2066898]
- PCI: brcmstb: Do not use __GENMASK (Myron Stowe) [2066898]
- PCI: brcmstb: Declare 'used' as bitmap, not unsigned long (Myron Stowe) [2066898]
- PCI: aardvark: Disable common PHY when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Disable link training when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Assert PERST# when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Fix memory leak in driver unbind (Myron Stowe) [2066898]
- PCI: aardvark: Mask all interrupts when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Disable bus mastering when unbinding driver (Myron Stowe) [2066898]
- PCI: aardvark: Comment actions in driver remove method (Myron Stowe) [2066898]
- PCI: aardvark: Clear all MSIs at setup (Myron Stowe) [2066898]
- PCI: aardvark: Add support for DEVCAP2, DEVCTL2, LNKCAP2 and LNKCTL2 registers on emulated bridge (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Add definitions for missing capabilities registers (Myron Stowe) [2066898]
- PCI: pci-bridge-emul: Add description for class_revision field (Myron Stowe) [2066898]
- PCI: Add function 1 DMA alias quirk for Marvell 88SE9125 SATA controller (Myron Stowe) [2066898]
- PCI/switchtec: Declare local state_names[] as static (Myron Stowe) [2066898]
- PCI/switchtec: Add Gen4 automotive device IDs (Myron Stowe) [2066898]
- PCI: Work around Intel I210 ROM BAR overlap defect (Myron Stowe) [2066898]
- PCI/P2PDMA: Use percpu_ref_tryget_live_rcu() inside RCU critical section (Myron Stowe) [2066898]
- MAINTAINERS: Add Logan Gunthorpe as P2PDMA maintainer (Myron Stowe) [2066898]
- via-agp: convert to generic power management (Myron Stowe) [2066898]
- sis-agp: convert to generic power management (Myron Stowe) [2066898]
- amd64-agp: convert to generic power management (Myron Stowe) [2066898]
- PCI: pciehp: Use down_read/write_nested(reset_lock) to fix lockdep errors (Myron Stowe) [2066898]
- PCI: ibmphp: Remove commented-out functions (Myron Stowe) [2066898]
- PCI: pciehp: Fix infinite loop in IRQ handler upon power fault (Myron Stowe) [2066898]
- x86/PCI: Remove initialization of static variables to false (Myron Stowe) [2066898]
- PCI: Use DWORD accesses for LTR, L1 SS to avoid erratum (Myron Stowe) [2066898]
- PCI/sysfs: Use default_groups in kobj_type for slot attrs (Myron Stowe) [2066898]
- PCI: Convert pci_dev_present() stub to static inline (Myron Stowe) [2066898]
- PCI: Use pci_find_vsec_capability() when looking for TBT devices (Myron Stowe) [2066898]
- PCI/ASPM: Remove struct aspm_latency (Myron Stowe) [2066898]
- PCI/ASPM: Stop caching device L0s, L1 acceptable exit latencies (Myron Stowe) [2066898]
- PCI/ASPM: Stop caching link L0s, L1 exit latencies (Myron Stowe) [2066898]
- PCI/ASPM: Move pci_function_0() upward (Myron Stowe) [2066898]
- PCI: Add MSI masking quirk for Nvidia ION AHCI (Myron Stowe) [2066898]
- PCI/MSI: Destroy sysfs before freeing entries (Myron Stowe) [2066898]
- PCI/MSI: Deal with devices lying about their MSI mask capability (Myron Stowe) [2066898]
- misc: pci_endpoint_test: Ensure relationship between miscdev and PCI (Myron Stowe) [2066898]
- redhat/configs: Enable CONFIG_NFT_SYNPROXY (Phil Sutter) [2069735]
- netfilter: nf_tables: validate registers coming from userspace. (Phil Sutter) [2065351] {CVE-2022-1015}
- netfilter: nf_tables: initialize registers in nft_do_chain() (Phil Sutter) [2067964] {CVE-2022-1016}
- netfilter: conntrack: Add and use nf_ct_set_auto_assign_helper_warned() (Phil Sutter) [2069114]
- ipmi: initialize len variable (Tony Camuso) [2067267]
- ipmi: kcs: aspeed: Remove old bindings support (Tony Camuso) [2067267]
- ipmi:ipmb: Add the ability to have a separate slave and master device (Tony Camuso) [2067267]
- ipmi:ipmi_ipmb: Unregister the SMI on remove (Tony Camuso) [2067267]
- ipmi: kcs: aspeed: Add AST2600 compatible string (Tony Camuso) [2067267]
- ipmi: ssif: replace strlcpy with strscpy (Tony Camuso) [2067267]
- ipmi/watchdog: Constify ident (Tony Camuso) [2067267]
- ipmi: Fix UAF when uninstall ipmi_si and ipmi_msghandler module (Tony Camuso) [2067267]
- ipmi: fix initialization when workqueue allocation fails (Tony Camuso) [2067267]
- ipmi: bail out if init_srcu_struct fails (Tony Camuso) [2067267]
- ipmi: ssif: initialize ssif_info->client early (Tony Camuso) [2067267]
- ipmi:ipmb: Fix unknown command response (Tony Camuso) [2067267]
- ipmi: fix IPMI_SMI_MSG_TYPE_IPMB_DIRECT response length checking (Tony Camuso) [2067267]
- ipmi: fix oob access due to uninit smi_msg type (Tony Camuso) [2067267]
- ipmi: msghandler: Make symbol 'remove_work_wq' static (Tony Camuso) [2067267]
- ipmi: Move remove_work to dedicated workqueue (Tony Camuso) [2067267]
- ipmi: kcs_bmc: Fix a memory leak in the error handling path of 'kcs_bmc_serio_add_device()' (Tony Camuso) [2067267]
- char: ipmi: replace snprintf in show functions with sysfs_emit (Tony Camuso) [2067267]
- ipmi: ipmb: fix dependencies to eliminate build error (Tony Camuso) [2067267]
- ipmi:ipmb: Add OF support (Tony Camuso) [2067267]
- ipmi: bt: Add ast2600 compatible string (Tony Camuso) [2067267]
- ipmi: bt-bmc: Use registers directly (Tony Camuso) [2067267]
- ipmi: ipmb: Fix off-by-one size check on rcvlen (Tony Camuso) [2067267]
- ipmi:ssif: Use depends on, not select, for I2C (Tony Camuso) [2067267]
- ipmi:ipmb: Add initial support for IPMI over IPMB (Tony Camuso) [2067267]
- ipmi: Add support for IPMB direct messages (Tony Camuso) [2067267]
- config: add CONFIG_IPMI_IPMB (Tony Camuso) [2067267]
- ipmi: Export ipmb_checksum() (Tony Camuso) [2067267]
- ipmi: Check error code before processing BMC response (Tony Camuso) [2067267]
- ipmi:devintf: Return a proper error when recv buffer too small (Tony Camuso) [2067267]
- ipmi: Disable some operations during a panic (Tony Camuso) [2067267]
- ipmi:watchdog: Set panic count to proper value on a panic (Tony Camuso) [2067267]
- parisc: Make struct parisc_driver::remove() return void (Tony Camuso) [2067267]
- char: ipmi: use DEVICE_ATTR helper macro (Tony Camuso) [2067267]
- ipmi: rate limit ipmi smi_event failure message (Tony Camuso) [2067267]

* Mon May 02 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-83.rt21.83.el9]
- [rt] build kernel-rt-5.14.0-83.rt21.83.el9 [2061574]
- redhat/configs: aarch64: enable CPU_FREQ_GOV_SCHEDUTIL (Mark Salter) [2077664]
- x86/platform/uv: Log gap hole end size (Frank Ramsay) [2074097]
- x86/platform/uv: Update TSC sync state for UV5 (Frank Ramsay) [2074097]
- x86/platform/uv: Update NMI Handler for UV5 (Frank Ramsay) [2074097]
- tun: annotate access to queue->trans_start (Ivan Vecera) [2073453]
- stmmac: fix build due to brainos in trans_start changes (Ivan Vecera) [2073453]
- net: no longer stop all TX queues in dev_watchdog() (Ivan Vecera) [2073453]
- net: do not inline netif_tx_lock()/netif_tx_unlock() (Ivan Vecera) [2073453]
- net: annotate accesses to queue->trans_start (Ivan Vecera) [2073453]
- net: use an atomic_long_t for queue->trans_timeout (Ivan Vecera) [2073453]
- virtio_net: introduce TX timeout watchdog (Ivan Vecera) [2073453]
- net: remove the unnecessary check in cipso_v4_doi_free (Guillaume Nault) [2074605]
- net: fix NULL pointer reference in cipso_v4_doi_free (Guillaume Nault) [2074605]
- selftest/powerpc: Add PAPR sysfs attributes sniff test (Steve Best) [1869665]
- powerpc/pseries: Interface to represent PAPR firmware attributes (Steve Best) [1869665]
- x86: intel_epb: Allow model specific normal EPB value (David Arcari) [2068330]
- redhat: configs: Disable CONFIG_MPLS for s390x/zfcpdump (Guillaume Nault) [2039239]
- ACPI: CPPC: Amend documentation in the comments (David Arcari) [1961725]
- ACPI: CPPC: Drop redundant local variable from cpc_read() (David Arcari) [1961725]
- ACPI: CPPC: Fix up I/O port access in cpc_read() (David Arcari) [1961725]
- cpufreq: amd-pstate: Fix Kconfig dependencies for AMD P-State (David Arcari) [1961725]
- cpufreq: amd-pstate: Fix struct amd_cpudata kernel-doc comment (David Arcari) [1961725]
- cpufreq: amd-pstate: Add AMD P-State performance attributes (David Arcari) [1961725]
- cpufreq: amd-pstate: Add AMD P-State frequencies attributes (David Arcari) [1961725]
- cpufreq: amd-pstate: Add boost mode support for AMD P-State (David Arcari) [1961725]
- cpufreq: amd-pstate: Add trace for AMD P-State module (David Arcari) [1961725]
- cpufreq: amd-pstate: Introduce the support for the processors with shared memory solution (David Arcari) [1961725]
- cpufreq: amd-pstate: Add fast switch function for AMD P-State (David Arcari) [1961725]
- redhat/configs: enable CONFIG_X86_AMD_PSTATE (David Arcari) [1961725]
- cpufreq: amd-pstate: Introduce a new AMD P-State driver to support future processors (David Arcari) [1961725]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (David Arcari) [1961725]
- x86/msr: Add AMD CPPC MSR definitions (David Arcari) [1961725]
- tools headers cpufeatures: Sync with the kernel sources (David Arcari) [1961725]
- x86/cpufeatures: Add AMD Collaborative Processor Performance Control feature flag (David Arcari) [1961725]
- ACPI: CPPC: Add CPPC enable register function (David Arcari) [1961725]
- ACPI: CPPC: Check present CPUs for determining _CPC is valid (David Arcari) [1961725]
- ACPI: CPPC: Implement support for SystemIO registers (David Arcari) [1961725]

* Thu Apr 28 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-82.rt21.82.el9]
- [rt] build kernel-rt-5.14.0-82.rt21.82.el9 [2061574]
- mt76: mt7921e: fix possible probe failure after reboot (Íñigo Huguet) [2065633]
- mm: lru_cache_disable: replace work queue synchronization with synchronize_rcu (Marcelo Tosatti) [2033500]
- powerpc/lib/sstep: Don't use __{get/put}_user() on kernel addresses (Michael Petlan) [2049226]
- bpf, test_offload.py: Skip base maps without names (Felix Maurer) [2076961]
- perf header: Fix spelling mistake "could't" -> "couldn't" (Michael Petlan) [2075504]
- perf build-id: Fix spelling mistake "Cant" -> "Can't" (Michael Petlan) [2075504]
- e1000e: Add support for the next LOM generation (David Arcari) [2076668]
- vsprintf: Update %%pGp documentation about that it prints hex value (Waiman Long) [2073625]
- mm/page_owner.c: record tgid (Waiman Long) [2073625]
- mm/page_owner: record task command name (Waiman Long) [2073625]
- mm/page_owner: print memcg information (Waiman Long) [2073625]
- mm/page_owner: use scnprintf() to avoid excessive buffer overrun check (Waiman Long) [2073625]
- lib/vsprintf: avoid redundant work with 0 size (Waiman Long) [2073625]
- mm: make some vars and functions static or __init (Waiman Long) [2073625]
- lib, stackdepot: add helper to print stack entries into buffer (Waiman Long) [2073625]
- lib, stackdepot: add helper to print stack entries (Waiman Long) [2073625]
- lib, stackdepot: check stackdepot handle before accessing slabs (Waiman Long) [2073625]
- stacktrace: move filter_irq_stacks() to kernel/stacktrace.c (Waiman Long) [2073625]
- vsprintf: Make %%pGp print the hex value (Waiman Long) [2073625]
- test_printf: Append strings more efficiently (Waiman Long) [2073625]
- test_printf: Remove custom appending of '|' (Waiman Long) [2073625]
- test_printf: Remove separate page_flags variable (Waiman Long) [2073625]
- test_printf: Make pft array const (Waiman Long) [2073625]
- proc: remove PDE_DATA() completely (Ivan Vecera) [2073492]
- fs: proc: store PDE()->data into inode->i_private (Ivan Vecera) [2073492]
- seq_file: fix passing wrong private data (Ivan Vecera) [2073492]
- tcp: seq_file: Refactor net and family matching (Ivan Vecera) [2073492]
- entry: Fix compile error in dynamic_irqentry_exit_cond_resched() (Phil Auld) [2065226]
- sched/preempt: Tell about PREEMPT_DYNAMIC on kernel headers (Phil Auld) [2065226]
- arm64: Support PREEMPT_DYNAMIC (Phil Auld) [2065226]
- arm64: entry: Centralize preemption decision (Phil Auld) [2065226]
- sched/preempt: Add PREEMPT_DYNAMIC using static keys (Phil Auld) [2065226]
- sched/preempt: Decouple HAVE_PREEMPT_DYNAMIC from GENERIC_ENTRY (Phil Auld) [2065226]
- sched/preempt: Simplify irqentry_exit_cond_resched() callers (Phil Auld) [2065226]
- sched/preempt: Refactor sched_dynamic_update() (Phil Auld) [2065226]
- sched/preempt: Move PREEMPT_DYNAMIC logic later (Phil Auld) [2065226]
- sched/debug: Remove mpol_get/put and task_lock/unlock from sched_show_numa (Phil Auld) [2062831]
- sched/numa: initialize numa statistics when forking new task (Phil Auld) [2062831]
- sched/uclamp: Fix iowait boost escaping uclamp restriction (Phil Auld) [2062831]
- sched/sugov: Ignore 'busy' filter when rq is capped by uclamp_max (Phil Auld) [2062831]
- sched/numa: Fix boot crash on arm64 systems (Phil Auld) [2062831]
- cgroup: Fix suspicious rcu_dereference_check() usage warning (Phil Auld) [2062831]
- sched/cpuacct: Remove redundant RCU read lock (Phil Auld) [2062831]
- sched/cpuacct: Optimize away RCU read lock (Phil Auld) [2062831]
- sched/cpuacct: Fix charge percpu cpuusage (Phil Auld) [2062831]
- sched/numa: Avoid migrating task to CPU-less node (Phil Auld) [2062831]
- sched/numa: Fix NUMA topology for systems with CPU-less nodes (Phil Auld) [2062831]
- sched: replace cpumask_weight with cpumask_empty where appropriate (Phil Auld) [2062831]
- sched/rt: Plug rt_mutex_setprio() vs push_rt_task() race (Phil Auld) [2062831]
- psi: fix possible trigger missing in the window (Phil Auld) [2062831]
- sched/tracing: Don't re-read p->state when emitting sched_switch event (Phil Auld) [2062831]
- sched/core: Export pelt_thermal_tp (Phil Auld) [2062831]
- sched/membarrier: Fix membarrier-rseq fence command missing from query bitmask (Phil Auld) [2062831]
- sched/core: Accounting forceidle time for all tasks except idle task (Phil Auld) [2062831]
- sched: Avoid double preemption in __cond_resched_*lock*() (Phil Auld) [2062831]
- fork: Stop protecting back_fork_cleanup_cgroup_lock with CONFIG_NUMA (Phil Auld) [2062831]
- sched/fair: Fix all kernel-doc warnings (Phil Auld) [2062831]
- sched/fair: Cleanup task_util and capacity type (Phil Auld) [2062831]
- sched/rt: Try to restart rt period timer when rt runtime exceeded (Phil Auld) [2062831]
- sched/fair: Fix per-CPU kthread and wakee stacking for asym CPU capacity (Phil Auld) [2062831]
- locking: Remove rt_rwlock_is_contended(). (Phil Auld) [2062831]
- sched: Trigger warning if ->migration_disabled counter underflows. (Phil Auld) [2062831]
- sched/fair: Fix detection of per-CPU kthreads waking a task (Phil Auld) [2062831]
- sched/fair: Replace CFS internal cpu_util() with cpu_util_cfs() (Phil Auld) [2062831]
- sched/cpuacct: Make user/system times in cpuacct.stat more precise (Phil Auld) [2062831]
- sched/cpuacct: Fix user/system in shown cpuacct.usage* (Phil Auld) [2062831]
- cpuacct: Convert BUG_ON() to WARN_ON_ONCE() (Phil Auld) [2062831]
- cputime, cpuacct: Include guest time in user time in cpuacct.stat (Phil Auld) [2062831]
- sched/core: Forced idle accounting (Phil Auld) [2062831]
- sched/fair: Document the slow path and fast path in select_task_rq_fair (Phil Auld) [2062831]
- pci: fix multiple definition error when CONFIG_RHEL_DIFFERENCES is not set (Joel Savitz) [2053991]
- selftests/bpf: Make test_lwt_ip_encap more stable and faster (Felix Maurer) [2019496]
- ucounts: Fix systemd LimitNPROC with private users regression (Alexey Gladkov) [2061724]
- ucounts: Enforce RLIMIT_NPROC not RLIMIT_NPROC+1 (Alexey Gladkov) [2061724]
- ucounts: Base set_cred_ucounts changes on the real user (Alexey Gladkov) [2061724]
- ucounts: Move RLIMIT_NPROC handling after set_user (Alexey Gladkov) [2061724]
- ucounts: Handle wrapping in is_ucounts_overlimit (Alexey Gladkov) [2061724]
- redhat/configs: enable CONFIG_AMD_PTDMA for x86_64 (John W. Linville) [2027972]
- dmaengine: ptdma: handle the cases based on DMA is complete (John W. Linville) [2027972]
- dmaengine: ptdma: fix concurrency issue with multiple dma transfer (John W. Linville) [2027972]
- dmaengine: ptdma: Fix the error handling path in pt_core_init() (John W. Linville) [2027972]
- dmaengine: remove debugfs #ifdef (John W. Linville) [2027972]
- MAINTAINERS: Fix AMD PTDMA DRIVER entry (John W. Linville) [2027972]
- dmaengine: ptdma: remove PT_OFFSET to avoid redefnition (John W. Linville) [2027972]
- dmaengine: ptdma: Add debugfs entries for PTDMA (John W. Linville) [2027972]
- dmaengine: ptdma: register PTDMA controller as a DMA resource (John W. Linville) [2027972]
- dmaengine: ptdma: Initial driver for the AMD PTDMA (John W. Linville) [2027972]

* Tue Apr 26 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-81.rt21.81.el9]
- [rt] build kernel-rt-5.14.0-81.rt21.81.el9 [2061574]
- powerpc/pseries/vas: Add VAS migration handler (Steve Best) [2028677]
- powerpc/pseries/vas: Modify reconfig open/close functions for migration (Steve Best) [2028677]
- powerpc/pseries/vas: Define global hv_cop_caps struct (Steve Best) [2028677]
- powerpc/pseries/vas: Add 'update_total_credits' entry for QoS capabilities (Steve Best) [2028677]
- powerpc/pseries/vas: sysfs interface to export capabilities (Steve Best) [2028677]
- powerpc/pseries/vas: Reopen windows with DLPAR core add (Steve Best) [2028677]
- powerpc/pseries/vas: Close windows with DLPAR core removal (Steve Best) [2028677]
- powerpc/vas: Map paste address only if window is active (Steve Best) [2028677]
- powerpc/vas: Return paste instruction failure if no active window (Steve Best) [2028677]
- powerpc/vas: Add paste address mmap fault handler (Steve Best) [2028677]
- powerpc/pseries/vas: Save PID in pseries_vas_window struct (Steve Best) [2028677]
- powerpc/pseries/vas: Use common names in VAS capability structure (Steve Best) [2028677]
- s390/kexec: fix return code handling (Lichen Liu) [2017023]
- s390/kexec: fix memory leak of ipl report buffer (Lichen Liu) [2017023]
- Build intel_sdsi with %%{tools_make} (David Arcari) [1971952]
- redhat/kernel.spec.template: Add intel_sdsi utility (David Arcari) [1971952]
- redhat/configs: enable CONFIG_INTEL_SDSI (David Arcari) [1971952]
- selftests: sdsi: test sysfs setup (David Arcari) [1971952]
- tools arch x86: Add Intel SDSi provisiong tool (David Arcari) [1971952]
- platform/x86: Add Intel Software Defined Silicon driver (David Arcari) [1971952]
- spi: pxa2xx: Add support for Intel Raptor Lake PCH-S (David Arcari) [2040032]
- redhat/configs: change intel-lpss to be a loadable module (David Arcari) [2040032]
- mfd: intel-lpss: Provide an SSP type to the driver (David Arcari) [2040032]
- mfd: intel-lpss: Add Intel Raptor Lake PCH-S PCI IDs (David Arcari) [2040032]
- mfd: intel-lpss: Fix I2C4 not being available on the Microsoft Surface Go & Go 2 (David Arcari) [2040032]
- mfd: intel-lpss-pci: Fix clock speed for 38a8 UART (David Arcari) [2040032]
- mfd: intel-lpss: Fix too early PM enablement in the ACPI ->probe() (David Arcari) [2040032]
- mfd: intel-lpss: Add Intel Lakefield PCH PCI IDs (David Arcari) [2040032]
- mfd: intel-lpss: Add support for MacBookPro16,2 ICL-N UART (David Arcari) [2040032]
- mfd: intel-lpss: Add Intel Cannon Lake ACPI IDs (David Arcari) [2040032]
- pinctrl: alderlake: Add Raptor Lake-S ACPI ID (David Arcari) [2040034]
- pinctrl: tigerlake: Revert "Add Alder Lake-M ACPI ID" (David Arcari) [2040034]
- pinctrl: intel: fix unexpected interrupt (David Arcari) [2040034]
- pinctrl: intel: Fix a glitch when updating IRQ flags on a preconfigured line (David Arcari) [2040034]
- pinctrl: intel: Kconfig: Add configuration menu to Intel pin control (David Arcari) [2040034]
- i2c: i801: Drop two outdated comments (David Arcari) [2040028]
- i2c: i801: Add support for the Process Call command (David Arcari) [2040028]
- i2c: i801: Drop useless masking in i801_access (David Arcari) [2040028]
- i2c: i801: Add support for Intel Raptor Lake PCH-S (David Arcari) [2040028]
- eeprom: ee1004: limit i2c reads to I2C_SMBUS_BLOCK_MAX (David Arcari) [2040028]
- i2c: i801: Don't clear status flags twice in interrupt mode (David Arcari) [2040028]
- i2c: i801: Don't read back cleared status in i801_check_pre() (David Arcari) [2040028]
- i2c: i801: Improve handling platform data for tco device (David Arcari) [2040028]
- i2c: i801: Improve handling of chip-specific feature definitions (David Arcari) [2040028]
- i2c: i801: Remove i801_set_block_buffer_mode (David Arcari) [2040028]
- i2c: i801: Don't silently correct invalid transfer size (David Arcari) [2040028]
- i2c: i801: Fix interrupt storm from SMB_ALERT signal (David Arcari) [2040028]
- i2c: i801: Restore INTREN on unload (David Arcari) [2040028]
- i2c: i801: Add support for Intel Ice Lake PCH-N (David Arcari) [2040028]
- i2c: i801: Fix incorrect and needless software PEC disabling (David Arcari) [2040028]
- i2c: i801: Stop using pm_runtime_set_autosuspend_delay(-1) (David Arcari) [2040028]
- i2c: i801: Use PCI bus rescan mutex to protect P2SB access (David Arcari) [2040028]
- i2c: i801: Improve i801_add_mux (David Arcari) [2040028]
- i2c: i801: Improve i801_acpi_probe/remove functions (David Arcari) [2040028]
- i2c: i801: Remove not needed check for PCI_COMMAND_INTX_DISABLE (David Arcari) [2040028]
- i2c: i801: Improve is_dell_system_with_lis3lv02d (David Arcari) [2040028]
- i2c: i801: Remove not needed debug message (David Arcari) [2040028]
- i2c: i801: make p2sb_spinlock a mutex (David Arcari) [2040028]
- i2c: i801: Improve disabling runtime pm (David Arcari) [2040028]
- i2c: i801: Fix handling SMBHSTCNT_PEC_EN (David Arcari) [2040028]
- kABI: Pad the address_space struct (Nico Pache) [2048328]
- kABI: Pad the readahead_control struct (Nico Pache) [2048328]
- kABI: Pad the vm_fault struct (Nico Pache) [2048328]
- kABI: Pad vm_operations_struct (Nico Pache) [2048328]
- kABI: Pad the mempolicy struct (Nico Pache) [2048328]
- kABI: Pad mempool_s (Nico Pache) [2048328]
- kABI: Pad dev_pagemap and dev_pagemap_ops (Nico Pache) [2048328]
- kABI: Pad struct swap_info_struct (Nico Pache) [2048328]
- kABI: Pad vmem_altmap (Nico Pache) [2048328]
- kABI: Pad the vm_area_struct (Nico Pache) [2048328]
- kABI: Pad the mm_struct (Nico Pache) [2048328]
- kABI: exclude reclaim_state struct (Nico Pache) [2048328]
- kABI: Pad the shrinker struct (Nico Pache) [2048328]
- kABI: Exclude memcg pointer from shrinker (Nico Pache) [2048328]
- pseries/eeh: Fix the kdump kernel crash during eeh_pseries_init (Steve Best) [2067770]
- scsi: smartpqi: Update version to 2.1.14-035 (Don Brace) [2012229]
- scsi: smartpqi: Fix lsscsi -t SAS addresses (Don Brace) [2012229]
- scsi: smartpqi: Fix hibernate and suspend (Don Brace) [2012229]
- scsi: smartpqi: Fix BUILD_BUG_ON() statements (Don Brace) [2012229]
- scsi: smartpqi: Fix NUMA node not updated during init (Don Brace) [2012229]
- scsi: smartpqi: Expose SAS address for SATA drives (Don Brace) [2012229]
- scsi: smartpqi: Speed up RAID 10 sequential reads (Don Brace) [2012229]
- scsi: smartpqi: Fix kdump issue when controller is locked up (Don Brace) [2012229]
- scsi: smartpqi: Update volume size after expansion (Don Brace) [2012229]
- scsi: smartpqi: Avoid drive spin-down during suspend (Don Brace) [2012229]
- scsi: smartpqi: Resolve delay issue with PQI_HZ value (Don Brace) [2012229]
- scsi: smartpqi: Fix a typo in func pqi_aio_submit_io() (Don Brace) [2012229]
- scsi: smartpqi: Fix a name typo and cleanup code (Don Brace) [2012229]
- scsi: smartpqi: Quickly propagate path failures to SCSI midlayer (Don Brace) [2012229]
- scsi: smartpqi: Eliminate drive spin down on warm boot (Don Brace) [2012229]
- scsi: smartpqi: Enable SATA NCQ priority in sysfs (Don Brace) [2012229]
- scsi: smartpqi: Add PCI IDs (Don Brace) [2012229]
- scsi: smartpqi: Fix rmmod stack trace (Don Brace) [2012229]
- selftests: xsk: Generate packet directly in umem (Felix Maurer) [2006330]
- selftests: xsk: Decrease sending speed (Felix Maurer) [2006330]
- selftests: xsk: Simplify packet validation in xsk tests (Felix Maurer) [2006330]
- selftests: xsk: Rename worker_* functions that are not thread entry points (Felix Maurer) [2006330]
- selftests: xsk: Remove end-of-test packet (Felix Maurer) [2006330]
- RDMA/qedr: Fix reporting max_{send/recv}_wr attrs (Kamal Heib) [2051532]

* Mon Apr 25 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-80.rt21.80.el9]
- [rt] build kernel-rt-5.14.0-80.rt21.80.el9 [2061574]
- redhat: Disable unset media configs on RT (Fernando Pacheco)
- redhat: disable uncommon media device infrastructure (Jarod Wilson) [2074598]
- netfilter: nf_tables: unregister flowtable hooks on netns exit (Florian Westphal) [2056869]
- netfilter: nf_tables_offload: incorrect flow offload action array size (Florian Westphal) [2056869] {CVE-2022-25636}
- netfilter: nf_tables: validate registers coming from userspace. (Phil Sutter) [2065350] {CVE-2022-1015}
- scsi: qedi: Fix failed disconnect handling (Chris Leech) [2071524]
- scsi: iscsi: Fix unbound endpoint error handling (Chris Leech) [2071524]
- scsi: iscsi: Fix conn cleanup and stop race during iscsid restart (Chris Leech) [2071524]
- scsi: iscsi: Fix endpoint reuse regression (Chris Leech) [2071524]
- scsi: iscsi: Release endpoint ID when its freed (Chris Leech) [2071524]
- scsi: iscsi: Fix offload conn cleanup when iscsid restarts (Chris Leech) [2071524]
- Revert "scsi: iscsi: Fix offload conn cleanup when iscsid restarts" (Chris Leech) [2071524]
- scsi: iscsi: Speed up session unblocking and removal (Chris Leech) [2071524]
- scsi: iscsi: Fix recovery and unblocking race (Chris Leech) [2071524]
- scsi: qedi: Fix cmd_cleanup_cmpl counter mismatch issue (Chris Leech) [2071524]
- scsi: iscsi: Unblock session then wake up error handler (Chris Leech) [2071524]
- scsi: iscsi: Fix set_param() handling (Chris Leech) [2071524]
- scsi: iscsi: Fix iscsi_task use after free (Chris Leech) [2071524]
- scsi: iscsi: Adjust iface sysfs attr detection (Chris Leech) [2071524]
- scsi: qedi: Add support for fastpath doorbell recovery (Chris Leech) [2071524]
- redhat: Enable KASAN on all ELN debug kernels (Nico Pache) [1995251]
- sched/topology: Remove redundant variable and fix incorrect type in build_sched_domains (Phil Auld) [2065198]
- sched/fair: Adjust the allowed NUMA imbalance when SD_NUMA spans multiple LLCs (Phil Auld) [2065198]
- sched/fair: Improve consistency of allowed NUMA balance calculations (Phil Auld) [2065198]
- redhat/configs: Enable CONFIG_RCU_SCALE_TEST & CONFIG_RCU_REF_SCALE_TEST (Waiman Long) [2070740]
- thermal: int340x: Fix VCoRefLow MMIO bit offset for TGL (David Arcari) [2039995]
- thermal: int340x: Use struct_group() for memcpy() region (David Arcari) [2039995]
- thermal: int340x: Limit Kconfig to 64-bit (David Arcari) [2039995]
- thermal: int340x: fix build on 32-bit targets (David Arcari) [2039995 2040066]
- thermal/drivers/int340x: processor_thermal: Suppot 64 bit RFIM responses (David Arcari) [2039995 2040066]
- thermal/drivers/int340x: Improve the tcc offset saving for suspend/resume (David Arcari) [2039995]
- thermal: int340x: delete bogus length check (David Arcari) [2039995]
- thermal/drivers/int340x: Do not set a wrong tcc offset on resume (David Arcari) [2039995]
- thermal/drivers/int340x: Use IMOK independently (David Arcari) [2039995]
- stddef: Introduce struct_group() helper macro (David Arcari) [2039995]
- gfs2: Initialize gh_error in gfs2_glock_nq (Andreas Gruenbacher) [2031240]
- gfs2: Make use of list_is_first (Andreas Gruenbacher) [2031240]
- gfs2: Switch lock order of inode and iopen glock (Andreas Gruenbacher) [2031240]
- gfs2: cancel timed-out glock requests (Andreas Gruenbacher) [2031240]
- gfs2: Expect -EBUSY after canceling dlm locking requests (Andreas Gruenbacher) [2031240]
- gfs2: gfs2_setattr_size error path fix (Andreas Gruenbacher) [2031240]
- gfs2: assign rgrp glock before compute_bitstructs (Bob Peterson) [2031240]

* Tue Apr 19 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-79.rt21.79.el9]
- [rt] build kernel-rt-5.14.0-79.rt21.79.el9 [2061574]
- redhat/configs: Enable WDT devices used by qemu VMs (Prarit Bhargava) [2074160]
- redhat/configs: disable CONFIG_CAN_SOFTING (Brian Masney) [2073521]
- myri10ge: mark as unmaintained (Michal Schmidt) [2054208]
- benet: mark device 0xe220 (Lancer) as unmaintained (Michal Schmidt) [2054208]
- bnx2: mark as unmaintained (Michal Schmidt) [2054208]
- ice: Fix race condition during interface enslave (Petr Oros) [1988953]
- ice: Fix error with handling of bonding MTU (Petr Oros) [1988953]
- ice: Avoid RTNL lock when re-creating auxiliary device (Petr Oros) [1988953]
- ice: Fix KASAN error in LAG NETDEV_UNREGISTER handler (Petr Oros) [1988953]
- userfaultfd/selftests: fix calculation of expected ioctls (Desnes A. Nunes do Rosario) [2036152]
- userfaultfd/selftests: fix feature support detection (Desnes A. Nunes do Rosario) [2036152]
- userfaultfd/selftests: don't rely on GNU extensions for random numbers (Desnes A. Nunes do Rosario) [2036152]
- CI: Drop baseline runs (Veronika Kabatova)
- PCI: hv: Propagate coherence from VMbus device to PCI device (Vitaly Kuznetsov) [2068432]
- Drivers: hv: vmbus: Propagate VMbus coherence to each VMbus device (Vitaly Kuznetsov) [2068432]
- ibmvnic: fix race between xmit and reset (Gustavo Walbon) [2061556]
- mlxsw: spectrum_router: Increase parsing depth for multipath hash (Ivan Vecera) [2020113]
- mlxsw: Remove old parsing depth infrastructure (Ivan Vecera) [2020113]
- mlxsw: Convert existing consumers to use new API for parsing configuration (Ivan Vecera) [2020113]
- mlxsw: spectrum: Add infrastructure for parsing configuration (Ivan Vecera) [2020113]
- ipv6: separate ndisc_ns_create() from ndisc_send_ns() (Ivan Vecera) [2073506]
- powerpc/mce: Modify the real address error logging messages (Desnes A. Nunes do Rosario) [2068688]
- selftests/powerpc: Add test for real address error handling (Desnes A. Nunes do Rosario) [2068688]
- powerpc/pseries: Parse control memory access error (Desnes A. Nunes do Rosario) [2068688]
- tools headers UAPI: Sync linux/perf_event.h with the kernel sources (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix power_pmu_disable to call clear_pmi_irq_pending only if PMI is pending (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Only define power_pmu_wants_prompt_pmi() for CONFIG_PPC64 (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Add data source encodings for power10 platform (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Add encodings to represent data based on newer composite PERF_MEM_LVLNUM* fields (Desnes A. Nunes do Rosario) [2048779]
- perf: Add new macros for mem_hops field (Desnes A. Nunes do Rosario) [2048779]
- tools headers UAPI: Add new macros for mem_hops field to perf_event.h (Desnes A. Nunes do Rosario) [2048779]
- bpf: Remove config check to enable bpf support for branch records (Desnes A. Nunes do Rosario) [2048779]
- perf powerpc: Update global/local variants for p_stage_cyc (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Include global and local variants for p_stage_cyc sort key (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Fix the 'p_stage_cyc' sort key behavior (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Fix the 'ins_lat' sort key behavior (Desnes A. Nunes do Rosario) [2048779]
- perf sort: Fix the 'weight' sort key behavior (Desnes A. Nunes do Rosario) [2048779]
- perf vendor events power10: Add metric events JSON file for power10 platform (Desnes A. Nunes do Rosario) [2048779]
- perf powerpc: Add support to expose instruction and data address registers as part of extended regs (Desnes A. Nunes do Rosario) [2048779]
- perf powerpc: Refactor the code definition of perf reg extended mask in tools side header file (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix cycles/instructions as PM_CYC/PM_INST_CMPL in power10 (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Expose instruction and data address registers as part of extended regs (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Refactor the code definition of perf reg extended mask (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix data source encodings for L2.1 and L3.1 accesses (Desnes A. Nunes do Rosario) [2048779]
- tools/perf: Add mem_hops field in perf_mem_data_src structure (Desnes A. Nunes do Rosario) [2048779]
- perf: Add mem_hops field in perf_mem_data_src structure (Desnes A. Nunes do Rosario) [2048779]
- perf: Add comment about current state of PERF_MEM_LVL_* namespace and remove an extra line (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix the check for SIAR value (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Drop the case of returning 0 as instruction pointer (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Use stack siar instead of mfspr (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf/hv-gpci: Fix counter value parsing (Desnes A. Nunes do Rosario) [2048779]
- powerpc/perf: Fix PMU callbacks to clear pending PMI before resetting an overflown PMC (Desnes A. Nunes do Rosario) [2048779]
- EVM: fix the evm= __setup handler return value (Bruno Meneguele) [2063906]
- ima: Do not print policy rule with inactive LSM labels (Bruno Meneguele) [2063906]
- ima: Allow template selection with ima_template[_fmt]= after ima_hash= (Bruno Meneguele) [2063906]
- ima: Remove ima_policy file before directory (Bruno Meneguele) [2063906]
- integrity: check the return value of audit_log_start() (Bruno Meneguele) [2063906]
- ima: fix reference leak in asymmetric_verify() (Bruno Meneguele) [2063906]
- ipv4: avoid using shared IP generator for connected sockets (Paolo Abeni) [2062428] {CVE-2020-36516}
- bpf/selftests: Fix namespace mount setup in tc_redirect (Yauheni Kaliuta) [2063067]
- memcg: do not tweak node in alloc_mem_cgroup_per_node_info (Nico Pache) [2024054]
- mm: make free_area_init_node aware of memory less nodes (Nico Pache) [2024054]
- mm, memory_hotplug: reorganize new pgdat initialization (Nico Pache) [2024054]
- mm, memory_hotplug: drop arch_free_nodedata (Nico Pache) [2024054]
- mm: handle uninitialized numa nodes gracefully (Nico Pache) [2024054]
- mm, memory_hotplug: make arch_alloc_nodedata independent on CONFIG_MEMORY_HOTPLUG (Nico Pache) [2024054]
- block: restore the old set_task_ioprio() behaviour wrt PF_EXITING (Ming Lei) [2066297]
- scsi: core: scsi_logging: Fix a BUG (Ming Lei) [2066297]
- scsi: sr: Fix typo in CDROM(CLOSETRAY|EJECT) handling (Ming Lei) [2066297]
- block: add __must_check for *add_disk*() callers (Ming Lei) [2066297]
- scsi: bsg: Fix errno when scsi_bsg_register_queue() fails (Ming Lei) [2066297]
- scsi: st: Add missing break in switch statement in st_ioctl() (Ming Lei) [2066297]
- scsi: core: scsi_ioctl: Fix error code propagation in SG_IO (Ming Lei) [2066297]
- scsi: bsg: Fix device unregistration (Ming Lei) [2066297]
- scsi: bsg-lib: Fix commands without data transfer in bsg_transport_sg_io_fn() (Ming Lei) [2066297]
- scsi: bsg: Fix commands without data transfer in scsi_bsg_sg_io_fn() (Ming Lei) [2066297]
- block: limit request dispatch loop duration (Ming Lei) [2066297]
- block: fix rq-qos breakage from skipping rq_qos_done_bio() (Ming Lei) [2066297]
- block: flush plug based on hardware and software queue order (Ming Lei) [2066297]
- block: ensure plug merging checks the correct queue at least once (Ming Lei) [2066297]
- block: update io_ticks when io hang (Ming Lei) [2066297]
- block: release rq qos structures for queue without disk (Ming Lei) [2066297]
- block: fix blk_mq_attempt_bio_merge and rq_qos_throttle protection (Ming Lei) [2066297]
- blktrace: fix use after free for struct blk_trace (Ming Lei) [2066297]
- block: clear iocb->private in blkdev_bio_end_io_async() (Ming Lei) [2066297]
- block/wbt: fix negative inflight counter when remove scsi device (Ming Lei) [2066297]
- block-map: add __GFP_ZERO flag for alloc_page in function bio_copy_kern (Ming Lei) [2066297]
- block: loop:use kstatfs.f_bsize of backing file to set discard granularity (Ming Lei) [2066297]
- block: Add handling for zone append command in blk_complete_request (Ming Lei) [2066297]
- loop: revert "make autoclear operation asynchronous" (Ming Lei) [2066297]
- block: fix DIO handling regressions in blkdev_read_iter() (Ming Lei) [2066297]
- blk-mq: fix missing blk_account_io_done() in error path (Ming Lei) [2066297]
- block: cleanup q->srcu (Ming Lei) [2066297]
- block: Remove unnecessary variable assignment (Ming Lei) [2066297]
- brd: remove brd_devices_mutex mutex (Ming Lei) [2066297]
- aoe: remove redundant assignment on variable n (Ming Lei) [2066297]
- loop: remove redundant initialization of pointer node (Ming Lei) [2066297]
- block/rnbd-clt-sysfs: use default_groups in kobj_type (Ming Lei) [2066297]
- pktcdvd: convert to use attribute groups (Ming Lei) [2066297]
- rsxx: Drop PCI legacy power management (Ming Lei) [2066297]
- mtip32xx: convert to generic power management (Ming Lei) [2066297]
- mtip32xx: remove pointless drvdata lookups (Ming Lei) [2066297]
- mtip32xx: remove pointless drvdata checking (Ming Lei) [2066297]
- drbd: Use struct_group() to zero algs (Ming Lei) [2066297]
- loop: make autoclear operation asynchronous (Ming Lei) [2066297]
- null_blk: cast command status to integer (Ming Lei) [2066297]
- pktdvd: stop using bdi congestion framework. (Ming Lei) [2066297]
- block: null_blk: batched complete poll requests (Ming Lei) [2066297]
- floppy: Add max size check for user space request (Ming Lei) [2066297]
- floppy: Fix hang in watchdog when disk is ejected (Ming Lei) [2066297]
- loop: don't hold lo_mutex during __loop_clr_fd() (Ming Lei) [2066297]
- MAINTAINERS: add entries for block layer documentation (Ming Lei) [2066297]
- docs: sysfs-block: add contact for nomerges (Ming Lei) [2066297]
- docs: sysfs-block: sort alphabetically (Ming Lei) [2066297]
- docs: sysfs-block: move to stable directory (Ming Lei) [2066297]
- block: fix old-style declaration (Ming Lei) [2066297]
- nvme-pci: fix queue_rqs list splitting (Ming Lei) [2066297]
- block: introduce rq_list_move (Ming Lei) [2066297]
- block: drop needless assignment in set_task_ioprio() (Ming Lei) [2066297]
- bio.h: fix kernel-doc warnings (Ming Lei) [2066297]
- block: check minor range in device_add_disk() (Ming Lei) [2066297]
- block: use "unsigned long" for blk_validate_block_size(). (Ming Lei) [2066297]
- block: fix error unwinding in device_add_disk (Ming Lei) [2066297]
- block: call blk_exit_queue() before freeing q->stats (Ming Lei) [2066297]
- block: fix error in handling dead task for ioprio setting (Ming Lei) [2066297]
- blk-mq: blk-mq: check quiesce state before queue_rqs (Ming Lei) [2066297]
- block: only build the icq tracking code when needed (Ming Lei) [2066297]
- block: fold create_task_io_context into ioc_find_get_icq (Ming Lei) [2066297]
- block: open code create_task_io_context in set_task_ioprio (Ming Lei) [2066297]
- block: fold get_task_io_context into set_task_ioprio (Ming Lei) [2066297]
- block: move set_task_ioprio to blk-ioc.c (Ming Lei) [2066297]
- block: cleanup ioc_clear_queue (Ming Lei) [2066297]
- block: refactor put_io_context (Ming Lei) [2066297]
- block: remove the NULL ioc check in put_io_context (Ming Lei) [2066297]
- block: refactor put_iocontext_active (Ming Lei) [2066297]
- block: simplify struct io_context refcounting (Ming Lei) [2066297]
- block: remove the nr_task field from struct io_context (Ming Lei) [2066297]
- nvme: add support for mq_ops->queue_rqs() (Ming Lei) [2066297]
- block: add mq_ops->queue_rqs hook (Ming Lei) [2066297]
- block: use singly linked list for bio cache (Ming Lei) [2066297]
- block: add completion handler for fast path (Ming Lei) [2066297]
- block: make queue stat accounting a reference (Ming Lei) [2066297]
- bdev: Improve lookup_bdev documentation (Ming Lei) [2066297]
- mtd_blkdevs: don't scan partitions for plain mtdblock (Ming Lei) [2066297]
- blk-mq: Optimise blk_mq_queue_tag_busy_iter() for shared tags (Ming Lei) [2066297]
- blk-mq: Delete busy_iter_fn (Ming Lei) [2066297]
- blk-mq: Drop busy_iter_fn blk_mq_hw_ctx argument (Ming Lei) [2066297]
- blk-mq: don't use plug->mq_list->q directly in blk_mq_run_dispatch_ops() (Ming Lei) [2066297]
- blk-mq: don't run might_sleep() if the operation needn't blocking (Ming Lei) [2066297]
- blk-mq: run dispatch lock once in case of issuing from list (Ming Lei) [2066297]
- blk-mq: pass request queue to blk_mq_run_dispatch_ops (Ming Lei) [2066297]
- blk-mq: move srcu from blk_mq_hw_ctx to request_queue (Ming Lei) [2066297]
- blk-mq: remove hctx_lock and hctx_unlock (Ming Lei) [2066297]
- block: switch to atomic_t for request references (Ming Lei) [2066297]
- block: move direct_IO into our own read_iter handler (Ming Lei) [2066297]
- mm: move filemap_range_needs_writeback() into header (Ming Lei) [2066297]
- mm: move more expensive part of XA setup out of mapping check (Ming Lei) [2066297]
- block: get rid of useless goto and label in blk_mq_get_new_requests() (Ming Lei) [2066297]
- blk-mq: check q->poll_stat in queue_poll_stat_show (Ming Lei) [2066297]
- scsi: remove the gendisk argument to scsi_ioctl (Ming Lei) [2066297]
- block: remove the gendisk argument to blk_execute_rq (Ming Lei) [2066297]
- block: remove the ->rq_disk field in struct request (Ming Lei) [2066297]
- block: don't check ->rq_disk in merges (Ming Lei) [2066297]
- mtd_blkdevs: remove the sector out of range check in do_blktrans_request (Ming Lei) [2066297]
- block: Remove redundant initialization of variable ret (Ming Lei) [2066297]
- block: simplify ioc_lookup_icq (Ming Lei) [2066297]
- block: simplify ioc_create_icq (Ming Lei) [2066297]
- block: return the io_context from create_task_io_context (Ming Lei) [2066297]
- block: use alloc_io_context in __copy_io (Ming Lei) [2066297]
- block: factor out a alloc_io_context helper (Ming Lei) [2066297]
- block: remove get_io_context_active (Ming Lei) [2066297]
- block: move the remaining elv.icq handling to the I/O scheduler (Ming Lei) [2066297]
- block: move blk_mq_sched_assign_ioc to blk-ioc.c (Ming Lei) [2066297]
- block: mark put_io_context_active static (Ming Lei) [2066297]
- Revert "block: Provide blk_mq_sched_get_icq()" (Ming Lei) [2066297]
- bfq: use bfq_bic_lookup in bfq_limit_depth (Ming Lei) [2066297]
- bfq: simplify bfq_bic_lookup (Ming Lei) [2066297]
- fork: move copy_io to block/blk-ioc.c (Ming Lei) [2066297]
- bfq: Do not let waker requests skip proper accounting (Ming Lei) [2066297]
- bfq: Log waker detections (Ming Lei) [2066297]
- bfq: Provide helper to generate bfqq name (Ming Lei) [2066297]
- bfq: Limit waker detection in time (Ming Lei) [2066297]
- bfq: Limit number of requests consumed by each cgroup (Ming Lei) [2066297]
- bfq: Store full bitmap depth in bfq_data (Ming Lei) [2066297]
- bfq: Track number of allocated requests in bfq_entity (Ming Lei) [2066297]
- block: Provide blk_mq_sched_get_icq() (Ming Lei) [2066297]
- mmc: core: Use blk_mq_complete_request_direct(). (Ming Lei) [2066297]
- blk-mq: Add blk_mq_complete_request_direct() (Ming Lei) [2066297]
- blk-crypto: remove blk_crypto_unregister() (Ming Lei) [2066297]
- block: don't include <linux/part_stat.h> in blk.h (Ming Lei) [2066297]
- block: don't include <linux/idr.h> in blk.h (Ming Lei) [2066297]
- block: don't include <linux/blk-mq.h> in blk.h (Ming Lei) [2066297]
- block: don't include blk-mq.h in blk.h (Ming Lei) [2066297]
- block: don't include blk-mq-sched.h in blk.h (Ming Lei) [2066297]
- block: remove the e argument to elevator_exit (Ming Lei) [2066297]
- block: remove elevator_exit (Ming Lei) [2066297]
- block: move blk_get_flush_queue to blk-flush.c (Ming Lei) [2066297]
- blk_mq: remove repeated includes (Ming Lei) [2066297]
- block: move io_context creation into where it's needed (Ming Lei) [2066297]
- block: only allocate poll_stats if there's a user of them (Ming Lei) [2066297]
- blk-ioprio: don't set bio priority if not needed (Ming Lei) [2066297]
- blk-mq: move more plug handling from blk_mq_submit_bio into blk_add_rq_to_plug (Ming Lei) [2066297]
- sr: set GENHD_FL_REMOVABLE earlier (Ming Lei) [2066297]
- block: cleanup the GENHD_FL_* definitions (Ming Lei) [2066297]
- block: don't set GENHD_FL_NO_PART for hidden gendisks (Ming Lei) [2066297]
- block: remove GENHD_FL_EXT_DEVT (Ming Lei) [2066297]
- block: remove GENHD_FL_SUPPRESS_PARTITION_INFO (Ming Lei) [2066297]
- mmc: don't set GENHD_FL_SUPPRESS_PARTITION_INFO (Ming Lei) [2066297]
- null_blk: don't suppress partitioning information (Ming Lei) [2066297]
- block: remove the GENHD_FL_HIDDEN check in blkdev_get_no_open (Ming Lei) [2066297]
- block: rename GENHD_FL_NO_PART_SCAN to GENHD_FL_NO_PART (Ming Lei) [2066297]
- block: merge disk_scan_partitions and blkdev_reread_part (Ming Lei) [2066297]
- block: remove a dead check in show_partition (Ming Lei) [2066297]
- block: remove GENHD_FL_CD (Ming Lei) [2066297]
- block: move GENHD_FL_BLOCK_EVENTS_ON_EXCL_WRITE to disk->event_flags (Ming Lei) [2066297]
- block: move GENHD_FL_NATIVE_CAPACITY to disk->state (Ming Lei) [2066297]
- block: don't include blk-mq headers in blk-core.c (Ming Lei) [2066297]
- block: move blk_print_req_error to blk-mq.c (Ming Lei) [2066297]
- block: move blk_dump_rq_flags to blk-mq.c (Ming Lei) [2066297]
- block: move blk_account_io_{start,done} to blk-mq.c (Ming Lei) [2066297]
- block: move blk_steal_bios to blk-mq.c (Ming Lei) [2066297]
- block: move blk_rq_init to blk-mq.c (Ming Lei) [2066297]
- block: move request based cloning helpers to blk-mq.c (Ming Lei) [2066297]
- blk-mq: move blk_mq_flush_plug_list (Ming Lei) [2066297]
- block: remove blk-exec.c (Ming Lei) [2066297]
- block: remove rq_flush_dcache_pages (Ming Lei) [2066297]
- block: move blk_rq_err_bytes to scsi (Ming Lei) [2066297]
- block: remove blk_{get,put}_request (Ming Lei) [2066297]
- block: remove QUEUE_FLAG_SCSI_PASSTHROUGH (Ming Lei) [2066297]
- block: remove the initialize_rq_fn blk_mq_ops method (Ming Lei) [2066297]
- scsi: add a scsi_alloc_request helper (Ming Lei) [2066297]
- bsg-lib: initialize the bsg_job in bsg_transport_sg_io_fn (Ming Lei) [2066297]
- nfsd/blocklayout: use ->get_unique_id instead of sending SCSI commands (Ming Lei) [2066297]
- sd: implement ->get_unique_id (Ming Lei) [2066297]
- block: add a ->get_unique_id method (Ming Lei) [2066297]
- scsi: bsg: Move the whole request execution into the SCSI/transport handlers (Ming Lei) [2066297]
- scsi: block: Remove the remaining SG_IO-related fields from struct request_queue (Ming Lei) [2066297]
- scsi: block: Remove BLK_SCSI_MAX_CMDS (Ming Lei) [2066297]
- scsi: bsg: Simplify device registration (Ming Lei) [2066297]
- scsi: sr: cdrom: Move cdrom_read_cdda_bpc() into the sr driver (Ming Lei) [2066297]
- scsi: scsi_ioctl: Unexport sg_scsi_ioctl() (Ming Lei) [2066297]
- scsi: scsi_ioctl: Factor SG_IO handling into a helper (Ming Lei) [2066297]
- scsi: scsi_ioctl: Factor SCSI_IOCTL_GET_IDLUN handling into a helper (Ming Lei) [2066297]
- scsi: scsi_ioctl: Consolidate the START STOP UNIT handling (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove a very misleading comment (Ming Lei) [2066297]
- scsi: core: Rename CONFIG_BLK_SCSI_REQUEST to CONFIG_SCSI_COMMON (Ming Lei) [2066297]
- scsi: scsi_ioctl: Move the "block layer" SCSI ioctl handling to drivers/scsi (Ming Lei) [2066297]
- scsi: scsi_ioctl: Simplify SCSI passthrough permission checking (Ming Lei) [2066297]
- scsi: scsi_ioctl: Move scsi_command_size_tbl to scsi_common.c (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove scsi_req_init() (Ming Lei) [2066297]
- scsi: bsg: Move bsg_scsi_ops to drivers/scsi/ (Ming Lei) [2066297]
- scsi: bsg: Decouple from scsi_cmd_ioctl() (Ming Lei) [2066297]
- scsi: block: Add a queue_max_bytes() helper (Ming Lei) [2066297]
- scsi: scsi_ioctl: Call scsi_cmd_ioctl() from scsi_ioctl() (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove scsi_verify_blk_ioctl() (Ming Lei) [2066297]
- scsi: scsi_ioctl: Remove scsi_cmd_blk_ioctl() (Ming Lei) [2066297]
- scsi: cdrom: Remove the call to scsi_cmd_blk_ioctl() from cdrom_ioctl() (Ming Lei) [2066297]
- scsi: st: Simplify ioctl handling (Ming Lei) [2066297]
- scsi: core: Remove scsi_compat_ioctl() (Ming Lei) [2066297]
- scsi: sg: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: ch: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: sd: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: sr: Consolidate compat ioctl handling (Ming Lei) [2066297]
- scsi: bsg: Remove support for SCSI_IOCTL_SEND_COMMAND (Ming Lei) [2066297]
- block: fix argument type of bio_trim() (Ming Lei) [2066297]
- powerpc/xive: Export XIVE IPI information for online-only processors. (Steve Best) [2038242]
- RDMA/cma: Do not change route.addr.src_addr outside state checks (Kamal Heib) [2056771]
- RDMA/ib_srp: Fix a deadlock (Kamal Heib) [2056771]
- RDMA/siw: Fix broken RDMA Read Fence/Resume logic. (Kamal Heib) [2056771]
- IB/cm: Release previously acquired reference counter in the cm_id_priv (Kamal Heib) [2056771]
- RDMA/siw: Fix refcounting leak in siw_create_qp() (Kamal Heib) [2056771]
- RDMA/ucma: Protect mc during concurrent multicast leaves (Kamal Heib) [2056771]
- RDMA/cma: Use correct address when leaving multicast group (Kamal Heib) [2056771]
- IB/hfi1: Fix tstats alloc and dealloc (Kamal Heib) [2049164 2056771]
- IB/hfi1: Fix AIP early init panic (Kamal Heib) [2049164 2056771]
- IB/hfi1: Fix alloc failure with larger txqueuelen (Kamal Heib) [2049164 2056771]
- IB/hfi1: Fix panic with larger ipoib send_queue_size (Kamal Heib) [2049164 2056771]
- all: replace find_next{,_zero}_bit with find_first{,_zero}_bit where appropriate (Kamal Heib) [2056771]
- RDMA/irdma: Remove the redundant return (Kamal Heib) [2037988 2056771]
- RDMA/irdma: Make the source udp port vary (Kamal Heib) [2037988 2056771]
- RDMA/core: Calculate UDP source port based on flow label or lqpn/rqpn (Kamal Heib) [2056771]
- IB/iser: Align coding style across driver (Kamal Heib) [2056771]
- IB/iser: Remove un-needed casting to/from void pointer (Kamal Heib) [2056771]
- IB/iser: Don't suppress send completions (Kamal Heib) [2056771]
- IB/iser: Rename ib_ret local variable (Kamal Heib) [2056771]
- IB/iser: Fix RNR errors (Kamal Heib) [2056771]
- IB/iser: Remove deprecated pi_guard module param (Kamal Heib) [2056771]
- IB/mlx5: Expose NDR speed through MAD (Kamal Heib) [2056771]
- RDMA/mad: Delete duplicated init_query_mad functions (Kamal Heib) [2056771]
- RDMA: Use default_groups in kobj_type (Kamal Heib) [2056771]
- RDMA/irdma: Use auxiliary_device driver data helpers (Kamal Heib) [2037988 2056771]
- driver core: auxiliary bus: Add driver data helpers (Kamal Heib) [2056771]
- RDMA/cma: Let cma_resolve_ib_dev() continue search even after empty entry (Kamal Heib) [2056771]
- RDMA/core: Let ib_find_gid() continue search even after empty entry (Kamal Heib) [2056771]
- RDMA/core: Modify rdma_query_gid() to return accurate error codes (Kamal Heib) [2056771]
- RDMA/irdma: Fix the type used to declare a bitmap (Kamal Heib) [2037988 2056771]
- IB/core: Remove redundant pointer mm (Kamal Heib) [2056771]
- RDMA/uverbs: Remove the unnecessary assignment (Kamal Heib) [2056771]
- RDMA/siw: Use max() instead of doing it manually (Kamal Heib) [2056771]
- RDMA/pvrdma: Use non-atomic bitmap functions when possible (Kamal Heib) [2056771]
- RDMA/pvrdma: Use bitmap_zalloc() when applicable (Kamal Heib) [2056771]
- IB/hfi1: Use bitmap_zalloc() when applicable (Kamal Heib) [2049164 2056771]
- RDMA/siw: Use helper function to set sys_image_guid (Kamal Heib) [2056771]
- RDMA/cma: Remove open coding of overflow checking for private_data_len (Kamal Heib) [2056771]
- RDMA/usnic: Clean up usnic_ib_alloc_pd() (Kamal Heib) [2056771]
- RDMA/irdma: Use helper function to set GUIDs (Kamal Heib) [2037988 2056771]
- IB/hfi1: Fix leak of rcvhdrtail_dummy_kvaddr (Kamal Heib) [2049164 2056770]
- IB/hfi1: Fix early init panic (Kamal Heib) [2049164 2056770]
- IB/hfi1: Insure use of smp_processor_id() is preempt disabled (Kamal Heib) [2049164 2056770]
- IB/hfi1: Correct guard on eager buffer deallocation (Kamal Heib) [2049164 2056770]
- RDMA/nldev: Check stat attribute before accessing it (Kamal Heib) [2056770]
- IB/hfi1: Properly allocate rdma counter desc memory (Kamal Heib) [2049164 2056770]
- RDMA/core: Set send and receive CQ before forwarding to the driver (Kamal Heib) [2056770]
- RDMA/netlink: Add __maybe_unused to static inline in C file (Kamal Heib) [2056770]
- RDMA/core: Require the driver to set the IOVA correctly during rereg_mr (Kamal Heib) [2056770]
- RDMA/irdma: optimize rx path by removing unnecessary copy (Kamal Heib) [2037988 2056770]
- IB/opa_vnic: Rebranding of OPA VNIC driver to Cornelis Networks (Kamal Heib) [2056770]
- IB/hfi1: Rebranding of hfi1 driver to Cornelis Networks (Kamal Heib) [2049164 2056770]
- RDMA/irdma: Remove the unused variable local_qp (Kamal Heib) [2037988 2056770]
- RDMA/core: Fix missed initialization of rdma_hw_stats::lock (Kamal Heib) [2056770]
- RDMA/efa: Add support for dmabuf memory regions (Kamal Heib) [2056770]
- RDMA/umem: Allow pinned dmabuf umem usage (Kamal Heib) [2056770]
- RDMA/irdma: Remove the unused spin lock in struct irdma_qp_uk (Kamal Heib) [2037988 2056770]
- RDMA: Constify netdev->dev_addr accesses (Kamal Heib) [2056770]
- RDMA/ipoib: Use dev_addr_mod() (Kamal Heib) [2056770]
- RDMA/core: Use kvzalloc when allocating the struct ib_port (Kamal Heib) [2056770]
- RDMA/irdma: Make irdma_uk_cq_init() return a void (Kamal Heib) [2037988 2056770]
- RDMA/core: Set sgtable nents when using ib_dma_virt_map_sg() (Kamal Heib) [2056770]
- RDMA/irdma: Remove irdma_cqp_up_map_cmd() (Kamal Heib) [2037988 2056770]
- RDMA/irdma: Remove irdma_get_hw_addr() (Kamal Heib) [2037988 2056770]
- RDMA/irdma: Remove irdma_sc_send_lsmm_nostag() (Kamal Heib) [2037988 2056770]
- RDMA/irdma: Remove irdma_uk_mw_bind() (Kamal Heib) [2037988 2056770]
- RDMA: Remove redundant 'flush_workqueue()' calls (Kamal Heib) [2056770]
- RDMA/iwpm: Remove redundant initialization of pointer err_str (Kamal Heib) [2056770]
- RDMA/nldev: Allow optional-counter status configuration through RDMA netlink (Kamal Heib) [2056770]
- RDMA/nldev: Split nldev_stat_set_mode_doit out of nldev_stat_set_doit (Kamal Heib) [2056770]
- RDMA/nldev: Add support to get status of all counters (Kamal Heib) [2056770]
- RDMA/counter: Add optional counter support (Kamal Heib) [2056770]
- RDMA/counter: Add an is_disabled field in struct rdma_hw_stats (Kamal Heib) [2056770]
- RDMA/core: Add a helper API rdma_free_hw_stats_struct (Kamal Heib) [2056770]
- RDMA/bnxt_re: Fix kernel panic when trying to access bnxt_re_stat_descs (Kamal Heib) [2056770]
- RDMA/counter: Add a descriptor in struct rdma_hw_stats (Kamal Heib) [2056770]
- RDMA/bnxt_re: Update statistics counter name (Kamal Heib) [2056770]
- RDMA/bnxt_re: Add extended statistics counters (Kamal Heib) [2056770]
- RDMA/efa: CQ notifications (Kamal Heib) [2056770]
- RDMA/irdma: Delete unused struct irdma_bth (Kamal Heib) [2037988 2056770]
- IB/hf1: Use string_upper() instead of an open coded variant (Kamal Heib) [2056770]
- RDMA/rw: switch to dma_map_sgtable() (Kamal Heib) [2056770]
- RDMA/cma: Split apart the multiple uses of the same list heads (Kamal Heib) [2056770]
- RDMA/hfi1: Use struct_size() and flex_array_size() helpers (Kamal Heib) [2049164 2056770]
- IB/hfi1: Add ring consumer and producers traces (Kamal Heib) [2049164 2056770]
- IB/hfi1: Remove atomic completion count (Kamal Heib) [2049164 2056770]
- IB/hfi1: Tune netdev xmit cachelines (Kamal Heib) [2049164 2056770]
- IB/hfi1: Get rid of tx priv backpointer (Kamal Heib) [2049164 2056770]
- IB/hfi1: Get rid of hot path divide (Kamal Heib) [2049164 2056770]
- IB/hfi1: Remove cache and embed txreq in ring (Kamal Heib) [2049164 2056770]
- RDMA/rdmavt: Fix error code in rvt_create_qp() (Kamal Heib) [2049164 2056769]
- IB/hfi1: Fix abba locking issue with sc_disable() (Kamal Heib) [2049164 2056769]
- RDMA/hfi1: Fix kernel pointer leak (Kamal Heib) [2049164 2056769]
- RDMA/usnic: Lock VF with mutex instead of spinlock (Kamal Heib) [2056769]
- IB/hfi1: make hist static (Kamal Heib) [2049164 2056769]
- RDMA/hfi1: Convert to SPDX identifier (Kamal Heib) [2049164 2056769]
- IB/rdmavt: Convert to SPDX identifier (Kamal Heib) [2049164 2056769]
- RDMA/irdma: Remove the repeated declaration (Kamal Heib) [2037988 2056769]
- RDMA/core/sa_query: Retry SA queries (Kamal Heib) [2056769]
- RDMA: Use the sg_table directly and remove the opencoded version from umem (Kamal Heib) [2056769]
- RDMA: switch from 'pci_' to 'dma_' API (Kamal Heib) [2056769]
- RDMA/efa: Rename vector field in efa_irq struct to irqn (Kamal Heib) [2056769]
- RDMA/efa: Remove unused cpu field from irq struct (Kamal Heib) [2056769]
- RDMA/core/sa_query: Remove unused function (Kamal Heib) [2056769]
- RDMA/hfi1: Stop using seq_get_buf in _driver_stats_seq_show (Kamal Heib) [2049164 2056769]
- RDMA/core: Create clean QP creations interface for uverbs (Kamal Heib) [2056769]
- RDMA/core: Properly increment and decrement QP usecnts (Kamal Heib) [2056769]
- RDMA/core: Configure selinux QP during creation (Kamal Heib) [2056769]
- RDMA/core: Reorganize create QP low-level functions (Kamal Heib) [2056769]
- RDMA/core: Remove protection from wrong in-kernel API usage (Kamal Heib) [2056769]
- RDMA/core: Delete duplicated and unreachable code (Kamal Heib) [2056769]
- rdma/qedr: Fix crash due to redundant release of device's qp memory (Kamal Heib) [2056769]
- RDMA: Globally allocate and release QP memory (Kamal Heib) [2056769]
- RDMA/mlx5: Rework custom driver QP type creation (Kamal Heib) [2056769]
- RDMA/rdmavt: Decouple QP and SGE lists allocations (Kamal Heib) [2049164 2056769]
- RDMA/efa: Remove double QP type assignment (Kamal Heib) [2056769]
- RDMA/hfi1: Fix typo in comments (Kamal Heib) [2049164 2056769]
- RDMA/iwpm: Rely on the rdma_nl_[un]register() to ensure that requests are valid (Kamal Heib) [2056769]
- RDMA/iwpm: Remove not-needed reference counting (Kamal Heib) [2056769]
- RDMA/hfi1: Convert from atomic_t to refcount_t on hfi1_devdata->user_refcount (Kamal Heib) [2049164 2056769]
- IB/hfi1: Adjust pkey entry in index 0 (Kamal Heib) [2049164 2056769]
- IB/hfi1: Indicate DMA wait when txq is queued for wakeup (Kamal Heib) [2049164 2056769]
- IB/core: Read subnet_prefix in ib_query_port via cache. (Kamal Heib) [2056769]
- IB/core: Shifting initialization of device->cache_lock (Kamal Heib) [2056769]
- IB/core: Updating cache for subnet_prefix in config_non_roce_gid_cache() (Kamal Heib) [2056769]
- RDMA/efa: Split hardware stats to device and port stats (Kamal Heib) [2056769]
- RDMA/siw: Convert siw_tx_hdt() to kmap_local_page() (Kamal Heib) [2056769]
- RDMA/siw: Remove kmap() (Kamal Heib) [2056769]
- lib/scatterlist: Fix wrong update of orig_nents (Kamal Heib) [2056769]
- lib/scatterlist: Provide a dedicated function to support table append (Kamal Heib) [2056769]
- PCI: mt7621: Remove unused function pcie_rmw() (Myron Stowe) [2052155]
- PCI: mt7621: Drop of_match_ptr() to avoid unused variable (Myron Stowe) [2052155]
- PCI: qcom: Fix an error handling path in 'qcom_pcie_probe()' (Myron Stowe) [2052155]
- PCI: mt7621: Rename mt7621_pci_ to mt7621_pcie_ (Myron Stowe) [2052155]
- PCI: mt7621: Add missing MODULE_LICENSE() (Myron Stowe) [2052155]
- PCI: mt7621: Move MIPS setup to pcibios_root_bridge_prepare() (Myron Stowe) [2052155]
- PCI: mt7621: Declare mt7621_pci_ops static (Myron Stowe) [2052155]
- PCI: mt7621: Convert driver into 'bool' (Myron Stowe) [2052155]
- PCI: xgene: Use PCI_VENDOR_ID_AMCC macro (Myron Stowe) [2052155]
- PCI: rcar-host: Remove unneeded includes (Myron Stowe) [2052155]
- PCI: rcar-ep: Remove unneeded includes (Myron Stowe) [2052155]
- PCI: qcom: Add sc8180x compatible (Myron Stowe) [2052155]
- PCI: qcom: Switch pcie_1_pipe_clk_src after PHY init in SC7280 (Myron Stowe) [2052155]
- PCI: qcom: Replace ops with struct pcie_cfg in pcie match data (Myron Stowe) [2052155]
- MAINTAINERS: Add entry for Qualcomm PCIe Endpoint driver and binding (Myron Stowe) [2052155]
- PCI: qcom-ep: Add Qualcomm PCIe Endpoint controller driver (Myron Stowe) [2052155]
- dt-bindings: PCI: Add Qualcomm PCIe Endpoint controller (Myron Stowe) [2052155]
- MAINTAINERS: Add Sergio Paracuellos as MT7621 PCIe maintainer (Myron Stowe) [2052155]
- PCI: mt7621: Add MediaTek MT7621 PCIe host controller driver (Myron Stowe) [2052155]
- dt-bindings: PCI: Add MT7621 SoC PCIe host controller (Myron Stowe) [2052155]
- staging: mt7621-pci: fix hang when nothing is connected to pcie ports (Myron Stowe) [2052155]
- PCI: kirin: Allow removing the driver (Myron Stowe) [2052155]
- PCI: kirin: De-init the dwc driver (Myron Stowe) [2052155]
- PCI: kirin: Disable clkreq during poweroff sequence (Myron Stowe) [2052155]
- PCI: kirin: Move the power-off code to a common routine (Myron Stowe) [2052155]
- PCI: kirin: Add power_off support for Kirin 960 PHY (Myron Stowe) [2052155]
- PCI: kirin: Allow building it as a module (Myron Stowe) [2052155]
- PCI: kirin: Add MODULE_* macros (Myron Stowe) [2052155]
- PCI: kirin: Add Kirin 970 compatible (Myron Stowe) [2052155]
- PCI: kirin: Support PERST# GPIOs for HiKey970 external PEX 8606 bridge (Myron Stowe) [2052155]
- PCI: kirin: Use regmap for APB registers (Myron Stowe) [2052155]
- PCI: kirin: Add support for a PHY layer (Myron Stowe) [2052155]
- PCI: kirin: Reorganize the PHY logic inside the driver (Myron Stowe) [2052155]
- PCI: imx6: Remove unused assignment to variable ret (Myron Stowe) [2052155]
- PCI: endpoint: Use sysfs_emit() in "show" functions (Myron Stowe) [2052155]
- PCI: uniphier: Serialize INTx masking/unmasking and fix the bit operation (Myron Stowe) [2052155]
- PCI: dwc: Perform host_init() before registering msi (Myron Stowe) [2052155]
- PCI: visconti: Remove surplus dev_err() when using platform_get_irq_byname() (Myron Stowe) [2052155]
- PCI: dwc: Clean up Kconfig dependencies (PCIE_DW_EP) (Myron Stowe) [2052155]
- PCI: dwc: Clean up Kconfig dependencies (PCIE_DW_HOST) (Myron Stowe) [2052155]
- PCI: dra7xx: Get an optional clock (Myron Stowe) [2052155]
- PCI: dra7xx: Remove unused include (Myron Stowe) [2052155]
- PCI: dra7xx: Make it a kernel module (Myron Stowe) [2052155]
- PCI: dwc: Export more symbols to allow modular drivers (Myron Stowe) [2052155]
- dt-bindings: rockchip: Add DesignWare based PCIe controller (Myron Stowe) [2052155]
- PCI: cadence: Add cdns_plat_pcie_probe() missing return (Myron Stowe) [2052155]
- PCI: j721e: Fix j721e_pcie_probe() error path (Myron Stowe) [2052155]
- PCI: aardvark: Fix support for PCI_BRIDGE_CTL_BUS_RESET on emulated bridge (Myron Stowe) [2052155]
- PCI: aardvark: Set PCI Bridge Class Code to PCI Bridge (Myron Stowe) [2052155]
- PCI: aardvark: Fix support for bus mastering and PCI_COMMAND on emulated bridge (Myron Stowe) [2052155]
- PCI: aardvark: Read all 16-bits from PCIE_MSI_PAYLOAD_REG (Myron Stowe) [2052155]
- PCI: aardvark: Fix return value of MSI domain .alloc() method (Myron Stowe) [2052155]
- PCI: pci-bridge-emul: Fix emulation of W1C bits (Myron Stowe) [2052155]
- PCI: aardvark: Fix reporting Data Link Layer Link Active (Myron Stowe) [2052155]
- PCI: aardvark: Fix checking for link up via LTSSM state (Myron Stowe) [2052155]
- PCI: aardvark: Fix link training (Myron Stowe) [2052155]
- PCI: aardvark: Simplify initialization of rootcap on virtual bridge (Myron Stowe) [2052155]
- PCI: aardvark: Do not unmask unused interrupts (Myron Stowe) [2052155]
- PCI: aardvark: Do not clear status bits of masked interrupts (Myron Stowe) [2052155]
- PCI: aardvark: Fix configuring Reference clock (Myron Stowe) [2052155]
- PCI: aardvark: Don't spam about PIO Response Status (Myron Stowe) [2052155]
- PCI: aardvark: Fix PCIe Max Payload Size setting (Myron Stowe) [2052155]
- PCI: Add PCI_EXP_DEVCTL_PAYLOAD_* macros (Myron Stowe) [2052155]
- PCI: vmd: Drop redundant includes of <asm/device.h>, <asm/msi.h> (Myron Stowe) [2052155]
- PCI: cpqphp: Use <linux/io.h> instead of <asm/io.h> (Myron Stowe) [2052155]
- MAINTAINERS: Update PCI subsystem information (Myron Stowe) [2052155]
- PCI: Prefer 'unsigned int' over bare 'unsigned' (Myron Stowe) [2052155]
- PCI: Remove redundant 'rc' initialization (Myron Stowe) [2052155]
- PCI: Remove unused pci_pool wrappers (Myron Stowe) [2052155]
- PCI: cpqphp: Format if-statement code block correctly (Myron Stowe) [2052155]
- PCI: Use unsigned to match sscanf("%%x") in pci_dev_str_match_path() (Myron Stowe) [2052155]
- PCI: Correct misspelled and remove duplicated words (Myron Stowe) [2052155]
- PCI: Tidy comments (Myron Stowe) [2052155]
- cxgb3: Remove seeprom_write and use VPD API (Myron Stowe) [2052155]
- cxgb3: Use VPD API in t3_seeprom_wp() (Myron Stowe) [2052155]
- cxgb3: Remove t3_seeprom_read and use VPD API (Myron Stowe) [2052155]
- PCI/VPD: Use pci_read_vpd_any() in pci_vpd_size() (Myron Stowe) [2052155]
- PCI/VPD: Add pci_read/write_vpd_any() (Myron Stowe) [2052155]
- PCI: Add ACS quirk for Pericom PI7C9X2G switches (Myron Stowe) [2052155]
- PCI: Mark Atheros QCA6174 to avoid bus reset (Myron Stowe) [2052155]
- PCI: Use kstrtobool() directly, sans strtobool() wrapper (Myron Stowe) [2052155]
- PCI/sysfs: Return -EINVAL consistently from "store" functions (Myron Stowe) [2052155]
- PCI/sysfs: Check CAP_SYS_ADMIN before parsing user input (Myron Stowe) [2052155]
- PCI/switchtec: Add check of event support (Myron Stowe) [2052155]
- PCI/switchtec: Replace ENOTSUPP with EOPNOTSUPP (Myron Stowe) [2052155]
- PCI/switchtec: Update the way of getting management VEP instance ID (Myron Stowe) [2052155]
- PCI/switchtec: Fix a MRPC error status handling issue (Myron Stowe) [2052155]
- PCI/switchtec: Error out MRPC execution when MMIO reads fail (Myron Stowe) [2052155]
- PCI: Coalesce host bridge contiguous apertures (Myron Stowe) [2052155]
- PCI/P2PDMA: Apply bus offset correctly in DMA address calculation (Myron Stowe) [2052155]
- PCI/sysfs: Explicitly show first MSI IRQ for 'irq' (Myron Stowe) [2052155]
- PCI: Document /sys/bus/pci/devices/.../irq (Myron Stowe) [2052155]
- PCI/ERR: Reduce compile time for CONFIG_PCIEAER=n (Myron Stowe) [2052155]
- PCI/portdrv: Remove unused pcie_port_bus_{,un}register() declarations (Myron Stowe) [2052155]
- PCI/portdrv: Remove unused resume err_handler (Myron Stowe) [2052155]
- PCI: pciehp: Ignore Link Down/Up caused by error-induced Hot Reset (Myron Stowe) [2052155]
- PCI/portdrv: Rename pm_iter() to pcie_port_device_iter() (Myron Stowe) [2052155]
- x86/pci/probe_roms: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- perf/x86/intel/uncore: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- powerpc/eeh: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- usb: xhci: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- cxl: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- cxl: Factor out common dev->driver expressions (Myron Stowe) [2052155]
- xen/pcifront: Use to_pci_driver() instead of pci_dev->driver (Myron Stowe) [2052155]
- xen/pcifront: Drop pcifront_common_process() tests of pcidev, pdrv (Myron Stowe) [2052155]
- nfp: use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- mlxsw: pci: Use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- net: marvell: prestera: use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- net: hns3: use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- crypto: hisilicon - use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- powerpc/eeh: Use dev_driver_string() instead of struct pci_dev->driver->name (Myron Stowe) [2052155]
- ssb: Use dev_driver_string() instead of pci_dev->driver->name (Myron Stowe) [2052155]
- bcma: simplify reference to driver name (Myron Stowe) [2052155]
- scsi: message: fusion: Remove unused mpt_pci driver .probe() 'id' parameter (Myron Stowe) [2052155]
- PCI/ERR: Factor out common dev->driver expressions (Myron Stowe) [2052155]
- PCI: Drop pci_device_probe() test of !pci_dev->driver (Myron Stowe) [2052155]
- PCI: Drop pci_device_remove() test of pci_dev->driver (Myron Stowe) [2052155]
- PCI: Return NULL for to_pci_driver(NULL) (Myron Stowe) [2052155]
- PCI: Do not enable AtomicOps on VFs (Myron Stowe) [2052155]
- PCI: Rename pcibios_add_device() to pcibios_device_add() (Myron Stowe) [2052155]
- PCI: Re-enable Downstream Port LTR after reset or hotplug (Myron Stowe) [2052155]
- rcu-tasks: Fix computation of CPU-to-list shift counts (Waiman Long) [2065994]
- torture: Properly redirect kvm-remote.sh "echo" commands (Waiman Long) [2065994]
- torture: Fix incorrectly redirected "exit" in kvm-remote.sh (Waiman Long) [2065994]
- rcu/exp: Mark current CPU as exp-QS in IPI loop second pass (Waiman Long) [2065994]
- rcu-tasks: Use fewer callbacks queues if callback flood ends (Waiman Long) [2065994]
- rcu-tasks: Use separate ->percpu_dequeue_lim for callback dequeueing (Waiman Long) [2065994]
- rcutorture: Test RCU Tasks lock-contention detection (Waiman Long) [2065994]
- rcu-tasks: Use more callback queues if contention encountered (Waiman Long) [2065994]
- rcu-tasks: Avoid raw-spinlocked wakeups from call_rcu_tasks_generic() (Waiman Long) [2065994]
- rcutorture: Combine n_max_cbs from all kthreads in a callback flood (Waiman Long) [2065994]
- rcutorture: Add ability to limit callback-flood intensity (Waiman Long) [2065994]
- rcutorture: Cause TREE02 and TREE10 scenarios to do more callback flooding (Waiman Long) [2065994]
- rcutorture: Enable multiple concurrent callback-flood kthreads (Waiman Long) [2065994]
- rcu/nocb: Merge rcu_spawn_cpu_nocb_kthread() and rcu_spawn_one_nocb_kthread() (Waiman Long) [2065994]
- rcu/nocb: Allow empty "rcu_nocbs" kernel parameter (Waiman Long) [2065994]
- rcu/nocb: Create kthreads on all CPUs if "rcu_nocbs=" or "nohz_full=" are passed (Waiman Long) [2065994]
- rcu/nocb: Optimize kthreads and rdp initialization (Waiman Long) [2065994]
- rcu/nocb: Prepare nocb_cb_wait() to start with a non-offloaded rdp (Waiman Long) [2065994]
- rcu/nocb: Remove rcu_node structure from nocb list when de-offloaded (Waiman Long) [2065994]
- rcu-tasks: Count trylocks to estimate call_rcu_tasks() contention (Waiman Long) [2065994]
- torture: Retry download once before giving up (Waiman Long) [2065994]
- rcutorture: Add CONFIG_PREEMPT_DYNAMIC=n to tiny scenarios (Waiman Long) [2065994]
- rcu: Avoid alloc_pages() when recording stack (Waiman Long) [2065994]
- rcu: Avoid running boost kthreads on isolated CPUs (Waiman Long) [2065994]
- rcutorture: Test RCU-tasks multiqueue callback queueing (Waiman Long) [2065994]
- rcu-tasks: Add rcupdate.rcu_task_enqueue_lim to set initial queueing (Waiman Long) [2065994]
- rcu-tasks: Make rcu_barrier_tasks*() handle multiple callback queues (Waiman Long) [2065994]
- rcu-tasks: Use workqueues for multiple rcu_tasks_invoke_cbs() invocations (Waiman Long) [2065994]
- torture: Make kvm-find-errors.sh report link-time undefined symbols (Waiman Long) [2065994]
- rcutorture: Avoid soft lockup during cpu stall (Waiman Long) [2065994]
- rcu-tasks: Abstract invocations of callbacks (Waiman Long) [2065994]
- rcu-tasks: Abstract checking of callback lists (Waiman Long) [2065994]
- rcu-tasks: Add a ->percpu_enqueue_lim to the rcu_tasks structure (Waiman Long) [2065994]
- rcu-tasks: Inspect stalled task's trc state in locked state (Waiman Long) [2065994]
- rcu-tasks: Use spin_lock_rcu_node() and friends (Waiman Long) [2065994]
- rcu_tasks: Convert bespoke callback list to rcu_segcblist structure (Waiman Long) [2065994]
- rcu-tasks: Convert grace-period counter to grace-period sequence number (Waiman Long) [2065994]
- rcu-tasks: Introduce ->percpu_enqueue_shift for dynamic queue selection (Waiman Long) [2065994]
- rcu-tasks: Create per-CPU callback lists (Waiman Long) [2065994]
- locktorture,rcutorture,torture: Always log error message (Waiman Long) [2065994]
- scftorture: Always log error message (Waiman Long) [2065994]
- doc: RCU: Avoid 'Symbol' font-family in SVG figures (Waiman Long) [2065994]
- rcuscale: Always log error message (Waiman Long) [2065994]
- scftorture: Account for weight_resched when checking for all zeroes (Waiman Long) [2065994]
- scftorture: Remove unused SCFTORTOUT (Waiman Long) [2065994]
- scftorture: Add missing '\n' to flush message (Waiman Long) [2065994]
- refscale: Add missing '\n' to flush message (Waiman Long) [2065994]
- doc: Add refcount analogy to What is RCU (Waiman Long) [2065994]
- refscale: Always log the error message (Waiman Long) [2065994]
- refscale: Prevent buffer to pr_alert() being too long (Waiman Long) [2065994]
- refscale: Simplify the errexit checkpoint (Waiman Long) [2065994]
- rcu: Improve tree_plugin.h comments and add code cleanups (Waiman Long) [2065994]
- rcu/nocb: Don't invoke local rcu core on callback overload from nocb kthread (Waiman Long) [2065994]
- rcu: Apply callbacks processing time limit only on softirq (Waiman Long) [2065994]
- rcu: Fix callbacks processing time limit retaining cond_resched() (Waiman Long) [2065994]
- rcu/nocb: Limit number of softirq callbacks only on softirq (Waiman Long) [2065994]
- rcu/nocb: Use appropriate rcu_nocb_lock_irqsave() (Waiman Long) [2065994]
- rcu/nocb: Check a stable offloaded state to manipulate qlen_last_fqs_check (Waiman Long) [2065994]
- rcu/nocb: Make rcu_core() callbacks acceleration (de-)offloading safe (Waiman Long) [2065994]
- rcu/nocb: Make rcu_core() callbacks acceleration preempt-safe (Waiman Long) [2065994]
- rcu/nocb: Invoke rcu_core() at the start of deoffloading (Waiman Long) [2065994]
- rcu/nocb: Prepare state machine for a new step (Waiman Long) [2065994]
- rcu/nocb: Make local rcu_nocb_lock_irqsave() safe against concurrent deoffloading (Waiman Long) [2065994]
- rcu: Make idle entry report expedited quiescent states (Waiman Long) [2065994]
- rcu: Prevent expedited GP from enabling tick on offline CPU (Waiman Long) [2065994]
- rcu: Mark sync_sched_exp_online_cleanup() ->cpu_no_qs.b.exp load (Waiman Long) [2065994]
- rcu: Always inline rcu_dynticks_task*_{enter,exit}() (Waiman Long) [2065994]
- rcu: in_irq() cleanup (Waiman Long) [2065994]
- doc: Remove obsolete kernel-per-CPU-kthreads RCU_FAST_NO_HZ advice (Waiman Long) [2065994]
- rcutorture: Suppress pi-lock-across read-unlock testing for Tiny SRCU (Waiman Long) [2065994]
- srcu: Prevent redundant __srcu_read_unlock() wakeup (Waiman Long) [2065994]
- rcutorture: More thoroughly test nested readers (Waiman Long) [2065994]
- rcutorture: Sanitize RCUTORTURE_RDR_MASK (Waiman Long) [2065994]
- torture: Catch kvm.sh help text up with actual options (Waiman Long) [2065994]
- rcu-tasks: Don't remove tasks with pending IPIs from holdout list (Waiman Long) [2065994]
- rcu: Remove rcu_data.exp_deferred_qs and convert to rcu_data.cpu no_qs.b.exp (Waiman Long) [2065994]
- rcu: Move rcu_data.cpu_no_qs.b.exp reset to rcu_export_exp_rdp() (Waiman Long) [2065994]
- rcu: Ignore rdp.cpu_no_qs.b.exp on preemptible RCU's rcu_qs() (Waiman Long) [2065994]
- rcu-tasks: Update comments to cond_resched_tasks_rcu_qs() (Waiman Long) [2065994]
- rcu: Replace ________p1 and _________p1 with __UNIQUE_ID(rcu) (Waiman Long) [2065994]
- rcu-tasks: Fix IPI failure handling in trc_wait_for_one_reader (Waiman Long) [2065994]
- rcu-tasks: Fix read-side primitives comment for call_rcu_tasks_trace (Waiman Long) [2065994]
- rcutorture: Avoid problematic critical section nesting on PREEMPT_RT (Waiman Long) [2065994]
- rcu: Fix existing exp request check in sync_sched_exp_online_cleanup() (Waiman Long) [2065994]
- rcu-tasks: Clarify read side section info for rcu_tasks_rude GP primitives (Waiman Long) [2065994]
- rcu-tasks: Correct comparisons for CPU numbers in show_stalled_task_trace (Waiman Long) [2065994]
- rcu-tasks: Correct firstreport usage in check_all_holdout_tasks_trace (Waiman Long) [2065994]
- rcu-tasks: Fix s/rcu_add_holdout/trc_add_holdout/ typo in comment (Waiman Long) [2065994]
- rcu-tasks: Move RTGS_WAIT_CBS to beginning of rcu_tasks_kthread() loop (Waiman Long) [2065994]
- rcu: Make rcu update module parameters world-readable (Waiman Long) [2065994]
- rcu: Make rcu_normal_after_boot writable again (Waiman Long) [2065994]
- rcutorture: Don't cpuhp_remove_state() if cpuhp_setup_state() failed (Waiman Long) [2065994]
- rcuscale: Warn on individual rcu_scale_init() error conditions (Waiman Long) [2065994]
- locktorture: Warn on individual lock_torture_init() error conditions (Waiman Long) [2065994]
- rcutorture: Warn on individual rcu_torture_init() error conditions (Waiman Long) [2065994]
- rcu-tasks: Fix s/instruction/instructions/ typo in comment (Waiman Long) [2065994]
- rcutorture: Suppressing read-exit testing is not an error (Waiman Long) [2065994]
- rcu-tasks: Wait for trc_read_check_handler() IPIs (Waiman Long) [2065994]
- rcu: Make rcutree_dying_cpu() use its "cpu" parameter (Waiman Long) [2065994]
- rcu: Simplify rcu_report_dead() call to rcu_report_exp_rdp() (Waiman Long) [2065994]
- rcu: Move rcu_dynticks_eqs_online() to rcu_cpu_starting() (Waiman Long) [2065994]
- rcu-tasks: Remove second argument of rcu_read_unlock_trace_special() (Waiman Long) [2065994]
- rcu-tasks: Add trc_inspect_reader() checks for exiting critical section (Waiman Long) [2065994]
- rcu-tasks: Simplify trc_read_check_handler() atomic operations (Waiman Long) [2065994]
- rcu: Comment rcu_gp_init() code waiting for CPU-hotplug operations (Waiman Long) [2065994]
- rcu: Fix undefined Kconfig macros (Waiman Long) [2065994]
- doc: Add another stall-warning root cause in stallwarn.rst (Waiman Long) [2065994]
- rcu: Eliminate rcu_implicit_dynticks_qs() local variable ruqp (Waiman Long) [2065994]
- rcu: Eliminate rcu_implicit_dynticks_qs() local variable rnhqp (Waiman Long) [2065994]
- rcu-nocb: Fix a couple of tree_nocb code-style nits (Waiman Long) [2065994]
- torture: Make torture.sh print the number of files to be compressed (Waiman Long) [2065994]
- torture: Apply CONFIG_KCSAN_STRICT to kvm.sh --kcsan argument (Waiman Long) [2065994]
- x86/tsc: Disable clocksource watchdog for TSC on qualified platorms (David Arcari) [2057923]
- x86/tsc: Add a timer to make sure TSC_adjust is always checked (David Arcari) [2057923]
- Revert "xfs: actually bump warning counts when we send warnings" (Carlos Maiolino) [2060081]
- vfs: check dentry is still valid in get_link() (Ian Kent) [2048567]
- xfs: don't expose internal symlink metadata buffers to the vfs (Ian Kent) [2048567]
- audit: log AUDIT_TIME_* records only from rules (Richard Guy Briggs) [2035124]
- audit: don't deref the syscall args when checking the openat2 open_how::flags (Richard Guy Briggs) [2035124]
- audit: improve audit queue handling when "audit=1" on cmdline (Richard Guy Briggs) [2035124]
- audit: replace zero-length array with flexible-array member (Richard Guy Briggs) [2035124]
- audit: use struct_size() helper in audit_[send|make]_reply() (Richard Guy Briggs) [2035124]
- audit: ensure userspace is penalized the same as the kernel when under pressure (Richard Guy Briggs) [2035124]
- audit: use struct_size() helper in kmalloc() (Richard Guy Briggs) [2035124]
- audit: improve robustness of the audit queue handling (Richard Guy Briggs) [2035124]
- fsnotify: clarify contract for create event hooks (Richard Guy Briggs) [2035124]
- fsnotify: pass dentry instead of inode data (Richard Guy Briggs) [2035124]
- fsnotify: pass data_type to fsnotify_name() (Richard Guy Briggs) [2035124]
- fsnotify: fix sb_connectors leak (Richard Guy Briggs) [2035124]
- fsnotify: optimize the case of no marks of any type (Richard Guy Briggs) [2035124]
- fsnotify: count all objects with attached connectors (Richard Guy Briggs) [2035124]
- fsnotify: count s_fsnotify_inode_refs for attached connectors (Richard Guy Briggs) [2035124]
- fsnotify: replace igrab() with ihold() on attach connector (Richard Guy Briggs) [2035124]
- audit: return early if the filter rule has a lower priority (Richard Guy Briggs) [2035124]
- audit: add OPENAT2 record to list "how" info (Richard Guy Briggs) [2035124]
- audit: add support for the openat2 syscall (Richard Guy Briggs) [2035124]
- audit: replace magic audit syscall class numbers with macros (Richard Guy Briggs) [2035124]
- lsm_audit: avoid overloading the "key" audit field (Richard Guy Briggs) [2035124]
- audit: Convert to SPDX identifier (Richard Guy Briggs) [2035124]
- audit: rename struct node to struct audit_node to prevent future name collisions (Richard Guy Briggs) [2035124]
- audit: add filtering for io_uring records (Richard Guy Briggs) [2035124]
- audit,io_uring,io-wq: add some basic audit support to io_uring (Richard Guy Briggs) [2035124]
- audit: prepare audit_context for use in calling contexts beyond syscalls (Richard Guy Briggs) [2035124]
- audit: fix possible null-pointer dereference in audit_filter_rules (Richard Guy Briggs) [2035124]
- audit: add header protection to kernel/audit.h (Richard Guy Briggs) [2035124]

* Mon Apr 11 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-78.rt21.78.el9]
- [rt] build kernel-rt-5.14.0-78.rt21.78.el9 [2061574]
- CI: Remove deprecated option (Veronika Kabatova)
- scsi: iscsi: Fix nop handling during conn recovery (Chris Leech) [2069973]
- scsi: iscsi: Merge suspend fields (Chris Leech) [2069973]
- scsi: iscsi: Fix offload conn cleanup when iscsid restarts (Chris Leech) [2069973]
- scsi: iscsi: Move iscsi_ep_disconnect (Chris Leech) [2069973]
- NFS: Don't loop forever in nfs_do_recoalesce() (Steve Dickson) [2069274]
- perf/x86/intel/uncore: Make uncore_discovery clean for 64 bit addresses (Michael Petlan) [2069686]
- KVM: SVM: Allow AVIC support on system w/ physical APIC ID > 255 (Bandan Das) [2033070]
- iommu/amd: Fix I/O page table memory leak (Jerry Snitselaar) [2053219]
- iommu/amd: Recover from event log overflow (Jerry Snitselaar) [2053219]
- redhat/configs: drop some config options for rhel 9. (David Airlie) [2067027]
- arm64: proton-pack: Include unprivileged eBPF status in Spectre v2 mitigation reporting (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Use the clearbhb instruction in mitigations (Waiman Long) [2062288] {CVE-2022-23960}
- KVM: arm64: Allow SMCCC_ARCH_WORKAROUND_3 to be discovered and migrated (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Mitigate spectre style branch history side channels (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: proton-pack: Report Spectre-BHB vulnerabilities as part of Spectre-v2 (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add percpu vectors for EL1 (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Add macro for reading symbol addresses from the trampoline (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Add vectors that have the bhb mitigation sequences (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Add non-kpti __bp_harden_el1_vectors for mitigations (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Allow the trampoline text to occupy multiple pages (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Make the kpti trampoline's kpti sequence optional (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Move trampoline macros out of ifdef'd section (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Don't assume tramp_vectors is the start of the vectors (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Allow tramp_alias to access symbols after the 4K boundary (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Move the trampoline data page before the text page (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Free up another register on kpti's tramp_exit path (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry: Make the trampoline cleanup optional (Waiman Long) [2062288] {CVE-2022-23960}
- KVM: arm64: Allow indirect vectors to be used without SPECTRE_V3A (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: spectre: Rename spectre_v4_patch_fw_mitigation_conduit (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: entry.S: Add ventry overflow sanity checks (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add Cortex-A510 CPU part definition (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add Cortex-X2 CPU part definition (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: cpufeature: add HWCAP for FEAT_RPRES (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: add ID_AA64ISAR2_EL1 sys register (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: cpufeature: add HWCAP for FEAT_AFP (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add Neoverse-N2, Cortex-A710 CPU part definition (Waiman Long) [2062288] {CVE-2022-23960}
- arm64: Add HWCAP for self-synchronising virtual counter (Waiman Long) [2062288] {CVE-2022-23960}
- iommu/vt-d: Fix double list_add when enabling VMD in scalable mode (Jerry Snitselaar) [2061621]
- redhat/configs: remove unnecessary GPIO options for aarch64 (Brian Masney) [2060951]
- redhat/configs: remove viperboard related Kconfig options (Brian Masney) [2060951]
- configs: enable CONFIG_RMI4_F3A (Benjamin Tissoires) [2067243]
- block: release rq qos structures for queue without disk (Ming Lei) [2065610]
- fuse: fix pipe buffer lifetime for direct_io (Miklos Szeredi) [2064862] {CVE-2022-1011}
- crypto: hmac - disallow keys < 112 bits in FIPS mode (Herbert Xu) [2033512]
- crypto: hmac - add fips_skip support (Herbert Xu) [2033512]
- crypto: des - disallow des3 in FIPS mode (Herbert Xu) [2033512]
- crypto: dh - limit key size to 2048 in FIPS mode (Herbert Xu) [2033512]
- crypto: rsa - limit key size to 2048 in FIPS mode (Herbert Xu) [2033512]
- watch_queue: Make comment about setting ->defunct more accurate (David Howells) [2063758]
- watch_queue: Fix lack of barrier/sync/lock between post and read (David Howells) [2063758]
- watch_queue: Free the alloc bitmap when the watch_queue is torn down (David Howells) [2063758]
- watch_queue: Fix the alloc bitmap size to reflect notes allocated (David Howells) [2063758]
- watch_queue: Use the bitmap API when applicable (David Howells) [2063758]
- watch_queue: Fix to always request a pow-of-2 pipe ring size (David Howells) [2063758]
- watch_queue: Fix to release page in ->release() (David Howells) [2063758]
- watch_queue, pipe: Free watchqueue state after clearing pipe ring (David Howells) [2063758]
- watch_queue: Fix filter limit check (David Howells) [2063758] {CVE-2022-0995}
- s390/mm: check 2KB-fragment page on release (Rafael Aquini) [2069978]
- s390/mm: better annotate 2KB pagetable fragments handling (Rafael Aquini) [2069978]
- s390/mm: fix 2KB pgtable release race (Rafael Aquini) [2069978]
- ima: fix deadlock when traversing "ima_default_rules". (Bruno Meneguele) [2063913]
- IMA: prevent SETXATTR_CHECK policy rules with unavailable algorithms (Bruno Meneguele) [2063913]
- IMA: introduce a new policy option func=SETXATTR_CHECK (Bruno Meneguele) [2063913]
- IMA: add a policy option to restrict xattr hash algorithms on appraisal (Bruno Meneguele) [2063913]
- IMA: add support to restrict the hash algorithms used for file appraisal (Bruno Meneguele) [2063913]
- IMA: block writes of the security.ima xattr with unsupported algorithms (Bruno Meneguele) [2063913]
- IMA: remove the dependency on CRYPTO_MD5 (Bruno Meneguele) [2063913]
- perf symbols: Fix symbol size calculation condition (Michael Petlan) [2049222]
- redhat/Makefile: Fix dist-dump-variables target (Prarit Bhargava)
- redhat/configs/process_configs.sh: Avoid race with find (Prarit Bhargava)
- redhat/configs/process_configs.sh: Remove CONTINUEONERROR (Prarit Bhargava)
- redhat/configs/process_configs.sh: Fix race with tools generation (Prarit Bhargava)
- redhat/Makefile: Silence dist-clean-configs output (Prarit Bhargava)
- Print arch with process_configs errors (Prarit Bhargava)
- Pass RHJOBS to process_configs for dist-configs-check as well (Prarit Bhargava)
- redhat/configs/process_configs.sh: Fix issue with old error files (Prarit Bhargava)
- redhat/configs/build_configs.sh: Parallelize execution (Prarit Bhargava)
- redhat/configs/build_configs.sh: Provide better messages (Prarit Bhargava)
- redhat/configs/build_configs.sh: Create unique output files (Prarit Bhargava)
- redhat/configs/build_configs.sh: Add local variables (Prarit Bhargava)
- redhat/configs/process_configs.sh: Parallelize execution (Prarit Bhargava)
- redhat/configs/process_configs.sh: Provide better messages (Prarit Bhargava)
- redhat/configs/process_configs.sh: Create unique output files (Prarit Bhargava)
- redhat/configs/process_configs.sh: Add processing config function (Prarit Bhargava)
- cifs: modefromsids must add an ACE for authenticated users (Ronnie Sahlberg) [1988278]

* Fri Apr 08 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-77.rt21.77.el9]
- [rt] build kernel-rt-5.14.0-77.rt21.77.el9 [2061574]
- Revert "Revert "Merge: kernel/futex: backport new futex_waitv(2) system call"" (Juri Lelli)
- NFSD: Fix offset type in I/O trace points (Benjamin Coddington) [2063045]
- NFSD: COMMIT operations must not return NFS?ERR_INVAL (Benjamin Coddington) [2063045]
- NFSD: Clamp WRITE offsets (Benjamin Coddington) [2063045]
- NFSD: Fix NFSv3 SETATTR/CREATE's handling of large file sizes (Benjamin Coddington) [2063045]
- NFSD: Fix ia_size underflow (Benjamin Coddington) [2063045]
- NFSD: Fix the behavior of READ near OFFSET_MAX (Benjamin Coddington) [2063045]
- perf/x86/intel/uncore: Fix Intel SPR CHA event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Fix Intel SPR IIO event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Fix Intel SPR M2PCIE event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Fix Intel SPR M3UPI event constraints (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Support IMC free-running counters on Sapphire Rapids server (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Support IIO free-running counters on Sapphire Rapids server (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Factor out snr_uncore_mmio_map() (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add alias PMU name (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server MDF support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server M3UPI support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server UPI support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2M support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server IMC support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server PCU support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2PCIe support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server IRP support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server IIO support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server CHA support (Michael Petlan) [2054100]
- perf/x86/intel/uncore: Add Sapphire Rapids server framework (Michael Petlan) [2054100]
- Revert "include/linux/ioport.h: Pad resource struct for KABI" (Prarit Bhargava) [2055736]
- powerpc/pseries: Fix use after free in remove_phb_dynamic() (Prarit Bhargava) [2055736]
- lib/sbitmap: kill 'depth' from sbitmap_word (Ming Lei) [2064695]
- KVM: use __vcalloc for very large allocations (David Hildenbrand) [2057367]
- mm: use vmalloc_array and vcalloc for array allocations (David Hildenbrand) [2057367]
- mm: vmalloc: introduce array allocation functions (David Hildenbrand) [2057367]
- tpm: fix potential NULL pointer access in tpm_del_char_device (Desnes A. Nunes do Rosario) [2032117]
- x86/speculation: Warn about eIBRS + LFENCE + Unprivileged eBPF + SMT (Waiman Long) [2062158 2062168] {CVE-2021-26401 CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Warn about Spectre v2 LFENCE mitigation (Waiman Long) [2062158 2062168] {CVE-2021-26401 CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Update link to AMD speculation whitepaper (Waiman Long) [2062168] {CVE-2021-26401}
- x86/speculation: Use generic retpoline by default on AMD (Waiman Long) [2062168] {CVE-2021-26401}
- x86/speculation: Include unprivileged eBPF status in Spectre v2 mitigation reporting (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- Documentation/hw-vuln: Update spectre doc (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Add eIBRS + Retpoline options (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86/speculation: Rename RETPOLINE_AMD to RETPOLINE_LFENCE (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86,bugs: Unconditionally allow spectre_v2=retpoline,amd (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- x86: deduplicate the spectre_v2_user documentation (Waiman Long) [2062158] {CVE-2022-0001 CVE-2022-0002}
- redhat/configs: aarch64: Enable ARM_SPE_PMU (Mark Salter) [2063234]
- drm/i915/audio: Use BIOS provided value for RKL HDA link (Mika Penttilä) [2046691]
- redhat: configs: Disable TPM 1.2 device drivers (Jerry Snitselaar) [2060516]
- redhat: configs: Change aarch64 default dma domain to lazy (Jerry Snitselaar) [2050415]
- powerpc/64s/hash: Make hash faults work in NMI context (Desnes A. Nunes do Rosario) [2062762]
- CI: Remove deprecated option (Veronika Kabatova)
- redhat/configs: make SHA512_arch algos and CRYPTO_USER built-ins (Vladis Dronov) [2070624]
- futex: Fix PREEMPT_RT build (Fernando Pacheco) [2070369]
- crypto: ccp - ccp_dmaengine_unregister release dma channels (Vladis Dronov) [2047836]
- crypto: ccp - remove redundant ret variable (Vladis Dronov) [2047836]
- crypto: ccp - Ensure psp_ret is always init'd in __sev_platform_init_locked() (Vladis Dronov) [2047836]
- crypto: ccp - remove unneeded semicolon (Vladis Dronov) [2047836]
- crypto: ccp - Add SEV_INIT_EX support (Vladis Dronov) [2047836]
- crypto: ccp - Add psp_init_on_probe module parameter (Vladis Dronov) [2047836]
- crypto: ccp - Refactor out sev_fw_alloc() (Vladis Dronov) [2047836]
- crypto: ccp - Move SEV_INIT retry for corrupted data (Vladis Dronov) [2047836]
- crypto: ccp - Add SEV_INIT rc error logging on init (Vladis Dronov) [2047836]
- crypto: ccp - no need to initialise statics to 0 (Vladis Dronov) [2047836]
- perf tests attr: Add missing topdown metrics events (Michael Petlan) [2062513]
- powerpc/papr_scm: Implement initial support for injecting smart errors (Steve Best) [1873827]
- redhat/koji/Makefile: Decouple koji Makefile from Makefile.common (Andrea Claudi) [2037486]
- redhat: fix make {distg-brew,distg-koji} (Andrea Claudi) [2037486]
- mm: memcg: synchronize objcg lists with a dedicated spinlock (Waiman Long) [2046537]
- mm: memcontrol: remove the kmem states (Waiman Long) [2046537]
- mm: memcontrol: remove kmemcg_id reparenting (Waiman Long) [2046537]
- mm/memcg: remove obsolete memcg_free_kmem() (Waiman Long) [2046537]
- PCI: rcar: Check if device is runtime suspended instead of __clk_is_enabled() (Myron Stowe) [2045254]
- PCI: aardvark: Fix checking for MEM resource type (Myron Stowe) [2045254]
- PCI/MSI: Move non-mask check back into low level accessors (Myron Stowe) [2045254]
- PCI: aardvark: Implement re-issuing config requests on CRS response (Myron Stowe) [2045254]
- PCI: aardvark: Deduplicate code in advk_pcie_rd_conf() (Myron Stowe) [2045254]
- PCI: aardvark: Fix preserving PCI_EXP_RTCTL_CRSSVE flag on emulated bridge (Myron Stowe) [2045254]
- PCI: ACPI: Drop acpi_pci_bus (Myron Stowe) [2045254]
- ACPI: glue: Eliminate acpi_platform_notify() (Myron Stowe) [2045254]
- ACPI: bus: Rename functions to avoid name collision (Myron Stowe) [2045254]
- ACPI: glue: Change return type of two functions to void (Myron Stowe) [2045254]
- ACPI: glue: Rearrange acpi_device_notify() (Myron Stowe) [2045254]
- PCI/MSI: Handle msi_populate_sysfs() errors correctly (Myron Stowe) [2045254]
- MAINTAINERS: Add Nirmal Patel as VMD maintainer (Myron Stowe) [2045254]
- PCI: Add AMD GPU multi-function power dependencies (Myron Stowe) [2045254]
- tools: PCI: Zero-initialize param (Myron Stowe) [2045254]
- PCI: controller: PCI_IXP4XX should depend on ARCH_IXP4XX (Myron Stowe) [2045254]
- Documentation: PCI: endpoint/pci-endpoint-cfs: Guide to use SR-IOV (Myron Stowe) [2045254]
- misc: pci_endpoint_test: Populate sriov_configure ops to configure SR-IOV device (Myron Stowe) [2045254]
- PCI: cadence: Add support to configure virtual functions (Myron Stowe) [2045254]
- PCI: cadence: Simplify code to get register base address for configuring BAR (Myron Stowe) [2045254]
- PCI: endpoint: Add virtual function number in pci_epc ops (Myron Stowe) [2045254]
- PCI: endpoint: Add support to link a physical function to a virtual function (Myron Stowe) [2045254]
- PCI: endpoint: Add support to add virtual function in endpoint core (Myron Stowe) [2045254]
- dt-bindings: PCI: pci-ep: Add binding to specify virtual function (Myron Stowe) [2045254]
- PCI: xilinx-nwl: Enable the clock through CCF (Myron Stowe) [2045254]
- dt-bindings: pci: xilinx-nwl: Document optional clock property (Myron Stowe) [2045254]
- PCI: xgene-msi: Remove redundant dev_err() call in xgene_msi_probe() (Myron Stowe) [2045254]
- PCI: tegra194: Cleanup unused code (Myron Stowe) [2045254]
- PCI: tegra194: Don't allow suspend when Tegra PCIe is in EP mode (Myron Stowe) [2045254]
- PCI: tegra194: Disable interrupts before entering L2 (Myron Stowe) [2045254]
- PCI: tegra194: Fix MSI-X programming (Myron Stowe) [2045254]
- PCI: tegra194: Fix handling BME_CHGED event (Myron Stowe) [2045254]
- PCI: tegra: make const array err_msg static (Myron Stowe) [2045254]
- PCI: tegra: Use 'seq_puts' instead of 'seq_printf' (Myron Stowe) [2045254]
- PCI: tegra: Fix OF node reference leak (Myron Stowe) [2045254]
- PCI: tegra: Remove unused struct tegra_pcie_bus (Myron Stowe) [2045254]
- PCI: rcar: Add L1 link state fix into data abort hook (Myron Stowe) [2045254]
- PCI: rcar: Fix runtime PM imbalance in rcar_pcie_ep_probe() (Myron Stowe) [2045254]
- PCI: mediatek: Use PCI domain to handle ports detection (Myron Stowe) [2045254]
- PCI: mediatek: Add new method to get irq number (Myron Stowe) [2045254]
- PCI: mediatek: Add new method to get shared pcie-cfg base address (Myron Stowe) [2045254]
- dt-bindings: PCI: mediatek: Update the Device tree bindings (Myron Stowe) [2045254]
- PCI: keembay: Add support for Intel Keem Bay (Myron Stowe) [2045254]
- dt-bindings: PCI: Add Intel Keem Bay PCIe controller (Myron Stowe) [2045254]
- PCI: iproc: Fix BCMA probe resource handling (Myron Stowe) [2045254]
- PCI: of: Don't fail devm_pci_alloc_host_bridge() on missing 'ranges' (Myron Stowe) [2045254]
- misc: pci_endpoint_test: Add deviceID for AM64 and J7200 (Myron Stowe) [2045254]
- PCI: j721e: Add PCIe support for AM64 (Myron Stowe) [2045254]
- PCI: j721e: Add PCIe support for J7200 (Myron Stowe) [2045254]
- PCI: cadence: Add quirk flag to set minimum delay in LTSSM Detect.Quiet state (Myron Stowe) [2045254]
- PCI: cadence: Use bitfield for *quirk_retrain_flag* instead of bool (Myron Stowe) [2045254]
- PCI: aardvark: Fix masking and unmasking legacy INTx interrupts (Myron Stowe) [2045254]
- PCI: aardvark: Configure PCIe resources from 'ranges' DT property (Myron Stowe) [2045254]
- PCI: aardvark: Fix reporting CRS value (Myron Stowe) [2045254]
- PCI: pci-bridge-emul: Add PCIe Root Capabilities Register (Myron Stowe) [2045254]
- PCI: aardvark: Increase polling delay to 1.5s while waiting for PIO response (Myron Stowe) [2045254]
- PCI: aardvark: Fix checking for PIO status (Myron Stowe) [2045254]
- MAINTAINERS: Add entries for Toshiba Visconti PCIe controller (Myron Stowe) [2045254]
- PCI: visconti: Add Toshiba Visconti PCIe host controller driver (Myron Stowe) [2045254]
- PCI: rockchip-dwc: Add Rockchip RK356X host controller driver (Myron Stowe) [2045254]
- PCI: dwc: Remove surplus break statement after return (Myron Stowe) [2045254]
- PCI: artpec6: Remove local code block from switch statement (Myron Stowe) [2045254]
- PCI: artpec6: Remove surplus break statement after return (Myron Stowe) [2045254]
- x86/PCI: sta2x11: switch from 'pci_' to 'dma_' API (Myron Stowe) [2045254]
- PCI: Sync __pci_register_driver() stub for CONFIG_PCI=n (Myron Stowe) [2045254]
- PCI: Add schedule point in proc_bus_pci_read() (Myron Stowe) [2045254]
- PCI: Correct the pci_iomap.h header guard #endif comment (Myron Stowe) [2045254]
- PCI/PTM: Remove error message at boot (Myron Stowe) [2045254]
- PCI: Fix pci_dev_str_match_path() alloc while atomic bug (Myron Stowe) [2045254]
- x86/PCI: Add pci_numachip_init() declaration (Myron Stowe) [2045254]
- PCI/ACS: Enforce pci=noats with Transaction Blocking (Myron Stowe) [2045254]
- PCI: Add ACS quirks for Cavium multi-function devices (Myron Stowe) [2045254]
- PCI: Add ACS quirks for NXP LX2xx0 and LX2xx2 platforms (Myron Stowe) [2045254]
- PCI: Optimize pci_resource_len() to reduce kernel size (Myron Stowe) [2045254]
- PCI: Refactor pci_ioremap_bar() and pci_ioremap_wc_bar() (Myron Stowe) [2045254]
- PCI/portdrv: Enable Bandwidth Notification only if port supports it (Myron Stowe) [2045254]
- PCI: Bulk conversion to generic_handle_domain_irq() (Myron Stowe) [2045254]
- PCI: Set dma-can-stall for HiSilicon chips (Myron Stowe) [2045254]
- PCI: ibmphp: Fix double unmap of io_mem (Myron Stowe) [2045254]
- PCI: Return int from pciconfig_read() syscall (Myron Stowe) [2045254]
- PCI: Return ~0 data on pciconfig_read() CAP_SYS_ADMIN failure (Myron Stowe) [2045254]
- PCI: Restrict ASMedia ASM1062 SATA Max Payload Size Supported (Myron Stowe) [2045254]
- PCI: Call Max Payload Size-related fixup quirks early (Myron Stowe) [2045254]
- platform-msi: Add ABI to show msi_irqs of platform devices (Myron Stowe) [2045254]
- genirq/msi: Move MSI sysfs handling from PCI to MSI core (Myron Stowe) [2045254]
- genirq/timings: Fix error return code in irq_timings_test_irqs() (Myron Stowe) [2045254]
- PCI/MSI: Use new mask/unmask functions (Myron Stowe) [2045254]
- PCI/MSI: Provide a new set of mask and unmask functions (Myron Stowe) [2045254]
- PCI/MSI: Cleanup msi_mask() (Myron Stowe) [2045254]
- PCI/MSI: Deobfuscate virtual MSI-X (Myron Stowe) [2045254]
- PCI/MSI: Consolidate error handling in msi_capability_init() (Myron Stowe) [2045254]
- PCI/MSI: Rename msi_desc::masked (Myron Stowe) [2045254]
- PCI/MSI: Simplify msi_verify_entries() (Myron Stowe) [2045254]
- s390/pci: Do not mask MSI[-X] entries on teardown (Myron Stowe) [2045254]
- genirq: Improve "hwirq" output in /proc and /sys/ (Myron Stowe) [2045254]
- perf/x86/intel/uncore: Fix Intel SPR CHA event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Fix Intel SPR IIO event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Fix Intel SPR M2PCIE event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Fix Intel SPR M3UPI event constraints (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Support IMC free-running counters on Sapphire Rapids server (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Support IIO free-running counters on Sapphire Rapids server (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Factor out snr_uncore_mmio_map() (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add alias PMU name (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server MDF support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server M3UPI support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server UPI support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2M support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server IMC support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server PCU support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server M2PCIe support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server IRP support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server IIO support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server CHA support (Michael Petlan) [2066225]
- perf/x86/intel/uncore: Add Sapphire Rapids server framework (Michael Petlan) [2066225]
- ibmvnic: Allow queueing resets during probe (Diego Domingos) [2058835]
- ibmvnic: clear fop when retrying probe (Diego Domingos) [2058835]
- ibmvnic: init init_done_rc earlier (Diego Domingos) [2058835]
- ibmvnic: register netdev after init of adapter (Diego Domingos) [2058835]
- ibmvnic: complete init_done on transport events (Diego Domingos) [2058835]
- ibmvnic: define flush_reset_queue helper (Diego Domingos) [2058835]
- ibmvnic: initialize rc before completing wait (Diego Domingos) [2058835]
- ibmvnic: free reset-work-item when flushing (Diego Domingos) [2058835]
- powerpc/smp: Update cpu_core_map on all PowerPc systems (Diego Domingos) [2063682]
- nvmet: revert "nvmet: make discovery NQN configurable" (Gopal Tiwari) [2066146]
- nvme-tcp: send H2CData PDUs based on MAXH2CDATA (Gopal Tiwari) [2066146]
- nvme: also mark passthrough-only namespaces ready in nvme_update_ns_info (Gopal Tiwari) [2066146]
- nvme: don't return an error from nvme_configure_metadata (Gopal Tiwari) [2066146]
- block: fix surprise removal for drivers calling blk_set_queue_dying (Gopal Tiwari) [2066146]
- nvme-tcp: fix bogus request completion when failing to send AER (Gopal Tiwari) [2066146]
- nvme: add nvme_complete_req tracepoint for batched completion (Gopal Tiwari) [2066146]
- nvme-fabrics: remove the unneeded ret variable in nvmf_dev_show (Gopal Tiwari) [2066146]
- nvme-pci: add the IGNORE_DEV_SUBNQN quirk for Intel P4500/P4600 SSDs (Gopal Tiwari) [2066146]
- block: introduce rq_list_for_each_safe macro (Gopal Tiwari) [2066146]
- block: move rq_list macros to blk-mq.h (Gopal Tiwari) [2066146]
- nvme: add 'iopolicy' module parameter (Gopal Tiwari) [2066146]
- nvme-fabrics: print out valid arguments when reading from /dev/nvme-fabrics (Gopal Tiwari) [2066146]
- nvme: separate command prep and issue (Gopal Tiwari) [2066146]
- nvme: split command copy into a helper (Gopal Tiwari) [2066146]
- nvmet-tcp: fix possible list corruption for unexpected command failure (Gopal Tiwari) [2066146]
- nvme: fix use after free when disconnecting a reconnecting ctrl (Gopal Tiwari) [2066146]
- nvme-multipath: set ana_log_size to 0 after free ana_log_buf (Gopal Tiwari) [2066146]
- nvme: disable namespace access for unsupported metadata (Gopal Tiwari) [2066146]
- nvme: report write pointer for a full zone as zone start + zone len (Gopal Tiwari) [2066146]
- nvme: show subsys nqn for duplicate cntlids (Gopal Tiwari) [2066146]
- nvme-pci: add NO APST quirk for Kioxia device (Gopal Tiwari) [2066146]
- nvme: fix write zeroes pi (Gopal Tiwari) [2066146]
- nvmet: use flex_array_size and struct_size (Gopal Tiwari) [2066146]
- nvmet: use struct_size over open coded arithmetic (Gopal Tiwari) [2066146]
- nvme-pci: clear shadow doorbell memory on resets (Gopal Tiwari) [2066146]
- nvmet: use macro definitions for setting cmic value (Gopal Tiwari) [2066146]
- nvme-multipath: add error handling support for add_disk() (Gopal Tiwari) [2066146]
- nvme-rdma: fix error code in nvme_rdma_setup_ctrl (Gopal Tiwari) [2066146]
- nvmet: use macro definition for setting nmic value (Gopal Tiwari) [2066146]
- nvmet-rdma: implement get_max_queue_size controller op (Gopal Tiwari) [2066146]
- nvmet: add get_max_queue_size op for controllers (Gopal Tiwari) [2066146]
- nvme-rdma: limit the maximal queue size for RDMA controllers (Gopal Tiwari) [2066146]
- nvme: generate uevent once a multipath namespace is operational again (Gopal Tiwari) [2066146]
- nvme-fc: add support for ->map_queues (Gopal Tiwari) [2066146]
- nvme: loop: clear NVME_CTRL_ADMIN_Q_STOPPED after admin queue is reallocated (Gopal Tiwari) [2066146]
- nvme: don't memset() the normal read/write command (Gopal Tiwari) [2066146]
- nvme: move command clear into the various setup helpers (Gopal Tiwari) [2066146]
- nvme: wire up completion batching for the IRQ path (Gopal Tiwari) [2066146]
- nvme: add support for batched completion of polled IO (Gopal Tiwari) [2066146]
- nvme-multipath: enable polled I/O (Gopal Tiwari) [2066146]
- nvme: remove the call to nvme_update_disk_info in nvme_ns_remove (Gopal Tiwari) [2066146]
- nvme-rdma: destroy cm id before destroy qp to avoid use after free (Gopal Tiwari) [2066146]
- nvme: add error handling support for add_disk() (Gopal Tiwari) [2066146]
- nvme: only call synchronize_srcu when clearing current path (Gopal Tiwari) [2066146]
- nvme-multipath: revalidate paths during rescan (Gopal Tiwari) [2066146]
- nvme-multipath: set QUEUE_FLAG_NOWAIT (Gopal Tiwari) [2066146]
- nvme: remove the unused NVME_NS_* enum (Gopal Tiwari) [2066146]
- nvme: remove nvm_ndev from ns (Gopal Tiwari) [2066146]
- nvme: Have NVME_FABRICS select NVME_CORE instead of transport drivers (Gopal Tiwari) [2066146]
- nvme-pci: disable hmb on idle suspend (Gopal Tiwari) [2066146]
- nvme: allow user toggling hmb usage (Gopal Tiwari) [2066146]
- nvme-fabrics: remove superfluous nvmf_host_put in nvmf_parse_options (Gopal Tiwari) [2066146]
- nvme: add set feature tracing support (Gopal Tiwari) [2066146]
- nvmet: add set feature tracing support (Gopal Tiwari) [2066146]
- nvme-pci: cmb sysfs: one file, one value (Gopal Tiwari) [2066146]
- nvme-pci: use attribute group for cmb sysfs (Gopal Tiwari) [2066146]
- remove the lightnvm subsystem (Gopal Tiwari) [2066146]
- compiler.h: Introduce absolute_pointer macro (Gopal Tiwari) [2066146]
- mm/usercopy: return 1 from hardened_usercopy __setup() handler (Rafael Aquini) [2064990]
- mm: madvise: return correct bytes advised with process_madvise (Rafael Aquini) [2064990]
- mm/thp: refix __split_huge_pmd_locked() for migration PMD (Rafael Aquini) [2064990]
- mm/mlock: fix potential imbalanced rlimit ucounts adjustment (Rafael Aquini) [2064990]
- mm/hwpoison: fix error page recovered but reported "not recovered" (Rafael Aquini) [2064990]
- mm/page_alloc: check high-order pages for corruption during PCP operations (Rafael Aquini) [2064990]
- mm/page_alloc: do not prefetch buddies during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: limit number of high-order pages on PCP during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: free pages in a single pass during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: drain the requested list first during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: simplify how many pages are selected per pcp list during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: track range of active PCP lists during bulk free (Rafael Aquini) [2064990]
- mm/page_alloc: fetch the correct pcp buddy during bulk free (Rafael Aquini) [2064990]
- mm/pages_alloc.c: don't create ZONE_MOVABLE beyond the end of a node (Rafael Aquini) [2064990]
- mm/page_alloc: mark pagesets as __maybe_unused (Rafael Aquini) [2064990]
- mm: Consider __GFP_NOWARN flag for oversized kvmalloc() calls (Rafael Aquini) [2064990]
- kasan: test: prevent cache merging in kmem_cache_double_destroy (Rafael Aquini) [2064990]
- mm: don't try to NUMA-migrate COW pages that have other uses (Rafael Aquini) [2064990]
- mm/debug_vm_pgtable: remove pte entry from the page table (Rafael Aquini) [2064990]
- Revert "mm/gup: small refactoring: simplify try_grab_page()" (Rafael Aquini) [2064990]
- kasan: fix quarantine conflicting with init_on_free (Rafael Aquini) [2064990]
- kasan: test: add test case for double-kmem_cache_destroy() (Rafael Aquini) [2064990]
- kasan: add ability to detect double-kmem_cache_destroy() (Rafael Aquini) [2064990]
- kasan: test: add globals left-out-of-bounds test (Rafael Aquini) [2064990]
- mm/slab_common: use WARN() if cache still has objects on destroy (Rafael Aquini) [2064990]
- mm: mempolicy: fix THP allocations escaping mempolicy restrictions (Rafael Aquini) [2064990]
- kfence: fix memory leak when cat kfence objects (Rafael Aquini) [2064990]
- mm/memcg: relocate mod_objcg_mlstate(), get_obj_stock() and put_obj_stock() (Rafael Aquini) [2064990]
- mm/slub: fix endianness bug for alloc/free_traces attributes (Rafael Aquini) [2064990]
- hugetlb, userfaultfd: fix reservation restore on userfaultfd error (Rafael Aquini) [2064990]
- mm/zsmalloc.c: close race window between zs_pool_dec_isolated() and zs_unregister_migration() (Rafael Aquini) [2064990]
- hugetlb: remove unnecessary set_page_count in prep_compound_gigantic_page (Rafael Aquini) [2064990]
- mm: move fold_vm_numa_events() to fix NUMA without SMP (Rafael Aquini) [2064990]
- mm/page_alloc.c: fix obsolete comment in free_pcppages_bulk() (Rafael Aquini) [2064990]
- mm/large system hash: avoid possible NULL deref in alloc_large_system_hash (Rafael Aquini) [2064990]
- lib/test_vmalloc.c: use swap() to make code cleaner (Rafael Aquini) [2064990]
- mm/vmalloc: be more explicit about supported gfp flags (Rafael Aquini) [2064990]
- vmalloc: choose a better start address in vm_area_register_early() (Rafael Aquini) [2064990]
- vmalloc: back off when the current task is OOM-killed (Rafael Aquini) [2064990]
- mm/vmalloc: check various alignments when debugging (Rafael Aquini) [2064990]
- mm/vmalloc: make sure to dump unpurged areas in /proc/vmallocinfo (Rafael Aquini) [2064990]
- mm/vmalloc: make show_numa_info() aware of hugepage mappings (Rafael Aquini) [2064990]
- mm/vmalloc: don't allow VM_NO_GUARD on vmap() (Rafael Aquini) [2064990]
- mm/vmalloc: repair warn_alloc()s in __vmalloc_area_node() (Rafael Aquini) [2064990]
- mm/mremap: don't account pages in vma_to_resize() (Rafael Aquini) [2064990]
- mm/filemap.c: remove bogus VM_BUG_ON (Rafael Aquini) [2064990]
- kasan: fix tag for large allocations when using CONFIG_SLAB (Rafael Aquini) [2064990]
- mm: don't include <linux/dax.h> in <linux/mempolicy.h> (Rafael Aquini) [2064990]
- mm: disable NUMA_BALANCING_DEFAULT_ENABLED and TRANSPARENT_HUGEPAGE on PREEMPT_RT (Rafael Aquini) [2064990]
- mm, slub: use prefetchw instead of prefetch (Rafael Aquini) [2064990]
- mm/slub: increase default cpu partial list sizes (Rafael Aquini) [2064990]
- mm, slub: change percpu partial accounting from objects to pages (Rafael Aquini) [2064990]
- slub: add back check for free nonslab objects (Rafael Aquini) [2064990]
- mm/slab.c: remove useless lines in enable_cpucache() (Rafael Aquini) [2064990]
- mm: move kvmalloc-related functions to slab.h (Rafael Aquini) [2064990]
- selftests: kvm: add amx_test to .gitignore (Paul Lai) [1924149]
- kvm: Move KVM_GET_XSAVE2 IOCTL definition at the end of kvm.h (Paul Lai) [1924149]
- kvm: selftests: sync uapi/linux/kvm.h with Linux header (Paul Lai) [1924149]
- kvm: selftests: conditionally build vm_xsave_req_perm() (Paul Lai) [1924149]
- KVM: x86/cpuid: Exclude unpermitted xfeatures sizes at KVM_GET_SUPPORTED_CPUID (Paul Lai) [1924149]
- KVM: x86/cpuid: Clear XFD for component i if the base feature is missing (Paul Lai) [1924149]
- selftest: kvm: Add amx selftest (Paul Lai) [1924149]
- selftest: kvm: Move struct kvm_x86_state to header (Paul Lai) [1924149]
- selftest: kvm: Reorder vcpu_load_state steps for AMX (Paul Lai) [1924149]
- kvm: x86: Disable interception for IA32_XFD on demand (Paul Lai) [1924149]
- x86/fpu: Provide fpu_sync_guest_vmexit_xfd_state() (Paul Lai) [1924149]
- kvm: selftests: Add support for KVM_CAP_XSAVE2 (Paul Lai) [1924149]
- kvm: x86: Add support for getting/setting expanded xstate buffer (Paul Lai) [1924149]
- x86/fpu: Add uabi_size to guest_fpu (Paul Lai) [1924149]
- kvm: x86: Add CPUID support for Intel AMX (Paul Lai) [1924149]
- kvm: x86: Add XCR0 support for Intel AMX (Paul Lai) [1924149]
- kvm: x86: Disable RDMSR interception of IA32_XFD_ERR (Paul Lai) [1924149]
- kvm: x86: Intercept #NM for saving IA32_XFD_ERR (Paul Lai) [1924149]
- x86/fpu: Make XFD initialization in __fpstate_reset() a function argument (Paul Lai) [1924149]
- kvm: x86: Exclude unpermitted xfeatures at KVM_GET_SUPPORTED_CPUID (Paul Lai) [1924149]
- kvm: x86: Fix xstate_required_size() to follow XSTATE alignment rule (Paul Lai) [1924149]
- kvm: selftests: move ucall declarations into ucall_common.h (Paul Lai) [1924149]
- kvm: selftests: move base kvm_util.h declarations to kvm_util_base.h (Paul Lai) [1924149]
- rename c9s pipeline from centos-stream-9 to c9s (Bruno Goncalves)
- genirq: Provide new interfaces for affinity hints (Phil Auld) [2055300]
- um: vector: adjust to coalesce API changes (Ivan Vecera) [2047636]
- igb: fix deadlock caused by taking RTNL in RPM resume path (Ivan Vecera) [2047636]
- ethtool: Fix link extended state for big endian (Ivan Vecera) [2047636]
- ethtool: use phydev variable (Ivan Vecera) [2047636]
- ethtool: Remove redundant ret assignments (Ivan Vecera) [2047636]
- ethtool: do not perform operations on net devices being unregistered (Ivan Vecera) [2047636]
- ethtool: netlink: Slightly simplify 'ethnl_features_to_bitmap()' (Ivan Vecera) [2047636]
- ethtool: ioctl: fix potential NULL deref in ethtool_set_coalesce() (Ivan Vecera) [2047636]
- net: ethtool: set a default driver name (Ivan Vecera) [2047636]
- ethtool: extend ringparam setting/getting API with rx_buf_len (Ivan Vecera) [2047636]
- ethtool: add support to set/get rx buf len via ethtool (Ivan Vecera) [2047636]
- ethtool: add support to set/get tx copybreak buf size via ethtool (Ivan Vecera) [2047636]
- ethtool: fix ethtool msg len calculation for pause stats (Ivan Vecera) [2047636]
- ethtool: don't drop the rtnl_lock half way thru the ioctl (Ivan Vecera) [2047636]
- devlink: expose get/put functions (Ivan Vecera) [2047636]
- ethtool: handle info/flash data copying outside rtnl_lock (Ivan Vecera) [2047636]
- ethtool: push the rtnl_lock into dev_ethtool() (Ivan Vecera) [2047636]
- ethtool: Add transceiver module extended state (Ivan Vecera) [2047636]
- ethtool: Add ability to control transceiver modules' power mode (Ivan Vecera) [2047636]
- ethtool: ioctl: Use array_size() helper in copy_{from,to}_user() (Ivan Vecera) [2047636]
- ethtool: prevent endless loop if eeprom size is smaller than announced (Ivan Vecera) [2047636]
- ethtool: extend coalesce setting uAPI with CQE mode (Ivan Vecera) [2047636]
- ethtool: add two coalesce attributes for CQE mode (Ivan Vecera) [2047636]
- ethtool: add two link extended substates of bad signal integrity (Ivan Vecera) [2047636]
- docs: ethtool: Add two link extended substates of bad signal integrity (Ivan Vecera) [2047636]
- ethtool: return error from ethnl_ops_begin if dev is NULL (Ivan Vecera) [2047636]
- ethtool: runtime-resume netdev parent in ethnl_ops_begin (Ivan Vecera) [2047636]
- ethtool: move netif_device_present check from ethnl_parse_header_dev_get to ethnl_ops_begin (Ivan Vecera) [2047636]
- ethtool: move implementation of ethnl_ops_begin/complete to netlink.c (Ivan Vecera) [2047636]
- ethtool: runtime-resume netdev parent before ethtool ioctl ops (Ivan Vecera) [2047636]

* Wed Mar 30 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-76.rt21.76.el9]
- [rt] build kernel-rt-5.14.0-76.rt21.76.el9 [2061574]
- Revert "Merge: kernel/futex: backport new futex_waitv(2) system call" (Fernando Pacheco)
- vdpa/mlx5: Fix tracking of current number of VQs (Cindy Lu) [2055451]
- vdpa/mlx5: Fix is_index_valid() to refer to features (Cindy Lu) [2055451]
- vdpa: Protect vdpa reset with cf_mutex (Cindy Lu) [2055451]
- vdpa: Avoid taking cf_mutex lock on get status (Cindy Lu) [2055451]
- vdpa/vdpa_sim_net: Report max device capabilities (Cindy Lu) [2055451]
- vdpa: Use BIT_ULL for bit operations (Cindy Lu) [2055451]
- vdpa/vdpa_sim: Configure max supported virtqueues (Cindy Lu) [2055451]
- vdpa/mlx5: Report max device capabilities (Cindy Lu) [2055451]
- vdpa: Support reporting max device capabilities (Cindy Lu) [2055451]
- vdpa/mlx5: Restore cur_num_vqs in case of failure in change_num_qps() (Cindy Lu) [2055451]
- vdpa: Add support for returning device configuration information (Cindy Lu) [2055451]
- vdpa/mlx5: Support configuring max data virtqueue (Cindy Lu) [2055451]
- vdpa/mlx5: Fix config_attr_mask assignment (Cindy Lu) [2055451]
- vdpa: Allow to configure max data virtqueues (Cindy Lu) [2055451]
- vdpa: Read device configuration only if FEATURES_OK (Cindy Lu) [2055451]
- vdpa: Sync calls set/get config/status with cf_mutex (Cindy Lu) [2055451]
- vdpa/mlx5: Distribute RX virtqueues in RQT object (Cindy Lu) [2055451]
- vdpa: Provide interface to read driver features (Cindy Lu) [2055451]
- vdpa: clean up get_config_size ret value handling (Cindy Lu) [2055451]
- vdpa/mlx5: Fix wrong configuration of virtio_version_1_0 (Cindy Lu) [2055451]
- vdpa: Mark vdpa_config_ops.get_vq_notification as optional (Cindy Lu) [2055451]
- vdpa: Avoid duplicate call to vp_vdpa get_status (Cindy Lu) [2055451]
- net/mlx5_vdpa: Offer VIRTIO_NET_F_MTU when setting MTU (Cindy Lu) [2055451]
- vdpa: add driver_override support (Cindy Lu) [2055451]
- docs: document sysfs ABI for vDPA bus (Cindy Lu) [2055451]
- ifcvf/vDPA: fix misuse virtio-net device config size for blk dev (Cindy Lu) [2055451]
- vdpa: Consider device id larger than 31 (Cindy Lu) [2055451]
- virtio: always enter drivers/virtio/ (Cindy Lu) [2055451]
- vdpa: check that offsets are within bounds (Cindy Lu) [2055451]
- vdpa_sim: avoid putting an uninitialized iova_domain (Cindy Lu) [2055451]
- vhost-vdpa: clean irqs before reseting vdpa device (Cindy Lu) [2055451]
- vdpa/mlx5: Forward only packets with allowed MAC address (Cindy Lu) [2055451]
- vdpa/mlx5: Support configuration of MAC (Cindy Lu) [2055451]
- vdpa/mlx5: Fix clearing of VIRTIO_NET_F_MAC feature bit (Cindy Lu) [2055451]
- vdpa_sim_net: Enable user to set mac address and mtu (Cindy Lu) [2055451]
- vdpa: Enable user to set mac and mtu of vdpa device (Cindy Lu) [2055451]
- vdpa: Use kernel coding style for structure comments (Cindy Lu) [2055451]
- vdpa: Introduce query of device config layout (Cindy Lu) [2055451]
- vdpa: Introduce and use vdpa device get, set config helpers (Cindy Lu) [2055451]
- vdpa/mlx5: Propagate link status from device to vdpa driver (Cindy Lu) [2055451]
- vdpa/mlx5: Rename control VQ workqueue to vdpa wq (Cindy Lu) [2055451]
- vdpa/mlx5: Remove mtu field from vdpa net device (Cindy Lu) [2055451]
- vdpa: add new attribute VDPA_ATTR_DEV_MIN_VQ_SIZE (Cindy Lu) [2055451]
- virtio_vdpa: setup correct vq size with callbacks get_vq_num_{max,min} (Cindy Lu) [2055451]
- vdpa: min vq num of vdpa device cannot be greater than max vq num (Cindy Lu) [2055451]
- vdpa: add new callback get_vq_num_min in vdpa_config_ops (Cindy Lu) [2055451]
- vp_vdpa: add vq irq offloading support (Cindy Lu) [2055451]
- vdpa: fix typo (Cindy Lu) [2055451]
- vhost-vdpa: Fix the wrong input in config_cb (Cindy Lu) [2055451]
- vhost_vdpa: unset vq irq before freeing irq (Cindy Lu) [2055451]
- vdpa: potential uninitialized return in vhost_vdpa_va_map() (Cindy Lu) [2055451]
- vdpa/mlx5: Avoid executing set_vq_ready() if device is reset (Cindy Lu) [2055451]
- vdpa/mlx5: Clear ready indication for control VQ (Cindy Lu) [2055451]
- vdpa: Support transferring virtual addressing during DMA mapping (Cindy Lu) [2055451]
- vdpa: factor out vhost_vdpa_pa_map() and vhost_vdpa_pa_unmap() (Cindy Lu) [2055451]
- vdpa: Add an opaque pointer for vdpa_config_ops.dma_map() (Cindy Lu) [2055451]
- vhost-iotlb: Add an opaque pointer for vhost IOTLB (Cindy Lu) [2055451]
- vhost-vdpa: Handle the failure of vdpa_reset() (Cindy Lu) [2055451]
- vdpa: Add reset callback in vdpa_config_ops (Cindy Lu) [2055451]
- vdpa: Fix some coding style issues (Cindy Lu) [2055451]
- vdpa: Make use of PFN_PHYS/PFN_UP/PFN_DOWN helper macro (Cindy Lu) [2055451]
- vdpa/mlx5: Add multiqueue support (Cindy Lu) [2055451]
- vdpa/mlx5: Add support for control VQ and MAC setting (Cindy Lu) [2055451]
- vdpa/mlx5: Ensure valid indices are provided (Cindy Lu) [2055451]
- vdpa/mlx5: Decouple virtqueue callback from struct mlx5_vdpa_virtqueue (Cindy Lu) [2055451]
- vdpa/mlx5: function prototype modifications in preparation to control VQ (Cindy Lu) [2055451]
- vdpa/mlx5: Remove redundant header file inclusion (Cindy Lu) [2055451]
- vDPA/ifcvf: enable multiqueue and control vq (Cindy Lu) [2055451]
- vDPA/ifcvf: detect and use the onboard number of queues directly (Cindy Lu) [2055451]
- vDPA/ifcvf: implement management netlink framework for ifcvf (Cindy Lu) [2055451]
- vDPA/ifcvf: introduce get_dev_type() which returns virtio dev id (Cindy Lu) [2055451]
- x86/hyperv: Output host build info as normal Windows version number (Vitaly Kuznetsov) [2060708]
- lib/irq_poll: Declare IRQ_POLL softirq vector as ksoftirqd-parking safe (Desnes A. Nunes do Rosario) [2059555]
- tick/rcu: Stop allowing RCU_SOFTIRQ in idle (Desnes A. Nunes do Rosario) [2059555]
- tick/rcu: Remove obsolete rcu_needs_cpu() parameters (Desnes A. Nunes do Rosario) [2059555]
- tick: Detect and fix jiffies update stall (Desnes A. Nunes do Rosario) [2059555]
- rcu: Move rcu_needs_cpu() to tree.c (Desnes A. Nunes do Rosario) [2059555]
- rcu: Remove the RCU_FAST_NO_HZ Kconfig option (Desnes A. Nunes do Rosario) [2059555]
- torture: Remove RCU_FAST_NO_HZ from rcu scenarios (Desnes A. Nunes do Rosario) [2059555]
- torture: Remove RCU_FAST_NO_HZ from rcuscale and refscale scenarios (Desnes A. Nunes do Rosario) [2059555]
- copy_process(): Move fd_install() out of sighand->siglock critical section (Waiman Long) [2051855]
- redhat/configs: enable CONFIG_INTEL_VSEC for x86 (David Arcari) [2058806]
- platform/x86/intel: Move intel_pmt from MFD to Auxiliary Bus (David Arcari) [2058806]
- platform/x86: intel_pmt_telemetry: Ignore zero sized entries (David Arcari) [2058806]
- platform/x86/intel: Move Intel PMT drivers to new subfolder (David Arcari) [2058806]
- driver core: auxiliary bus: Add driver data helpers (David Arcari) [2058806]
- PCI: Add #defines for accessing PCIe DVSEC fields (David Arcari) [2058806]
- tools headers UAPI: Sync powerpc syscall table file changed by new futex_waitv syscall (Joel Savitz) [2038794]
- tools headers UAPI: Sync s390 syscall table file changed by new futex_waitv syscall (Joel Savitz) [2038794]
- futex: Wireup futex_waitv syscall (Joel Savitz) [2038794]
- tools headers UAPI: Sync MIPS syscall table file changed by new futex_waitv syscall (Joel Savitz) [2038794]
- parisc: Wire up futex_waitv (Joel Savitz) [2038794]
- s390: wire up sys_futex_waitv system call (Joel Savitz) [2038794]
- MIPS: syscalls: Wire up futex_waitv syscall (Joel Savitz) [2038794]
- tools headers UAPI: Sync files changed by new futex_waitv syscall (Joel Savitz) [2038794]
- futex2: Documentation: Document sys_futex_waitv() uAPI (Joel Savitz) [2038794]
- selftests: futex: Test sys_futex_waitv() wouldblock (Joel Savitz) [2038794]
- selftests: futex: Test sys_futex_waitv() timeout (Joel Savitz) [2038794]
- selftests: futex: Add sys_futex_waitv() test (Joel Savitz) [2038794]
- futex,arm: Wire up sys_futex_waitv() (Joel Savitz) [2038794]
- futex,x86: Wire up sys_futex_waitv() (Joel Savitz) [2038794]
- futex: Implement sys_futex_waitv() (Joel Savitz) [2038794]
- futex: Simplify double_lock_hb() (Joel Savitz) [2038794]
- futex: Split out wait/wake (Joel Savitz) [2038794]
- futex: Split out requeue (Joel Savitz) [2038794]
- futex: Rename mark_wake_futex() (Joel Savitz) [2038794]
- futex: Rename: match_futex() (Joel Savitz) [2038794]
- futex: Rename: hb_waiter_{inc,dec,pending}() (Joel Savitz) [2038794]
- futex: Split out PI futex (Joel Savitz) [2038794]
- futex: Rename: {get,cmpxchg}_futex_value_locked() (Joel Savitz) [2038794]
- futex: Rename hash_futex() (Joel Savitz) [2038794]
- futex: Rename __unqueue_futex() (Joel Savitz) [2038794]
- futex: Rename: queue_{,un}lock() (Joel Savitz) [2038794]
- futex: Rename futex_wait_queue_me() (Joel Savitz) [2038794]
- futex: Rename {,__}{,un}queue_me() (Joel Savitz) [2038794]
- futex: Split out syscalls (Joel Savitz) [2038794]
- futex: Move to kernel/futex/ (Joel Savitz) [2038794]
- cifs: fix double free race when mount fails in cifs_get_root() (Ronnie Sahlberg) [1979175]

* Mon Mar 28 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-75.rt21.75.el9]
- [rt] build kernel-rt-5.14.0-75.rt21.75.el9 [2061574]
- ipv6: fix skb drops in igmp6_event_query() and igmp6_event_report() (Hangbin Liu) [2059308] {CVE-2022-0742}
- redhat/configs: aarch64: Fix PAC/BTI config settings (Mark Salter) [2063215]
- RHEL9.0: arch_hw Update CONFIG_MOUSE_VSXXXAA=m (Tony Camuso) [2062909]
- redhat/configs: Disable KVM on POWER (Laurent Vivier) [2052898]
- drm/ast: Create threshold values for AST2600 (Jocelyn Falempe) [2062560]
- mm: gup: make fault_in_safe_writeable() use fixup_user_fault() (Andreas Gruenbacher) [2062797]
- drm/vmwgfx: Fix stale file descriptors on failed usercopy (David Airlie) [2047613] {CVE-2022-22942}
- netfilter: nf_queue: handle socket prefetch (Florian Westphal) [2060092]
- netfilter: nf_queue: fix possible use-after-free (Florian Westphal) [2060092]
- selftests: netfilter: add nfqueue TCP_NEW_SYN_RECV socket race test (Florian Westphal) [2060092]
- netfilter: nf_queue: don't assume sk is full socket (Florian Westphal) [2060092]
- scsi: mpi3mr: Fix flushing !WQ_MEM_RECLAIM events warning (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix memory leaks (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix reporting of actual data transfer size (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix cmnd getting marked as in use forever (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix hibernation issue (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix printing of pending I/O count (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fix deadlock while canceling the fw event (Tomas Henzl) [2056626]
- scsi: mpi3mr: Fixes around reply request queues (Tomas Henzl) [2056626]
- scsi: mpi3mr: Enhanced Task Management Support Reply handling (Tomas Henzl) [2056626]
- scsi: mpi3mr: Use TM response codes from MPI3 headers (Tomas Henzl) [2056626]
- scsi: mpi3mr: Increase internal cmnds timeout to 60s (Tomas Henzl) [2056626]
- scsi: mpi3mr: Do access status validation before adding devices (Tomas Henzl) [2056626]
- scsi: mpi3mr: Update MPI3 headers - part2 (Tomas Henzl) [2056626]
- scsi: mpi3mr: Update MPI3 headers - part1 (Tomas Henzl) [2056626]
- scsi: mpi3mr: Don't reset IOC if cmnds flush with reset status (Tomas Henzl) [2056626]
- scsi: mpi3mr: Replace spin_lock() with spin_lock_irqsave() (Tomas Henzl) [2056626]
- scsi: mpi3mr: Add debug APIs based on logging_level bits (Tomas Henzl) [2056626]
- x86/kvm/fpu: Remove kvm_vcpu_arch.guest_supported_xcr0 (Leonardo Bras) [2043545]
- x86/kvm/fpu: Limit guest user_xfeatures to supported bits of XCR0 (Leonardo Bras) [2043545]
- KVM: x86: Move CPUID.(EAX=0x12,ECX=1) mangling to __kvm_update_cpuid_runtime() (Leonardo Bras) [2043545]
- KVM: x86: Do runtime CPUID update before updating vcpu->arch.cpuid_entries (Leonardo Bras) [2043545]
- x86/fpu: Fix inline prefix warnings (Leonardo Bras) [2043545]
- kvm: x86: Emulate IA32_XFD_ERR for guest (Leonardo Bras) [2043545]
- x86/fpu: Prepare xfd_err in struct fpu_guest (Leonardo Bras) [2043545]
- kvm: x86: Add emulation for IA32_XFD (Leonardo Bras) [2043545]
- x86/fpu: Provide fpu_update_guest_xfd() for IA32_XFD emulation (Leonardo Bras) [2043545]
- kvm: x86: Enable dynamic xfeatures at KVM_SET_CPUID2 (Leonardo Bras) [2043545]
- x86/fpu: Provide fpu_enable_guest_xfd_features() for KVM (Leonardo Bras) [2043545]
- x86/fpu: Add guest support to xfd_enable_feature() (Leonardo Bras) [2043545]
- x86/fpu: Prepare guest FPU for dynamically enabled FPU features (Leonardo Bras) [2043545]
- x86/fpu: Extend fpu_xstate_prctl() with guest permissions (Leonardo Bras) [2043545]
- cpuid: kvm_find_kvm_cpuid_features() should be declared 'static' (Leonardo Bras) [2043545]
- KVM: x86: Make sure KVM_CPUID_FEATURES really are KVM_CPUID_FEATURES (Leonardo Bras) [2043545]
- KVM: x86: Add helper to consolidate core logic of SET_CPUID{2} flows (Leonardo Bras) [2043545]
- redhat/configs: Disable watchdog components (Prarit Bhargava) [2060117]
- sched: Fix yet more sched_fork() races (Phil Auld) [2062836]
- sched/fair: Fix fault in reweight_entity (Phil Auld) [2062836]
- x86/cpu: Add Xeon Icelake-D to list of CPUs that support PPIN (David Arcari) [2043225]
- powerpc/pseries/ddw: Revert "Extend upper limit for huge DMA window for persistent memory" (Steve Best) [2056057]
- drivers/char: permit access to the RTAS user buffer under lockdown (Desnes A. Nunes do Rosario) [2046472]

* Tue Mar 22 2022 Fernando Pacheco <fpacheco@redhat.com> [5.14.0-74.rt21.74.el9]
- [rt] build kernel-rt-5.14.0-74.rt21.74.el9 [2061574]
- redhat: rpminspect: disable 'patches' check for known empty patch files (Patrick Talbert)
- KVM: x86/mmu: Don't advance iterator after restart due to yielding (Nico Pache) [2055725]
- ibmvnic: don't release napi in __ibmvnic_open() (Diego Domingos) [2055981]

* Mon Mar 21 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-73.rt21.73.el9]
- [rt] build kernel-rt-5.14.0-73.rt21.73.el9 [2061574]
- CI: Use 9.0-rt branch for rhel-9 realtime_check (Juri Lelli)
- redhat: enable zstream release numbering for rhel 9.0 (Herton R. Krzesinski)
- redhat: change kabi tarballs to use the package release (Herton R. Krzesinski)
- redhat: generate distgit changelog in genspec.sh as well (Herton R. Krzesinski)
- redhat: make genspec prefer metadata from git notes (Herton R. Krzesinski)
- redhat: use tags from git notes for zstream to generate changelog (Herton R. Krzesinski)
- CI: Add disttag setting (Veronika Kabatova)
- CI: Drop c9s config (Veronika Kabatova)
- virtio-net: fix pages leaking when building skb in big mode (Laurent Vivier) [2042559]
- lib/iov_iter: initialize "flags" in new pipe_buffer (Carlos Maiolino) [2060869] {CVE-2022-0847}
- redhat/configs: Make CRYPTO_ECDH algos built-in (Simo Sorce) [2062199]
- crypto: api - Move cryptomgr soft dependency into algapi (Vladis Dronov) [2062199]
- crypto: api - Fix boot-up crash when crypto manager is disabled (Vladis Dronov) [2062199]
- crypto: api - Do not create test larvals if manager is disabled (Vladis Dronov) [2062199]
- crypto: api - Export crypto_boot_test_finished (Vladis Dronov) [2062199]
- crypto: api - Fix built-in testing dependency failures (Vladis Dronov) [2062199]
- redhat/configs: Add CRYPTO_AES_ARM64 config explicitly (Vladis Dronov) [2062199]
- crypto: arm64/aes-ce - stop using SIMD helper for skciphers (Vladis Dronov) [2062199]
- crypto: arm64/aes-neonbs - stop using SIMD helper for skciphers (Vladis Dronov) [2062199]
- redhat: change default dist suffix for RHEL 9.0 (Herton R. Krzesinski)
- selftests: kvm: Check whether SIDA memop fails for normal guests (Thomas Huth) [2050813]
- KVM: s390: Return error on SIDA memop on normal guest (Thomas Huth) [2050813]
- block: kabi: reserve space for block layer public structure (Ming Lei) [2057238]
- block: kabi: reserve space for blk-mq related structure (Ming Lei) [2057238]
- block: kabi: reserve space for bsg related structure (Ming Lei) [2057238]
- block: kabi: reserve space for integrity related structure (Ming Lei) [2057238]
- scsi: lpfc: Fix pt2pt NVMe PRLI reject LOGO loop (Dick Kennedy) [2054866]
- x86/MCE/AMD, EDAC/mce_amd: Support non-uniform MCA bank type enumeration (Aristeu Rozanski) [1898165 2047430 2047446]
- x86/MCE/AMD, EDAC/mce_amd: Add new SMCA bank types (Aristeu Rozanski) [1898165 2047430 2047446]
- EDAC/amd64: Add support for AMD Family 19h Models 10h-1Fh and A0h-AFh (Aristeu Rozanski) [1898165 2047430 2047446]
- EDAC: Add RDDR5 and LRDDR5 memory types (Aristeu Rozanski) [1898165 2047430 2047446]
- drm/amdgpu: Register MCE notifier for Aldebaran RAS (Aristeu Rozanski) [1898165 2047430 2047446]
- x86/MCE/AMD: Export smca_get_bank_type symbol (Aristeu Rozanski) [1898165 2047430 2047446]
- PCI/ACPI: Fix acpi_pci_osc_control_set() kernel-doc comment (Mark Langsdorf) [2049635]
- PCI/ACPI: Check for _OSC support in acpi_pci_osc_control_set() (Mark Langsdorf) [2049635]
- PCI/ACPI: Move _OSC query checks to separate function (Mark Langsdorf) [2049635]
- PCI/ACPI: Move supported and control calculations to separate functions (Mark Langsdorf) [2049635]
- PCI/ACPI: Remove OSC_PCI_SUPPORT_MASKS and OSC_PCI_CONTROL_MASKS (Mark Langsdorf) [2049635]
- nvmet-tcp: fix missing unmainted messages (Chris Leech) [2054441]
- dm stats: fix too short end duration_ns when using precise_timestamps (Benjamin Marzinski) [2051798]
- dm: fix double accounting of flush with data (Benjamin Marzinski) [2051798]
- dm: interlock pending dm_io and dm_wait_for_bios_completion (Benjamin Marzinski) [2051798]
- dm: properly fix redundant bio-based IO accounting (Benjamin Marzinski) [2051798]
- dm: revert partial fix for redundant bio-based IO accounting (Benjamin Marzinski) [2051798]
- block: add bio_start_io_acct_time() to control start_time (Benjamin Marzinski) [2051798]
- scsi: mpt3sas: Fix incorrect system timestamp (Tomas Henzl) [2049631]
- scsi: mpt3sas: Fix system going into read-only mode (Tomas Henzl) [2049631]
- scsi: mpt3sas: Fix kernel panic during drive powercycle test (Tomas Henzl) [2049631]
- redhat/configs: enable mellanox platform drivers to support LED, fan & watchdog devices (Ivan Vecera) [2057491]
- x86/cpu: Drop spurious underscore from RAPTOR_LAKE #define (David Arcari) [2040022]
- x86/cpu: Add Raptor Lake to Intel family (David Arcari) [2040022]
- powerpc/64: Move paca allocation later in boot (Desnes A. Nunes do Rosario) [2055566]
- powerpc: Set crashkernel offset to mid of RMA region (Desnes A. Nunes do Rosario) [2055566]
- selftests: kvm: Check whether SIDA memop fails for normal guests (Thomas Huth) [2060814]
- KVM: s390: Return error on SIDA memop on normal guest (Thomas Huth) [2060814]
- igb: refactor XDP registration (Corinna Vinschen) [2054379]
- igc: avoid kernel warning when changing RX ring parameters (Corinna Vinschen) [2054379]
- redhat/configs: Enable CONFIG_ACER_WIRELESS (Peter Georg) [2025985]

* Thu Mar 17 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-72.rt21.72.el9]
- Revert 8dffe2b6 "Merge: kabi: add lib ACKed symbols" (Čestmír Kalina) [2059972]
- include/linux/kernel.h: fix function name for mark_hardware_unmaintained() if !CONFIG_RHEL_DIFFERENCES (Ewan D. Milne) [2059687]
- scsi: sd: Mark ZBC host-managed SCSI disks as unmaintained (Ewan D. Milne) [2059687]
- spec: make linux-firmware weak(er) dependency (Jan Stancek) [2031113]
- redhat/configs: Enable CONFIG_INTEL_PCH_THERMAL for x86 (David Arcari) [2058186]
- redhat/configs: Disable CONFIG_SURFACE_PLATFORMS (David Arcari) [2056609]
- spec: Fix separate tools build (Jiri Olsa) [2054579]
- redhat: use centos x509.genkey file if building under centos (Herton R. Krzesinski) [2029952]

* Wed Mar 09 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-71.rt21.71.el9]
- redhat: Update RTBZ for 9.1 cycle (Juri Lelli)
- redhat: Add kernel-rt 9.1 changelog as a copy of 9.0 (Juri Lelli)
- CI: Build coverage RPMs on c9s environment (Veronika Kabatova)
- md: use default_groups in kobj_type (Nigel Croxon) [2042797]
- md: Move alloc/free acct bioset in to personality (Nigel Croxon) [2042797]
- md: fix spelling of "its" (Nigel Croxon) [2042797]
- md: raid456 add nowait support (Nigel Croxon) [2042797]
- md: raid10 add nowait support (Nigel Croxon) [2042797]
- md: raid1 add nowait support (Nigel Croxon) [2042797]
- md: add support for REQ_NOWAIT (Nigel Croxon) [2042797]
- md: drop queue limitation for RAID1 and RAID10 (Nigel Croxon) [2042797]
- md/raid5: play nice with PREEMPT_RT (Nigel Croxon) [2042797]
- md/raid1: fix missing bitmap update w/o WriteMostly devices (Nigel Croxon) [2042797]
- md: fix double free of mddev->private in autorun_array() (Nigel Croxon) [2042797]
- md: fix update super 1.0 on rdev size change (Nigel Croxon) [2042797]
- raid5-ppl: use swap() to make code cleaner (Nigel Croxon) [2042797]
- md/bitmap: don't set max_write_behind if there is no write mostly device (Nigel Croxon) [2042797]
- md: update superblock after changing rdev flags in state_store (Nigel Croxon) [2042797]
- md: remove unused argument from md_new_event (Nigel Croxon) [2042797]
- md/raid5: call roundup_pow_of_two in raid5_run (Nigel Croxon) [2042797]
- md/raid1: use rdev in raid1_write_request directly (Nigel Croxon) [2042797]
- md/raid1: only allocate write behind bio fof WriteMostly device (Nigel Croxon) [2042797]
- md: properly unwind when failing to add the kobject in md_alloc (Nigel Croxon) [2042797]
- md: extend disks_mutex coverage (Nigel Croxon) [2042797]
- md: add the bitmap group to the default groups for the md kobject (Nigel Croxon) [2042797]
- md: add error handling support for add_disk() (Nigel Croxon) [2042797]
- redhat: Bump RHEL_MINOR for 9.1 (Patrick Talbert)

* Fri Feb 25 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-70.rt21.70.el9]
- stmmac/intel: mark driver as tech preview (Mark Salter) [2045594]
- net: stmmac: Add GFP_DMA32 for rx buffers if no 64 capability (Mark Salter) [2045594]
- mm: fix invalid page pointer returned with FOLL_PIN gups (Peter Xu) [2037300]
- tipc: improve size validations for received domain records (Xin Long) [2048972] {CVE-2022-0435}
- cgroup-v1: Require capabilities to set release_agent (Waiman Long) [2052168] {CVE-2022-0492}
- bpf, arm64: Use emit_addr_mov_i64() for BPF_PSEUDO_FUNC (Yauheni Kaliuta) [2033596]
- bpf: Stop caching subprog index in the bpf_pseudo_func insn (Yauheni Kaliuta) [2033596]
- ucount: Make get_ucount a safe get_user replacement (Alexey Gladkov) [2049040] {CVE-2022-24122}
- ucounts: Add get_ucounts_or_wrap for clarity (Alexey Gladkov) [2049040]
- ucounts: Remove unnecessary test for NULL ucount in get_ucounts (Alexey Gladkov) [2049040]
- ucounts: Use atomic_long_sub_return for clarity (Alexey Gladkov) [2049040]
- ucounts: Fix rlimit max values check (Alexey Gladkov) [2049040]
- redhat/Makefile: fix access issue on shared build system (Bruno Meneguele)

* Thu Feb 24 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-69.rt21.69.el9]
- config: mt76: set CONFIG_MT7921S to not set, like in ark (Íñigo Huguet) [2043454]
- config: rtw89: enable driver and device RTL8852AE (Íñigo Huguet) [2043454]
- rtw89: 8852a: correct bit definition of dfs_en (Íñigo Huguet) [2043454]
- rtw89: coex: Update COEX to 5.5.8 (Íñigo Huguet) [2043454]
- rtw89: coex: Cancel PS leaving while C2H comes (Íñigo Huguet) [2043454]
- rtw89: coex: Update BT counters while receiving report (Íñigo Huguet) [2043454]
- rtw89: coex: Define LPS state for BTC using (Íñigo Huguet) [2043454]
- rtw89: coex: Add MAC API to get BT polluted counter (Íñigo Huguet) [2043454]
- rtw89: coex: Not to send H2C when WL not ready and count H2C (Íñigo Huguet) [2043454]
- rtw89: coex: correct C2H header length (Íñigo Huguet) [2043454]
- rtw89: don't kick off TX DMA if failed to write skb (Íñigo Huguet) [2043454]
- rtw89: remove cch_by_bw which is not used (Íñigo Huguet) [2043454]
- rtw89: fix sending wrong rtwsta->mac_id to firmware to fill address CAM (Íñigo Huguet) [2043454]
- rtw89: fix incorrect channel info during scan (Íñigo Huguet) [2043454]
- rtw89: update scan_mac_addr during scanning period (Íñigo Huguet) [2043454]
- rtw89: use inline function instead macro to set H2C and CAM (Íñigo Huguet) [2043454]
- rtw89: add const in the cast of le32_get_bits() (Íñigo Huguet) [2043454]
- rtw89: add AXIDMA and TX FIFO dump in mac_mem_dump (Íñigo Huguet) [2043454]
- rtw89: fix potentially access out of range of RF register array (Íñigo Huguet) [2043454]
- rtw89: remove unneeded variable (Íñigo Huguet) [2043454]
- rtw89: remove unnecessary conditional operators (Íñigo Huguet) [2043454]
- rtw89: update rtw89_regulatory map to R58-R31 (Íñigo Huguet) [2043454]
- rtw89: update tx power limit/limit_ru tables to R54 (Íñigo Huguet) [2043454]
- rtw89: update rtw89 regulation definition to R58-R31 (Íñigo Huguet) [2043454]
- rtw89: fill regd field of limit/limit_ru tables by enum (Íñigo Huguet) [2043454]
- iwlwifi: pcie: add killer devices to the driver (Íñigo Huguet) [2043454]
- iwlwifi: add support for BNJ HW (Íñigo Huguet) [2043454]
- iwlwifi: Read the correct addresses when getting the crf id (Íñigo Huguet) [2043454]
- iwlwifi: pcie: add jacket bit to device configuration parsing (Íñigo Huguet) [2043454]
- iwlwifi: add new ax1650 killer device (Íñigo Huguet) [2043454]
- iwlwifi: add new Qu-Hr device (Íñigo Huguet) [2043454]
- iwlwifi: add missing entries for Gf4 with So and SoF (Íñigo Huguet) [2043454]
- iwlwifi: remove unused iwlax210_2ax_cfg_so_hr_a0 structure (Íñigo Huguet) [2043454]
- iwlwifi: support 4-bits in MAC step value (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Increase the scan timeout guard to 30 seconds (Íñigo Huguet) [2043454]
- wilc1000: fix double free error in probe() (Íñigo Huguet) [2043454]
- wilc1000: Fix spurious "FW not responding" error (Íñigo Huguet) [2043454]
- wilc1000: Fix missing newline in error message (Íñigo Huguet) [2043454]
- wilc1000: Fix copy-and-paste typo in wilc_set_mac_address (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Use div_s64 instead of do_div in iwl_mvm_ftm_rtt_smoothing() (Íñigo Huguet) [2043454]
- mt76: mt7921: fix a possible race enabling/disabling runtime-pm (Íñigo Huguet) [2043454]
- ath11k: Fix unexpected return buffer manager error for QCA6390 (Íñigo Huguet) [2043454]
- ath11k: Fix napi related hang (Íñigo Huguet) [2043454]
- iwlwifi: yoyo: fix issue with new DBGI_SRAM region read. (Íñigo Huguet) [2043454]
- iwlwifi: pcie: make sure prph_info is set when treating wakeup IRQ (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix AUX ROC removal (Íñigo Huguet) [2043454]
- iwlwifi: mvm: set protected flag only for NDP ranging (Íñigo Huguet) [2043454]
- iwlwifi: mvm: perform 6GHz passive scan after suspend (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Fix calculation of frame length (Íñigo Huguet) [2043454]
- iwlwifi: mvm: test roc running status bits before removing the sta (Íñigo Huguet) [2043454]
- iwlwifi: don't pass actual WGDS revision number in table_revision (Íñigo Huguet) [2043454]
- iwlwifi: fix leaks/bad data after failed firmware load (Íñigo Huguet) [2043454]
- iwlwifi: fix debug TLV parsing (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix 32-bit build in FTM (Íñigo Huguet) [2043454]
- iwlwifi: fix Bz NMI behaviour (Íñigo Huguet) [2043454]
- rtlwifi: rtl8192cu: Fix WARNING when calling local_irq_restore() with interrupts enabled (Íñigo Huguet) [2043454]
- rtw88: 8822c: update rx settings to prevent potential hw deadlock (Íñigo Huguet) [2043454]
- rtw88: Disable PCIe ASPM while doing NAPI poll on 8821CE (Íñigo Huguet) [2043454]
- ath9k: Fix out-of-bound memcpy in ath9k_hif_usb_rx_stream (Íñigo Huguet) [2043454]
- ath9k_htc: fix NULL pointer dereference at ath9k_htc_tx_get_packet() (Íñigo Huguet) [2043454]
- ath9k_htc: fix NULL pointer dereference at ath9k_htc_rxep() (Íñigo Huguet) [2043454]
- mac80211: fix FEC flag in radio tap header (Íñigo Huguet) [2043454]
- mt76: mt7921: fix possible resume failure (Íñigo Huguet) [2043454]
- mt76: mt7921: move mt76_connac_mcu_set_hif_suspend to bus-related files (Íñigo Huguet) [2043454]
- mt76: mt7921: fix network buffer leak by txs missing (Íñigo Huguet) [2043454]
- mt76: mt7615: clear mcu error interrupt status on mt7663 (Íñigo Huguet) [2043454]
- mt76: connac: fix last_chan configuration in mt76_connac_mcu_rate_txpower_band (Íñigo Huguet) [2043454]
- mt76: mt7921: use correct iftype data on 6GHz cap init (Íñigo Huguet) [2043454]
- mt76: mt7921: fix boolreturn.cocci warning (Íñigo Huguet) [2043454]
- mt76: mt7615: fix unused tx antenna mask in testmode (Íñigo Huguet) [2043454]
- mt76: fix the wiphy's available antennas to the correct value (Íñigo Huguet) [2043454]
- mt76: connac: fix a theoretical NULL pointer dereference in mt76_connac_get_phy_mode (Íñigo Huguet) [2043454]
- mt76: mt7921: fix possible NULL pointer dereference in mt7921_mac_write_txwi (Íñigo Huguet) [2043454]
- mt76: fix possible OOB issue in mt76_calculate_default_rate (Íñigo Huguet) [2043454]
- mt76: debugfs: fix queue reporting for mt76-usb (Íñigo Huguet) [2043454]
- mt76: mt7915: fix SMPS operation fail (Íñigo Huguet) [2043454]
- mt76: mt7915: fix return condition in mt7915_tm_reg_backup_restore() (Íñigo Huguet) [2043454]
- mt76: mt7921: fix MT7921E reset failure (Íñigo Huguet) [2043454]
- mt76: mt7615: fix possible deadlock while mt7615_register_ext_phy() (Íñigo Huguet) [2043454]
- mt76: mt7921: drop offload_flags overwritten (Íñigo Huguet) [2043454]
- mt76: mt7915: get rid of mt7915_mcu_set_fixed_rate routine (Íñigo Huguet) [2043454]
- bus: mhi: core: Use correctly sized arguments for bit field (Íñigo Huguet) [2043454]
- bus: mhi: core: Fix race while handling SYS_ERR at power up (Íñigo Huguet) [2043454]
- bus: mhi: core: Fix reading wake_capable channel configuration (Íñigo Huguet) [2043454]
- bus: mhi: core: Minor style and comment fixes (Íñigo Huguet) [2043454]
- bus: mhi: pci_generic: Graceful shutdown on freeze (Íñigo Huguet) [2043454]
- ath11k: Fix a NULL pointer dereference in ath11k_mac_op_hw_scan() (Íñigo Huguet) [2043454]
- mt76: remove variable set but not used (Íñigo Huguet) [2043454]
- ath11k: Fix deleting uninitialized kernel timer during fragment cache flush (Íñigo Huguet) [2043454]
- ath11k: add spectral/CFR buffer validation support (Íñigo Huguet) [2043454]
- ath11k: Fix buffer overflow when scanning with extraie (Íñigo Huguet) [2043454]
- mwifiex: Fix possible ABBA deadlock (Íñigo Huguet) [2043454]
- ath10k: fix scan abort when duration is set for hw scan (Íñigo Huguet) [2043454]
- ath10k: Fix tx hanging (Íñigo Huguet) [2043454]
- iwlwifi: Fix FW name for gl (Íñigo Huguet) [2043454]
- iwlwifi: add support for Bz-Z HW (Íñigo Huguet) [2043454]
- iwlwifi: acpi: fix wgds rev 3 size (Íñigo Huguet) [2043454]
- iwlwifi: mvm: avoid clearing a just saved session protection id (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Fix wrong documentation for scan request command (Íñigo Huguet) [2043454]
- iwlwifi: mvm: synchronize with FW after multicast commands (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix delBA vs. NSSN queue sync race (Íñigo Huguet) [2043454]
- ath11k: Fix QMI file type enum value (Íñigo Huguet) [2043454]
- ath11k: add support for WCN6855 hw2.1 (Íñigo Huguet) [2043454]
- ath10k: Fix the MTU size on QCA9377 SDIO (Íñigo Huguet) [2043454]
- wireless: iwlwifi: Fix a double free in iwl_txq_dyn_alloc_dma (Íñigo Huguet) [2043454]
- mwifiex: Ignore BTCOEX events from the 88W8897 firmware (Íñigo Huguet) [2043454]
- mwifiex: Fix skb_over_panic in mwifiex_usb_recv() (Íñigo Huguet) [2043454]
- ath11k: Use host CE parameters for CE interrupts configuration (Íñigo Huguet) [2043454]
- ath11k: Fix mon status ring rx tlv processing (Íñigo Huguet) [2043454]
- ath11k: skip sending vdev down for channel switch (Íñigo Huguet) [2043454]
- ath11k: fix read fail for htt_stats and htt_peer_stats for single pdev (Íñigo Huguet) [2043454]
- ath11k: Set IRQ affinity to CPU0 in case of one MSI vector (Íñigo Huguet) [2043454]
- ath11k: do not restore ASPM in case of single MSI vector (Íñigo Huguet) [2043454]
- ath11k: add support one MSI vector (Íñigo Huguet) [2043454]
- ath11k: refactor multiple MSI vector implementation (Íñigo Huguet) [2043454]
- ath11k: use ATH11K_PCI_IRQ_DP_OFFSET for DP IRQ (Íñigo Huguet) [2043454]
- ath11k: add CE and ext IRQ flag to indicate irq_handler (Íñigo Huguet) [2043454]
- ath11k: get msi_data again after request_irq is called (Íñigo Huguet) [2043454]
- ath9k: fix intr_txqs setting (Íñigo Huguet) [2043454]
- ath11k: add hw_param for wakeup_mhi (Íñigo Huguet) [2043454]
- ath11k: reset RSN/WPA present state for open BSS (Íñigo Huguet) [2043454]
- ath11k: clear the keys properly via DISABLE_KEY (Íñigo Huguet) [2043454]
- ath11k: Fix crash caused by uninitialized TX ring (Íñigo Huguet) [2043454]
- ath11k: use cache line aligned buffers for dbring (Íñigo Huguet) [2043454]
- ath11k: Fix ETSI regd with weather radar overlap (Íñigo Huguet) [2043454]
- ath11k: fix FCS_ERR flag in radio tap header (Íñigo Huguet) [2043454]
- ath11k: fix the value of msecs_to_jiffies in ath11k_debugfs_fw_stats_request (Íñigo Huguet) [2043454]
- ath11k: fix firmware crash during channel switch (Íñigo Huguet) [2043454]
- ath11k: Fix 'unused-but-set-parameter' error (Íñigo Huguet) [2043454]
- ath11k: fix DMA memory free in CE pipe cleanup (Íñigo Huguet) [2043454]
- ath11k: fix error routine when fallback of add interface fails (Íñigo Huguet) [2043454]
- ath11k: fix fw crash due to peer get authorized before key install (Íñigo Huguet) [2043454]
- ath11k: Clear auth flag only for actual association in security mode (Íñigo Huguet) [2043454]
- ath11k: Send PPDU_STATS_CFG with proper pdev mask to firmware (Íñigo Huguet) [2043454]
- ath11k: set correct NL80211_FEATURE_DYNAMIC_SMPS for WCN6855 (Íñigo Huguet) [2043454]
- mac80211: mesh: embedd mesh_paths and mpp_paths into ieee80211_if_mesh (Íñigo Huguet) [2043454]
- mac80211: initialize variable have_higher_than_11mbit (Íñigo Huguet) [2043454]
- mac80211: fix locking in ieee80211_start_ap error path (Íñigo Huguet) [2043454]
- mac80211: do drv_reconfig_complete() before restarting all (Íñigo Huguet) [2043454]
- mac80211: mark TX-during-stop for TX in in_reconfig (Íñigo Huguet) [2043454]
- mac80211: update channel context before station state (Íñigo Huguet) [2043454]
- mac80211: Fix the size used for building probe request (Íñigo Huguet) [2043454]
- mac80211: fix lookup when adding AddBA extension element (Íñigo Huguet) [2043454]
- mac80211: validate extended element ID is present (Íñigo Huguet) [2043454]
- cfg80211: Acquire wiphy mutex on regulatory work (Íñigo Huguet) [2043454]
- mac80211: agg-tx: don't schedule_and_wake_txq() under sta->lock (Íñigo Huguet) [2043454]
- nl80211: remove reload flag from regulatory_request (Íñigo Huguet) [2043454]
- mac80211: send ADDBA requests using the tid/queue of the aggregation session (Íñigo Huguet) [2043454]
- bus: mhi: core: Add support for forced PM resume (Íñigo Huguet) [2043454]
- mt76: mt7921: fix build regression (Íñigo Huguet) [2043454]
- brcmsmac: rework LED dependencies (Íñigo Huguet) [2043454]
- iwlwifi: fix LED dependencies (Íñigo Huguet) [2043454]
- iwlwifi: mvm: don't crash on invalid rate w/o STA (Íñigo Huguet) [2043454]
- bus: mhi: pci_generic: Fix device recovery failed issue (Íñigo Huguet) [2043454]
- mt76: fix key pointer overwrite in mt7921s_write_txwi/mt7663_usb_sdio_write_txwi (Íñigo Huguet) [2043454]
- rt2x00: do not mark device gone on EPROTO errors during start (Íñigo Huguet) [2043454]
- nl80211: reset regdom when reloading regdb (Íñigo Huguet) [2043454]
- mac80211: add docs for ssn in struct tid_ampdu_tx (Íñigo Huguet) [2043454]
- mac80211: fix a memory leak where sta_info is not freed (Íñigo Huguet) [2043454]
- mac80211: set up the fwd_skb->dev for mesh forwarding (Íñigo Huguet) [2043454]
- mac80211: fix regression in SSN handling of addba tx (Íñigo Huguet) [2043454]
- mac80211: fix rate control for retransmitted frames (Íñigo Huguet) [2043454]
- mac80211: track only QoS data frames for admission control (Íñigo Huguet) [2043454]
- mac80211: fix TCP performance on mesh interface (Íñigo Huguet) [2043454]
- mt76: fix possible pktid leak (Íñigo Huguet) [2043454]
- mt76: fix timestamp check in tx_status (Íñigo Huguet) [2043454]
- mt76: mt7915: fix NULL pointer dereference in mt7915_get_phy_mode (Íñigo Huguet) [2043454]
- rtw89: update partition size of firmware header on skb->data (Íñigo Huguet) [2043454]
- iwlwifi: Fix memory leaks in error handling path (Íñigo Huguet) [2043454]
- iwlwifi: fix warnings produced by kernel debug options (Íñigo Huguet) [2043454]
- iwlwifi: mvm: retry init flow if failed (Íñigo Huguet) [2043454]
- iwlwifi: Fix missing error code in iwl_pci_probe() (Íñigo Huguet) [2043454]
- iwlwifi: pcie: fix constant-conversion warning (Íñigo Huguet) [2043454]
- mac80211: fix throughput LED trigger (Íñigo Huguet) [2043454]
- mac80211: fix monitor_sdata RCU/locking assertions (Íñigo Huguet) [2043454]
- mac80211: drop check for DONT_REORDER in __ieee80211_select_queue (Íñigo Huguet) [2043454]
- mac80211: fix radiotap header generation (Íñigo Huguet) [2043454]
- mac80211: do not access the IV when it was stripped (Íñigo Huguet) [2043454]
- nl80211: fix radio statistics in survey dump (Íñigo Huguet) [2043454]
- cfg80211: call cfg80211_stop_ap when switch from P2P_GO type (Íñigo Huguet) [2043454]
- mwifiex: fix division by zero in fw download path (Íñigo Huguet) [2043454]
- iwlwifi: bump FW API to 67 for AX devices (Íñigo Huguet) [2043454]
- iwlwifi: mvm: extend session protection on association (Íñigo Huguet) [2043454]
- iwlwifi: rename CHANNEL_SWITCH_NOA_NOTIF to CHANNEL_SWITCH_START_NOTIF (Íñigo Huguet) [2043454]
- iwlwifi: mvm: remove session protection on disassoc (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix WGDS table print in iwl_mvm_chub_update_mcc() (Íñigo Huguet) [2043454]
- iwlwifi: rename GEO_TX_POWER_LIMIT to PER_CHAIN_LIMIT_OFFSET_CMD (Íñigo Huguet) [2043454]
- iwlwifi: mvm: d3: use internal data representation (Íñigo Huguet) [2043454]
- iwlwifi: mvm: update RFI TLV (Íñigo Huguet) [2043454]
- iwlwifi: mvm: don't get address of mvm->fwrt just to dereference as a pointer (Íñigo Huguet) [2043454]
- iwlwifi: yoyo: support for ROM usniffer (Íñigo Huguet) [2043454]
- iwlwifi: fw: uefi: add missing include guards (Íñigo Huguet) [2043454]
- iwlwifi: dump host monitor data when NIC doesn't init (Íñigo Huguet) [2043454]
- iwlwifi: pcie: simplify iwl_pci_find_dev_info() (Íñigo Huguet) [2043454]
- iwlwifi: ACPI: support revision 3 WGDS tables (Íñigo Huguet) [2043454]
- iwlwifi: pcie: update sw error interrupt for BZ family (Íñigo Huguet) [2043454]
- iwlwifi: add new pci SoF with JF (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Use all Rx chains for roaming scan (Íñigo Huguet) [2043454]
- iwlwifi: pcie: remove two duplicate PNJ device entries (Íñigo Huguet) [2043454]
- iwlwifi: pcie: refactor dev_info lookup (Íñigo Huguet) [2043454]
- iwlwifi: pcie: remove duplicate entry (Íñigo Huguet) [2043454]
- iwlwifi: pcie: fix killer name matching for AX200 (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix some kerneldoc issues (Íñigo Huguet) [2043454]
- ath10k: fix division by zero in send path (Íñigo Huguet) [2043454]
- ath10k: fix control-message timeout (Íñigo Huguet) [2043454]
- rtw89: Fix variable dereferenced before check 'sta' (Íñigo Huguet) [2043454]
- rtw89: fix return value in hfc_pub_cfg_chk (Íñigo Huguet) [2043454]
- rtw89: remove duplicate register definitions (Íñigo Huguet) [2043454]
- rtw89: fix error function parameter (Íñigo Huguet) [2043454]
- ath10k: fix module load regression with iram-recovery feature (Íñigo Huguet) [2043454]
- ath10k: fix invalid dma_addr_t token assignment (Íñigo Huguet) [2043454]
- ath11k: change return buffer manager for QCA6390 (Íñigo Huguet) [2043454]
- mt76: connac: fix unresolved symbols when CONFIG_PM is unset (Íñigo Huguet) [2043454]
- mt76: Make use of the helper macro kthread_run() (Íñigo Huguet) [2043454]
- mt76: Print error message when reading EEPROM from mtd failed (Íñigo Huguet) [2043454]
- mt76: mt7921: disable 4addr capability (Íñigo Huguet) [2043454]
- mt76: mt7915: add debugfs knobs for MCU utilization (Íñigo Huguet) [2043454]
- mt76: mt7915: add WA firmware log support (Íñigo Huguet) [2043454]
- mt76: mt7915: fix endiannes warning mt7915_mcu_beacon_check_caps (Íñigo Huguet) [2043454]
- mt76: mt7915: rework debugfs fixed-rate knob (Íñigo Huguet) [2043454]
- mt76: mt7915: rework .set_bitrate_mask() to support more options (Íñigo Huguet) [2043454]
- mt76: mt7915: remove mt7915_mcu_add_he() (Íñigo Huguet) [2043454]
- mt76: mt7615: apply cached RF data for DBDC (Íñigo Huguet) [2043454]
- mt76: mt7615: mt7622: fix ibss and meshpoint (Íñigo Huguet) [2043454]
- mt76: mt7921: fix Wformat build warning (Íñigo Huguet) [2043454]
- mt76: mt7921: fix mt7921s Kconfig (Íñigo Huguet) [2043454]
- iwlwifi: pnvm: print out the version properly (Íñigo Huguet) [2043454]
- iwlwifi: dbg: treat non active regions as unsupported regions (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Read acpi dsm to get channel activation bitmap (Íñigo Huguet) [2043454]
- iwlwifi: add new device id 7F70 (Íñigo Huguet) [2043454]
- iwlwifi: mvm: improve log when processing CSA (Íñigo Huguet) [2043454]
- iwlwifi: mvm: set BT-coex high priority for 802.1X/4-way-HS (Íñigo Huguet) [2043454]
- iwlwifi: dbg: treat dbgc allocation failure when tlv is missing (Íñigo Huguet) [2043454]
- iwlwifi: add new killer devices to the driver (Íñigo Huguet) [2043454]
- iwlwifi: mvm: set inactivity timeouts also for PS-poll (Íñigo Huguet) [2043454]
- iwlwifi: pcie: try to grab NIC access early (Íñigo Huguet) [2043454]
- iwlwifi: mvm: reduce WARN_ON() in TX status path (Íñigo Huguet) [2043454]
- iwlwifi: allow rate-limited error messages (Íñigo Huguet) [2043454]
- iwlwifi: mvm: remove session protection after auth/assoc (Íñigo Huguet) [2043454]
- iwlwifi: remove redundant iwl_finish_nic_init() argument (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Add RTS and CTS flags to iwl_tx_cmd_flags. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: remove csi from iwl_mvm_pass_packet_to_mac80211() (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new rate_n_flags for REPLY_RX_MPDU_CMD and RX_NO_DATA_NOTIF (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new TX_RSP and COMPRESSED_BA_RES versions (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new version of BEACON_TEMPLATE_CMD. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Add support for new rate_n_flags in tx_cmd. (Íñigo Huguet) [2043454]
- iwlwifi: BZ Family SW reset support (Íñigo Huguet) [2043454]
- iwlwifi: BZ Family BUS_MASTER_DISABLE_REQ code duplication (Íñigo Huguet) [2043454]
- iwlwifi: yoyo: fw debug config from context info and preset (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support new version of ranging response notification (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Support version 3 of tlc_update_notif. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: convert old rate & flags to the new format. (Íñigo Huguet) [2043454]
- iwlwifi: mvm: add definitions for new rate & flags (Íñigo Huguet) [2043454]
- iwlwifi: mvm: update definitions due to new rate & flags (Íñigo Huguet) [2043454]
- iwlwifi: mvm: scrub key material in firmware dumps (Íñigo Huguet) [2043454]
- iwlwifi: parse debug exclude data from firmware file (Íñigo Huguet) [2043454]
- iwlwifi: fw dump: add infrastructure for dump scrubbing (Íñigo Huguet) [2043454]
- iwlwifi: mvm: correct sta-state logic for TDLS (Íñigo Huguet) [2043454]
- iwlwifi: api: fix struct iwl_wowlan_status_v7 kernel-doc (Íñigo Huguet) [2043454]
- iwlwifi: fix fw/img.c license statement (Íñigo Huguet) [2043454]
- iwlwifi: remove contact information (Íñigo Huguet) [2043454]
- iwlwifi: remove MODULE_AUTHOR() statements (Íñigo Huguet) [2043454]
- iwlwifi: api: remove unused RX status bits (Íñigo Huguet) [2043454]
- iwlwifi: add some missing kernel-doc in struct iwl_fw (Íñigo Huguet) [2043454]
- iwlwifi: mvm: Remove antenna c references (Íñigo Huguet) [2043454]
- iwlwifi: mvm: add support for 160Mhz in ranging measurements (Íñigo Huguet) [2043454]
- iwlwifi: add vendor specific capabilities for some RFs (Íñigo Huguet) [2043454]
- iwlwifi: mvm: add lmac/umac PC info in case of error (Íñigo Huguet) [2043454]
- iwlwifi: mvm: disable RX-diversity in powersave (Íñigo Huguet) [2043454]
- iwlwifi: mvm: fix ieee80211_get_he_iftype_cap() iftype (Íñigo Huguet) [2043454]
- iwlwifi: Start scratch debug register for Bz family (Íñigo Huguet) [2043454]
- iwlwifi: Add support for more BZ HWs (Íñigo Huguet) [2043454]
- iwlwifi: Add support for getting rf id with blank otp (Íñigo Huguet) [2043454]
- cfg80211: fix kernel-doc for MBSSID EMA (Íñigo Huguet) [2043454]
- mac80211: Prevent AP probing during suspend (Íñigo Huguet) [2043454]
- nl80211: Add LC placeholder band definition to nl80211_band (Íñigo Huguet) [2043454]
- mac80211: split beacon retrieval functions (Íñigo Huguet) [2043454]
- cfg80211: separate get channel number from ies (Íñigo Huguet) [2043454]
- mac80211: use ieee80211_bss_get_elem() in most places (Íñigo Huguet) [2043454]
- cfg80211: scan: use element finding functions in easy cases (Íñigo Huguet) [2043454]
- nl80211: use element finding functions (Íñigo Huguet) [2043454]
- mac80211: fils: use cfg80211_find_ext_elem() (Íñigo Huguet) [2043454]
- mac80211: fix memory leaks with element parsing (Íñigo Huguet) [2043454]
- cfg80211: prepare for const netdev->dev_addr (Íñigo Huguet) [2043454]
- mac80211: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- wireless: mac80211_hwsim: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- mac80211: debugfs: calculate free buffer size correctly (Íñigo Huguet) [2043454]
- fq_codel: generalise ce_threshold marking for subset of traffic (Íñigo Huguet) [2043454]
- wl3501_cs: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- ray_cs: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- wilc1000: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- brcmfmac: prepare for const netdev->dev_addr (Íñigo Huguet) [2043454]
- wireless: use eth_hw_addr_set() instead of ether_addr_copy() (Íñigo Huguet) [2043454]
- wireless: use eth_hw_addr_set() (Íñigo Huguet) [2043454]
- iwlwifi: cfg: set low-latency-xtal for some integrated So devices (Íñigo Huguet) [2043454]
- iwlwifi: pnvm: read EFI data only if long enough (Íñigo Huguet) [2043454]
- iwlwifi: pnvm: don't kmemdup() more than we have (Íñigo Huguet) [2043454]
- iwlwifi: change all JnP to NO-160 configuration (Íñigo Huguet) [2043454]
- iwlwifi: mvm: reset PM state on unsuccessful resume (Íñigo Huguet) [2043454]
- mwifiex: Deactive host sleep using HSCFG after it was activated manually (Íñigo Huguet) [2043454]
- mwifiex: Send DELBA requests according to spec (Íñigo Huguet) [2043454]
- mwifiex: Fix an incorrect comment (Íñigo Huguet) [2043454]
- mwifiex: Log an error on command failure during key-material upload (Íñigo Huguet) [2043454]
- mwifiex: Don't log error on suspend if wake-on-wlan is disabled (Íñigo Huguet) [2043454]
- rtw89: remove unneeded semicolon (Íñigo Huguet) [2043454]
- rtw89: fix return value check in rtw89_cam_send_sec_key_cmd() (Íñigo Huguet) [2043454]
- mt76: mt7915: change max rx len limit of hw modules (Íñigo Huguet) [2043454]
- mt76: mt7915: fix missing HE phy cap (Íñigo Huguet) [2043454]
- mt76: mt7915: rework mt7915_mcu_sta_muru_tlv() (Íñigo Huguet) [2043454]
- mt76: mt7915: enable HE UL MU-MIMO (Íñigo Huguet) [2043454]
- mt76: mt7921: add per-vif counters in ethtool (Íñigo Huguet) [2043454]
- mt76: mt7921: move tx amsdu stats in mib_stats (Íñigo Huguet) [2043454]
- mt76: mt7921: add sta stats accounting in mt7921_mac_add_txs_skb (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce stats reporting through ethtool (Íñigo Huguet) [2043454]
- mt76: mt7921: add some more MIB counters (Íñigo Huguet) [2043454]
- mt76: do not reset MIB counters in get_stats callback (Íñigo Huguet) [2043454]
- mt76: mt7915: move tx amsdu stats in mib_stats (Íñigo Huguet) [2043454]
- mt76: mt7915: run mt7915_get_et_stats holding mt76 mutex (Íñigo Huguet) [2043454]
- mt76: move mt76_ethtool_worker_info in mt76 module (Íñigo Huguet) [2043454]
- mt76: move mt76_sta_stats in mt76.h (Íñigo Huguet) [2043454]
- mt76: mt76x0: correct VHT MCS 8/9 tx power eeprom offset (Íñigo Huguet) [2043454]
- mt76: mt7921s: add reset support (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce mt7921s support (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor mt7921_mcu_send_message (Íñigo Huguet) [2043454]
- mt76: mt7921: rely on mcu_get_nic_capability (Íñigo Huguet) [2043454]
- mt76: connac: extend mcu_get_nic_capability (Íñigo Huguet) [2043454]
- mt76: sdio: extend sdio module to support CONNAC2 (Íñigo Huguet) [2043454]
- mt76: sdio: introduce parse_irq callback (Íñigo Huguet) [2043454]
- mt76: sdio: move common code in mt76_sdio module (Íñigo Huguet) [2043454]
- mt76: mt7921: use physical addr to unify register access (Íñigo Huguet) [2043454]
- mt76: mt7921: make all event parser reusable between mt7921s and mt7921e (Íñigo Huguet) [2043454]
- mt76: mt7663s: rely on mcu reg access utility (Íñigo Huguet) [2043454]
- mt76: connac: move mcu reg access utility routines in mt76_connac_lib module (Íñigo Huguet) [2043454]
- mt76: mt7921: add MT7921_COMMON module (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor init.c to be bus independent (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor mcu.c to be bus independent (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor dma.c to be pcie specific (Íñigo Huguet) [2043454]
- mt76: mt7921: refactor mac.c to be bus independent (Íñigo Huguet) [2043454]
- mt76: mt7921: add MU EDCA cmd support (Íñigo Huguet) [2043454]
- mt76: mt7915: remove dead code in debugfs code (Íñigo Huguet) [2043454]
- mt76: sdio: export mt76s_alloc_rx_queue and mt76s_alloc_tx routines (Íñigo Huguet) [2043454]
- mt76: mt7915: improve code readability for xmit-queue handler (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt76 debugfs sub-dir for ext-phy (Íñigo Huguet) [2043454]
- mt76: rely on phy pointer in mt76_register_debugfs_fops routine signature (Íñigo Huguet) [2043454]
- mt76: mt7915: set muru platform type (Íñigo Huguet) [2043454]
- mt76: mt7915: set VTA bit in tx descriptor (Íñigo Huguet) [2043454]
- mt76: mt7915: fix muar_idx in mt7915_mcu_alloc_sta_req() (Íñigo Huguet) [2043454]
- mt76: mt7915: rework starec TLV tags (Íñigo Huguet) [2043454]
- mt76: mt7915: fix sta_rec_wtbl tag len (Íñigo Huguet) [2043454]
- mt76: mt7915: improve starec readability of txbf (Íñigo Huguet) [2043454]
- mt76: mt7915: fix txbf starec TLV issues (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt7915_mcu_beacon_check_caps() (Íñigo Huguet) [2043454]
- mt76: connac: fix possible NULL pointer dereference in mt76_connac_get_phy_mode_v2 (Íñigo Huguet) [2043454]
- mt76: do not access 802.11 header in ccmp check for 802.3 rx skbs (Íñigo Huguet) [2043454]
- mt76: use a separate CCMP PN receive counter for management frames (Íñigo Huguet) [2043454]
- mt76: mt7921: add delay config for sched scan (Íñigo Huguet) [2043454]
- mt76: mt7615: fix monitor mode tear down crash (Íñigo Huguet) [2043454]
- mt76: debugfs: improve queue node readability (Íñigo Huguet) [2043454]
- mt76: mt7915: add twt_stats knob in debugfs (Íñigo Huguet) [2043454]
- mt76: mt7915: enable twt responder capability (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt7915_mac_add_twt_setup routine (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce mt7915_mcu_twt_agrt_update mcu command (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce __mt7915_get_tsf routine (Íñigo Huguet) [2043454]
- mt76: drop MCU header size from buffer size in __mt76_mcu_send_firmware (Íñigo Huguet) [2043454]
- mt76: introduce __mt76_mcu_send_firmware routine (Íñigo Huguet) [2043454]
- mt76: support reading EEPROM data embedded in fdt (Íñigo Huguet) [2043454]
- mt76: schedule status timeout at dma completion (Íñigo Huguet) [2043454]
- mt76: substitute sk_buff_head status_list with spinlock_t status_lock (Íñigo Huguet) [2043454]
- mt76: remove mt76_wcid pointer from mt76_tx_status_check signature (Íñigo Huguet) [2043454]
- mt76: introduce packet_id idr (Íñigo Huguet) [2043454]
- mt76: mt7921: add 6GHz support (Íñigo Huguet) [2043454]
- mt76: add 6GHz support (Íñigo Huguet) [2043454]
- mt76: connac: enable hw amsdu @ 6GHz (Íñigo Huguet) [2043454]
- mt76: connac: add 6GHz support to mt76_connac_mcu_uni_add_bss (Íñigo Huguet) [2043454]
- mt76: connac: add 6GHz support to mt76_connac_mcu_sta_tlv (Íñigo Huguet) [2043454]
- mt76: connac: set 6G phymode in single-sku support (Íñigo Huguet) [2043454]
- mt76: connac: add 6GHz support to mt76_connac_mcu_set_channel_domain (Íñigo Huguet) [2043454]
- mt76: connac: enable 6GHz band for hw scan (Íñigo Huguet) [2043454]
- mt76: connac: set 6G phymode in mt76_connac_get_phy_mode{,v2} (Íñigo Huguet) [2043454]
- mt76: mt7915: add mib counters to ethtool stats (Íñigo Huguet) [2043454]
- mt76: mt7915: add more MIB registers (Íñigo Huguet) [2043454]
- mt76: mt7915: add tx mu/su counters to mib (Íñigo Huguet) [2043454]
- mt76: mt7915: add some per-station tx stats to ethtool (Íñigo Huguet) [2043454]
- mt76: mt7915: add tx stats gathered from tx-status callbacks (Íñigo Huguet) [2043454]
- mt76: mt7915: add ethtool stats support (Íñigo Huguet) [2043454]
- mt76: mt7921: fix retrying release semaphore without end (Íñigo Huguet) [2043454]
- mt76: mt7921: robustify hardware initialization flow (Íñigo Huguet) [2043454]
- mt76: mt7915: fix possible infinite loop release semaphore (Íñigo Huguet) [2043454]
- mt76: mt7915: honor all possible error conditions in mt7915_mcu_init() (Íñigo Huguet) [2043454]
- mt76: move spin_lock_bh to spin_lock in tasklet (Íñigo Huguet) [2043454]
- mt76: mt7921: remove mt7921_sta_stats (Íñigo Huguet) [2043454]
- mt76: mt7921: remove mcu rate reporting code (Íñigo Huguet) [2043454]
- mt76: mt7921: report tx rate directly from tx status (Íñigo Huguet) [2043454]
- mt76: mt7921: add support for tx status reporting (Íñigo Huguet) [2043454]
- mt76: mt7921: start reworking tx rate reporting (Íñigo Huguet) [2043454]
- mt76: mt7615: fix hwmon temp sensor mem use-after-free (Íñigo Huguet) [2043454]
- mt76: mt7915: fix hwmon temp sensor mem use-after-free (Íñigo Huguet) [2043454]
- mt76: mt7915: enable configured beacon tx rate (Íñigo Huguet) [2043454]
- mt76: disable BH around napi_schedule() calls (Íñigo Huguet) [2043454]
- mt76: fill boottime_ns in Rx path (Íñigo Huguet) [2043454]
- mt76: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2043454]
- mt76: fix boolreturn.cocci warnings (Íñigo Huguet) [2043454]
- mt76: mt7921: update mib counters dumping phy stats (Íñigo Huguet) [2043454]
- mt76: mt7921: always wake device if necessary in debugfs (Íñigo Huguet) [2043454]
- mt76: mt7915: rename debugfs tx-queues (Íñigo Huguet) [2043454]
- mt76: mt7915: rework debugfs queue info (Íñigo Huguet) [2043454]
- mt76: mt7921: move mt7921_queue_rx_skb to mac.c (Íñigo Huguet) [2043454]
- mt76: mt7915: fix WMM index on DBDC cards (Íñigo Huguet) [2043454]
- mt76: mt7915: improve code readability in mt7915_mcu_sta_bfer_ht (Íñigo Huguet) [2043454]
- mt76: mt7915: introduce bss coloring support (Íñigo Huguet) [2043454]
- mt76: mt7915: add LED support (Íñigo Huguet) [2043454]
- mt76: mt7915: fix potential NPE in TXS processing (Íñigo Huguet) [2043454]
- mt76: mt7915: fix he_mcs capabilities for 160mhz (Íñigo Huguet) [2043454]
- mt76: use IEEE80211_OFFLOAD_ENCAP_ENABLED instead of MT_DRV_AMSDU_OFFLOAD (Íñigo Huguet) [2043454]
- mt76: mt7915: update mac timing settings (Íñigo Huguet) [2043454]
- mt76: mt7921: fix endianness warnings in mt7921_mac_decode_he_mu_radiotap (Íñigo Huguet) [2043454]
- mt76: mt7921: fix kernel warning from cfg80211_calculate_bitrate (Íñigo Huguet) [2043454]
- mt76: mt7921: fix firmware usage of RA info using legacy rates (Íñigo Huguet) [2043454]
- mt76: mt7915: add HE-LTF into fixed rate command (Íñigo Huguet) [2043454]
- mt76: mt7921: report HE MU radiotap (Íñigo Huguet) [2043454]
- mt76: mt7615: move mt7615_mcu_set_p2p_oppps in mt76_connac module (Íñigo Huguet) [2043454]
- mt76: overwrite default reg_ops if necessary (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce mt7921_mcu_set_beacon_filter utility routine (Íñigo Huguet) [2043454]
- mt76: mt7921: get rid of mt7921_mac_set_beacon_filter (Íñigo Huguet) [2043454]
- mt76: mt7921: get rid of monitor_vif (Íñigo Huguet) [2043454]
- mt76: connac: add support for limiting to maximum regulatory Tx power (Íñigo Huguet) [2043454]
- mt76: connac: fix GTK rekey offload failure on WPA mixed mode (Íñigo Huguet) [2043454]
- mt76: mt7921: fix dma hang in rmmod (Íñigo Huguet) [2043454]
- mt76: add support for setting mcast rate (Íñigo Huguet) [2043454]
- mt76: mt7915: fix bit fields for HT rate idx (Íñigo Huguet) [2043454]
- mt76: mt7915: switch proper tx arbiter mode in testmode (Íñigo Huguet) [2043454]
- mt76: mt7915: fix potential overflow of eeprom page index (Íñigo Huguet) [2043454]
- mt76: mt7921: send EAPOL frames at lowest rate (Íñigo Huguet) [2043454]
- mt76: mt7915: send EAPOL frames at lowest rate (Íñigo Huguet) [2043454]
- mt76: mt7915: add control knobs for thermal throttling (Íñigo Huguet) [2043454]
- mt76: mt7921: Add mt7922 support (Íñigo Huguet) [2043454]
- mt76: mt7615: fix skb use-after-free on mac reset (Íñigo Huguet) [2043454]
- mt76: mt7921: Fix out of order process by invalid event pkt (Íñigo Huguet) [2043454]
- mt76: mt7915: fix mgmt frame using unexpected bitrate (Íñigo Huguet) [2043454]
- mt76: mt7921: fix mgmt frame using unexpected bitrate (Íñigo Huguet) [2043454]
- mt76: add mt76_default_basic_rate more devices can rely on (Íñigo Huguet) [2043454]
- mt76: mt7921: introduce testmode support (Íñigo Huguet) [2043454]
- mt76: mt7915: remove mt7915_sta_stats (Íñigo Huguet) [2043454]
- mt76: mt7915: report tx rate directly from tx status (Íñigo Huguet) [2043454]
- mt76: mt7915: cleanup -Wunused-but-set-variable (Íñigo Huguet) [2043454]
- mt76: mt7915: take RCU read lock when calling ieee80211_bss_get_elem() (Íñigo Huguet) [2043454]
- mt76: mt7915: fix an off-by-one bound check (Íñigo Huguet) [2043454]
- mt76: mt7921: add .set_sar_specs support (Íñigo Huguet) [2043454]
- mt76: mt7915: adapt new firmware to update BA winsize for Rx session (Íñigo Huguet) [2043454]
- mt76: mt7915: report HE MU radiotap (Íñigo Huguet) [2043454]
- mt76: mt76x02: fix endianness warnings in mt76x02_mac.c (Íñigo Huguet) [2043454]
- mt76: mt7921: fix survey-dump reporting (Íñigo Huguet) [2043454]
- mt76: fix build error implicit enumeration conversion (Íñigo Huguet) [2043454]
- mt76: mt7921: enable aspm by default (Íñigo Huguet) [2043454]
- mt76: connac: fix mt76_connac_gtk_rekey_tlv usage (Íñigo Huguet) [2043454]
- mt76: mt7915: fix calling mt76_wcid_alloc with incorrect parameter (Íñigo Huguet) [2043454]
- mt76: mt7915: fix info leak in mt7915_mcu_set_pre_cal() (Íñigo Huguet) [2043454]
- mt76: mt7615: fix endianness warning in mt7615_mac_write_txwi (Íñigo Huguet) [2043454]
- mt76: mt7921: fix endianness warning in mt7921_update_txs (Íñigo Huguet) [2043454]
- mt76: mt7915: fix endianness warning in mt7915_mac_add_txs_skb (Íñigo Huguet) [2043454]
- mt76: mt7921: avoid unnecessary spin_lock/spin_unlock in mt7921_mcu_tx_done_event (Íñigo Huguet) [2043454]
- mt76: mt7921: fix endianness in mt7921_mcu_tx_done_event (Íñigo Huguet) [2043454]
- rtw89: Remove redundant check of ret after call to rtw89_mac_enable_bb_rf (Íñigo Huguet) [2043454]
- rtw89: Fix two spelling mistakes in debug messages (Íñigo Huguet) [2043454]
- mwifiex: Try waking the firmware until we get an interrupt (Íñigo Huguet) [2043454]
- mwifiex: Read a PCI register after writing the TX ring write pointer (Íñigo Huguet) [2043454]
- fq_codel: implement L4S style ce_threshold_ect1 marking (Íñigo Huguet) [2043454]
- net: add skb_get_dsfield() helper (Íñigo Huguet) [2043454]
- wireless: Remove redundant 'flush_workqueue()' calls (Íñigo Huguet) [2043454]
- mt7601u: Remove redundant initialization of variable ret (Íñigo Huguet) [2043454]
- rtlwifi: rtl8192ee: Remove redundant initialization of variable version (Íñigo Huguet) [2043454]
- rtw89: add Realtek 802.11ax driver (Íñigo Huguet) [2043454]
- ath10k: fix max antenna gain unit (Íñigo Huguet) [2043454]
- ath9k: fix an IS_ERR() vs NULL check (Íñigo Huguet) [2043454]
- ath11k: Identify DFS channel when sending scan channel list command (Íñigo Huguet) [2043454]
- ath9k: support DT ieee80211-freq-limit property to limit channels (Íñigo Huguet) [2043454]
- ath11k: Change number of TCL rings to one for QCA6390 (Íñigo Huguet) [2043454]
- ath11k: Handle MSI enablement during rmmod and SSR (Íñigo Huguet) [2043454]
- ath: dfs_pattern_detector: Fix possible null-pointer dereference in channel_detector_create() (Íñigo Huguet) [2043454]
- ath11k: Use kcalloc() instead of kzalloc() (Íñigo Huguet) [2043454]
- ath11k: Remove redundant assignment to variable fw_size (Íñigo Huguet) [2043454]
- ath11k: fix m68k and xtensa build failure in ath11k_peer_assoc_h_smps() (Íñigo Huguet) [2043454]
- ath11k: Fix spelling mistake "incompaitiblity" -> "incompatibility" (Íñigo Huguet) [2043454]
- ath11k: Remove unused variable in ath11k_dp_rx_mon_merg_msdus() (Íñigo Huguet) [2043454]
- ath9k: Fix potential interrupt storm on queue reset (Íñigo Huguet) [2043454]
- ath9k: add option to reset the wifi chip via debugfs (Íñigo Huguet) [2043454]
- ath10k: Don't always treat modem stop events as crashes (Íñigo Huguet) [2043454]
- rtl8xxxu: Use lower tx rates for the ack packet (Íñigo Huguet) [2043454]
- brcmfmac: Add DMI nvram filename quirk for Cyberbook T116 tablet (Íñigo Huguet) [2043454]
- rtw88: refine fw_crash debugfs to show non-zero while triggering (Íñigo Huguet) [2043454]
- rtw88: fix RX clock gate setting while fifo dump (Íñigo Huguet) [2043454]
- net: qrtr: combine nameservice into main module (Íñigo Huguet) [2043454]
- ath10k: sdio: Add missing BH locking around napi_schdule() (Íñigo Huguet) [2043454]
- ath10k: Fix missing frame timestamp for beacon/probe-resp (Íñigo Huguet) [2043454]
- ath10k: high latency fixes for beacon buffer (Íñigo Huguet) [2043454]
- ath11k: Change DMA_FROM_DEVICE to DMA_TO_DEVICE when map reinjected packets (Íñigo Huguet) [2043454]
- ath11k: support SMPS configuration for 6 GHz (Íñigo Huguet) [2043454]
- ath11k: add 6 GHz params in peer assoc command (Íñigo Huguet) [2043454]
- ieee80211: Add new A-MPDU factor macro for HE 6 GHz peer caps (Íñigo Huguet) [2043454]
- ath11k: indicate to mac80211 scan complete with aborted flag for ATH11K_SCAN_STARTING state (Íñigo Huguet) [2043454]
- ath11k: indicate scan complete for scan canceled when scan running (Íñigo Huguet) [2043454]
- ath11k: add handler for scan event WMI_SCAN_EVENT_DEQUEUED (Íñigo Huguet) [2043454]
- ath11k: add HTT stats support for new stats (Íñigo Huguet) [2043454]
- ath11k: Change masking and shifting in htt stats (Íñigo Huguet) [2043454]
- ath11k: Remove htt stats fixed size array usage (Íñigo Huguet) [2043454]
- ath11k: Replace HTT_DBG_OUT with scnprintf (Íñigo Huguet) [2043454]
- ath11k: Rename macro ARRAY_TO_STRING to PRINT_ARRAY_TO_BUF (Íñigo Huguet) [2043454]
- ath11k: Fix memory leak in ath11k_qmi_driver_event_work (Íñigo Huguet) [2043454]
- ath11k: Fix inaccessible debug registers (Íñigo Huguet) [2043454]
- ath11k: Drop MSDU with length error in DP rx path (Íñigo Huguet) [2043454]
- ath11k: copy cap info of 6G band under WMI_HOST_WLAN_5G_CAP for WCN6855 (Íñigo Huguet) [2043454]
- ath11k: enable 6G channels for WCN6855 (Íñigo Huguet) [2043454]
- ath11k: re-enable ht_cap/vht_cap for 5G band for WCN6855 (Íñigo Huguet) [2043454]
- ath11k: fix survey dump collection in 6 GHz (Íñigo Huguet) [2043454]
- ath11k: fix packet drops due to incorrect 6 GHz freq value in rx status (Íñigo Huguet) [2043454]
- ath11k: add channel 2 into 6 GHz channel list (Íñigo Huguet) [2043454]
- mac80211: MBSSID support in interface handling (Íñigo Huguet) [2043454]
- ath11k: Add wmi peer create conf event in wmi_tlv_event_id (Íñigo Huguet) [2043454]
- ath11k: Avoid "No VIF found" warning message (Íñigo Huguet) [2043454]
- ath11k: Fix crash during firmware recovery on reo cmd ring access (Íñigo Huguet) [2043454]
- ath11k: Assign free_vdev_map value before ieee80211_register_hw (Íñigo Huguet) [2043454]
- ath11k: Add vdev start flag to disable hardware encryption (Íñigo Huguet) [2043454]
- ath11k: Avoid race during regd updates (Íñigo Huguet) [2043454]
- ath11k: Avoid reg rules update during firmware recovery (Íñigo Huguet) [2043454]
- ath11k: Update pdev tx and rx firmware stats (Íñigo Huguet) [2043454]
- ath11k: Fix pktlog lite rx events (Íñigo Huguet) [2043454]
- ath11k: Add support for RX decapsulation offload (Íñigo Huguet) [2043454]
- ath11k: fix some sleeping in atomic bugs (Íñigo Huguet) [2043454]
- ath11k: qmi: avoid error messages when dma allocation fails (Íñigo Huguet) [2043454]
- ath11k: Replace one-element array with flexible-array member (Íñigo Huguet) [2043454]
- ath11k: add caldata download support from EEPROM (Íñigo Huguet) [2043454]
- ath11k: add caldata file for multiple radios (Íñigo Huguet) [2043454]
- ath11k: clean up BDF download functions (Íñigo Huguet) [2043454]
- ath11k: use hw_params to access board_size and cal_offset (Íñigo Huguet) [2043454]
- ath11k: Wstringop-overread warning (Íñigo Huguet) [2043454]
- ath11k: Add spectral scan support for QCN9074 (Íñigo Huguet) [2043454]
- ath11k: Fix the spectral minimum FFT bin count (Íñigo Huguet) [2043454]
- ath11k: Introduce spectral hw configurable param (Íñigo Huguet) [2043454]
- ath11k: Refactor spectral FFT bin size (Íñigo Huguet) [2043454]
- ath11k: add support for 80P80 and 160 MHz bandwidth (Íñigo Huguet) [2043454]
- ath11k: add support for setting fixed HE rate/gi/ltf (Íñigo Huguet) [2043454]
- nl80211: MBSSID and EMA support in AP mode (Íñigo Huguet) [2043454]
- nl80211: don't kfree() ERR_PTR() value (Íñigo Huguet) [2043454]
- cfg80211: always free wiphy specific regdomain (Íñigo Huguet) [2043454]
- mac80211: save transmit power envelope element and power constraint (Íñigo Huguet) [2043454]
- mac80211: add parse regulatory info in 6 GHz operation information (Íñigo Huguet) [2043454]
- ieee80211: add power type definition for 6 GHz (Íñigo Huguet) [2043454]
- mac80211: twt: don't use potentially unaligned pointer (Íñigo Huguet) [2043454]
- cfg80211: AP mode driver offload for FILS association crypto (Íñigo Huguet) [2043454]
- ath11k: monitor mode clean up to use separate APIs (Íñigo Huguet) [2043454]
- ath11k: add separate APIs for monitor mode (Íñigo Huguet) [2043454]
- ath11k: move static function ath11k_mac_vdev_setup_sync to top (Íñigo Huguet) [2043454]
- rtw88: 8821c: correct 2.4G tx power for type 2/4 NIC (Íñigo Huguet) [2043454]
- rtw88: 8821c: support RFE type4 wifi NIC (Íñigo Huguet) [2043454]
- brcmfmac: Replace zero-length array with flexible array member (Íñigo Huguet) [2043454]
- mac80211_hwsim: enable 6GHz channels (Íñigo Huguet) [2043454]
- mac80211: use ieee802_11_parse_elems() in ieee80211_prep_channel() (Íñigo Huguet) [2043454]
- nl80211: don't put struct cfg80211_ap_settings on stack (Íñigo Huguet) [2043454]
- mac80211: always allocate struct ieee802_11_elems (Íñigo Huguet) [2043454]
- mac80211: mlme: find auth challenge directly (Íñigo Huguet) [2043454]
- mac80211: move CRC into struct ieee802_11_elems (Íñigo Huguet) [2043454]
- mac80211: mesh: clean up rx_bcn_presp API (Íñigo Huguet) [2043454]
- mac80211: reduce stack usage in debugfs (Íñigo Huguet) [2043454]
- nl80211: prefer struct_size over open coded arithmetic (Íñigo Huguet) [2043454]
- mac80211: check hostapd configuration parsing twt requests (Íñigo Huguet) [2043454]
- cfg80211: honour V=1 in certificate code generation (Íñigo Huguet) [2043454]
- rt2x00: remove duplicate USB device ID (Íñigo Huguet) [2043454]
- wilc1000: increase config packets response wait timeout limit (Íñigo Huguet) [2043454]
- wilc1000: use correct write command sequence in wilc_spi_sync_ext() (Íñigo Huguet) [2043454]
- wilc1000: add 'initialized' flag check before adding an element to TX queue (Íñigo Huguet) [2043454]
- wilc1000: invoke chip reset register before firmware download (Íñigo Huguet) [2043454]
- wilc1000: ignore clockless registers status response for SPI (Íñigo Huguet) [2043454]
- wilc1000: handle read failure issue for clockless registers (Íñigo Huguet) [2043454]
- wilc1000: add reset/terminate/repeat command support for SPI bus (Íñigo Huguet) [2043454]
- wilc1000: configure registers to handle chip wakeup sequence (Íñigo Huguet) [2043454]
- wilc1000: add new WID to pass wake_enable information to firmware (Íñigo Huguet) [2043454]
- wilc1000: fix possible memory leak in cfg_scan_result() (Íñigo Huguet) [2043454]
- wilc1000: move 'deinit_lock' lock init/destroy inside module probe (Íñigo Huguet) [2043454]
- mwifiex: Fix copy-paste mistake when creating virtual interface (Íñigo Huguet) [2043454]
- mwifiex: Properly initialize private structure on interface type changes (Íñigo Huguet) [2043454]
- mwifiex: Handle interface type changes from AP to STATION (Íñigo Huguet) [2043454]
- mwifiex: Allow switching interface type from P2P_CLIENT to P2P_GO (Íñigo Huguet) [2043454]
- mwifiex: Update virtual interface counters right after setting bss_type (Íñigo Huguet) [2043454]
- mwifiex: Use helper function for counting interface types (Íñigo Huguet) [2043454]
- mwifiex: Run SET_BSS_MODE when changing from P2P to STATION vif-type (Íñigo Huguet) [2043454]
- mwifiex: Use function to check whether interface type change is allowed (Íñigo Huguet) [2043454]
- mwifiex: Small cleanup for handling virtual interface type changes (Íñigo Huguet) [2043454]
- rtw88: move adaptivity mechanism to firmware (Íñigo Huguet) [2043454]
- rtw88: support adaptivity for ETSI/JP DFS region (Íñigo Huguet) [2043454]
- rtw88: add regulatory strategy by chip type (Íñigo Huguet) [2043454]
- rtw88: upgrade rtw_regulatory mechanism and mapping (Íñigo Huguet) [2043454]
- brcmfmac: fix incorrect error prints (Íñigo Huguet) [2043454]
- ath11k: Align bss_chan_info structure with firmware (Íñigo Huguet) [2043454]
- ath11k: add support in survey dump with bss_chan_info (Íñigo Huguet) [2043454]
- ath11k: Rename atf_config to flag1 in target_resource_config (Íñigo Huguet) [2043454]
- ath11k: fix 4addr multicast packet tx (Íñigo Huguet) [2043454]
- ath11k: fix 4-addr tx failure for AP and STA modes (Íñigo Huguet) [2043454]
- ath9k: owl-loader: fetch pci init values through nvmem (Íñigo Huguet) [2043454]
- ath9k: fetch calibration data via nvmem subsystem (Íñigo Huguet) [2043454]

* Wed Feb 23 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-68.rt21.68.el9]
- net: ena: Extract recurring driver reset code into a function (Petr Oros) [2038150]
- net: ena: Change the name of bad_csum variable (Petr Oros) [2038150]
- net: ena: Add debug prints for invalid req_id resets (Petr Oros) [2038150]
- net: ena: Remove ena_calc_queue_size_ctx struct (Petr Oros) [2038150]
- net: ena: Move reset completion print to the reset function (Petr Oros) [2038150]
- net: ena: Remove redundant return code check (Petr Oros) [2038150]
- net: ena: Update LLQ header length in ena documentation (Petr Oros) [2038150]
- net: ena: Change ENI stats support check to use capabilities field (Petr Oros) [2038150]
- net: ena: Add capabilities field with support for ENI stats capability (Petr Oros) [2038150]
- net: ena: Change return value of ena_calc_io_queue_size() to void (Petr Oros) [2038150]
- net: ena: Fix error handling when calculating max IO queues number (Petr Oros) [2038150]
- net: ena: Fix wrong rx request id by resetting device (Petr Oros) [2038150]
- net: ena: Fix undefined state when tx request id is out of bounds (Petr Oros) [2038150]
- net/packet: rx_owner_map depends on pg_vec (Hangbin Liu) [2050329] {CVE-2021-22600}
- powerpc: security: Lock down the kernel if booted in secure boot mode (Desnes A. Nunes do Rosario) [2041984]
- drm/i915: Flush TLBs before releasing backing store (Dave Airlie) [2044335] {CVE-2022-0330}
- sfc: The RX page_ring is optional (Íñigo Huguet) [2042801]
- sfc: Check null pointer of rx_queue->page_ring (Íñigo Huguet) [2042801]
- sfc_ef100: potential dereference of null pointer (Íñigo Huguet) [2042801]
- sfc: Don't use netif_info before net_device setup (Íñigo Huguet) [2042801]
- sfc: Export fibre-specific supported link modes (Íñigo Huguet) [2042801]
- sfc: Fix reading non-legacy supported link modes (Íñigo Huguet) [2042801]
- ethernet: constify references to netdev->dev_addr in drivers (Íñigo Huguet) [2042801]
- sfc: last resort fallback for lack of xdp tx queues (Íñigo Huguet) [2042801]
- sfc: fallback for lack of xdp tx queues (Íñigo Huguet) [2042801]
- RDMA/cma: Do not change route.addr.src_addr.ss_family (Kamal Heib) [2032069] {CVE-2021-4028}
- kernel/sched/sched.h: Exclude cpuidle from KABI (Prarit Bhargava) [2033340]
- redhat/configs: Disable CONFIG_SENSORS_NCT6683 in RHEL for arm/aarch64 (Dean Nelson) [2041186]
- kernel.spec: Add glibc-static build requirement (Prarit Bhargava)
- libbpf: Fix memleak in libbpf_netlink_recv() (Toke Høiland-Jørgensen) [2052543]
- libbpf: Use dynamically allocated buffer when receiving netlink messages (Toke Høiland-Jørgensen) [2052543]
- redhat/configs: Disable arch_hw disabled CONFIGS (Prarit Bhargava) [2053029]
- netfilter: conntrack: re-init state for retransmitted syn-ack (Florian Westphal) [2051973]
- netfilter: conntrack: move synack init code to helper (Florian Westphal) [2051973]
- ext4: fix remount with 'abort' option (Lukas Czerner) [2049657]
- thunderbolt: Enable retry logic for intra-domain control packets (David Arcari) [1960445]
- thunderbolt: Handle ring interrupt by reading interrupt status register (David Arcari) [1960445]
- thunderbolt: Add vendor specific NHI quirk for auto-clearing interrupt status (David Arcari) [1960445]
- thunderbolt: Fix port linking by checking all adapters (David Arcari) [1960445]
- thunderbolt: Do not read control adapter config space (David Arcari) [1960445]
- ext4: fix potential NULL pointer dereference in ext4_fill_super() (Lukas Czerner) [2051466]
- nvme: drop unused variable ctrl in nvme_setup_cmd (John Meneghini) [2044616]
- nvme: increment request genctr on completion (John Meneghini) [2044616]
- nvme-pci: Fix abort command id (John Meneghini) [2044616]
- nvme: add command id quirk for apple controllers (John Meneghini) [2044616]
- nvme: move nvme_multi_css into nvme.h (John Meneghini) [2044616]
- nvme: code command_id with a genctr for use-after-free validation (John Meneghini) [2044616]
- nvme-pci: limit maximum queue depth to 4095 (John Meneghini) [2044616]
- quota: correct error number in free_dqentry() (Lukas Czerner) [2041793]
- quota: check block number when reading the block in quota file (Lukas Czerner) [2041793]
- ext4: don't use the orphan list when migrating an inode (Lukas Czerner) [2041486]
- ext4: use BUG_ON instead of if condition followed by BUG (Lukas Czerner) [2041486]
- ext4: fix a copy and paste typo (Lukas Czerner) [2041777]
- ext4: set csum seed in tmp inode while migrating to extents (Lukas Czerner) [2041486]
- ext4: remove unnecessary 'offset' assignment (Lukas Czerner) [2041486]
- ext4: remove redundant o_start statement (Lukas Czerner) [2041486]
- ext4: drop an always true check (Lukas Czerner) [2041486]
- ext4: remove unused assignments (Lukas Czerner) [2041486]
- ext4: remove redundant statement (Lukas Czerner) [2041486]
- ext4: remove useless resetting io_end_size in mpage_process_page() (Lukas Czerner) [2041486]
- ext4: allow to change s_last_trim_minblks via sysfs (Lukas Czerner) [2041486]
- ext4: change s_last_trim_minblks type to unsigned long (Lukas Czerner) [2041486]
- ext4: implement support for get/set fs label (Lukas Czerner) [2041486]
- ext4: only set EXT4_MOUNT_QUOTA when journalled quota file is specified (Lukas Czerner) [2041777]
- ext4: don't use kfree() on rcu protected pointer sbi->s_qf_names (Lukas Czerner) [2041486]
- ext4: avoid trim error on fs with small groups (Lukas Czerner) [2041486]
- ext4: fix an use-after-free issue about data=journal writeback mode (Lukas Czerner) [2041486]
- ext4: fix null-ptr-deref in '__ext4_journal_ensure_credits' (Lukas Czerner) [2041486]
- ext4: initialize err_blk before calling __ext4_get_inode_loc (Lukas Czerner) [2041486]
- ext4: fix a possible ABBA deadlock due to busy PA (Lukas Czerner) [2041486]
- ext4: replace snprintf in show functions with sysfs_emit (Lukas Czerner) [2041486]
- ext4: make sure to reset inode lockdep class when quota enabling fails (Lukas Czerner) [2041486]
- ext4: make sure quota gets properly shutdown on error (Lukas Czerner) [2041486]
- ext4: Fix BUG_ON in ext4_bread when write quota data (Lukas Czerner) [2041486]
- ext4: destroy ext4_fc_dentry_cachep kmemcache on module removal (Lukas Czerner) [2041486]
- ext4: fast commit may miss tracking unwritten range during ftruncate (Lukas Czerner) [2041486]
- ext4: use ext4_ext_remove_space() for fast commit replay delete range (Lukas Czerner) [2041486]
- ext4: fix fast commit may miss tracking range for FALLOC_FL_ZERO_RANGE (Lukas Czerner) [2041486]
- ext4: update fast commit TODOs (Lukas Czerner) [2041486]
- ext4: simplify updating of fast commit stats (Lukas Czerner) [2041486]
- ext4: drop ineligible txn start stop APIs (Lukas Czerner) [2041486]
- ext4: use ext4_journal_start/stop for fast commit transactions (Lukas Czerner) [2041486]
- ext4: fix i_version handling on remount (Lukas Czerner) [2041777]
- ext4: remove lazytime/nolazytime mount options handled by MS_LAZYTIME (Lukas Czerner) [2041777]
- ext4: don't fail remount if journalling mode didn't change (Lukas Czerner) [2041777]
- ext4: Remove unused match_table_t tokens (Lukas Czerner) [2041777]
- ext4: switch to the new mount api (Lukas Czerner) [2041777]
- ext4: change token2str() to use ext4_param_specs (Lukas Czerner) [2041777]
- ext4: clean up return values in handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: Completely separate options parsing and sb setup (Lukas Czerner) [2041777]
- ext4: get rid of super block and sbi from handle_mount_ops() (Lukas Czerner) [2041777]
- ext4: check ext2/3 compatibility outside handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: move quota configuration out of handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: Allow sb to be NULL in ext4_msg() (Lukas Czerner) [2041777]
- ext4: Change handle_mount_opt() to use fs_parameter (Lukas Czerner) [2041777]
- ext4: move option validation to a separate function (Lukas Czerner) [2041777]
- ext4: Add fs parameter specifications for mount options (Lukas Czerner) [2041777]
- fs_parse: allow parameter value to be empty (Lukas Czerner) [2041777]
- ext4: fix error code saved on super block during file system abort (Lukas Czerner) [2041486]
- ext4: inline data inode fast commit replay fixes (Lukas Czerner) [2041486]
- ext4: commit inline data during fast commit (Lukas Czerner) [2041486]
- ext4: scope ret locally in ext4_try_to_trim_range() (Lukas Czerner) [2041486]
- ext4: remove an unused variable warning with CONFIG_QUOTA=n (Lukas Czerner) [2041486]
- ext4: fix boolreturn.cocci warnings in fs/ext4/name.c (Lukas Czerner) [2041486]
- ext4: prevent getting empty inode buffer (Lukas Czerner) [2041486]
- ext4: move ext4_fill_raw_inode() related functions (Lukas Czerner) [2041486]
- ext4: factor out ext4_fill_raw_inode() (Lukas Czerner) [2041486]
- ext4: prevent partial update of the extent blocks (Lukas Czerner) [2035878]
- ext4: check for inconsistent extents between index and leaf block (Lukas Czerner) [2035878]
- ext4: check for out-of-order index extents in ext4_valid_extent_entries() (Lukas Czerner) [2035878]
- ext4: convert from atomic_t to refcount_t on ext4_io_end->count (Lukas Czerner) [2041486]
- ext4: refresh the ext4_ext_path struct after dropping i_data_sem. (Lukas Czerner) [2041486]
- ext4: ensure enough credits in ext4_ext_shift_path_extents (Lukas Czerner) [2041486]
- ext4: correct the left/middle/right debug message for binsearch (Lukas Czerner) [2041486]
- ext4: fix lazy initialization next schedule time computation in more granular unit (Lukas Czerner) [2041486]
- ext4: recheck buffer uptodate bit under buffer lock (Lukas Czerner) [2041486]
- ext4: fix potential infinite loop in ext4_dx_readdir() (Lukas Czerner) [2041486]
- ext4: flush s_error_work before journal destroy in ext4_fill_super (Lukas Czerner) [2041486]
- ext4: fix loff_t overflow in ext4_max_bitmap_size() (Lukas Czerner) [2041486]
- ext4: fix reserved space counter leakage (Lukas Czerner) [2041486]
- ext4: limit the number of blocks in one ADD_RANGE TLV (Lukas Czerner) [2041486]
- ext4: remove extent cache entries when truncating inline data (Lukas Czerner) [2041486]
- ext4: drop unnecessary journal handle in delalloc write (Lukas Czerner) [2041486]
- ext4: factor out write end code of inline file (Lukas Czerner) [2041486]
- ext4: correct the error path of ext4_write_inline_data_end() (Lukas Czerner) [2041486]
- ext4: check and update i_disksize properly (Lukas Czerner) [2041486]
- ext4: add error checking to ext4_ext_replay_set_iblocks() (Lukas Czerner) [2041486]
- ext4: make the updating inode data procedure atomic (Lukas Czerner) [2041486]
- ext4: remove an unnecessary if statement in __ext4_get_inode_loc() (Lukas Czerner) [2041486]
- ext4: move inode eio simulation behind io completeion (Lukas Czerner) [2041486]
- ext4: Improve scalability of ext4 orphan file handling (Lukas Czerner) [2041486]
- ext4: Speedup ext4 orphan inode handling (Lukas Czerner) [2041486]
- ext4: Move orphan inode handling into a separate file (Lukas Czerner) [2041486]
- jbd2: add sparse annotations for add_transaction_credits() (Lukas Czerner) [2041486]
- ext4: Support for checksumming from journal triggers (Lukas Czerner) [2041486]
- ext4: fix sparse warnings (Lukas Czerner) [2041486]
- ext4: fix race writing to an inline_data file while its xattrs are changing (Lukas Czerner) [2003461]
- ext4: Make sure quota files are not grabbed accidentally (Lukas Czerner) [2041486]
- ext4: fix e2fsprogs checksum failure for mounted filesystem (Lukas Czerner) [2022859]
- ext4: if zeroout fails fall back to splitting the extent node (Lukas Czerner) [2041486]
- ext4: reduce arguments of ext4_fc_add_dentry_tlv (Lukas Czerner) [2041486]
- ext4: remove the repeated comment of ext4_trim_all_free (Lukas Czerner) [2041486]
- ext4: add new helper interface ext4_try_to_trim_range() (Lukas Czerner) [2041486]
- ext4: remove the 'group' parameter of ext4_trim_extent (Lukas Czerner) [2041486]
- jbd2: clean up two gcc -Wall warnings in recovery.c (Lukas Czerner) [2041486]
- jbd2: fix clang warning in recovery.c (Lukas Czerner) [2041486]
- jbd2: fix portability problems caused by unaligned accesses (Lukas Czerner) [2041486]
- ext4: Convert to use mapping->invalidate_lock (Lukas Czerner) [2041486]
- redhat: support virtio-mem on x86-64 as tech-preview (David Hildenbrand) [2014492]
- proc/vmcore: fix clearing user buffer by properly using clear_user() (David Hildenbrand) [2014492]
- virtio-mem: support VIRTIO_MEM_F_UNPLUGGED_INACCESSIBLE (David Hildenbrand) [2014492]
- virtio-mem: disallow mapping virtio-mem memory via /dev/mem (David Hildenbrand) [2014492]
- kernel/resource: disallow access to exclusive system RAM regions (David Hildenbrand) [2014492]
- kernel/resource: clean up and optimize iomem_is_exclusive() (David Hildenbrand) [2014492]
- virtio-mem: kdump mode to sanitize /proc/vmcore access (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_remove() into virtio_mem_deinit_hotplug() (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_probe() into virtio_mem_init_hotplug() (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_init() into virtio_mem_init_hotplug() (David Hildenbrand) [2014492]
- proc/vmcore: convert oldmem_pfn_is_ram callback to more generic vmcore callbacks (David Hildenbrand) [2014492]
- proc/vmcore: let pfn_is_ram() return a bool (David Hildenbrand) [2014492]
- x86/xen: print a warning when HVMOP_get_mem_type fails (David Hildenbrand) [2014492]
- x86/xen: simplify xen_oldmem_pfn_is_ram() (David Hildenbrand) [2014492]
- x86/xen: update xen_oldmem_pfn_is_ram() documentation (David Hildenbrand) [2014492]

* Tue Feb 22 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-67.rt21.67.el9]
- kabi: Adding symbol strncpy_from_user (lib/strncpy_from_user.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strlcpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strchr (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol simple_strtoull (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol simple_strtol (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memparse (lib/cmdline.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strsep (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol kstrtoll (lib/kstrtox.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol __bitmap_weight (lib/bitmap.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol vsprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol vsnprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strstr (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strrchr (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strlcat (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strcpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol sprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strnlen (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strncpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol snprintf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memcmp (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol dump_stack (lib/dump_stack.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strncmp (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol sscanf (lib/vsprintf.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memset (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memmove (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol __list_add_valid (lib/list_debug.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strlen (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol strcmp (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol memcpy (lib/string.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol _copy_to_user (lib/usercopy.c) (Čestmír Kalina) [2008872]
- kabi: Adding symbol _copy_from_user (lib/usercopy.c) (Čestmír Kalina) [2008872]
- block: bio-integrity: Advance seed correctly for larger interval sizes (Ming Lei) [2044184]
- blk-mq: Fix wrong wakeup batch configuration which will cause hang (Ming Lei) [2044184]
- block: fix memory leak in disk_register_independent_access_ranges (Ming Lei) [2044184]
- block: fix async_depth sysfs interface for mq-deadline (Ming Lei) [2044184]
- blk-mq: fix tag_get wait task can't be awakened (Ming Lei) [2044184]
- block: Fix wrong offset in bio_truncate() (Ming Lei) [2044184]
- block: assign bi_bdev for cloned bios in blk_rq_prep_clone (Ming Lei) [2044184]
- block: Fix fsync always failed if once failed (Ming Lei) [2044184]
- block: don't protect submit_bio_checks by q_usage_counter (Ming Lei) [2044184]
- blk-mq: use bio->bi_opf after bio is checked (Ming Lei) [2044184]
- block: fix double bio queue when merging in cached request path (Ming Lei) [2044184]
- blk-mq: cleanup request allocation (Ming Lei) [2044184]
- blk-mq: simplify the plug handling in blk_mq_submit_bio (Ming Lei) [2044184]
- block: null_blk: only set set->nr_maps as 3 if active poll_queues is > 0 (Ming Lei) [2044184]
- null_blk: allow zero poll queues (Ming Lei) [2044184]
- iocost: Fix divide-by-zero on donation from low hweight cgroup (Ming Lei) [2044184]
- block: fix ioprio_get(IOPRIO_WHO_PGRP) vs setuid(2) (Ming Lei) [2044184]
- block: fix single bio async DIO error handling (Ming Lei) [2044184]
- usb: xhci: Extend support for runtime power management for AMD's Yellow carp. (Renjith Pananchikkal) [2015776]
- usb: xhci: Enable runtime-pm by default on AMD Yellow Carp platform (Renjith Pananchikkal) [2015776]
- redhat: switch the vsyscall config to CONFIG_LEGACY_VSYSCALL_XONLY=y (Herton R. Krzesinski) [2023041]
- ice: Implement support for SMA and U.FL on E810-T (Jonathan Toppins) [1975008]
- ice: Add support for SMA control multiplexer (Jonathan Toppins) [1975008]
- ice: Implement functions for reading and setting GPIO pins (Jonathan Toppins) [1975008]
- ice: Refactor ice_aqc_link_topo_addr (Jonathan Toppins) [1975008]
- blktrace: switch trace spinlock to a raw spinlock (Luis Claudio R. Goncalves) [2042495]
- block: assign bi_bdev for cloned bios in blk_rq_prep_clone (Luis Claudio R. Goncalves) [2042495]
- nvdimm/pmem: cleanup the disk if pmem_release_disk() is yet assigned (Ming Lei) [2042495]
- nvdimm/pmem: stop using q_usage_count as external pgmap refcount (Ming Lei) [2042495]
- libnvdimm/pmem: Fix crash triggered when I/O in-flight during unbind (Ming Lei) [2042495]
- nvdimm/pmem: fix creating the dax group (Ming Lei) [2042495]
- md: fix a lock order reversal in md_alloc (Ming Lei) [2042495]
- tools headers UAPI: Sync linux/fs.h with the kernel sources (Ming Lei) [2042495]
- Documentation: raise minimum supported version of GCC to 5.1 (Ming Lei) [2042495]
- loop: Use pr_warn_once() for loop_control_remove() warning (Ming Lei) [2042495]
- zram: only make zram_wb_devops for CONFIG_ZRAM_WRITEBACK (Ming Lei) [2042495]
- block: call rq_qos_done() before ref check in batch completions (Ming Lei) [2042495]
- block: fix parameter not described warning (Ming Lei) [2042495]
- block: avoid to touch unloaded module instance when opening bdev (Ming Lei) [2042495]
- block: Hold invalidate_lock in BLKRESETZONE ioctl (Ming Lei) [2042495]
- block: Hold invalidate_lock in BLKZEROOUT ioctl (Ming Lei) [2042495]
- block: Hold invalidate_lock in BLKDISCARD ioctl (Ming Lei) [2042495]
- blk-mq: don't insert FUA request with data into scheduler queue (Ming Lei) [2042495]
- blk-cgroup: fix missing put device in error path from blkg_conf_pref() (Ming Lei) [2042495]
- block: avoid to quiesce queue in elevator_init_mq (Ming Lei) [2042495]
- Revert "mark pstore-blk as broken" (Ming Lei) [2042495]
- blk-mq: cancel blk-mq dispatch work in both blk_cleanup_queue and disk_release() (Ming Lei) [2042495]
- block: fix missing queue put in error path (Ming Lei) [2042495]
- block: Check ADMIN before NICE for IOPRIO_CLASS_RT (Ming Lei) [2042495]
- blk-mq: fix filesystem I/O request allocation (Ming Lei) [2042495]
- blkcg: Remove extra blkcg_bio_issue_init (Ming Lei) [2042495]
- blk-mq: rename blk_attempt_bio_merge (Ming Lei) [2042495]
- blk-mq: don't grab ->q_usage_counter in blk_mq_sched_bio_merge (Ming Lei) [2042495]
- block: fix kerneldoc for disk_register_independent_access__ranges() (Ming Lei) [2042495]
- block: use enum type for blk_mq_alloc_data->rq_flags (Ming Lei) [2042495]
- bcache: Revert "bcache: use bvec_virt" (Ming Lei) [2042495]
- ataflop: Add missing semicolon to return statement (Ming Lei) [2042495]
- floppy: address add_disk() error handling on probe (Ming Lei) [2042495]
- ataflop: address add_disk() error handling on probe (Ming Lei) [2042495]
- block: update __register_blkdev() probe documentation (Ming Lei) [2042495]
- ataflop: remove ataflop_probe_lock mutex (Ming Lei) [2042495]
- mtd/ubi/block: add error handling support for add_disk() (Ming Lei) [2042495]
- block/sunvdc: add error handling support for add_disk() (Ming Lei) [2042495]
- z2ram: add error handling support for add_disk() (Ming Lei) [2042495]
- loop: Remove duplicate assignments (Ming Lei) [2042495]
- drbd: Fix double free problem in drbd_create_device (Ming Lei) [2042495]
- bcache: fix use-after-free problem in bcache_device_free() (Ming Lei) [2042495]
- zram: replace fsync_bdev with sync_blockdev (Ming Lei) [2042495]
- zram: avoid race between zram_remove and disksize_store (Ming Lei) [2042495]
- zram: don't fail to remove zram during unloading module (Ming Lei) [2042495]
- zram: fix race between zram_reset_device() and disksize_store() (Ming Lei) [2042495]
- nbd: error out if socket index doesn't match in nbd_handle_reply() (Ming Lei) [2042495]
- nbd: Fix hungtask when nbd_config_put (Ming Lei) [2042495]
- nbd: Fix incorrect error handle when first_minor is illegal in nbd_dev_add (Ming Lei) [2042495]
- nbd: fix possible overflow for 'first_minor' in nbd_dev_add() (Ming Lei) [2042495]
- nbd: fix max value for 'first_minor' (Ming Lei) [2042495]
- block/brd: add error handling support for add_disk() (Ming Lei) [2042495]
- ps3vram: add error handling support for add_disk() (Ming Lei) [2042495]
- ps3disk: add error handling support for add_disk() (Ming Lei) [2042495]
- zram: add error handling support for add_disk() (Ming Lei) [2042495]
- nvme: wait until quiesce is done (Ming Lei) [2042495]
- scsi: make sure that request queue queiesce and unquiesce balanced (Ming Lei) [2042495]
- scsi: avoid to quiesce sdev->request_queue two times (Ming Lei) [2042495]
- blk-mq: add one API for waiting until quiesce is done (Ming Lei) [2042495]
- blk-mq: don't free tags if the tag_set is used by other device in queue initialztion (Ming Lei) [2042495]
- block: fix device_add_disk() kobject_create_and_add() error handling (Ming Lei) [2042495]
- block: ensure cached plug request matches the current queue (Ming Lei) [2042495]
- block: move queue enter logic into blk_mq_submit_bio() (Ming Lei) [2042495]
- block: make bio_queue_enter() fast-path available inline (Ming Lei) [2042495]
- block: split request allocation components into helpers (Ming Lei) [2042495]
- block: have plug stored requests hold references to the queue (Ming Lei) [2042495]
- blk-mq: update hctx->nr_active in blk_mq_end_request_batch() (Ming Lei) [2042495]
- blk-mq: add RQF_ELV debug entry (Ming Lei) [2042495]
- blk-mq: only try to run plug merge if request has same queue with incoming bio (Ming Lei) [2042495]
- block: move RQF_ELV setting into allocators (Ming Lei) [2042495]
- dm: don't stop request queue after the dm device is suspended (Ming Lei) [2042495]
- block: replace always false argument with 'false' (Ming Lei) [2042495]
- block: assign correct tag before doing prefetch of request (Ming Lei) [2042495]
- blk-mq: fix redundant check of !e expression (Ming Lei) [2042495]
- block: use new bdev_nr_bytes() helper for blkdev_{read,write}_iter() (Ming Lei) [2042495]
- block: add a loff_t cast to bdev_nr_bytes (Ming Lei) [2042495]
- null_blk: Fix handling of submit_queues and poll_queues attributes (Ming Lei) [2042495]
- block: ataflop: Fix warning comparing pointer to 0 (Ming Lei) [2042495]
- bcache: replace snprintf in show functions with sysfs_emit (Ming Lei) [2042495]
- bcache: move uapi header bcache.h to bcache code directory (Ming Lei) [2042495]
- block: ataflop: more blk-mq refactoring fixes (Ming Lei) [2042495]
- block: remove support for cryptoloop and the xor transfer (Ming Lei) [2042495]
- mtd: add add_disk() error handling (Ming Lei) [2042495]
- rnbd: add error handling support for add_disk() (Ming Lei) [2042495]
- um/drivers/ubd_kern: add error handling support for add_disk() (Ming Lei) [2042495]
- m68k/emu/nfblock: add error handling support for add_disk() (Ming Lei) [2042495]
- xen-blkfront: add error handling support for add_disk() (Ming Lei) [2042495]
- bcache: add error handling support for add_disk() (Ming Lei) [2042495]
- dm: add add_disk() error handling (Ming Lei) [2042495]
- block: aoe: fixup coccinelle warnings (Ming Lei) [2042495]
- bcache: remove bch_crc64_update (Ming Lei) [2042495]
- bcache: use bvec_kmap_local in bch_data_verify (Ming Lei) [2042495]
- bcache: remove the backing_dev_name field from struct cached_dev (Ming Lei) [2042495]
- bcache: remove the cache_dev_name field from struct cache (Ming Lei) [2042495]
- bcache: move calc_cached_dev_sectors to proper place on backing device detach (Ming Lei) [2042495]
- bcache: fix error info in register_bcache() (Ming Lei) [2042495]
- bcache: reserve never used bits from bkey.high (Ming Lei) [2042495]
- md: bcache: Fix spelling of 'acquire' (Ming Lei) [2042495]
- s390/dasd: fix possibly missed path verification (Ming Lei) [2042495]
- s390/dasd: fix missing path conf_data after failed allocation (Ming Lei) [2042495]
- s390/dasd: summarize dasd configuration data in a separate structure (Ming Lei) [2042495]
- s390/dasd: move dasd_eckd_read_fc_security (Ming Lei) [2042495]
- s390/dasd: split up dasd_eckd_read_conf (Ming Lei) [2042495]
- s390/dasd: fix kernel doc comment (Ming Lei) [2042495]
- s390/dasd: handle request magic consistently as unsigned int (Ming Lei) [2042495]
- nbd: Fix use-after-free in pid_show (Ming Lei) [2042495]
- block: ataflop: fix breakage introduced at blk-mq refactoring (Ming Lei) [2042495]
- nbd: fix uaf in nbd_handle_reply() (Ming Lei) [2042495]
- nbd: partition nbd_read_stat() into nbd_read_reply() and nbd_handle_reply() (Ming Lei) [2042495]
- nbd: clean up return value checking of sock_xmit() (Ming Lei) [2042495]
- nbd: don't start request if nbd_queue_rq() failed (Ming Lei) [2042495]
- nbd: check sock index in nbd_read_stat() (Ming Lei) [2042495]
- nbd: make sure request completion won't concurrent (Ming Lei) [2042495]
- nbd: don't handle response without a corresponding request message (Ming Lei) [2042495]
- mtip32xx: Remove redundant 'flush_workqueue()' calls (Ming Lei) [2042495]
- swim3: add missing major.h include (Ming Lei) [2042495]
- sx8: fix an error code in carm_init_one() (Ming Lei) [2042495]
- pf: fix error codes in pf_init_unit() (Ming Lei) [2042495]
- pcd: fix error codes in pcd_init_unit() (Ming Lei) [2042495]
- xtensa/platforms/iss/simdisk: add error handling support for add_disk() (Ming Lei) [2042495]
- block/ataflop: add error handling support for add_disk() (Ming Lei) [2042495]
- block/ataflop: provide a helper for cleanup up an atari disk (Ming Lei) [2042495]
- block/ataflop: add registration bool before calling del_gendisk() (Ming Lei) [2042495]
- block/ataflop: use the blk_cleanup_disk() helper (Ming Lei) [2042495]
- swim: add error handling support for add_disk() (Ming Lei) [2042495]
- swim: add a floppy registration bool which triggers del_gendisk() (Ming Lei) [2042495]
- swim: add helper for disk cleanup (Ming Lei) [2042495]
- swim: simplify using blk_cleanup_disk() on swim_remove() (Ming Lei) [2042495]
- amiflop: add error handling support for add_disk() (Ming Lei) [2042495]
- floppy: add error handling support for add_disk() (Ming Lei) [2042495]
- floppy: fix calling platform_device_unregister() on invalid drives (Ming Lei) [2042495]
- floppy: use blk_cleanup_disk() (Ming Lei) [2042495]
- floppy: fix add_disk() assumption on exit due to new developments (Ming Lei) [2042495]
- block/swim3: add error handling support for add_disk() (Ming Lei) [2042495]
- rbd: add add_disk() error handling (Ming Lei) [2042495]
- cdrom/gdrom: add error handling support for add_disk() (Ming Lei) [2042495]
- pf: add error handling support for add_disk() (Ming Lei) [2042495]
- block/sx8: add error handling support for add_disk() (Ming Lei) [2042495]
- block/rsxx: add error handling support for add_disk() (Ming Lei) [2042495]
- pktcdvd: add error handling support for add_disk() (Ming Lei) [2042495]
- mtip32xx: add error handling support for add_disk() (Ming Lei) [2042495]
- pd: add error handling support for add_disk() (Ming Lei) [2042495]
- pcd: capture errors on cdrom_register() (Ming Lei) [2042495]
- pcd: fix ordering of unregister_cdrom() (Ming Lei) [2042495]
- pcd: add error handling support for add_disk() (Ming Lei) [2042495]
- pd: cleanup initialization (Ming Lei) [2042495]
- pf: cleanup initialization (Ming Lei) [2042495]
- pcd: cleanup initialization (Ming Lei) [2042495]
- pcd: move the identify buffer into pcd_identify (Ming Lei) [2042495]
- n64cart: add error handling support for add_disk() (Ming Lei) [2042495]
- drbd: add error handling support for add_disk() (Ming Lei) [2042495]
- aoe: add error handling support for add_disk() (Ming Lei) [2042495]
- nbd: add error handling support for add_disk() (Ming Lei) [2042495]
- loop: add error handling support for add_disk() (Ming Lei) [2042495]
- null_blk: poll queue support (Ming Lei) [2042495]
- block: simplify the block device syncing code (Ming Lei) [2042495]
- fat: use sync_blockdev_nowait (Ming Lei) [2042495]
- btrfs: use sync_blockdev (Ming Lei) [2042495]
- xen-blkback: use sync_blockdev (Ming Lei) [2042495]
- block: remove __sync_blockdev (Ming Lei) [2042495]
- fs: remove __sync_filesystem (Ming Lei) [2042495]
- cdrom: Remove redundant variable and its assignment (Ming Lei) [2042495]
- cdrom: docs: reformat table in Documentation/userspace-api/ioctl/cdrom.rst (Ming Lei) [2042495]
- drivers/cdrom: improved ioctl for media change detection (Ming Lei) [2042495]
- partitions/ibm: use bdev_nr_sectors instead of open coding it (Ming Lei) [2042495]
- partitions/efi: use bdev_nr_bytes instead of open coding it (Ming Lei) [2042495]
- block/ioctl: use bdev_nr_sectors and bdev_nr_bytes (Ming Lei) [2042495]
- block: cache inode size in bdev (Ming Lei) [2042495]
- udf: use sb_bdev_nr_blocks (Ming Lei) [2042495]
- reiserfs: use sb_bdev_nr_blocks (Ming Lei) [2042495]
- ntfs: use sb_bdev_nr_blocks (Ming Lei) [2042495]
- jfs: use sb_bdev_nr_blocks (Ming Lei) [2042495]
- ext4: use sb_bdev_nr_blocks (Ming Lei) [2042495]
- block: add a sb_bdev_nr_blocks helper (Ming Lei) [2042495]
- block: use bdev_nr_bytes instead of open coding it in blkdev_fallocate (Ming Lei) [2042495]
- squashfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2042495]
- reiserfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2042495]
- pstore/blk: use bdev_nr_bytes instead of open coding it (Ming Lei) [2042495]
- nilfs2: use bdev_nr_bytes instead of open coding it (Ming Lei) [2042495]
- nfs/blocklayout: use bdev_nr_bytes instead of open coding it (Ming Lei) [2042495]
- jfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2042495]
- hfsplus: use bdev_nr_sectors instead of open coding it (Ming Lei) [2042495]
- hfs: use bdev_nr_sectors instead of open coding it (Ming Lei) [2042495]
- fat: use bdev_nr_sectors instead of open coding it (Ming Lei) [2042495]
- cramfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2042495]
- btrfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2042495]
- affs: use bdev_nr_sectors instead of open coding it (Ming Lei) [2042495]
- fs: simplify init_page_buffers (Ming Lei) [2042495]
- fs: use bdev_nr_bytes instead of open coding it in blkdev_max_block (Ming Lei) [2042495]
- target/iblock: use bdev_nr_bytes instead of open coding it (Ming Lei) [2042495]
- nvmet: use bdev_nr_bytes instead of open coding it (Ming Lei) [2042495]
- md: use bdev_nr_sectors instead of open coding it (Ming Lei) [2042495]
- dm: use bdev_nr_sectors and bdev_nr_bytes instead of open coding them (Ming Lei) [2042495]
- drbd: use bdev_nr_sectors instead of open coding it (Ming Lei) [2042495]
- bcache: remove bdev_sectors (Ming Lei) [2042495]
- block: add a bdev_nr_bytes helper (Ming Lei) [2042495]
- block: move the SECTOR_SIZE related definitions to blk_types.h (Ming Lei) [2042495]
- blk-mq-debugfs: Show active requests per queue for shared tags (Ming Lei) [2042495]
- block: improve readability of blk_mq_end_request_batch() (Ming Lei) [2042495]
- virtio-blk: Use blk_validate_block_size() to validate block size (Ming Lei) [2042495]
- loop: Use blk_validate_block_size() to validate block size (Ming Lei) [2042495]
- nbd: Use blk_validate_block_size() to validate block size (Ming Lei) [2042495]
- block: Add a helper to validate the block size (Ming Lei) [2042495]
- block: re-flow blk_mq_rq_ctx_init() (Ming Lei) [2042495]
- block: prefetch request to be initialized (Ming Lei) [2042495]
- block: pass in blk_mq_tags to blk_mq_rq_ctx_init() (Ming Lei) [2042495]
- block: add rq_flags to struct blk_mq_alloc_data (Ming Lei) [2042495]
- block: add async version of bio_set_polled (Ming Lei) [2042495]
- block: kill DIO_MULTI_BIO (Ming Lei) [2042495]
- block: kill unused polling bits in __blkdev_direct_IO() (Ming Lei) [2042495]
- block: avoid extra iter advance with async iocb (Ming Lei) [2042495]
- block: Add independent access ranges support (Ming Lei) [2042495]
- blk-mq: don't issue request directly in case that current is to be blocked (Ming Lei) [2042495]
- sbitmap: silence data race warning (Ming Lei) [2042495]
- blk-cgroup: synchronize blkg creation against policy deactivation (Ming Lei) [2042495]
- block: refactor bio_iov_bvec_set() (Ming Lei) [2042495]
- block: add single bio async direct IO helper (Ming Lei) [2042495]
- sched: make task_struct->plug always defined (Ming Lei) [2042495]
- blk-mq-sched: Don't reference queue tagset in blk_mq_sched_tags_teardown() (Ming Lei) [2042495]
- block: fix req_bio_endio append error handling (Ming Lei) [2042495]
- blk-crypto: update inline encryption documentation (Ming Lei) [2042495]
- blk-crypto: rename blk_keyslot_manager to blk_crypto_profile (Ming Lei) [2042495]
- blk-crypto: rename keyslot-manager files to blk-crypto-profile (Ming Lei) [2042495]
- blk-crypto-fallback: properly prefix function and struct names (Ming Lei) [2042495]
- nbd: Use invalidate_disk() helper on disconnect (Ming Lei) [2042495]
- loop: Remove the unnecessary bdev checks and unused bdev variable (Ming Lei) [2042495]
- loop: Use invalidate_disk() helper to invalidate gendisk (Ming Lei) [2042495]
- block: Add invalidate_disk() helper to invalidate the gendisk (Ming Lei) [2042495]
- block: kill extra rcu lock/unlock in queue enter (Ming Lei) [2042495]
- percpu_ref: percpu_ref_tryget_live() version holding RCU (Ming Lei) [2042495]
- block: convert fops.c magic constants to SHIFT_SECTOR (Ming Lei) [2042495]
- block: clean up blk_mq_submit_bio() merging (Ming Lei) [2042495]
- block: optimise boundary blkdev_read_iter's checks (Ming Lei) [2042495]
- fs: bdev: fix conflicting comment from lookup_bdev (Ming Lei) [2042495]
- blk-mq: Fix blk_mq_tagset_busy_iter() for shared tags (Ming Lei) [2042495]
- block: cleanup the flush plug helpers (Ming Lei) [2042495]
- block: optimise blk_flush_plug_list (Ming Lei) [2042495]
- blk-mq: move blk_mq_flush_plug_list to block/blk-mq.h (Ming Lei) [2042495]
- blk-mq: only flush requests from the plug in blk_mq_submit_bio (Ming Lei) [2042495]
- block: remove inaccurate requeue check (Ming Lei) [2042495]
- block: inline a part of bio_release_pages() (Ming Lei) [2042495]
- block: don't bloat enter_queue with percpu_ref (Ming Lei) [2042495]
- block: optimise req_bio_endio() (Ming Lei) [2042495]
- block: convert leftovers to bdev_get_queue (Ming Lei) [2042495]
- block: turn macro helpers into inline functions (Ming Lei) [2042495]
- blk-mq: support concurrent queue quiesce/unquiesce (Ming Lei) [2042495]
- nvme: loop: clear NVME_CTRL_ADMIN_Q_STOPPED after admin queue is reallocated (Ming Lei) [2042495]
- nvme: paring quiesce/unquiesce (Ming Lei) [2042495]
- nvme: prepare for pairing quiescing and unquiescing (Ming Lei) [2042495]
- nvme: apply nvme API to quiesce/unquiesce admin queue (Luis Claudio R. Goncalves) [2042495]
- nvme: add APIs for stopping/starting admin queue (Ming Lei) [2042495]
- block, bfq: fix UAF problem in bfqg_stats_init() (Ming Lei) [2042495]
- block: inline fast path of driver tag allocation (Ming Lei) [2042495]
- blk-mq: don't handle non-flush requests in blk_insert_flush (Ming Lei) [2042495]
- block: attempt direct issue of plug list (Ming Lei) [2042495]
- block: change plugging to use a singly linked list (Ming Lei) [2042495]
- blk-wbt: prevent NULL pointer dereference in wb_timer_fn (Ming Lei) [2042495]
- block: align blkdev_dio inlined bio to a cacheline (Ming Lei) [2042495]
- block: move blk_mq_tag_to_rq() inline (Ming Lei) [2042495]
- block: get rid of plug list sorting (Ming Lei) [2042495]
- block: return whether or not to unplug through boolean (Ming Lei) [2042495]
- block: don't call blk_status_to_errno in blk_update_request (Ming Lei) [2042495]
- block: move bdev_read_only() into the header (Ming Lei) [2042495]
- block: fix too broad elevator check in blk_mq_free_request() (Ming Lei) [2042495]
- block: add support for blk_mq_end_request_batch() (Ming Lei) [2042495]
- sbitmap: add helper to clear a batch of tags (Ming Lei) [2042495]
- block: add a struct io_comp_batch argument to fops->iopoll() (Ming Lei) [2042495]
- block: provide helpers for rq_list manipulation (Ming Lei) [2042495]
- block: remove some blk_mq_hw_ctx debugfs entries (Ming Lei) [2042495]
- block: remove debugfs blk_mq_ctx dispatched/merged/completed attributes (Ming Lei) [2042495]
- block: cache rq_flags inside blk_mq_rq_ctx_init() (Ming Lei) [2042495]
- block: blk_mq_rq_ctx_init cache ctx/q/hctx (Ming Lei) [2042495]
- block: skip elevator fields init for non-elv queue (Ming Lei) [2042495]
- block: store elevator state in request (Ming Lei) [2042495]
- block: only mark bio as tracked if it really is tracked (Ming Lei) [2042495]
- block: improve layout of struct request (Ming Lei) [2042495]
- block: move update request helpers into blk-mq.c (Ming Lei) [2042495]
- block: remove useless caller argument to print_req_error() (Ming Lei) [2042495]
- block: don't bother iter advancing a fully done bio (Ming Lei) [2042495]
- block: convert the rest of block to bdev_get_queue (Ming Lei) [2042495]
- block: use bdev_get_queue() in blk-core.c (Ming Lei) [2042495]
- block: use bdev_get_queue() in bio.c (Ming Lei) [2042495]
- block: use bdev_get_queue() in bdev.c (Ming Lei) [2042495]
- block: cache request queue in bdev (Ming Lei) [2042495]
- block: handle fast path of bio splitting inline (Ming Lei) [2042495]
- block: use flags instead of bit fields for blkdev_dio (Ming Lei) [2042495]
- block: cache bdev in struct file for raw bdev IO (Ming Lei) [2042495]
- block: don't allow writing to the poll queue attribute (Ming Lei) [2042495]
- block: switch polling to be bio based (Ming Lei) [2042495]
- block: define 'struct bvec_iter' as packed (Ming Lei) [2042495]
- block: use SLAB_TYPESAFE_BY_RCU for the bio slab (Ming Lei) [2042495]
- block: rename REQ_HIPRI to REQ_POLLED (Ming Lei) [2042495]
- io_uring: don't sleep when polling for I/O (Ming Lei) [2042495]
- block: replace the spin argument to blk_iopoll with a flags argument (Ming Lei) [2042495]
- blk-mq: remove blk_qc_t_valid (Ming Lei) [2042495]
- blk-mq: remove blk_qc_t_to_tag and blk_qc_t_is_internal (Ming Lei) [2042495]
- blk-mq: factor out a "classic" poll helper (Ming Lei) [2042495]
- blk-mq: factor out a blk_qc_to_hctx helper (Ming Lei) [2042495]
- io_uring: fix a layering violation in io_iopoll_req_issued (Ming Lei) [2042495]
- block: don't try to poll multi-bio I/Os in __blkdev_direct_IO (Ming Lei) [2042495]
- direct-io: remove blk_poll support (Ming Lei) [2042495]
- block: only check previous entry for plug merge attempt (Ming Lei) [2042495]
- block: move CONFIG_BLOCK guard to top Makefile (Ming Lei) [2042495]
- block: move menu "Partition type" to block/partitions/Kconfig (Ming Lei) [2042495]
- block: simplify Kconfig files (Ming Lei) [2042495]
- block: remove redundant =y from BLK_CGROUP dependency (Ming Lei) [2042495]
- block: improve batched tag allocation (Ming Lei) [2042495]
- sbitmap: add __sbitmap_queue_get_batch() (Ming Lei) [2042495]
- blk-mq: optimise *end_request non-stat path (Ming Lei) [2042495]
- block: mark bio_truncate static (Ming Lei) [2042495]
- block: move bio_get_{first,last}_bvec out of bio.h (Ming Lei) [2042495]
- block: mark __bio_try_merge_page static (Ming Lei) [2042495]
- block: move bio_full out of bio.h (Ming Lei) [2042495]
- block: fold bio_cur_bytes into blk_rq_cur_bytes (Ming Lei) [2042495]
- block: move bio_mergeable out of bio.h (Ming Lei) [2042495]
- block: don't include <linux/ioprio.h> in <linux/bio.h> (Ming Lei) [2042495]
- block: remove BIO_BUG_ON (Ming Lei) [2042495]
- blk-mq: inline hot part of __blk_mq_sched_restart (Ming Lei) [2042495]
- block: inline hot paths of blk_account_io_*() (Ming Lei) [2042495]
- block: merge block_ioctl into blkdev_ioctl (Ming Lei) [2042495]
- block: move the *blkdev_ioctl declarations out of blkdev.h (Ming Lei) [2042495]
- block: unexport blkdev_ioctl (Ming Lei) [2042495]
- block: don't dereference request after flush insertion (Ming Lei) [2042495]
- blk-mq: cleanup blk_mq_submit_bio (Ming Lei) [2042495]
- blk-mq: cleanup and rename __blk_mq_alloc_request (Ming Lei) [2042495]
- block: pre-allocate requests if plug is started and is a batch (Ming Lei) [2042495]
- block: bump max plugged deferred size from 16 to 32 (Ming Lei) [2042495]
- block: inherit request start time from bio for BLK_CGROUP (Ming Lei) [2042495]
- block: move blk-throtl fast path inline (Ming Lei) [2042495]
- blk-mq: Change shared sbitmap naming to shared tags (Ming Lei) [2042495]
- blk-mq: Stop using pointers for blk_mq_tags bitmap tags (Ming Lei) [2042495]
- blk-mq: Use shared tags for shared sbitmap support (Ming Lei) [2042495]
- blk-mq: Refactor and rename blk_mq_free_map_and_{requests->rqs}() (Ming Lei) [2042495]
- blk-mq: Add blk_mq_alloc_map_and_rqs() (Ming Lei) [2042495]
- blk-mq: Add blk_mq_tag_update_sched_shared_sbitmap() (Ming Lei) [2042495]
- blk-mq: Don't clear driver tags own mapping (Ming Lei) [2042495]
- blk-mq: Pass driver tags to blk_mq_clear_rq_mapping() (Ming Lei) [2042495]
- blk-mq-sched: Rename blk_mq_sched_free_{requests -> rqs}() (Ming Lei) [2042495]
- blk-mq-sched: Rename blk_mq_sched_alloc_{tags -> map_and_rqs}() (Ming Lei) [2042495]
- blk-mq: Invert check in blk_mq_update_nr_requests() (Ming Lei) [2042495]
- blk-mq: Relocate shared sbitmap resize in blk_mq_update_nr_requests() (Ming Lei) [2042495]
- block: Rename BLKDEV_MAX_RQ -> BLKDEV_DEFAULT_RQ (Ming Lei) [2042495]
- blk-mq: Change rqs check in blk_mq_free_rqs() (Ming Lei) [2042495]
- block: print the current process in handle_bad_sector (Ming Lei) [2042495]
- block/mq-deadline: Prioritize high-priority requests (Ming Lei) [2042495]
- block/mq-deadline: Stop using per-CPU counters (Ming Lei) [2042495]
- block/mq-deadline: Add an invariant check (Ming Lei) [2042495]
- block/mq-deadline: Improve request accounting further (Ming Lei) [2042495]
- block: move struct request to blk-mq.h (Ming Lei) [2042495]
- block: move integrity handling out of <linux/blkdev.h> (Ming Lei) [2042495]
- block: move a few merge helpers out of <linux/blkdev.h> (Ming Lei) [2042495]
- block: drop unused includes in <linux/genhd.h> (Ming Lei) [2042495]
- block: drop unused includes in <linux/blkdev.h> (Ming Lei) [2042495]
- block: move elevator.h to block/ (Ming Lei) [2042495]
- block: remove the struct blk_queue_ctx forward declaration (Ming Lei) [2042495]
- block: remove the cmd_size field from struct request_queue (Ming Lei) [2042495]
- block: remove the unused blk_queue_state enum (Ming Lei) [2042495]
- block: remove the unused rq_end_sector macro (Ming Lei) [2042495]
- sched: move the <linux/blkdev.h> include out of kernel/sched/sched.h (Ming Lei) [2042495]
- kernel: remove spurious blkdev.h includes (Ming Lei) [2042495]
- arch: remove spurious blkdev.h includes (Ming Lei) [2042495]
- mm: remove spurious blkdev.h includes (Ming Lei) [2042495]
- mm: don't include <linux/blkdev.h> in <linux/backing-dev.h> (Ming Lei) [2042495]
- mm: don't include <linux/blk-cgroup.h> in <linux/backing-dev.h> (Ming Lei) [2042495]
- mm: don't include <linux/blk-cgroup.h> in <linux/writeback.h> (Ming Lei) [2042495]
- block: nbd: add sanity check for first_minor (Ming Lei) [2042495]
- mmc: core: Store pointer to bio_crypt_ctx in mmc_request (Ming Lei) [2042495]
- iomap: simplify iomap_add_to_ioend (Ming Lei) [2042495]
- iomap: simplify iomap_readpage_actor (Ming Lei) [2042495]
- io_uring: don't halt iopoll too early (Ming Lei) [2042495]
- block: Fix partition check for host-aware zoned block devices (Ming Lei) [2042495]
- block: schedule queue restart after BLK_STS_ZONE_RESOURCE (Ming Lei) [2042495]
- block: drain queue after disk is removed from sysfs (Ming Lei) [2042495]
- block: fix incorrect references to disk objects (Ming Lei) [2042495]
- blk-cgroup: blk_cgroup_bio_start() should use irq-safe operations on blkg->iostat_cpu (Ming Lei) [2042495]
- block, bfq: reset last_bfqq_created on group change (Ming Lei) [2042495]
- block: warn when putting the final reference on a registered disk (Ming Lei) [2042495]
- brd: reduce the brd_devices_mutex scope (Ming Lei) [2042495]
- kyber: avoid q->disk dereferences in trace points (Ming Lei) [2042495]
- block: keep q_usage_counter in atomic mode after del_gendisk (Ming Lei) [2042495]
- block: drain file system I/O on del_gendisk (Ming Lei) [2042495]
- block: split bio_queue_enter from blk_queue_enter (Ming Lei) [2042495]
- block: factor out a blk_try_enter_queue helper (Ming Lei) [2042495]
- block: call submit_bio_checks under q_usage_counter (Ming Lei) [2042495]
- block/rnbd-clt-sysfs: fix a couple uninitialized variable bugs (Ming Lei) [2042495]
- block: decode QUEUE_FLAG_HCTX_ACTIVE in debugfs output (Ming Lei) [2042495]
- block: genhd: fix double kfree() in __alloc_disk_node() (Ming Lei) [2042495]
- nbd: use shifts rather than multiplies (Ming Lei) [2042495]
- Revert "block, bfq: honor already-setup queue merges" (Ming Lei) [2042495]
- block: hold ->invalidate_lock in blkdev_fallocate (Ming Lei) [2042495]
- blktrace: Fix uaf in blk_trace access after removing by sysfs (Ming Lei) [2042495]
- block: don't call rq_qos_ops->done_bio if the bio isn't tracked (Ming Lei) [2042495]
- blk-cgroup: fix UAF by grabbing blkcg lock before destroying blkg pd (Ming Lei) [2042495]
- blkcg: fix memory leak in blk_iolatency_init (Ming Lei) [2042495]
- block: flush the integrity workqueue in blk_integrity_unregister (Ming Lei) [2042495]
- block: check if a profile is actually registered in blk_integrity_unregister (Ming Lei) [2042495]
- blk-mq: avoid to iterate over stale request (Ming Lei) [2042495]
- n64cart: fix return value check in n64cart_probe() (Ming Lei) [2042495]
- blk-mq: allow 4x BLK_MAX_REQUEST_COUNT at blk_plug for multiple_queues (Ming Lei) [2042495]
- block: move fs/block_dev.c to block/bdev.c (Ming Lei) [2042495]
- block: split out operations on block special files (Ming Lei) [2042495]
- blk-throttle: fix UAF by deleteing timer in blk_throtl_exit() (Ming Lei) [2042495]
- block: genhd: don't call blkdev_show() with major_names_lock held (Ming Lei) [2042495]
- cdrom: update uniform CD-ROM maintainership in MAINTAINERS file (Ming Lei) [2042495]
- loop: reduce the loop_ctl_mutex scope (Ming Lei) [2042495]
- bio: fix kerneldoc documentation for bio_alloc_kiocb() (Ming Lei) [2042495]
- block, bfq: honor already-setup queue merges (Ming Lei) [2042495]
- block/mq-deadline: Move dd_queued() to fix defined but not used warning (Ming Lei) [2042495]
- bio: improve kerneldoc documentation for bio_alloc_kiocb() (Ming Lei) [2042495]
- block: provide bio_clear_hipri() helper (Ming Lei) [2042495]
- block: use the percpu bio cache in __blkdev_direct_IO (Ming Lei) [2042495]
- io_uring: enable use of bio alloc cache (Ming Lei) [2042495]
- block: clear BIO_PERCPU_CACHE flag if polling isn't supported (Ming Lei) [2042495]
- bio: add allocation cache abstraction (Ming Lei) [2042495]
- fs: add kiocb alloc cache flag (Ming Lei) [2042495]
- bio: optimize initialization of a bio (Ming Lei) [2042495]
- Revert "floppy: reintroduce O_NDELAY fix" (Ming Lei) [2042495]
- nbd: remove nbd->destroy_complete (Ming Lei) [2042495]
- nbd: only return usable devices from nbd_find_unused (Ming Lei) [2042495]
- nbd: set nbd->index before releasing nbd_index_mutex (Ming Lei) [2042495]
- nbd: prevent IDR lookups from finding partially initialized devices (Ming Lei) [2042495]
- nbd: reset NBD to NULL when restarting in nbd_genl_connect (Ming Lei) [2042495]
- nbd: add missing locking to the nbd_dev_add error path (Ming Lei) [2042495]
- params: lift param_set_uint_minmax to common code (Ming Lei) [2042495]
- nbd: reduce the nbd_index_mutex scope (Ming Lei) [2042495]
- nbd: refactor device search and allocation in nbd_genl_connect (Ming Lei) [2042495]
- nbd: return the allocated nbd_device from nbd_dev_add (Ming Lei) [2042495]
- nbd: remove nbd_del_disk (Ming Lei) [2042495]
- nbd: refactor device removal (Ming Lei) [2042495]
- nbd: do del_gendisk() asynchronously for NBD_DESTROY_ON_DISCONNECT (Ming Lei) [2042495]
- nbd: add the check to prevent overflow in __nbd_ioctl() (Ming Lei) [2042495]
- xen-blkfront: Remove redundant assignment to variable err (Ming Lei) [2042495]
- block/rnbd: Use sysfs_emit instead of s*printf function for sysfs show (Ming Lei) [2042495]
- block/rnbd-clt: Use put_cpu_ptr after get_cpu_ptr (Ming Lei) [2042495]
- sg: pass the device name to blk_trace_setup (Ming Lei) [2042495]
- block, bfq: cleanup the repeated declaration (Ming Lei) [2042495]
- blk-crypto: fix check for too-large dun_bytes (Ming Lei) [2042495]
- blk-zoned: allow BLKREPORTZONE without CAP_SYS_ADMIN (Ming Lei) [2042495]
- blk-zoned: allow zone management send operations without CAP_SYS_ADMIN (Ming Lei) [2042495]
- block: mark blkdev_fsync static (Ming Lei) [2042495]
- block: refine the disk_live check in del_gendisk (Ming Lei) [2042495]
- mmc: sdhci-tegra: Enable MMC_CAP2_ALT_GPT_TEGRA (Ming Lei) [2042495]
- mmc: block: Support alternative_gpt_sector() operation (Ming Lei) [2042495]
- partitions/efi: Support non-standard GPT location (Ming Lei) [2042495]
- block: Add alternative_gpt_sector() operation (Ming Lei) [2042495]
- bio: fix page leak bio_add_hw_page failure (Ming Lei) [2042495]
- block: remove CONFIG_DEBUG_BLOCK_EXT_DEVT (Ming Lei) [2042495]
- block: remove a pointless call to MINOR() in device_add_disk (Ming Lei) [2042495]
- null_blk: add error handling support for add_disk() (Ming Lei) [2042495]
- virtio_blk: add error handling support for add_disk() (Ming Lei) [2042495]
- block: add error handling for device_add_disk / add_disk (Ming Lei) [2042495]
- block: return errors from disk_alloc_events (Ming Lei) [2042495]
- block: return errors from blk_integrity_add (Ming Lei) [2042495]
- block: call blk_register_queue earlier in device_add_disk (Ming Lei) [2042495]
- block: call blk_integrity_add earlier in device_add_disk (Ming Lei) [2042495]
- block: create the bdi link earlier in device_add_disk (Ming Lei) [2042495]
- block: call bdev_add later in device_add_disk (Ming Lei) [2042495]
- block: fold register_disk into device_add_disk (Ming Lei) [2042495]
- block: add a sanity check for a live disk in del_gendisk (Ming Lei) [2042495]
- block: add an explicit ->disk backpointer to the request_queue (Ming Lei) [2042495]
- block: hold a request_queue reference for the lifetime of struct gendisk (Ming Lei) [2042495]
- block: pass a request_queue to __blk_alloc_disk (Ming Lei) [2042495]
- block: remove the minors argument to __alloc_disk_node (Ming Lei) [2042495]
- block: remove alloc_disk and alloc_disk_node (Ming Lei) [2042495]
- block: cleanup the lockdep handling in *alloc_disk (Ming Lei) [2042495]
- sg: do not allocate a gendisk (Ming Lei) [2042495]
- st: do not allocate a gendisk (Ming Lei) [2042495]
- nvme: use blk_mq_alloc_disk (Ming Lei) [2042495]
- block: add back the bd_holder_dir reference in bd_link_disk_holder (Ming Lei) [2042495]
- block: fix default IO priority handling (Ming Lei) [2042495]
- block: Introduce IOPRIO_NR_LEVELS (Ming Lei) [2042495]
- block: fix IOPRIO_PRIO_CLASS() and IOPRIO_PRIO_VALUE() macros (Ming Lei) [2042495]
- block: change ioprio_valid() to an inline function (Ming Lei) [2042495]
- block: improve ioprio class description comment (Ming Lei) [2042495]
- block: bfq: fix bfq_set_next_ioprio_data() (Ming Lei) [2042495]
- block: unexport blk_register_queue (Ming Lei) [2042495]
- blk-cgroup: stop using seq_get_buf (Ming Lei) [2042495]
- blk-cgroup: refactor blkcg_print_stat (Ming Lei) [2042495]
- nvme: use bvec_virt (Ming Lei) [2042495]
- dcssblk: use bvec_virt (Ming Lei) [2042495]
- dasd: use bvec_virt (Ming Lei) [2042495]
- ps3vram: use bvec_virt (Ming Lei) [2042495]
- ubd: use bvec_virt (Ming Lei) [2042495]
- sd: use bvec_virt (Ming Lei) [2042495]
- bcache: use bvec_virt (Ming Lei) [2042495]
- virtio_blk: use bvec_virt (Ming Lei) [2042495]
- rbd: use bvec_virt (Ming Lei) [2042495]
- squashfs: use bvec_virt (Ming Lei) [2042495]
- dm-integrity: use bvec_virt (Ming Lei) [2042495]
- dm-ebs: use bvec_virt (Ming Lei) [2042495]
- dm: make EBS depend on !HIGHMEM (Ming Lei) [2042495]
- block: use bvec_virt in bio_integrity_{process,free} (Ming Lei) [2042495]
- bvec: add a bvec_virt helper (Ming Lei) [2042495]
- block: ensure the bdi is freed after inode_detach_wb (Ming Lei) [2042495]
- block: free the extended dev_t minor later (Ming Lei) [2042495]
- blk-throtl: optimize IOPS throttle for large IO scenarios (Ming Lei) [2042495]
- block: pass a gendisk to bdev_resize_partition (Ming Lei) [2042495]
- block: pass a gendisk to bdev_del_partition (Ming Lei) [2042495]
- block: pass a gendisk to bdev_add_partition (Ming Lei) [2042495]
- block: store a gendisk in struct parsed_partitions (Ming Lei) [2042495]
- block: remove GENHD_FL_UP (Ming Lei) [2042495]
- bcache: move the del_gendisk call out of bcache_device_free (Ming Lei) [2042495]
- bcache: add proper error unwinding in bcache_device_init (Ming Lei) [2042495]
- sx8: use the internal state machine to check if del_gendisk needs to be called (Ming Lei) [2042495]
- nvme: replace the GENHD_FL_UP check in nvme_mpath_shutdown_disk (Ming Lei) [2042495]
- nvme: remove the GENHD_FL_UP check in nvme_ns_remove (Ming Lei) [2042495]
- mmc: block: cleanup gendisk creation (Ming Lei) [2042495]
- mmc: block: let device_add_disk create disk attributes (Ming Lei) [2042495]
- block: move some macros to blkdev.h (Ming Lei) [2042495]
- block: return ELEVATOR_DISCARD_MERGE if possible (Ming Lei) [2042495]
- block: remove the bd_bdi in struct block_device (Ming Lei) [2042495]
- block: move the bdi from the request_queue to the gendisk (Ming Lei) [2042495]
- block: add a queue_has_disk helper (Ming Lei) [2042495]
- block: pass a gendisk to blk_queue_update_readahead (Ming Lei) [2042495]
- block: remove support for delayed queue registrations (Ming Lei) [2042495]
- dm: delay registering the gendisk (Ming Lei) [2042495]
- dm: move setting md->type into dm_setup_md_queue (Ming Lei) [2042495]
- dm: cleanup cleanup_mapped_device (Ming Lei) [2042495]
- block: support delayed holder registration (Ming Lei) [2042495]
- block: look up holders by bdev (Ming Lei) [2042495]
- block: remove the extra kobject reference in bd_link_disk_holder (Ming Lei) [2042495]
- block: make the block holder code optional (Ming Lei) [2042495]
- loop: Select I/O scheduler 'none' from inside add_disk() (Ming Lei) [2042495]
- blk-mq: Introduce the BLK_MQ_F_NO_SCHED_BY_DEFAULT flag (Ming Lei) [2042495]
- block: remove blk-mq-sysfs dead code (Ming Lei) [2042495]
- loop: raise media_change event (Ming Lei) [2042495]
- block: add a helper to raise a media changed event (Ming Lei) [2042495]
- block: export diskseq in sysfs (Ming Lei) [2042495]
- block: add ioctl to read the disk sequence number (Ming Lei) [2042495]
- block: export the diskseq in uevents (Ming Lei) [2042495]
- block: add disk sequence number (Ming Lei) [2042495]
- block: remove cmdline-parser.c (Ming Lei) [2042495]
- block: remove disk_name() (Ming Lei) [2042495]
- block: simplify disk name formatting in check_partition (Ming Lei) [2042495]
- block: simplify printing the device names disk_stack_limits (Ming Lei) [2042495]
- block: use the %%pg format specifier in show_partition (Ming Lei) [2042495]
- block: use the %%pg format specifier in printk_all_partitions (Ming Lei) [2042495]
- block: reduce stack usage in diskstats_show (Ming Lei) [2042495]
- block: remove bdput (Ming Lei) [2042495]
- block: remove bdgrab (Ming Lei) [2042495]
- loop: don't grab a reference to the block device (Ming Lei) [2042495]
- block: change the refcounting for partitions (Ming Lei) [2042495]
- block: allocate bd_meta_info later in add_partitions (Ming Lei) [2042495]
- block: unhash the whole device inode earlier (Ming Lei) [2042495]
- block: assert the locking state in delete_partition (Ming Lei) [2042495]
- block: use bvec_kmap_local in bio_integrity_process (Ming Lei) [2042495]
- block: use bvec_kmap_local in t10_pi_type1_{prepare,complete} (Ming Lei) [2042495]
- block: use memcpy_from_bvec in __blk_queue_bounce (Ming Lei) [2042495]
- block: use memcpy_from_bvec in bio_copy_kern_endio_read (Ming Lei) [2042495]
- block: use memcpy_to_bvec in copy_to_high_bio_irq (Ming Lei) [2042495]
- block: rewrite bio_copy_data_iter to use bvec_kmap_local and memcpy_to_bvec (Ming Lei) [2042495]
- block: remove bvec_kmap_irq and bvec_kunmap_irq (Ming Lei) [2042495]
- ps3disk: use memcpy_{from,to}_bvec (Ming Lei) [2042495]
- dm-writecache: use bvec_kmap_local instead of bvec_kmap_irq (Ming Lei) [2042495]
- rbd: use memzero_bvec (Ming Lei) [2042495]
- block: use memzero_page in zero_fill_bio (Ming Lei) [2042495]
- bvec: add memcpy_{from,to}_bvec and memzero_bvec helper (Ming Lei) [2042495]
- bvec: add a bvec_kmap_local helper (Ming Lei) [2042495]
- bvec: fix the include guards for bvec.h (Ming Lei) [2042495]
- MIPS: don't include <linux/genhd.h> in <asm/mach-rc32434/rb.h> (Ming Lei) [2042495]
- ioprio: move user space relevant ioprio bits to UAPI includes (Ming Lei) [2042495]
- Revert "virtio-blk: Add validation for block size in config space" (Ming Lei) [2042495]
- virtio-blk: remove unneeded "likely" statements (Ming Lei) [2042495]
- Revert "blk-mq: avoid to iterate over stale request" (Ming Lei) [2042495]
- Revert "block: return ELEVATOR_DISCARD_MERGE if possible" (Ming Lei) [2042495]

* Tue Feb 22 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-66.rt21.66.el9]
- mm/vmalloc: Remove unused `cpu' variable. (Luis Claudio R. Goncalves) [2023946]
- preempt: Remove preempt_disable_rt(). (Juri Lelli) [2023946]
- fs/dcache: disable preemption on i_dir_seq's write side. (Luis Claudio R. Goncalves) [2023946]
- fscache: Use only one fscache_object_cong_wait. (Luis Claudio R. Goncalves) [2023946]
- drm/i915: Update the i915 patches (Luis Claudio R. Goncalves) [2023946]
- locking/lockdep: Provide lockdep_assert{,_once}() helpers (Luis Claudio R. Goncalves) [2023946]
- mm: Disable NUMA_BALANCING_DEFAULT_ENABLED and TRANSPARENT_HUGEPAGE on PREEMPT_RT (Luis Claudio R. Goncalves) [2023946]
- fs/namespace: Boost the mount_lock.lock owner instead of spinning on PREEMPT_RT. (Luis Claudio R. Goncalves) [2023946]
- fscache: Use only one fscache_object_cong_wait. (Luis Claudio R. Goncalves) [2023946]
- net: Update the seqcount_t removal from Qdisc. (Juri Lelli) [2023946]
- net: Update the seqcount_t removal from Qdisc. (Luis Claudio R. Goncalves) [2023946]
- arm64: signal: Use ARCH_RT_DELAYS_SIGNAL_SEND. (Luis Claudio R. Goncalves) [2023946]
- net: Update the Qdisc-seqcount series. (Luis Claudio R. Goncalves) [2023946]
- drm/i915: Update the i915 patches. (Luis Claudio R. Goncalves) [2023946]
- irq_work: Update to the latest version. (Juri Lelli) [2023946]
- sched: Sync the sched patches (Luis Claudio R. Goncalves) [2023946]
- irq_work: Sync the patches (Luis Claudio R. Goncalves) [2023946]
- smp: Wake ksoftirqd on PREEMPT_RT instead do_softirq(). (Luis Claudio R. Goncalves) [2023946]
- mm/scatterlist: Sync with the proposed patch. (Luis Claudio R. Goncalves) [2023946]
- zsmalloc. Sync patch (Luis Claudio R. Goncalves) [2023946]
- irq_poll: Use raise_softirq_irqoff() in cpu_dead notifier (Luis Claudio R. Goncalves) [2023946]
- Revert "softirq: Check preemption after reenabling interrupts" for irq_poll (Luis Claudio R. Goncalves) [2023946]
- irq: Export force_irqthreads_key (Luis Claudio R. Goncalves) [2023946]
- sched: Redo delayed mm_struct & task struct deallocation. (Juri Lelli) [2023946]
- sched: Additional might_sleep() improvements. (Luis Claudio R. Goncalves) [2023946]
- Remove a few atomic.h includes. (Luis Claudio R. Goncalves) [2023946]
- smp: Wake ksoftirqd from idle when it is not running. (Luis Claudio R. Goncalves) [2023946]
- smack: Correct intendention level. (Luis Claudio R. Goncalves) [2023946]
- preempt: Move preempt_enable_no_resched() to the RT block (Luis Claudio R. Goncalves) [2023946]
- Revert preempt: Provide preempt_*_nort variants (Luis Claudio R. Goncalves) [2023946]
- locking/rt: Take RCU nesting into account for might_sleep() (Luis Claudio R. Goncalves) [2023946]
- sched: Make cond_resched_lock() RT aware (Luis Claudio R. Goncalves) [2023946]
- genirq: Disable irqfixup/poll on PREEMPT_RT. (Luis Claudio R. Goncalves) [2023946]
- Revert "cpuset: Convert callback_lock to raw_spinlock_t" (Luis Claudio R. Goncalves) [2023946]
- Revert "crypto: limit more FPU-enabled sections" (Luis Claudio R. Goncalves) [2023946]
- lockd: fix failure to cleanup client locks (Scott Mayhew) [2049200]
- lockd: fix server crash on reboot of client holding lock (Scott Mayhew) [2049200]
- SUNRPC: Don't dereference xprt->snd_task if it's a cookie (Scott Mayhew) [2049200]
- tracing: Fix mismatched comment in __string_len (Scott Mayhew) [2049200]
- nfs: block notification on fs with its own ->lock (Scott Mayhew) [2049200]
- NFSD: Fix READDIR buffer overflow (Scott Mayhew) [2049200]
- nfsd: fix use-after-free due to delegation race (Scott Mayhew) [2049200]
- nfsd: Fix nsfd startup race (again) (Scott Mayhew) [2049200]
- SUNRPC: use different lock keys for INET6 and LOCAL (Scott Mayhew) [2049200]
- NFSv4.1: handle NFS4ERR_NOSPC by CREATE_SESSION (Scott Mayhew) [2049200]
- NFSv42: Fix pagecache invalidation after COPY/CLONE (Scott Mayhew) [2049200]
- NFS: Add a tracepoint to show the results of nfs_set_cache_invalid() (Scott Mayhew) [2049200]
- NFSv42: Don't fail clone() unless the OP_CLONE operation failed (Scott Mayhew) [2049200]
- NFSD: Fix exposure in nfsd4_decode_bitmap() (Scott Mayhew) [2049200]
- NFSv4: Sanity check the parameters in nfs41_update_target_slotid() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from decode_getattr_*() functions (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_setsecurity (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_fhget() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_add_or_obtain() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label argument from nfs_instantiate() (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs_setattrres (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_getattr_res (Scott Mayhew) [2049200]
- NFS: Remove the f_label from the nfs4_opendata and nfs_openres (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_lookupp_res struct (Scott Mayhew) [2049200]
- NFS: Remove the label from the nfs4_lookup_res struct (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_link_res struct (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs4_create_res struct (Scott Mayhew) [2049200]
- NFS: Remove the nfs4_label from the nfs_entry struct (Scott Mayhew) [2049200]
- NFS: Create a new nfs_alloc_fattr_with_label() function (Scott Mayhew) [2049200]
- NFS: Always initialise fattr->label in nfs_fattr_alloc() (Scott Mayhew) [2049200]
- NFSv4.2: alloc_file_pseudo() takes an open flag, not an f_mode (Scott Mayhew) [2049200]
- NFS: Don't allocate nfs_fattr on the stack in __nfs42_ssc_open() (Scott Mayhew) [2049200]
- NFSv4: Remove unnecessary 'minor version' check (Scott Mayhew) [2049200]
- NFSv4: Fix potential Oops in decode_op_map() (Scott Mayhew) [2049200]
- NFSv4: Ensure decode_compound_hdr() sanity checks the tag (Scott Mayhew) [2049200]
- NFS: Don't trace an uninitialised value (Scott Mayhew) [2049200]
- SUNRPC: Prevent immediate close+reconnect (Scott Mayhew) [2049200]
- SUNRPC: Fix races when closing the socket (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to OFFLOAD_CANCEL (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to COPY_NOTIFY (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to CB_OFFLOAD (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to CLONE (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to COPY (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoints to FALLOCATE and DEALLOCATE (Scott Mayhew) [2049200]
- NFSv4.2 add tracepoint to SEEK (Scott Mayhew) [2049200]
- SUNRPC: Check if the xprt is connected before handling sysfs reads (Scott Mayhew) [2049200]
- nfs4: take a reference on the nfs_client when running FREE_STATEID (Scott Mayhew) [2049200]
- NFS: Add offset to nfs_aop_readahead tracepoint (Scott Mayhew) [2049200]
- xprtrdma: Fix a maybe-uninitialized compiler warning (Scott Mayhew) [2049200]
- NFS: Move NFS protocol display macros to global header (Scott Mayhew) [2049200]
- NFS: Move generic FS show macros to global header (Scott Mayhew) [2049200]
- nfsd4: remove obselete comment (Scott Mayhew) [2049200]
- SUNRPC: Clean up xs_tcp_setup_sock() (Scott Mayhew) [2049200]
- SUNRPC: Replace use of socket sk_callback_lock with sock_lock (Scott Mayhew) [2049200]
- NFSv4: Fix a regression in nfs_set_open_stateid_locked() (Scott Mayhew) [2049200]
- fsnotify: Protect fsnotify_handle_inode_event from no-inode events (Scott Mayhew) [2049200]
- NFS: Remove redundant call to __set_page_dirty_nobuffers (Scott Mayhew) [2049200]
- sunrpc: remove unnecessary test in rpc_task_set_client() (Scott Mayhew) [2049200]
- NFS: Unexport nfs_probe_fsinfo() (Scott Mayhew) [2049200]
- NFS: Call nfs_probe_server() during a fscontext-reconfigure event (Scott Mayhew) [2049200]
- NFS: Replace calls to nfs_probe_fsinfo() with nfs_probe_server() (Scott Mayhew) [2049200]
- NFS: Move nfs_probe_destination() into the generic client (Scott Mayhew) [2049200]
- NFS: Create an nfs4_server_set_init_caps() function (Scott Mayhew) [2049200]
- NFS: Remove --> and <-- dprintk call sites (Scott Mayhew) [2049200]
- SUNRPC: Trace calls to .rpc_call_done (Scott Mayhew) [2049200]
- NFS: Replace dprintk callsites in nfs_readpage(s) (Scott Mayhew) [2049200]
- SUNRPC: Use BIT() macro in rpc_show_xprt_state() (Scott Mayhew) [2049200]
- SUNRPC: Tracepoints should display tk_pid and cl_clid as a fixed-size field (Scott Mayhew) [2049200]
- xprtrdma: Remove rpcrdma_ep::re_implicit_roundup (Scott Mayhew) [2049200]
- xprtrdma: Provide a buffer to pad Write chunks of unaligned length (Scott Mayhew) [2049200]
- Fix user namespace leak (Scott Mayhew) [2049200]
- NFS: Save some space in the inode (Scott Mayhew) [2049200]
- NFS: Fix WARN_ON due to unionization of nfs_inode.nrequests (Scott Mayhew) [2049200]
- NFSv4: Fixes for nfs4_inode_return_delegation() (Scott Mayhew) [2049200]
- NFS: Fix an Oops in pnfs_mark_request_commit() (Scott Mayhew) [2049200]
- NFS: Fix up commit deadlocks (Scott Mayhew) [2049200]
- NFSD:fix boolreturn.cocci warning (Scott Mayhew) [2049200]
- nfsd: update create verifier comment (Scott Mayhew) [2049200]
- SUNRPC: Change return value type of .pc_encode (Scott Mayhew) [2049200]
- SUNRPC: Replace the "__be32 *p" parameter to .pc_encode (Scott Mayhew) [2049200]
- NFSD: Save location of NFSv4 COMPOUND status (Scott Mayhew) [2049200]
- SUNRPC: Change return value type of .pc_decode (Scott Mayhew) [2049200]
- SUNRPC: Replace the "__be32 *p" parameter to .pc_decode (Scott Mayhew) [2049200]
- SUNRPC: De-duplicate .pc_release() call sites (Scott Mayhew) [2049200]
- SUNRPC: Simplify the SVC dispatch code path (Scott Mayhew) [2049200]
- NFS: Fix deadlocks in nfs_scan_commit_list() (Scott Mayhew) [2049200]
- NFS: Instrument i_size_write() (Scott Mayhew) [2049200]
- SUNRPC: Per-rpc_clnt task PIDs (Scott Mayhew) [2049200]
- NFS: Remove unnecessary TRACE_DEFINE_ENUM()s (Scott Mayhew) [2049200]
- NFSD: Keep existing listeners on portlist error (Scott Mayhew) [2049200]
- nfs: Fix kerneldoc warning shown up by W=1 (Scott Mayhew) [2049200]
- SUNRPC: Capture value of xdr_buf::page_base (Scott Mayhew) [2049200]
- SUNRPC: Add trace event when alloc_pages_bulk() makes no progress (Scott Mayhew) [2049200]
- svcrdma: Split svcrmda_wc_{read,write} tracepoints (Scott Mayhew) [2049200]
- svcrdma: Split the svcrdma_wc_send() tracepoint (Scott Mayhew) [2049200]
- svcrdma: Split the svcrdma_wc_receive() tracepoint (Scott Mayhew) [2049200]
- pnfs/flexfiles: Fix misplaced barrier in nfs4_ff_layout_prepare_ds (Scott Mayhew) [2049200]
- NFS: Remove unnecessary page cache invalidations (Scott Mayhew) [2049200]
- NFS: Do not flush the readdir cache in nfs_dentry_iput() (Scott Mayhew) [2049200]
- NFS: Fix dentry verifier races (Scott Mayhew) [2049200]
- NFS: Further optimisations for 'ls -l' (Scott Mayhew) [2049200]
- NFS: Fix up nfs_readdir_inode_mapping_valid() (Scott Mayhew) [2049200]
- NFS: Ignore the directory size when marking for revalidation (Scott Mayhew) [2049200]
- NFS: Don't set NFS_INO_DATA_INVAL_DEFER and NFS_INO_INVALID_DATA (Scott Mayhew) [2049200]
- NFS: Default change_attr_type to NFS4_CHANGE_TYPE_IS_UNDEFINED (Scott Mayhew) [2049200]
- NFSv4: Retrieve ACCESS on open if we're not using NFS4_CREATE_EXCLUSIVE (Scott Mayhew) [2049200]
- NFS: Fix a few more clear_bit() instances that need release semantics (Scott Mayhew) [2049200]
- SUNRPC: xprt_clear_locked() only needs release memory semantics (Scott Mayhew) [2049200]
- SUNRPC: Remove unnecessary memory barriers (Scott Mayhew) [2049200]
- SUNRPC: Remove WQ_HIGHPRI from xprtiod (Scott Mayhew) [2049200]
- SUNRPC: Add cond_resched() at the appropriate point in __rpc_execute() (Scott Mayhew) [2049200]
- SUNRPC: Partial revert of commit 6f9f17287e78 (Scott Mayhew) [2049200]
- NFS: Fix up nfs_ctx_key_to_expire() (Scott Mayhew) [2049200]
- NFS: Label the dentry with a verifier in nfs_rmdir() and nfs_unlink() (Scott Mayhew) [2049200]
- NFS: Label the dentry with a verifier in nfs_link(), nfs_symlink() (Scott Mayhew) [2049200]
- NFSD: Have legacy NFSD WRITE decoders use xdr_stream_subsegment() (Scott Mayhew) [2049200]
- SUNRPC: xdr_stream_subsegment() must handle non-zero page_bases (Scott Mayhew) [2049200]
- NFSD: Initialize pointer ni with NULL and not plain integer 0 (Scott Mayhew) [2049200]
- NFSD: simplify struct nfsfh (Scott Mayhew) [2049200]
- NFSD: drop support for ancient filehandles (Scott Mayhew) [2049200]
- NFSD: move filehandle format declarations out of "uapi". (Scott Mayhew) [2049200]
- SUNRPC: fix sign error causing rpcsec_gss drops (Scott Mayhew) [2049200]
- nfsd: Fix a warning for nfsd_file_close_inode (Scott Mayhew) [2049200]
- nfsd4: Handle the NFSv4 READDIR 'dircount' hint being zero (Scott Mayhew) [2049200]
- nfsd: fix error handling of register_pernet_subsys() in init_nfsd() (Scott Mayhew) [2049200]
- UNRPC: Return specific error code on kmalloc failure (Scott Mayhew) [2049200]
- NFSD: Optimize DRC bucket pruning (Scott Mayhew) [2049200]
- nfsd: don't alloc under spinlock in rpc_parse_scope_id (Scott Mayhew) [2049200]
- nfsd: back channel stuck in SEQ4_STATUS_CB_PATH_DOWN (Scott Mayhew) [2049200]
- NLM: Fix svcxdr_encode_owner() (Scott Mayhew) [2049200]
- SUNRPC: improve error response to over-size gss credential (Scott Mayhew) [2049200]
- SUNRPC: don't pause on incomplete allocation (Scott Mayhew) [2049200]
- NFS: Always provide aligned buffers to the RPC read layers (Scott Mayhew) [2049200]
- NFSv4.1 add network transport when session trunking is detected (Scott Mayhew) [2049200]
- SUNRPC enforce creation of no more than max_connect xprts (Scott Mayhew) [2049200]
- NFSv4 introduce max_connect mount options (Scott Mayhew) [2049200]
- SUNRPC add xps_nunique_destaddr_xprts to xprt_switch_info in sysfs (Scott Mayhew) [2049200]
- SUNRPC keep track of number of transports to unique addresses (Scott Mayhew) [2049200]
- NFSv3: Delete duplicate judgement in nfs3_async_handle_jukebox (Scott Mayhew) [2049200]
- SUNRPC: Tweak TCP socket shutdown in the RPC client (Scott Mayhew) [2049200]
- SUNRPC: Simplify socket shutdown when not reusing TCP ports (Scott Mayhew) [2049200]
- nfsd: fix crash on LOCKT on reexported NFSv3 (Scott Mayhew) [2049200]
- nfs: don't allow reexport reclaims (Scott Mayhew) [2049200]
- lockd: don't attempt blocking locks on nfs reexports (Scott Mayhew) [2049200]
- nfs: don't atempt blocking locks on nfs reexports (Scott Mayhew) [2049200]
- Keep read and write fds with each nlm_file (Scott Mayhew) [2049200]
- lockd: update nlm_lookup_file reexport comment (Scott Mayhew) [2049200]
- nlm: minor refactoring (Scott Mayhew) [2049200]
- nlm: minor nlm_lookup_file argument change (Scott Mayhew) [2049200]
- lockd: lockd server-side shouldn't set fl_ops (Scott Mayhew) [2049200]
- SUNRPC: Server-side disconnect injection (Scott Mayhew) [2049200]
- SUNRPC: Move client-side disconnect injection (Scott Mayhew) [2049200]
- SUNRPC: Add a /sys/kernel/debug/fail_sunrpc/ directory (Scott Mayhew) [2049200]
- redhat/configs: Add CONFIG_FAIL_SUNRPC (Scott Mayhew) [2049200]
- svcrdma: xpt_bc_xprt is already clear in __svc_rdma_free() (Scott Mayhew) [2049200]
- nfsd4: Fix forced-expiry locking (Scott Mayhew) [2049200]
- rpc: fix gss_svc_init cleanup on failure (Scott Mayhew) [2049200]
- SUNRPC: Add RPC_AUTH_TLS protocol numbers (Scott Mayhew) [2049200]
- lockd: change the proc_handler for nsm_use_hostnames (Scott Mayhew) [2049200]
- sysctl: introduce new proc handler proc_dobool (Scott Mayhew) [2049200]
- SUNRPC: Fix a NULL pointer deref in trace_svc_stats_latency() (Scott Mayhew) [2049200]
- NFSD: remove vanity comments (Scott Mayhew) [2049200]
- svcrdma: Convert rdma->sc_rw_ctxts to llist (Scott Mayhew) [2049200]
- svcrdma: Relieve contention on sc_send_lock. (Scott Mayhew) [2049200]
- svcrdma: Fewer calls to wake_up() in Send completion handler (Scott Mayhew) [2049200]
- lockd: Fix invalid lockowner cast after vfs_test_lock (Scott Mayhew) [2049200]
- NFSD: Use new __string_len C macros for nfsd_clid_class (Scott Mayhew) [2049200]
- NFSD: Use new __string_len C macros for the nfs_dirent tracepoint (Scott Mayhew) [2049200]
- tracing: Add trace_event helper macros __string_len() and __assign_str_len() (Scott Mayhew) [2049200]
- NFSD: Batch release pages during splice read (Scott Mayhew) [2049200]
- SUNRPC: Add svc_rqst_replace_page() API (Scott Mayhew) [2049200]
- NFSD: Clean up splice actor (Scott Mayhew) [2049200]
- NFSv4.2: remove restriction of copy size for inter-server copy. (Scott Mayhew) [2049200]
- NFS: Clean up the synopsis of callback process_op() (Scott Mayhew) [2049200]
- NFS: Extract the xdr_init_encode/decode() calls from decode_compound (Scott Mayhew) [2049200]
- NFS: Remove unused callback void decoder (Scott Mayhew) [2049200]
- NFS: Add a private local dispatcher for NFSv4 callback operations (Scott Mayhew) [2049200]
- SUNRPC: Eliminate the RQ_AUTHERR flag (Scott Mayhew) [2049200]
- SUNRPC: Set rq_auth_stat in the pg_authenticate() callout (Scott Mayhew) [2049200]
- SUNRPC: Add svc_rqst::rq_auth_stat (Scott Mayhew) [2049200]
- SUNRPC: Add dst_port to the sysfs xprt info file (Scott Mayhew) [2049200]
- SUNRPC: Add srcaddr as a file in sysfs (Scott Mayhew) [2049200]
- sunrpc: Fix return value of get_srcport() (Scott Mayhew) [2049200]
- SUNRPC/xprtrdma: Fix reconnection locking (Scott Mayhew) [2049200]
- SUNRPC: Clean up scheduling of autoclose (Scott Mayhew) [2049200]
- SUNRPC: Fix potential memory corruption (Scott Mayhew) [2049200]
- NFSv4/pnfs: The layout barrier indicate a minimal value for the seqid (Scott Mayhew) [2049200]
- NFSv4/pNFS: Always allow update of a zero valued layout barrier (Scott Mayhew) [2049200]
- NFSv4/pNFS: Remove dead code (Scott Mayhew) [2049200]
- NFSv4/pNFS: Fix a layoutget livelock loop (Scott Mayhew) [2049200]
- SUNRPC: Convert rpc_client refcount to use refcount_t (Scott Mayhew) [2049200]
- xprtrdma: Eliminate rpcrdma_post_sends() (Scott Mayhew) [2049200]
- xprtrdma: Add an xprtrdma_post_send_err tracepoint (Scott Mayhew) [2049200]
- xprtrdma: Add xprtrdma_post_recvs_err() tracepoint (Scott Mayhew) [2049200]
- xprtrdma: Put rpcrdma_reps before waking the tear-down completion (Scott Mayhew) [2049200]
- xprtrdma: Disconnect after an ib_post_send() immediate error (Scott Mayhew) [2049200]
- SUNRPC: Record timeout value in xprt_retransmit tracepoint (Scott Mayhew) [2049200]
- SUNRPC: xprt_retransmit() displays the the NULL procedure incorrectly (Scott Mayhew) [2049200]
- SUNRPC: Update trace flags (Scott Mayhew) [2049200]
- SUNRPC: Remove unneeded TRACE_DEFINE_ENUMs (Scott Mayhew) [2049200]
- SUNRPC: Unset RPC_TASK_NO_RETRANS_TIMEOUT for NULL RPCs (Scott Mayhew) [2049200]
- SUNRPC: Refactor rpc_ping() (Scott Mayhew) [2049200]

* Tue Feb 22 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-65.rt21.65.el9]
- ALSA: memalloc: Unify x86 SG-buffer handling (take#3) (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: add mapping for MSI MPG X570S Carbon Max Wifi. (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Drop CONFIG_PM ifdefs (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix dB level of Bose Revolve+ SoundLink (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add minimal-mute notion in dB mapping table (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Use int for dB map values (Jaroslav Kysela) [2017320]
- ALSA: hda/tegra: Fix Tegra194 HDA reset failure (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Use ALC285_FIXUP_HP_GPIO_LED on another HP laptop (Jaroslav Kysela) [2017320]
- ALSA: hda: Add new AlderLake-P variant PCI ID (Jaroslav Kysela) [2017320]
- ALSA: hda: Add AlderLake-N PCI ID (Jaroslav Kysela) [2017320]
- ALSA: hda: use swap() to make code cleaner (Jaroslav Kysela) [2017320]
- ALSA: Fix some typo (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: Consider ELD is invalid when no SAD is present (Jaroslav Kysela) [2017320]
- ALSA: hda: Remove redundant runtime PM calls (Jaroslav Kysela) [2017320]
- ALSA: hda: Do disconnect jacks at codec unbind (Jaroslav Kysela) [2017320]
- ALSA: hda: intel: More comprehensive PM runtime setup for controller driver (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: fix build issue related to CODEC_PROBE_ENTRIES (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Report initial jack state (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Re-order quirk entries for Lenovo (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Legion Y9000X 2020 (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add speaker fixup for some Yoga 15ITL5 devices (Jaroslav Kysela) [2017320]
- tools headers UAPI: Sync sound/asound.h with the kernel sources (Jaroslav Kysela) [2017320]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2017320]
- tools include UAPI: Sync sound/asound.h copy with the kernel sources (Jaroslav Kysela) [2017320]
- ASoC: SOF: handle paused streams during system suspend (Jaroslav Kysela) [2017320]
- ASoC: SOF: sof-audio: setup sched widgets during pipeline complete step (Jaroslav Kysela) [2017320]
- ASoC: SOF: free widgets in sof_tear_down_pipelines() for static pipelines (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: correct default value (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: correct pcmif BE dai control flow (Jaroslav Kysela) [2017320]
- ALSA: RHEL - update kernel configs for RHEL 9.0 (Jaroslav Kysela) [2017320]
- ALSA: core: Fix SSID quirk lookup for subvendor=0 (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Fix Jack detection after resume (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Increase delay during jack detection (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus Master after reboot from Windows (Jaroslav Kysela) [2017320]
- ASoC: Intel: catpt: Test dmaengine_submit() result before moving on (Jaroslav Kysela) [2017320]
- ASoC: amd: Fix dependency for SPI master (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Drop superfluous '0' in Presonus Studio 1810c's ID (Jaroslav Kysela) [2017320]
- ALSA: oss: fix compile error when OSS_DEBUG is enabled (Jaroslav Kysela) [2017320]
- ALSA: hda: Make proper use of timecounter (Jaroslav Kysela) [2017320]
- ALSA: led: Use restricted type for iface assignment (Jaroslav Kysela) [2017320]
- ALSA: hda: Fix potential deadlock at codec unbinding (Jaroslav Kysela) [2017320]
- ALSA: hda: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ALSA: PCM: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ALSA: jack: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: fix jack detection on HP Spectre x360 convertible (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix quirk for Clevo NJ51CU (Jaroslav Kysela) [2017320]
- ALSA: rawmidi - fix the uninitalized user_pversion (Jaroslav Kysela) [2017320]
- ALSA: hda: intel-sdw-acpi: go through HDAS ACPI at max depth of 2 (Jaroslav Kysela) [2017320]
- ALSA: hda: intel-sdw-acpi: harden detection of controller (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: Disable silent stream on GLK (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP ProBook (Jaroslav Kysela) [2017320]
- ASoC: meson: aiu: Move AIU_I2S_MISC hold setting to aiu-fifo-i2s (Jaroslav Kysela) [2017320]
- ASoC: meson: aiu: fifo: Add missing dma_coerce_mask_and_coherent() (Jaroslav Kysela) [2017320]
- ASoC: tas2770: Fix setting of high sample rates (Jaroslav Kysela) [2017320]
- ASoC: rt5682: fix the wrong jack type detected (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add new alc285-hp-amp-init model (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Amp init fixup for HP ZBook 15 G6 (Jaroslav Kysela) [2017320]
- ASoC: tegra: Restore headphones jack name on Nyan Big (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add DAPM switches for headphones and mic jack (Jaroslav Kysela) [2017320]
- ALSA: jack: Check the return value of kstrdup() (Jaroslav Kysela) [2017320]
- ALSA: drivers: opl3: Fix incorrect use of vp->state (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek - Add headset Mic support for Lenovo ALC897 platform (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: pci-tgl: add new ADL-P variant (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: pci-tgl: add ADL-N support (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Reorder snd_djm_devices[] entries (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix quirk for TongFang PHxTxX1 (Jaroslav Kysela) [2017320]
- ALSA: ctl: Fix copy of updated id with element read/write (Jaroslav Kysela) [2017320]
- ALSA: pcm: oss: Handle missing errors in snd_pcm_oss_change_params*() (Jaroslav Kysela) [2017320]
- ALSA: pcm: oss: Limit the period size to 16MB (Jaroslav Kysela) [2017320]
- ALSA: pcm: oss: Fix negative period/buffer sizes (Jaroslav Kysela) [2017320]
- ASoC: codecs: wsa881x: fix return values from kcontrol put (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd934x: return correct value from mixer put (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd934x: handle channel mappping list correctly (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6routing: Fix return value from msm_routing_put_audio_mixer (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: fix HDA codec entry table order for ADL-P (Jaroslav Kysela) [2017320]
- ALSA: hda: Add Intel DG2 PCI ID and HDMI codec vid (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Retry codec probing if it fails (Jaroslav Kysela) [2017320]
- ASoC: amd: fix uninitialized variable in snd_acp6x_probe() (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Set PMSG_ON earlier inside cs8409 driver (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Fix crash due to out of scope stack vars (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Fix crash due to out of scope stack vars (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for ADX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for AMX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for Mixer (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for MVC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use normal system sleep for SFC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Balance runtime PM count (Jaroslav Kysela) [2017320]
- ASoC: SOF: hda: reset DAI widget before reconfiguring it (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Set the max SPI speed for the whole device (Jaroslav Kysela) [2017320]
- ALSA: intel-dsp-config: add quirk for CML devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add entry for ESSX8336 on CML (Jaroslav Kysela) [2017320]
- ASoC: rk817: Add module alias for rk817-codec (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: Set mach->id field on comp_ids matches (Jaroslav Kysela) [2017320]
- ALSA: intel-dsp-config: add quirk for JSL devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Don't start stream for capture at prepare (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Switch back to non-latency mode at a later point (Jaroslav Kysela) [2017320]
- ALSA: ctxfi: Fix out-of-range access (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in Mixer (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in ADX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in AMX (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in SFC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in MVC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in AHUB (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in DSPK (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in DMIC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in I2S (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix kcontrol put callback in ADMAIF (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in MVC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in SFC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in DSPK (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in DMIC (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in I2S (Jaroslav Kysela) [2017320]
- ASoC: tegra: Fix wrong value type in ADMAIF (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix LED on HP ProBook 435 G7 (Jaroslav Kysela) [2017320]
- ASoC: stm32: i2s: fix 32 bits channel length without mclk (Jaroslav Kysela) [2017320]
- ASoC: codecs: lpass-rx-macro: fix HPHR setting CLSH mask (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd934x: return error code correctly from hw_params (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: fix volatile register range (Jaroslav Kysela) [2017320]
- ASoC: topology: Add missing rwsem around snd_ctl_remove() calls (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6routing: validate port id before setting up route (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6adm: improve error reporting (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6asm: fix q6asm_dai_prepare error handling (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6routing: Conditionally reset FrontEnd Mixer (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: qdsp6: q6prm: handle clk disable correctly (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: wm_adsp_control_add() error: uninitialized symbol 'ret' (Jaroslav Kysela) [2017320]
- ALSA: cmipci: Drop stale variable assignment (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for ASRock NUC Box 1100 (Jaroslav Kysela) [2017320]
- ASoC: rsnd: fixup DMAEngine API (Jaroslav Kysela) [2017320]
- ASoC: SOF: build compression interface into snd_sof.ko (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8173: Fix debugfs registration for components (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Re-detect the combo jack after resuming (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Avoid the unexpected IRQ event during going to suspend (Jaroslav Kysela) [2017320]
- ASoC: rt1011: revert 'I2S Reference' to SOC_ENUM_EXT (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Add the compatibility with rt9120s (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Fix clock auto sync issue when fs is the multiple of 48 (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Update internal ocp level to the correct value (Jaroslav Kysela) [2017320]
- ALSA: fireworks: add support for Loud Onyx 1200f quirk (Jaroslav Kysela) [2017320]
- ALSA: hda: fix general protection fault in azx_runtime_idle (Jaroslav Kysela) [2017320]
- ALSA: hda: Free card instance properly at probe errors (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for HP EliteBook 840 G7 mute LED (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Remove a stale comment (Jaroslav Kysela) [2017320]
- ALSA: synth: missing check for possible NULL after the call to kstrdup (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Use proper SG helpers for noncontig allocations (Jaroslav Kysela) [2017320]
- ALSA: pci: rme: Fix unaligned buffer addresses (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add support for MOTU Track 16 (Jaroslav Kysela) [2017320]
- ALSA: PCM: Fix NULL dereference at mmap checks (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for ASUS UX550VE (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B12 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add SKU 0B29 SoundWire configuration (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B29 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add SKU 0B13 SoundWire configuration (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B13 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B11 product (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0B00 and 0B01 products (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add SKU 0AF3 SoundWire configuration (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: Add support for SKU 0AF3 product (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8173-rt5650: Rename Speaker control to Ext Spk (Jaroslav Kysela) [2017320]
- mfd: arizona: Split of_match table into I2C and SPI versions (Jaroslav Kysela) [2017320]
- ASoC: DAPM: Cover regression by kctl change notification fix (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: fix hotplug when only codec is suspended (Jaroslav Kysela) [2017320]
- ALSA: timer: Unconditionally unlink slave instances, too (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Catch call with NULL snd_dma_buffer pointer (Jaroslav Kysela) [2017320]
- Revert "ALSA: memalloc: Convert x86 SG-buffer handling with non-contiguous type" (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add a quirk for Acer Spin SP513-54N (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add support for MOTU Traveler mk3 (Jaroslav Kysela) [2017320]
- ASoC: SOF:control: Fix variable type in snd_sof_refresh_control() (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Headset fixup for Clevo NH77HJQ (Jaroslav Kysela) [2017320]
- ALSA: timer: Fix use-after-free problem (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add quirk for Audient iD14 (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Change monitor widgets to siggens (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Clevo PC70HS (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Line6 HX-Stomp XL USB_ID for 48k-fixed quirk (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add registration quirk for JBL Quantum 400 (Jaroslav Kysela) [2017320]
- ASoC: rsnd: Fix an error handling path in 'rsnd_node_count()' (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic3x: Make aic3x_remove() return void (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: use const for all uses of snd_soc_acpi_codecs (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi-cht: shrink tables using compatible IDs (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi-byt: shrink tables using compatible IDs (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: use comp_ids to enumerate rt5682s (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: detect codec variant in probe function (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: add comp_ids field for machine driver matching (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add machine driver with mt6359, rt1011 and rt5682 (Jaroslav Kysela) [2017320]
- ASoC: Stop dummy from overriding hwparams (Jaroslav Kysela) [2017320]
- ASoC: topology: Change topology device to card device (Jaroslav Kysela) [2017320]
- ASoC: topology: Use correct device for prints (Jaroslav Kysela) [2017320]
- ASoC: topology: Check for dapm widget completeness (Jaroslav Kysela) [2017320]
- ASoC: topology: Add header payload_size verification (Jaroslav Kysela) [2017320]
- ASoC: core: Remove invalid snd_soc_component_set_jack call (Jaroslav Kysela) [2017320]
- ASoC: codecs: tfa989x: Add support for tfa9897 RCV bit (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: select CONFIG_SND_SOC_ACPI (Jaroslav Kysela) [2017320]
- ASoC: Intel: glk_rt5682_max98357a: support ALC5682I-VS codec (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependencies on GPIOLIB for SND_SOC_RT1015P (Jaroslav Kysela) [2017320]
- ASoC: es8316: add support for ESSX8336 ACPI _HID (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Correct configuring of switch inversion from ts-inv (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: remove TODO for interaction with userspace about control message (Jaroslav Kysela) [2017320]
- ALSA: oxfw: fix functional regression for Mackie Onyx 1640i in v5.14 or later (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: Fix clang -Wimplicit-fallthrough (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependencies on GPIOLIB for SND_SOC_DMIC (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: export meter information to userspace as float value (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: refine parser for meter information in register DSP models (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: fix null pointer dereference when polling hwdep character device (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add a quirk for HP OMEN 15 mute LED (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: fix Kconfig dependencies (Jaroslav Kysela) [2017320]
- ASoC: rt5682-i2c: Use devm_clk_get_optional for optional clock (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add entry for ESSX8336 on JSL (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Fix return value check in acp_machine_select() (Jaroslav Kysela) [2017320]
- ASoC: max98520: add max98520 audio amplifier driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: fix return value (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: rename shadowed array (Jaroslav Kysela) [2017320]
- ASoC: mediatek: remove unnecessary initialization (Jaroslav Kysela) [2017320]
- ASoC: nau8821: clarify out-of-bounds check (Jaroslav Kysela) [2017320]
- ASoC: nau8821: fix kernel-doc (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: use 'static' qualifier (Jaroslav Kysela) [2017320]
- ASoC: topology: handle endianness warning (Jaroslav Kysela) [2017320]
- ALSA: ua101: fix division by zero at probe (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: SND_SOC_AMD_ACP_COMMON should depend on X86 && PCI (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: SND_SOC_AMD_{LEGACY_MACH,SOF_MACH} should depend on X86 && PCI && I2C (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Wrap AMD Audio ACP components in SND_SOC_AMD_ACP_COMMON (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: free_irq() before powering-down on probe() fail (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Reset and power-down on remove() and failed probe() (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add support for q6prm-clocks (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6prm support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6apm lpass dai support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6apm-dai support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add topology support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add Kconfig and Makefile (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add module configuration command helpers (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add q6apm support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: audioreach: add basic pkt alloc support (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6afe-clocks: move audio-clocks to common file (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6afe-dai: move lpass audio ports to common file (Jaroslav Kysela) [2017320]
- ASoC: codecs: Change bulk clock voting to optional voting in digital codecs (Jaroslav Kysela) [2017320]
- ASoC: codecs: tx-macro: Update tx default values (Jaroslav Kysela) [2017320]
- ASoC: codecs: tx-macro: Enable tx top soundwire mic clock (Jaroslav Kysela) [2017320]
- ASoC: qcom: Add compatible names in va,wsa,rx,tx codec drivers for sc7280 (Jaroslav Kysela) [2017320]
- ASoC: nau8825: add clock management for power saving (Jaroslav Kysela) [2017320]
- ASoC: nau8825: add set_jack coponment support (Jaroslav Kysela) [2017320]
- ALSA: line6: fix control and interrupt message timeouts (Jaroslav Kysela) [2017320]
- ALSA: 6fire: fix control and bulk message timeouts (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: fix null pointer dereference on pointer cs_desc (Jaroslav Kysela) [2017320]
- ALSA: gus: fix null pointer dereference on pointer block (Jaroslav Kysela) [2017320]
- ALSA: mixer: fix deadlock in snd_mixer_oss_set_volume (Jaroslav Kysela) [2017320]
- ASoC: topology: Fix stub for snd_soc_tplg_component_remove() (Jaroslav Kysela) [2017320]
- ASoC: qcom: common: Respect status = "disabled" on DAI link nodes (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Prevent NULL pointer deref in interrupt handler (Jaroslav Kysela) [2017320]
- ASoC: wm8962: Convert to devm_clk_get_optional() (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependency on GPIOLIB for SND_SOC_MAX98357A (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Make cs35l41_remove() return void (Jaroslav Kysela) [2017320]
- ASoc: wm8900: Drop empty spi_driver remove callback (Jaroslav Kysela) [2017320]
- ASoC: tegra: Set default card name for Trimslice (Jaroslav Kysela) [2017320]
- ASoC: tegra: Restore AC97 support (Jaroslav Kysela) [2017320]
- ASoc: wm8731: Drop empty spi_driver remove callback (Jaroslav Kysela) [2017320]
- ASoC: doc: update codec example code (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add acp_machine struct for renoir platform. (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Downsizing the DAC volume scale (Jaroslav Kysela) [2017320]
- ASoC: meson: axg-tdm-interface: manage formatters in trigger (Jaroslav Kysela) [2017320]
- ASoC: meson: axg-card: make links nonatomic (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Remove unused runtime_suspend/runtime_resume callbacks (Jaroslav Kysela) [2017320]
- ASoC: fix unmet dependency on GPIOLIB (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix mic mute LED for the HP Spectre x360 14 (Jaroslav Kysela) [2017320]
- ALSA: mixer: oss: Fix racy access to slots (Jaroslav Kysela) [2017320]
- ASoC: cirrus: i2s: Prepare clock before using it (Jaroslav Kysela) [2017320]
- soundwire: qcom: add debugfs entry for soundwire register dump (Jaroslav Kysela) [2017320]
- soundwire: bus: stop dereferencing invalid slave pointer (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add support for RT5682-VS codec (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add support for Maxim amplifier codec (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add callback for machine driver on ACP (Jaroslav Kysela) [2017320]
- ASoC: rockchip: Use generic dmaengine code (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s_tdm: Dup static DAI template (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s_tdm: improve return value handling (Jaroslav Kysela) [2017320]
- ASoC: Intel: Move soc_intel_is_foo() helpers to a generic header (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Fix a typo in snd_dma_buffer_sync() description (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Drop superfluous snd_dma_buffer_sync() declaration (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix microphone sound on Jieli webcam. (Jaroslav Kysela) [2017320]
- ASoC: qcom: sm8250: Add Jack support (Jaroslav Kysela) [2017320]
- ASoC: qcom: sm8250: add support for TX and RX Macro dais (Jaroslav Kysela) [2017320]
- ASoC: amd: enable Yellow Carp platform machine driver build (Jaroslav Kysela) [2017320]
- ASoC: amd: add YC machine driver using dmic (Jaroslav Kysela) [2017320]
- ASoC: amd: create platform device for acp6x machine driver (Jaroslav Kysela) [2017320]
- ASoC: amd: enable Yellow carp acp6x drivers build (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pdm driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pci driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pdm driver dma ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x irq handler (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x pdm platform driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add platform devices for acp6x pdm driver and dmic driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add acp6x init/de-init functions (Jaroslav Kysela) [2017320]
- ASoC: amd: add Yellow Carp ACP PCI driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add Yellow Carp ACP6x IP register header (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add SOF audio support on Chrome board (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add legacy sound card support for Chrome audio (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add generic machine driver support for ACP cards (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: Add I2S support on Renoir platform (Jaroslav Kysela) [2017320]
- ASoC: amd: Add common framework to support I2S on ACP SOC (Jaroslav Kysela) [2017320]
- ALSA: uapi: Fix a C++ style comment in asound.h (Jaroslav Kysela) [2017320]
- ALSA: firewire: Fix C++ style comments in uapi header (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Fix refcount test (Jaroslav Kysela) [2017320]
- ASoC: meson: implement driver_name for snd_soc_card in meson-card-utils (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic32x4: Make aic32x4_remove() return void (Jaroslav Kysela) [2017320]
- ASoC: soc-core: accept zero format at snd_soc_runtime_set_dai_fmt() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: tidyup empty function (Jaroslav Kysela) [2017320]
- ASoC: soc-component: add snd_soc_component_is_codec() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: tidyup soc_pcm_hw_clean() - step2 (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: tidyup soc_pcm_hw_clean() - step1 (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Convert x86 SG-buffer handling with non-contiguous type (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Support for non-coherent page allocation (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Support for non-contiguous page allocation (Jaroslav Kysela) [2017320]
- ALSA: ISA: not for M68K (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Strip out direct CRU use (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: notify event for parameter change in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: queue event for parameter change in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add ioctl command to read cached parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for input parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for line input parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for output parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for mixer output parameters in register DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: parse messages for mixer source parameters in register-DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add ioctl command to read cached hardware meter (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add message parser for meter information in command DSP model (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add message parser to gather meter information in register DSP model (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Always enable TS_PLUG and TS_UNPLUG interrupts (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Fix WARN in remove() if running without an interrupt (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Mark OSC_SWITCH_STATUS register volatile (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Set correct SRC MCLK (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Allow time for HP/ADC to power-up after enable (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Use PLL for SCLK > 12.288MHz (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Don't claim to support 192k (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Defer probe if request_threaded_irq() returns EPROBE_DEFER (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Don't set defaults for volatile registers (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Correct some register default values (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Always configure both ASP TX channels (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Don't reconfigure the PLL while it is running (Jaroslav Kysela) [2017320]
- ASoC: soc-component: improve error reporting for register access (Jaroslav Kysela) [2017320]
- ASoC: amd: enable vangogh platform machine driver build (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh machine driver (Jaroslav Kysela) [2017320]
- ASoc: amd: create platform device for VG machine driver (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Codec2Codec sample (Multi) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Codec2Codec sample (Single) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add DPCM sample (Multi) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add DPCM sample (Single) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Sample DT for Normal (Nulti) (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2-custom-sample.dtsi: add Sample DT for Normal (Single) (Jaroslav Kysela) [2017320]
- ASoC: add Audio Graph Card2 Custom Sample (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2: add Codec2Codec support (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2: add DPCM support (Jaroslav Kysela) [2017320]
- ASoC: audio-graph-card2: add Multi CPU/Codec support (Jaroslav Kysela) [2017320]
- ASoC: add Audio Graph Card2 driver (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: add codec2codec support (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: add asoc_graph_is_ports0() (Jaroslav Kysela) [2017320]
- ASoC: test-component: add Test Component for Sound debug/test (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fixes HP Spectre x360 15-eb1xxx speakers (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Provide quirk for Sennheiser GSP670 Headset (Jaroslav Kysela) [2017320]
- ALSA: pcm: Unify snd_pcm_delay() and snd_pcm_hwsync() (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Initialize every feature unit once at probe time (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Drop superfluous error message after disconnection (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Downgrade error message in get_ctl_value_v2() (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Clevo PC50HS (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: add Schiit Hel device to quirk table (Jaroslav Kysela) [2017320]
- ASoC: rt5682: fix a little pop while playback (Jaroslav Kysela) [2017320]
- ASoC: rt1011: Fix 'I2S Reference' enum control (Jaroslav Kysela) [2017320]
- ASoC: wm8960: Fix clock configuration on slave mode (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Add rt9210 audio amplifier support (Jaroslav Kysela) [2017320]
- ASoC: amd: vangogh: constify static struct snd_soc_dai_ops (Jaroslav Kysela) [2017320]
- ASoC: mediatek: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Drop rt9210 audio amplifier support (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add quirk for VF0770 (Jaroslav Kysela) [2017320]
- ALSA: hda: avoid write to STATESTS if controller is in reset (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Less restriction for low-latency playback mode (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix the mic type detection issue for ASUS G551JW (Jaroslav Kysela) [2017320]
- ASoC: rt1011: Fix 'I2S Reference' enum control caused error (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Ensure 0dB full scale volume is used for headsets (Jaroslav Kysela) [2017320]
- ALSA: pcm: Workaround for a wrong offset in SYNC_PTR compat ioctl (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: use devm_clk_get_optional() for mclk (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: Use temporary variable for struct device (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5651: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: use devm_clk_get_optional() for mclk (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Use temporary variable for struct device (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2017320]
- ASoC: amd: Kconfig: Select fch clock support with machine driver (Jaroslav Kysela) [2017320]
- ASoC: soc-core: fix null-ptr-deref in snd_soc_del_component_unlocked() (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Fix for quirk to enable speaker output on the Lenovo 13s Gen2 (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add support for the Pioneer DJM 750MK2 Mixer/Soundcard (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Fix error handling on i2s_tdm_prepare_enable_mclk failure (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s-tdm: Remove call to rockchip_i2s_ch_to_io (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: update audsys clock parent name (Jaroslav Kysela) [2017320]
- ASoC: SOF: prepare code to allocate IPC messages in fw_ready (Jaroslav Kysela) [2017320]
- ASoC: rt9120: Add rt9210 audio amplifier support (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: restore mixer functionality (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Fix hp pop produced immediately after resuming (Jaroslav Kysela) [2017320]
- ASoC: rockchip: add support for i2s-tdm controller (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce fragment elapsed notification API (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: Use newly introduced generic IPC stream ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: Make Intel IPC stream ops generic (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce snd_sof_mailbox_read / snd_sof_mailbox_write callbacks (Jaroslav Kysela) [2017320]
- ASoC: SOF: pipelines: Harmonize all functions to use struct snd_sof_dev (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: do not power down primary core during topology removal (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: Dump registers and stack when SOF_DBG_DUMP_REGS is set (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-loader: Drop SOF_DBG_DUMP_REGS flag from dbg_dump calls (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Drop SOF_DBG_DUMP_REGS flag when firmware start fails (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: Clean up snd_sof_get_status() prints (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: hda: Drop 'error' prefix from error dump functions (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce macro to set the firmware state (Jaroslav Kysela) [2017320]
- ASoC: SOF: ops: Force DSP panic dumps to be printed (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Re-enable dumps after successful IPC tx (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Print out the fw_state along with the DSP dump (Jaroslav Kysela) [2017320]
- ASoC: SOF: Drop SOF_DBG_DUMP_FORCE_ERR_LEVEL and sof_dev_dbg_or_err (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: hda-loader: Use snd_sof_dsp_dbg_dump() for DSP dump (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Add SOF_DBG_DUMP_OPTIONAL flag for DSP dumping (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug/ops: Move the IPC and DSP dump functions out from the header (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: atom: No need to do a DSP dump in atom_run() (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Print the DSP dump if boot fails (Jaroslav Kysela) [2017320]
- ASoC: SOF: Print the dbg_dump and ipc_dump once to reduce kernel log noise (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc and dsp dump: Add markers for better visibility (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Swap the dsp_dump and ipc_dump sequence for fw_exception (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: debug: force all processing on primary core (Jaroslav Kysela) [2017320]
- ASoC: max98927: Handle reset gpio when probing i2c (Jaroslav Kysela) [2017320]
- ASoC: codec: wcd938x: Add irq config support (Jaroslav Kysela) [2017320]
- ASoC: DAPM: Fix missing kctl change notifications (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Utilize dev_err_probe() to avoid log saturation (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Switch to use gpiod_get_optional() (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Use temporary variable for struct device (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcht_es8316: Get platform data via dev_get_platdata() (Jaroslav Kysela) [2017320]
- ASoC: wcd938x: Fix jack detection issue (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Pass JOINT_DUPLEX info flag for implicit fb streams (Jaroslav Kysela) [2017320]
- ALSA: pcm: Add more disconnection checks at file ops (Jaroslav Kysela) [2017320]
- ALSA: hda: intel: Allow repeatedly probing on codec configuration errors (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for TongFang PHxTxX1 (Jaroslav Kysela) [2017320]
- ASoC: SOF: OF: Add fw_path and tplg_path parameters (Jaroslav Kysela) [2017320]
- ASoC: amd: acp-rt5645: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: return error if sof_connect_dai_widget() fails (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: allow for dynamic pipelines override for debug (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: show clks_control value in dynamic debug (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-dai: improve SSP DAI handling for dynamic pipelines (Jaroslav Kysela) [2017320]
- ASoC: SOF: dai-intel: add SOF_DAI_INTEL_SSP_CLKCTRL_MCLK/BCLK_ES bits (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: add new flags for DAI_CONFIG (Jaroslav Kysela) [2017320]
- ASoC: SOF: dai: include new flags for DAI_CONFIG (Jaroslav Kysela) [2017320]
- ASoC: SOF: dai: mirror group_id definition added in firmware (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: add missing quirk for Dell SKU 0A45 (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add missing quirk for TGL SDCA single amp (Jaroslav Kysela) [2017320]
- ASoC: Intel: add machine driver for SOF+ES8336 (Jaroslav Kysela) [2017320]
- ALSA: intel-dsp-config: add quirk for APL/GLK/TGL devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: apl/glk/tgl: add entry for devices based on ES8336 codec (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek - ALC236 headset MIC recording issue (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Enable rate validation for Scarlett devices (Jaroslav Kysela) [2017320]
- ASoC: Intel: cht_bsw_nau8824: Set card.components string (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Add a nau8824_components() helper (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Add DMI quirk mechanism for active-high jack-detect (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Fix NAU8824_JACK_LOGIC define (Jaroslav Kysela) [2017320]
- ASoC: rt5651: Use IRQF_NO_AUTOEN when requesting the IRQ (Jaroslav Kysela) [2017320]
- ASoC: es8316: Use IRQF_NO_AUTOEN when requesting the IRQ (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Add quirk for Clevo X170KM-G (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Complete partial device name to avoid ambiguity (Jaroslav Kysela) [2017320]
- ASoC: nau8821: new driver (Jaroslav Kysela) [2017320]
- ASoC: fsl_spdif: implement bypass mode from in to out (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: Add kernel parameter for topology verification (Jaroslav Kysela) [2017320]
- ASoC: SOF: Add support for dynamic pipelines (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: make sure DAI widget is set up before IPC (Jaroslav Kysela) [2017320]
- ASoC: SOF: Introduce widget use_count (Jaroslav Kysela) [2017320]
- ASoC: SOF: Don't set up widgets during topology parsing (Jaroslav Kysela) [2017320]
- ASoC: SOF: restore kcontrols for widget during set up (Jaroslav Kysela) [2017320]
- ASoC: SOF: Add new fields to snd_sof_route (Jaroslav Kysela) [2017320]
- AsoC: dapm: export a couple of functions (Jaroslav Kysela) [2017320]
- ASoC: SOF: sof-audio: add helpers for widgets, kcontrols and dai config set up (Jaroslav Kysela) [2017320]
- ASoC: SOF: topology: Add new token for dynamic pipeline (Jaroslav Kysela) [2017320]
- ASoC: SOF: control: Add access field in struct snd_sof_control (Jaroslav Kysela) [2017320]
- ASoC: topology: change the complete op in snd_soc_tplg_ops to return int (Jaroslav Kysela) [2017320]
- ASoC: qcom: apq8096: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Fix HP noise caused by SAR mode switch when the system resumes (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Enable ASRC auto-disable to fix pop during jack plug-in while playback (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: move of_node_put to remove function (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: Add support for max98360a speaker amp (Jaroslav Kysela) [2017320]
- ASoC: tegra: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: soc-component: Remove conditional definition of debugfs data members (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix packet size calculation regression (Jaroslav Kysela) [2017320]
- ALSA: hda - Enable headphone mic on Dell Latitude laptops with ALC3254 (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: disable implicit feedback sync for Behringer UFX1204 and UFX1604 (Jaroslav Kysela) [2017320]
- soundwire: debugfs: use controller id and link_id for debugfs (Jaroslav Kysela) [2017320]
- ASoC: rt5682: move clk related code to rt5682_i2c_probe (Jaroslav Kysela) [2017320]
- ASoC: fsl_rpmsg: Add rpmsg audio support for i.MX8ULP (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: remove a repeated including (Jaroslav Kysela) [2017320]
- ASoC: SOF: Change SND_SOC_SOF_TOPLEVEL from config to menuconfig (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Revise the macro RT5682S_PLLB_SRC_MASK (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Use dev_dbg instead of pr_debug (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Remove the volatile SW reset register from reg_default (Jaroslav Kysela) [2017320]
- ASoC: nau8824: Fix headphone vs headset, button-press detection no longer working (Jaroslav Kysela) [2017320]
- ALSA: seq: Fix a potential UAF by wrong private_free call order (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Avoid killing in-flight URBs during draining (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Improved lowlatency playback support (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add spinlock to stop_urbs() (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Check available frames for the next packet size (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Disable low-latency mode for implicit feedback sync (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Disable low-latency playback for free-wheel mode (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Rename early_playback_start flag with lowlatency_playback (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix possible race at sync of urb completions (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Restrict rates for the shared clocks (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Enable 4-speaker output for Dell Precision 5560 laptop (Jaroslav Kysela) [2017320]
- ALSA: hda: Use position buffer for SKL+ again (Jaroslav Kysela) [2017320]
- ALSA: hda: Reduce udelay() at SKL+ position reporting (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix a missing error check in scarlett gen2 mixer (Jaroslav Kysela) [2017320]
- ALSA: virtio: Replace zero-length array with flexible-array member (Jaroslav Kysela) [2017320]
- ASoC: ux500: mop500: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: ti: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: update platform device name for Maxim amplifier (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Make the error prints consistent in tx_wait_done() (Jaroslav Kysela) [2017320]
- ASoC: SOF: prefix some terse and cryptic dev_dbg() with __func__ (Jaroslav Kysela) [2017320]
- ASoC: SOF: add error handling to snd_sof_ipc_msg_data() (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add missing of_node_put in probe (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: add header file for ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: pm: fix a stale comment (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-stream: Print stream name on STREAM_SD_OFFSET timeout (Jaroslav Kysela) [2017320]
- ALSA: pcsp: Make hrtimer forwarding more robust (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-dai: fix potential locking issue (Jaroslav Kysela) [2017320]
- ALSA: hda: hdac_ext_stream: fix potential locking issues (Jaroslav Kysela) [2017320]
- ALSA: hda: hdac_stream: fix potential locking issue in snd_hdac_stream_assign() (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: fix comment reference in __uac_clock_find_source (Jaroslav Kysela) [2017320]
- ASoC: ak4458: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: ak5558: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: dmaengine: Introduce module option prealloc_buffer_size_kbytes (Jaroslav Kysela) [2017320]
- ASoC: dwc-i2s: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ak4671: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: alc5623: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: bcm: Convert to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: cpcap: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: meson: aiu: Fix spelling mistake "Unsupport" -> "Unsupported" (Jaroslav Kysela) [2017320]
- ASoC: codecs: Fix spelling mistake "Unsupport" -> "Unsupported" (Jaroslav Kysela) [2017320]
- ASoC: ad193x: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: tegra: Constify static snd_soc_dai_ops structs (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Use two thresholds and increased wait time for manual type detection (Jaroslav Kysela) [2017320]
- ASoC: adav80x: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1977: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau17x1: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1701: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1373: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: adau1372: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ad1836: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ep93xx: Convert to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: samsung: add missing "fallthrough;" (Jaroslav Kysela) [2017320]
- ASoC: ak4642: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Use correct version to initialize Class H (Jaroslav Kysela) [2017320]
- ASoC: alc5632: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ASoC: ak4104: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ak4118: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: zl38060: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- firmware: cs_dsp: add driver to support firmware loading on Cirrus Logic DSPs (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Separate wm_adsp specifics in cs_dsp_client_ops (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Split out struct cs_dsp from struct wm_adsp (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: move firmware loading to client (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Pass firmware names as parameters when starting DSP core (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Move check of dsp->running to better place (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Separate generic cs_dsp_coeff_ctl handling (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Move sys_config_size to wm_adsp (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Split DSP power operations into helper functions (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Separate some ASoC and generic functions (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Introduce cs_dsp logging macros (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Rename generic DSP support (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Cancel ongoing work when removing controls (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Switch to using wm_coeff_read_ctrl for compressed buffers (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Move check for control existence (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Remove use of snd_ctl_elem_type_t (Jaroslav Kysela) [2017320]
- ASoC: cs4341: Add SPI device ID table (Jaroslav Kysela) [2017320]
- ASoC: pcm179x: Add missing entries SPI to device ID table (Jaroslav Kysela) [2017320]
- ALSA: rawmidi: introduce SNDRV_RAWMIDI_IOCTL_USER_PVERSION (Jaroslav Kysela) [2017320]
- ASoC: pl1022_rdk: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: pl1022_ds: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: mpc8610_hpcd: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-sgtl5000: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-rpmsg: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-hdmi: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-es8328: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-card: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: imx-audmix: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl_ssi: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl_sai: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-mqs: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-esai: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-audmix: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: fsl-asoc-card: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: eureka-tlv320: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: cros_ec_codec: Use modern ASoC DAI format terminology (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: fix truncated bytes in message tracepoints (Jaroslav Kysela) [2017320]
- ALSA: usx2y: Prefer struct_size over open coded arithmetic (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6afe-dai: Fix spelling mistake "Fronend" -> "Frontend" (Jaroslav Kysela) [2017320]
- ASoC: fsl_spdif: Add support for i.MX8ULP (Jaroslav Kysela) [2017320]
- ASoC: fsl: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: fsl_xcvr: Fix channel swap issue with ARC (Jaroslav Kysela) [2017320]
- ASoC: pcm512x: Mend accesses to the I2S_1 and I2S_2 registers (Jaroslav Kysela) [2017320]
- ASoC: codecs: max98390: simplify getting the adapter of a client (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: ab8500: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: SOF: Remove struct sof_ops_table and sof_get_ops() macro (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: make rt5682s_aif2_dai_ops and rt5682s_soc_component_dev (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based Mixer driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based ADX driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based AMX driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based SFC driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add Tegra210 based MVC driver (Jaroslav Kysela) [2017320]
- ASoC: tegra: Add routes for few AHUB modules (Jaroslav Kysela) [2017320]
- ASoC: audio-graph: Fixup CPU endpoint hw_params in a BE<->BE link (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: Increase maximum DAI links limit to 512 (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: Don't reconnect an already active BE (Jaroslav Kysela) [2017320]
- ASoC: compress/component: Use module_get_when_open/put_when_close for cstream (Jaroslav Kysela) [2017320]
- ASoC: soc-component: Convert the mark_module to void* (Jaroslav Kysela) [2017320]
- ASoC: 88pm860x: Update to modern clocking terminology (Jaroslav Kysela) [2017320]
- ASoC: SOF: Rename sof_arch_ops to dsp_arch_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Remove redundant error check from sof_ipc_tx_message_unlocked (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Print 0x prefix for errors in ipc_trace/stream_message() (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Clarify the parameter name for ipc_trace_message() (Jaroslav Kysela) [2017320]
- ASoC: SOF: trace: Omit error print when waking up trace sleepers (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: remove wrong fixup assignment on HDMITX (Jaroslav Kysela) [2017320]
- ASoC: au1x: Convert to modern terminology for DAI clocking (Jaroslav Kysela) [2017320]
- ASoC: atmel: Convert to new style DAI format definitions (Jaroslav Kysela) [2017320]
- misc: cs35l41: Remove unused pdn variable (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx8m: add SAI1 info (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Minor fix all errors reported by checkpatch.pl script (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: Move probe work related code under a single if () branch (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Implement Manual Type detection as fallback (Jaroslav Kysela) [2017320]
- ASoC: SOF: sof-probes: Correct the function names used for snd_soc_cdai_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Rename hda-compress.c to hda-probes.c (Jaroslav Kysela) [2017320]
- ASoC: SOF: probe: Merge and clean up the probe and compress files (Jaroslav Kysela) [2017320]
- ASoC: SOF: compress: move and export sof_probe_compr_ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: pcm: Remove non existent CONFIG_SND_SOC_SOF_COMPRESS reference (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Add probe message logging to ipc_log_header() (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Re-phrase the missing firmware error to avoid duplication (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: release_firmware() on load failure to avoid batching (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Setup Dolphin Headset Mic as Phantom Jack (Jaroslav Kysela) [2017320]
- ALSA: pcxhr: "fix" PCXHR_REG_TO_PORT definition (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: No need to export the snd_sof_debugfs_io_item() (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: Use the generic ops for region debugfs handling (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Provide debugfs_add_region_item ops for core (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: Provide debugfs_add_region_item ops for core (Jaroslav Kysela) [2017320]
- ASoC: SOF: debug: Add generic API and ops for DSP regions (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: Do not use 'bar' as parameter for block_read/write (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: No need to export snd_sof_fw_parse_ext_data() (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: Do not initialize the snd_sof_dsp_ops.read64 (Jaroslav Kysela) [2017320]
- ASoC: SOF: ipc: Remove snd_sof_dsp_mailbox_init() (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: bdw: Set the mailbox offset directly in bdw_probe (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: imx8m: Bar index is only valid for IRAM and SRAM types (Jaroslav Kysela) [2017320]
- ASoC: SOF: imx: imx8: Bar index is only valid for IRAM and SRAM types (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Fix a bunch of trivial code formating/style issues (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Fixup the error messages (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Don't overwrite returned error code (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Combine adjacent register writes (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Use regmap_read_poll_timeout to wait for OTP boot (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: Fix use of an uninitialised variable (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt6359: Fix unexpected error in bind/unbind flow (Jaroslav Kysela) [2017320]
- ASoC: SOF: loader: load_firmware callback is mandatory, treat it like that (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: make array adda_dai_list static const (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Add missing of_node_put() (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: Relocate inline definitions from hda.h to hda.c for sdw (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda: Remove boot_firmware skl and iccmax_icl declarations (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-dsp: Declare locally used functions as static (Jaroslav Kysela) [2017320]
- ASoC: SOF: Drop resindex_dma_base, dma_engine, dma_size from sof_dev_desc (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: Do no initialize resindex_dma_base (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_mx98360a board (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_rt1015 board (Jaroslav Kysela) [2017320]
- ASoC: intel: sof_rt5682: support jsl_rt5682s_rt1015p board (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: support ALC5682I-VS codec (Jaroslav Kysela) [2017320]
- ASoC: SOF: Fix DSP oops stack dump output contents (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Quirks to enable speaker output for Lenovo Legion 7i 15IMHG05, Yoga 7i 14ITL5/15ITL5, and 13s Gen2 laptops. (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Unify mixer resume and reset_resume procedure (Jaroslav Kysela) [2017320]
- Revert "ALSA: hda: Drop workaround for a hang at shutdown again" (Jaroslav Kysela) [2017320]
- ALSA: oxfw: fix transmission method for Loud models based on OXFW971 (Jaroslav Kysela) [2017320]
- ASoC: pcm5102a: increase rate from 192k to 384k (Jaroslav Kysela) [2017320]
- ASoC: rt1011: add i2s reference control for rt1011 (Jaroslav Kysela) [2017320]
- ASoC: SOF: Handle control change notification from firmware (Jaroslav Kysela) [2017320]
- ASoC: mt8195: remove unnecessary CONFIG_PM (Jaroslav Kysela) [2017320]
- ASoC: SOF: control: fix a typo in put operations for kcontrol (Jaroslav Kysela) [2017320]
- ASoC: fsl_rpmsg: add soc specific data structure (Jaroslav Kysela) [2017320]
- ASoC: rt5682s: Add driver for ALC5682I-VS codec (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Fix unused initialization of pointer etdm_data (Jaroslav Kysela) [2017320]
- ASoC: ti: rename CONFIG_SND_SOC_DM365_VOICE_CODEC_MODULE (Jaroslav Kysela) [2017320]
- ASoC: SOF: core: allow module parameter to override dma trace Kconfig (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Make use of the helper function devm_platform_ioremap_resource() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: Move template info print soc_tplg_dapm_widget_create() (Jaroslav Kysela) [2017320]
- ASoC: amd: acp: declare and add prefix to 'bt_uart_enable' symbol (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Remove unsued irqs_lock. (Jaroslav Kysela) [2017320]
- ASoC: cs35l41: CS35L41 Boosted Smart Amplifier (Jaroslav Kysela) [2017320]
- ASoC: rockchip: pdm: Add support for path map (Jaroslav Kysela) [2017320]
- ASoC: rockchip: pdm: Add support for rk3568 pdm (Jaroslav Kysela) [2017320]
- ASoC: rockchip: Add support for rv1126 pdm (Jaroslav Kysela) [2017320]
- ASoC: mediatek: common: handle NULL case in suspend/resume function (Jaroslav Kysela) [2017320]
- ASoC: fsl_xcvr: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_spdif: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_micfil: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_esai: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: fsl_sai: register platform component before registering cpu dai (Jaroslav Kysela) [2017320]
- ASoC: mediatek: add required config dependency (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: tag SoundWire BEs as non-atomic (Jaroslav Kysela) [2017320]
- ALSA: gus: Fix repeated probe for ISA interwave card (Jaroslav Kysela) [2017320]
- ALSA: gus: Fix repeated probes of snd_gus_create() (Jaroslav Kysela) [2017320]
- ALSA: vx222: fix null-ptr-deref (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fix concurrency between tx/rx (Jaroslav Kysela) [2017320]
- ASoC: mt8195: correct the dts parsing logic about DPTX and HDMITX (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: Fix CONFIG_SND_SOC_SDW_MOCKUP select (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add registration quirk for JBL Quantum 800 (Jaroslav Kysela) [2017320]
- ASoC: rt5682: fix headset background noise when S3 state (Jaroslav Kysela) [2017320]
- ASoC: mediatek: SND_SOC_MT8195 should depend on ARCH_MEDIATEK (Jaroslav Kysela) [2017320]
- ASoC: samsung: s3c24xx_simtec: fix spelling mistake "devicec" -> "device" (Jaroslav Kysela) [2017320]
- ASoC: audio-graph: respawn Platform Support (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add MTK_PMIC_WRAP dependency (Jaroslav Kysela) [2017320]
- ASoC: Revert PCM trigger changes (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add lowlatency module option (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Initialize Codec only in init fixup. (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Ensure Type Detection is only run on startup when necessary (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Work around for XRUN with low latency playback (Jaroslav Kysela) [2017320]
- ALSA: pcm: fix divide error in snd_pcm_lib_ioctl (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: test refcount before triggering (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: protect BE dailink state changes in trigger (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Disable irq on slave ports in the remove function (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Fix a memory leak in the error handling path of the probe function (Jaroslav Kysela) [2017320]
- ASoC: wcd9335: Fix a double irq free in the remove function (Jaroslav Kysela) [2017320]
- ALSA: hda: Disable runtime resume at shutdown (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Add support for frame inversion (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Add compatible for more SoCs (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Make playback/capture optional (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fixup config for DAIFMT_DSP_A/B (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fix regmap_ops hang (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Improve dma data transfer efficiency (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Fixup clk div error (Jaroslav Kysela) [2017320]
- ASoC: rockchip: i2s: Add support for set bclk ratio (Jaroslav Kysela) [2017320]
- ASoC: rockchip: spdif: Add support for rk3568 spdif (Jaroslav Kysela) [2017320]
- ASoC: rockchip: spdif: Fix some coding style (Jaroslav Kysela) [2017320]
- ASoC: rockchip: spdif: Mark SPDIF_SMPDR as volatile (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: Fix spelling mistake "bitwiedh" -> "bitwidth" (Jaroslav Kysela) [2017320]
- ASoC: dwc: Get IRQ optionally (Jaroslav Kysela) [2017320]
- ASoC: imx-rpmsg: change dev_err to dev_err_probe for -EPROBE_DEFER (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Fix the vol+ button detection issue (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Make rt5640_jack_gpio/rt5640_jack2_gpio static (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: remove duplicate include (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add HDMITX audio support (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add DPTX audio support (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add machine driver with mt6359, rt1019 and rt5682 (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: add platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support pcm in platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support adda in platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support etdm in platform driver (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: support audsys clock control (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8195: update mediatek common driver (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Put debugfs_remove_recursive back in (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move set-interface-first workaround into common quirk (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Quirk for HP Spectre x360 14 amp setup (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Fix regression on Sony WALKMAN NW-A45 DAC (Jaroslav Kysela) [2017320]
- ASoC: rt1015: remove possible unused variable `bclk_ms' (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Mark hp_elitepad_1000g2_jack?_check functions static (Jaroslav Kysela) [2017320]
- ASoC: ics43432: add CMM-4030D-261 support (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Select first entry for singular pipe config arrays (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Properly configure modules with generic extension (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Support modules with generic extension (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Support multiple format configs (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Simplify m_state for loadable modules (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Fix passing loadable flag for module (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Fix module configuration for KPB and MIXER (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Fix module resource and format selection (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Select proper format for NHLT blob (Jaroslav Kysela) [2017320]
- ASoC: Intel: Skylake: Leave data as is when invoking TLV IPCs (Jaroslav Kysela) [2017320]
- ASoC: Intel: kbl_da7219_max98927: Fix format selection for max98373 (Jaroslav Kysela) [2017320]
- soundwire: cadence: do not extend reset delay (Jaroslav Kysela) [2017320]
- soundwire: intel: conditionally exit clock stop mode on system suspend (Jaroslav Kysela) [2017320]
- soundwire: intel: skip suspend/resume/wake when link was not started (Jaroslav Kysela) [2017320]
- soundwire: intel: fix potential race condition during power down (Jaroslav Kysela) [2017320]
- ASoC: intel: atom: Revert PCM buffer address setup workaround again (Jaroslav Kysela) [2017320]
- ALSA: doc: Fix indentation warning (Jaroslav Kysela) [2017320]
- ALSA: hda: Update documentation for aliasing via the model option (Jaroslav Kysela) [2017320]
- ALSA: hda: Allow model option to specify PCI SSID alias (Jaroslav Kysela) [2017320]
- ALSA: hda: Code refactoring snd_hda_pick_fixup() (Jaroslav Kysela) [2017320]
- ALSA: firewire-motu: add support for MOTU 896HD (Jaroslav Kysela) [2017320]
- ALSA: hda/realtek: Workaround for conflicting SSID on ASUS ROG Strix G17 (Jaroslav Kysela) [2017320]
- ASoC: rsnd: adg: clearly handle clock error / NULL case (Jaroslav Kysela) [2017320]
- ASoC: rsnd: core: make some arrays static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add support for HP Elite Pad 1000G2 jack-detect (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytct_rt5640: Add a separate "Headset Mic 2" DAPM pin for the mic on the 2nd jack (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Add rt5640_set_ovcd_params() helper (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Add optional hp_det_gpio parameter to rt5640_detect_headset() (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Delay requesting IRQ until the machine-drv calls set_jack (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Move rt5640_disable_jack_detect() up in the rt5640.c file (Jaroslav Kysela) [2017320]
- ASoC: uniphier: make arrays mul and div static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Improve error handling in rz_ssi_dma_request function (Jaroslav Kysela) [2017320]
- ASoC: fsl_rpmsg: Check -EPROBE_DEFER for getting clocks (Jaroslav Kysela) [2017320]
- ALSA: hda/analog - Sink ad198x_shutup() and shuffle CONFIG_PM guards (Jaroslav Kysela) [2017320]
- ALSA: hda/sigmatel - Sink stac_shutup() into stac_suspend() (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Use cfg-lineout:2 in the components string (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Fix wrong operator used issue (Jaroslav Kysela) [2017320]
- ASoC: tegra30: i2s: Fix incorrect usage of of_device_get_match_data (Jaroslav Kysela) [2017320]
- ASoC: tegra30: ahub: Fix incorrect usage of of_device_get_match_data (Jaroslav Kysela) [2017320]
- ALSA: hda: Drop workaround for a hang at shutdown again (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Fix dereference of noderef expression warning (Jaroslav Kysela) [2017320]
- ASoC: tegra30: i2s: Use of_device_get_match_data (Jaroslav Kysela) [2017320]
- ASoC: tegra30: ahub: Use of_device_get_match_data (Jaroslav Kysela) [2017320]
- ASoC: soc-ac97: cleanup cppcheck warning (Jaroslav Kysela) [2017320]
- ASoC: soc-component: cleanup cppcheck warning at snd_soc_pcm_component_pm_runtime_get() (Jaroslav Kysela) [2017320]
- ASoC: soc-jack: cleanup cppcheck warning for CONFIG_GPIOLIB (Jaroslav Kysela) [2017320]
- ASoC: soc-jack: cleanup cppcheck warning at snd_soc_jack_report() (Jaroslav Kysela) [2017320]
- ASoC: soc-dai: cleanup cppcheck warning at snd_soc_pcm_dai_new() (Jaroslav Kysela) [2017320]
- ASoC: soc-dai: cleanup cppcheck warning at snd_soc_dai_link_set_capabilities() (Jaroslav Kysela) [2017320]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_copy_user() (Jaroslav Kysela) [2017320]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_pcm_new() (Jaroslav Kysela) [2017320]
- ASoC: soc-generic-dmaengine-pcm: cleanup cppcheck warning at dmaengine_pcm_hw_params() (Jaroslav Kysela) [2017320]
- ALSA: hda: Nuke unused reboot_notify callback (Jaroslav Kysela) [2017320]
- ALSA: hda: Suspend codec at shutdown (Jaroslav Kysela) [2017320]
- ALSA: hda: conexant: Turn off EAPD at suspend, too (Jaroslav Kysela) [2017320]
- ALSA: pcm: Add SNDRV_PCM_INFO_EXPLICIT_SYNC flag (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Input source control - digidesign mbox (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: use software node API in Atom boards (Jaroslav Kysela) [2017320]
- ASoC: Intel: remove device_properties for Atom boards (Jaroslav Kysela) [2017320]
- ASoC: Intel: use software node API in SoundWire machines (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw_rt711*: keep codec device reference until remove (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: pass card information to init/exit functions (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: get codec device with ACPI instead of bus search (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: handle errors with acpi_dev_get_first_match_dev() (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: harden codec property handling (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Remove unused variable in rt5682_i2c_remove() (Jaroslav Kysela) [2017320]
- ASoC: sh: rz-ssi: Add SSI DMAC support (Jaroslav Kysela) [2017320]
- ASoC: sh: Add RZ/G2L SSIF-2 driver (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: make DMI L1 selection more robust (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: simplify logic for DMI_L1 handling (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: hda-stream: remove always true condition (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Kconfig: clarify DMI L1 option description (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Count continuous pages in vmalloc buffer handler (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Prevent pops and clicks during suspend (Jaroslav Kysela) [2017320]
- ALSA: hda_audio_ext: fix kernel-doc (Jaroslav Kysela) [2017320]
- ALSA: core: control_led: use strscpy instead of strlcpy (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Unmute/Mute codec when stream starts/stops (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Follow correct CS42L42 power down sequence for suspend (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Remove unnecessary delays (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Use timeout rather than retries for I2C transaction waits (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Set fixed sample rate of 48kHz for CS42L42 (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Enable Full Scale Volume for Line Out Codec on Dolphin (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Add support for dolphin (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Add Support to disable jack type detection for CS42L42 (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Support multiple sub_codecs for Suspend/Resume/Unsol events (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Move codec properties to its own struct (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Separate CS8409, CS42L42 and project functions (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Support i2c bulk read/write functions (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Avoid re-setting the same page as the last access (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Avoid setting the same I2C address for every access (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Dont disable I2C clock between consecutive accesses (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Generalize volume controls (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Prevent I2C access during suspend time (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Simplify CS42L42 jack detect. (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Mask CS42L42 wake events (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Disable unsolicited response for the first boot (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Disable unsolicited responses during suspend (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Disable unnecessary Ring Sense for Cyborg/Warlock/Bullseye (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Reduce HS pops/clicks for Cyborg (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Mask all CS42L42 interrupts on initialization (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Use enums for register names and coefficients (Jaroslav Kysela) [2017320]
- ALSA: hda/cs8409: Move arrays of configuration to a new file (Jaroslav Kysela) [2017320]
- ALSA: hda/cirrus: Move CS8409 HDA bridge to separate module (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Properly turn off regulators if wrong device ID (Jaroslav Kysela) [2017320]
- ASoC: rt5682: Adjust headset volume button threshold again (Jaroslav Kysela) [2017320]
- ASoC: Intel: Fix platform ID matching (Jaroslav Kysela) [2017320]
- ASoC: rt1015p: add new acpi id and comapatible id (Jaroslav Kysela) [2017320]
- ASoC: max98390: Add support change dsm param name (Jaroslav Kysela) [2017320]
- ALSA: msnd: Use proper mmap method (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6adm: fix cppcheck warnings for unnecessary initialization (Jaroslav Kysela) [2017320]
- ASoC: qdsp6: q6asm: fix cppcheck warnings for unnecessary initialization (Jaroslav Kysela) [2017320]
- ASoC: qcom: apq8016_sbc: Add SEC_MI2S support (Jaroslav Kysela) [2017320]
- ALSA: pci: cs46xx: Fix set up buffer type properly (Jaroslav Kysela) [2017320]
- ALSA: pci: rme: Set up buffer type properly (Jaroslav Kysela) [2017320]
- ALSA: pcm: Check mmap capability of runtime dma buffer at first (Jaroslav Kysela) [2017320]
- ALSA: harmony: Drop superfluous address setup (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Fix mmap of SG-buffer with WC pages (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Update module authors (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Assume 24-bit samples are in 32-bit slots (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Validate dai_set_sysclk() frequency (Jaroslav Kysela) [2017320]
- ASoC: cs42l42: Add PLL configuration for 44.1kHz/16-bit (Jaroslav Kysela) [2017320]
- ASoC: rt5640: Silence warning message about missing interrupt (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: add Multi Button Headset Control support (Jaroslav Kysela) [2017320]
- ASoC: simple-card-utils: Avoid over-allocating DLCs (Jaroslav Kysela) [2017320]
- ASoC: wcd938x: simplify return value (Jaroslav Kysela) [2017320]
- ASoC: mt6359-accdet.c: remove useless assignments (Jaroslav Kysela) [2017320]
- ASoC: max98090: remove duplicate status reads and useless assignmment (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at soc_dapm_dai_stream_event() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_new_controls() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_weak_routes() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_add_routes() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at snd_soc_dapm_del_route() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_seq_run() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_seq_check_event() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_new_dai_link() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_new_pga() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_set_mixer_path_status() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_connect_mux() (Jaroslav Kysela) [2017320]
- ASoC: soc-dapm: cleanup cppcheck warning at dapm_wcache_lookup() (Jaroslav Kysela) [2017320]
- ALSA: es1688: Avoid devres management for es1688 object creation (Jaroslav Kysela) [2017320]
- ALSA: pci/korg1212: completely remove 'set but not used' warnings (Jaroslav Kysela) [2017320]
- ASoC: amd: vangogh: Drop superfluous mmap callback (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Store snd_dma_buffer.addr for continuous pages, too (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Fix pgprot for WC mmap on x86 (Jaroslav Kysela) [2017320]
- ASoC: sprd: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: qcom: qdsp6: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: qcom: lpass: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: mpc5200: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl_dma: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl_asrc_dma: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: tegra: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl: imx-pcm-rpmsg: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: fsl: imx-pcm-fiq: Use managed buffer allocation (Jaroslav Kysela) [2017320]
- ASoC: bcm: Use managed PCM buffer allocation (Jaroslav Kysela) [2017320]
- ALSA: pxa2xx: Use managed PCM buffer allocation (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Support WC allocation on all architectures (Jaroslav Kysela) [2017320]
- ALSA: pcm: Allow exact buffer preallocation (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Correctly name as WC (Jaroslav Kysela) [2017320]
- ALSA: memalloc: Minor refactoring (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt6359: convert to use module_platform_driver (Jaroslav Kysela) [2017320]
- ASoC: rt5514: make array div static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: codecs: ad193x: add support for 96kHz and 192kHz playback rates (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_put_xr_sx() (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_get_xr_sx() (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_limit_volume() (Jaroslav Kysela) [2017320]
- ASoC: soc-ops: cleanup cppcheck warning at snd_soc_put_volsw_sx() (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw_max98373: remove useless inits (Jaroslav Kysela) [2017320]
- ASoC: Intel: update sof_pcm512x quirks (Jaroslav Kysela) [2017320]
- ASoC: SOF: Intel: Use DMI string to search for adl_mx98373_rt5682 variant (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: add quirk for Dell XPS 9710 (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: make array static const, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic32x4: make array clocks static, makes object smaller (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Fix HP ElitePad 1000 G2 quirk (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add support for a second headset mic input (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add support for a second headphones output (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add a byt_rt5640_get_codec_dai() helper (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Add line-out support (Jaroslav Kysela) [2017320]
- ASoC: Intel: bytcr_rt5640: Move "Platform Clock" routes to the maps for the matching in-/output (Jaroslav Kysela) [2017320]
- soundwire: intel: introduce shim and alh base (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: add snd_sof_dsp_check_sdw_irq ops (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: move sof_intel_dsp_desc() forward (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: hda: remove HDA_DSP_REG_SNDW_WAKE_STS definition (Jaroslav Kysela) [2017320]
- ASoC: SOF: intel: add sdw_shim/alh_base to sof_intel_dsp_desc (Jaroslav Kysela) [2017320]
- soundwire: move intel sdw register definitions to sdw_intel.h (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at snd_soc_find_dai_link() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_kcontrol_elems_load() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_dapm_widget_elems_load() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_dai_elems_load() (Jaroslav Kysela) [2017320]
- ASoC: soc-topology: cleanup cppcheck warning at soc_tplg_process_headers() (Jaroslav Kysela) [2017320]
- ASoC: rsnd: make some arrays static const, makes object smaller (Jaroslav Kysela) [2017320]
- ALSA: doc: Add the description of quirk_flags option for snd-usb-audio (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Add quirk_flags module option (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move generic DSD raw detection into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move ignore_ctl_error check into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move autosuspend quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move rate validation quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move interface setup delay into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move control message delay quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move ITF-USB DSD quirk handling into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move clock setup quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move playback_first flag into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move tx_length quirk handling to quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move txfr_quirk handling to quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Move media-controller API quirk into quirk_flags (Jaroslav Kysela) [2017320]
- ALSA: usb-audio: Introduce quirk_flags field (Jaroslav Kysela) [2017320]
- soundwire: cadence: override PDI configurations to create loopback (Jaroslav Kysela) [2017320]
- soundwire: cadence: add debugfs interface for PDI loopbacks (Jaroslav Kysela) [2017320]
- soundwire: stream: don't program mockup device ports (Jaroslav Kysela) [2017320]
- soundwire: bus: squelch error returned by mockup devices (Jaroslav Kysela) [2017320]
- soundwire: add flag to ignore all command/control for mockup devices (Jaroslav Kysela) [2017320]
- soundwire: stream: don't abort bank switch on Command_Ignored/-ENODATA (Jaroslav Kysela) [2017320]
- soundwire: cadence: add paranoid check on self-clearing bits (Jaroslav Kysela) [2017320]
- ALSA: core: Fix double calls of snd_card_free() via devres (Jaroslav Kysela) [2017320]
- ALSA: pcxhr: use __func__ to get funcion's name in an output message (Jaroslav Kysela) [2017320]
- ASoC: intel: skylake: Drop superfluous mmap callback (Jaroslav Kysela) [2017320]
- ASoC: amd: Drop superfluous mmap callbacks (Jaroslav Kysela) [2017320]
- ASoC: v253_init: eliminate pointer to string (Jaroslav Kysela) [2017320]
- ASoC: cx20442: tty_ldisc_ops::write_wakeup is optional (Jaroslav Kysela) [2017320]
- ASoC: samsung: Constify static snd_soc_ops (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_of_parse_audio_routing() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_of_parse_audio_simple_widgets() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_add_controls() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_unregister_component() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_daifmt_parse_format() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_get_dai_name() (Jaroslav Kysela) [2017320]
- ASoC: soc-core: cleanup cppcheck warning at snd_soc_set_dmi_name() (Jaroslav Kysela) [2017320]
- ASoC: bcm: cygnus-pcm: Fix unused assignment about 'rc' (Jaroslav Kysela) [2017320]
- ASoC: Intel: Fix spelling contraction "cant" -> "can't" (Jaroslav Kysela) [2017320]
- ASoC: amd: fix an IS_ERR() vs NULL bug in probe (Jaroslav Kysela) [2017320]
- ASoC: rt5682: enable SAR ADC power saving mode during suspend (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at dpcm_runtime_setup_be_chan() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at dpcm_be_is_active() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_get_playback_capture() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_pcm_components_close() (Jaroslav Kysela) [2017320]
- ASoC: soc-pcm: cleanup cppcheck warning at soc_pcm_apply_msb() (Jaroslav Kysela) [2017320]
- ALSA: seq: Fix comments of wrong client number for MIDI Passthrough (Jaroslav Kysela) [2017320]
- ASoC: rt1015: Remove unnecessary flush work on rt1015 driver (Jaroslav Kysela) [2017320]
- docs: sound: kernel-api: writing-an-alsa-driver.rst: replace some characters (Jaroslav Kysela) [2017320]
- ASoC: amd: Use dev_probe_err helper (Jaroslav Kysela) [2017320]
- ASoC: amd: Don't show messages about deferred probing by default (Jaroslav Kysela) [2017320]
- soundwire: dmi-quirks: add quirk for Intel 'Bishop County' NUC M15 (Jaroslav Kysela) [2017320]
- soundwire: bus: update Slave status in sdw_clear_slave_status (Jaroslav Kysela) [2017320]
- soundwire: cadence: Remove ret variable from sdw_cdns_irq() (Jaroslav Kysela) [2017320]
- soundwire: bus: filter out more -EDATA errors on clock stop (Jaroslav Kysela) [2017320]
- soundwire: dmi-quirks: add ull suffix for SoundWire _ADR values (Jaroslav Kysela) [2017320]
- ASoC: amd: enable vangogh acp5x driver build (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh i2s dma driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh pci driver pm ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh i2s dai driver ops (Jaroslav Kysela) [2017320]
- ASoC: amd: add vangogh i2s controller driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add ACP5x pcm dma driver ops (Jaroslav Kysela) [2017320]
- ASoC: amd: irq handler changes for ACP5x PCM dma driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add ACP5x PCM platform driver (Jaroslav Kysela) [2017320]
- ASoC: amd: create acp5x platform devices (Jaroslav Kysela) [2017320]
- ASoc: amd: add acp5x init/de-init functions (Jaroslav Kysela) [2017320]
- ASoC: amd: add Vangogh ACP PCI driver (Jaroslav Kysela) [2017320]
- ASoC: amd: add Vangogh ACP5x IP register header (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Use explicit cast for __iomem pointer (Jaroslav Kysela) [2017320]
- ALSA: korg1212: Fix wrongly shuffled firmware loader code (Jaroslav Kysela) [2017320]
- ALSA: als300: Fix missing chip initialization (Jaroslav Kysela) [2017320]
- ALSA: cs4281: Fix missing chip initialization (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Assign vport directly on card's private_data (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Fix incorrect sizeof operator (Jaroslav Kysela) [2017320]
- ALSA: opti9xx: fix missing { } around an if block (Jaroslav Kysela) [2017320]
- ALSA: nm256: Fix error return code in snd_nm256_create() (Jaroslav Kysela) [2017320]
- ASOC: Intel: sof_sdw: add quirk for Intel 'Bishop County' NUC M15 (Jaroslav Kysela) [2017320]
- ASoC: ti: j721e-evm: Convert the audio domain IDs to enum (Jaroslav Kysela) [2017320]
- ALSA: pcsp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: dummy: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: aloop: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: mpu401: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: serial-u16550: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: mtpav: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: virmidi: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: x86: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: wavefront: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sscape: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sc6000: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: opl3sa2: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: opti9xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: msnd: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: gus: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: galaxy: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es18xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es1688: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs423x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cmi8330: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cmi8328: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: azt2320: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: als100: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: adlib: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ad1848: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sb: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: wss: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ad1816a: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ymfpci: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: vx222: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: vx: Manage vx_core object with devres (Jaroslav Kysela) [2017320]
- ALSA: trident: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: rme9652: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: hdspm: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: hdsp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: riptide: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: oxygen: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: nm256: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: lx6464es: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: lola: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: korg1212: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ice1724: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ali5451: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ice1724: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ice1712: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: emu10k1x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: emu10k1: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: echoaudio: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs5535audio: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs46xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ca0106: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: aw2: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: au88x0: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ali5451: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: via82xx: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sonicvibes: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: sis7019: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: rme96: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: rme32: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: maestro3: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: fm801: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es1968: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: es1938: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ens137x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs5530: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cs4281: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: cmipci: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: bt87x: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: azt3328: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: als4000: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: als300: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: ad1889: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: hda: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: atiixp: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: intel8x0: Allocate resources with device-managed APIs (Jaroslav Kysela) [2017320]
- ALSA: doc: Add device-managed resource section (Jaroslav Kysela) [2017320]
- ALSA: core: Add device-managed request_dma() (Jaroslav Kysela) [2017320]
- ALSA: core: Add managed card creation (Jaroslav Kysela) [2017320]
- ALSA: core: Add device-managed page allocator helper (Jaroslav Kysela) [2017320]
- ALSA: aloop: Fix spelling mistake "synchronization" -> "synchronization" (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: remove unused port-map reference (Jaroslav Kysela) [2017320]
- ASoC: codecs: lpass-rx-macro: clean up for-loop indentation in switch statement (Jaroslav Kysela) [2017320]
- ALSA: compress: Initialize mutex in snd_compress_new() (Jaroslav Kysela) [2017320]
- ALSA: compress: Drop unused functions (Jaroslav Kysela) [2017320]
- ASoC: Intel: boards: sof_sdw: add SoundWire mockup codecs for tests (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: tgl: add table for SoundWire mockup devices (Jaroslav Kysela) [2017320]
- ASoC: soc-acpi: cnl: add table for SoundWire mockup devices (Jaroslav Kysela) [2017320]
- ASoC: codecs: add SoundWire mockup device support (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: update quirk for jack detection in ADL RVP (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: include rt711.h for RT711 JD mode (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_sdw: extends SOF_RT711_JDSRC to 4 bits (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_rt5682: code refactor for max98360a (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_cs42l42: add support for jsl_cs4242_mx98360a (Jaroslav Kysela) [2017320]
- ASoC: Intel: maxim-common: support max98360a (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_cs42l42: support arbitrary DAI link sequence (Jaroslav Kysela) [2017320]
- ALSA: intel8x0: Skip ac97 clock measurement on VM (Jaroslav Kysela) [2017320]
- ALSA: hda/hdmi: Add option to enable all pins forcibly (Jaroslav Kysela) [2017320]
- ALSA: x86: simplify with sync_stop PCM ops (Jaroslav Kysela) [2017320]
- ALSA: ice1724: Remove superfluous loop over model table (Jaroslav Kysela) [2017320]
- ALSA: hda/ca0132: remove redundant initialization of variable status (Jaroslav Kysela) [2017320]
- ASoC: amd: fix spelling mistakes (Jaroslav Kysela) [2017320]
- ASoC: tlv320aic32x4: Fix TAS2505/TAS2521 channel count (Jaroslav Kysela) [2017320]
- ASoC: fsl_xcvr: Omit superfluous error message in fsl_xcvr_probe() (Jaroslav Kysela) [2017320]
- ASoC: sh: rcar: dma: : use proper DMAENGINE API for termination (Jaroslav Kysela) [2017320]
- ASoC: wm_adsp: Remove pointless string comparison (Jaroslav Kysela) [2017320]
- ASoC: codecs: wcd938x: fix returnvar.cocci warnings (Jaroslav Kysela) [2017320]
- ASoC: atmel: ATMEL drivers don't need HAS_DMA (Jaroslav Kysela) [2017320]
- ASoC: ti: delete some dead code in omap_abe_probe() (Jaroslav Kysela) [2017320]
- ASoC: atmel: fix spelling mistakes (Jaroslav Kysela) [2017320]
- ASoC: Intel: sof_cs42l42: use helper function to get bclk frequency (Jaroslav Kysela) [2017320]
- ASoC: SOF: add a helper to get topology configured bclk (Jaroslav Kysela) [2017320]
- ASoC: Intel: soc-acpi: add support for SoundWire of TGL-H-RVP (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8183: Fix Unbalanced pm_runtime_enable in mt8183_afe_pcm_dev_probe (Jaroslav Kysela) [2017320]
- ASoC: mediatek: mt8192:Fix Unbalanced pm_runtime_enable in mt8192_afe_pcm_dev_probe (Jaroslav Kysela) [2017320]
- ASoC: ti: davinci-mcasp: Add support for the OMAP4 version of McASP (Jaroslav Kysela) [2017320]
- ASoC: ti: davinci-mcasp: Fix DIT mode support (Jaroslav Kysela) [2017320]

* Mon Feb 21 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-64.rt21.64.el9]
- igc: Fix TX timestamp support for non-MSI-X platforms (Corinna Vinschen) [2040335]
- igc: Do not enable crosstimestamping for i225-V models (Corinna Vinschen) [2040335]
- igc: Fix typo in i225 LTR functions (Corinna Vinschen) [2040335]
- igc: enable XDP metadata in driver (Corinna Vinschen) [2040335]
- igc: AF_XDP zero-copy metadata adjust breaks SKBs on XDP_PASS (Corinna Vinschen) [2040335]
- igc: Change Device Reset to Port Reset (Corinna Vinschen) [2040335]
- igc: Add new device ID (Corinna Vinschen) [2040335]
- igc: Remove media type checking on the PHY initialization (Corinna Vinschen) [2040335]
- igc: Update I226_K device ID (Corinna Vinschen) [2040335]
- net: intel: igc_ptp: fix build for UML (Corinna Vinschen) [2040335]
- igc: fix tunnel offloading (Corinna Vinschen) [2040335]
- igc: Add support for CBS offloading (Corinna Vinschen) [2040335]
- igc: Simplify TSN flags handling (Corinna Vinschen) [2040335]
- igc: Use default cycle 'start' and 'end' values for queues (Corinna Vinschen) [2040335]
- igc: Add support for PTP getcrosststamp() (Corinna Vinschen) [2040335]
- igc: Enable PCIe PTM (Corinna Vinschen) [2040335]
- igc: Increase timeout value for Speed 100/1000/2500 (Corinna Vinschen) [2040335]
- igc: Set QBVCYCLET_S to 0 for TSN Basic Scheduling (Corinna Vinschen) [2040335]
- igc: Remove phy->type checking (Corinna Vinschen) [2040335]
- igc: Remove _I_PHY_ID checking (Corinna Vinschen) [2040335]
- igc: Check if num of q_vectors is smaller than max before array access (Corinna Vinschen) [2040335]
- Revert "igc: Export LEDs" (Corinna Vinschen) [2040335]
- igc: Export LEDs (Corinna Vinschen) [2040335]
- igc: Make flex filter more flexible (Corinna Vinschen) [2040335]
- igc: Allow for Flex Filters to be installed (Corinna Vinschen) [2040335]
- igc: Integrate flex filter into ethtool ops (Corinna Vinschen) [2040335]
- igc: Add possibility to add flex filter (Corinna Vinschen) [2040335]
- EDAC/i10nm: Retrieve and print retry_rd_err_log registers (Aristeu Rozanski) [1998360]
- nvme-fabrics: fix state check in nvmf_ctlr_matches_baseopts() (Gopal Tiwari) [2043756]
- scsi: reserve space in structures for KABI (Ewan D. Milne) [2044443]
- vt_kdsetmode: extend console locking (John W. Linville) [2003820]
- ice: Fix problems with DSCP QoS implementation (Jonathan Toppins) [2032582]
- ice: Fix race conditions between virtchnl handling and VF ndo ops (Jonathan Toppins) [2032582]
- ice: Fix not stopping Tx queues for VFs (Jonathan Toppins) [2032582]
- ice: Fix replacing VF hardware MAC to existing MAC filter (Jonathan Toppins) [2032582]
- ice: Remove toggling of antispoof for VF trusted promiscuous mode (Jonathan Toppins) [2032582]
- ice: Fix VF true promiscuous mode (Jonathan Toppins) [2032582]
- ice: Remove boolean vlan_promisc flag from function (Jonathan Toppins) [2032582]
- ice: check whether PTP is initialized in ice_ptp_release() (Jonathan Toppins) [2032582]
- ice: Respond to a NETDEV_UNREGISTER event for LAG (Jonathan Toppins) [2032582]
- ice: use devm_kcalloc() instead of devm_kzalloc() (Jonathan Toppins) [2032582]
- ice: Make use of the helper function devm_add_action_or_reset() (Jonathan Toppins) [2032582]
- ice: fix software generating extra interrupts (Jonathan Toppins) [2032582]
- ice: fix rate limit update after coalesce change (Jonathan Toppins) [2032582]
- ice: update dim usage and moderation (Jonathan Toppins) [2032582]
- ice: Add support for VF rate limiting (Jonathan Toppins) [2032582]
- ice: Add missing E810 device ids (Jonathan Toppins) [2032582]
- ice: make use of ice_for_each_* macros (Jonathan Toppins) [2032582]
- ice: split ice_ring onto Tx/Rx separate structs (Jonathan Toppins) [2032582]
- ice: move ice_container_type onto ice_ring_container (Jonathan Toppins) [2032582]
- ice: remove ring_active from ice_ring (Jonathan Toppins) [2032582]
- ice: Print the api_patch as part of the fw.mgmt.api (Jonathan Toppins) [2032582]
- ice: fix getting UDP tunnel entry (Jonathan Toppins) [1978828 2032582]
- ice: Avoid crash from unnecessary IDA free (Jonathan Toppins) [2032582]
- ice: Fix failure to re-add LAN/RDMA Tx queues (Jonathan Toppins) [2032582]
- ice: fix locking for Tx timestamp tracking flush (Jonathan Toppins) [2032582]
- ice: Prefer kcalloc over open coded arithmetic (Jonathan Toppins) [2032582]
- ice: Fix macro name for IPv4 fragment flag (Jonathan Toppins) [2032582]
- ice: refactor devlink getter/fallback functions to void (Jonathan Toppins) [2032582]
- ice: Fix link mode handling (Jonathan Toppins) [2032582]
- ice: Add feature bitmap, helpers and a check for DSCP (Jonathan Toppins) [2032582]
- ice: Add DSCP support (Jonathan Toppins) [2032582]
- ice: Correctly deal with PFs that do not support RDMA (Jonathan Toppins) [2032582]
- ice: add lock around Tx timestamp tracker flush (Jonathan Toppins) [2032582]
- ice: remove dead code for allocating pin_config (Jonathan Toppins) [2032582]
- wireguard: ratelimiter: use kvcalloc() instead of kvzalloc() (Hangbin Liu) [2041408]
- wireguard: receive: drop handshakes if queue lock is contended (Hangbin Liu) [2041408]
- wireguard: receive: use ring buffer for incoming handshakes (Hangbin Liu) [2041408]
- wireguard: allowedips: add missing __rcu annotation to satisfy sparse (Hangbin Liu) [2041408]
- ionic: Initialize the 'lif->dbid_inuse' bitmap (Jonathan Toppins) [2039988]
- ionic: tame the filter no space message (Jonathan Toppins) [2013549 2039988]
- ionic: allow adminq requests to override default error message (Jonathan Toppins) [2013549 2039988]
- ionic: handle vlan id overflow (Jonathan Toppins) [2013549 2039988]
- ionic: generic filter delete (Jonathan Toppins) [2013549 2039988]
- ionic: generic filter add (Jonathan Toppins) [2013549 2039988]
- ionic: add generic filter search (Jonathan Toppins) [2013549 2039988]
- ionic: remove mac overflow flags (Jonathan Toppins) [2013549 2039988]
- ionic: move lif mac address functions (Jonathan Toppins) [2013549 2039988]
- ionic: add filterlist to debugfs (Jonathan Toppins) [2013549 2039988]
- ionic: add lif param to ionic_qcq_disable (Jonathan Toppins) [2039988]
- ionic: have ionic_qcq_disable decide on sending to hardware (Jonathan Toppins) [2039988]
- ionic: add polling to adminq wait (Jonathan Toppins) [2039988]
- ionic: widen queue_lock use around lif init and deinit (Jonathan Toppins) [2039988]
- ionic: move lif mutex setup and delete (Jonathan Toppins) [2039988]
- ionic: check for binary values in FW ver string (Jonathan Toppins) [2039988]
- ionic: remove debug stats (Jonathan Toppins) [2039988]
- ionic: don't remove netdev->dev_addr when syncing uc list (Jonathan Toppins) [2039988]
- ionic: move filter sync_needed bit set (Jonathan Toppins) [2039988]
- ionic: fix gathering of debug stats (Jonathan Toppins) [2039988]
- ionic: fix a sleeping in atomic bug (Jonathan Toppins) [2039988]
- ionic: fix double use of queue-lock (Jonathan Toppins) [2039988]
- ionic: recreate hwstamp queues on ifup (Jonathan Toppins) [2039988]
- ionic: pull hwstamp queue_lock up a level (Jonathan Toppins) [2039988]
- ionic: add queue lock around open and stop (Jonathan Toppins) [2039988]
- ionic: fill mac addr earlier in add_addr (Jonathan Toppins) [2039988]
- ionic: squelch unnecessary fw halted message (Jonathan Toppins) [2039988]
- ionic: fire watchdog again after fw_down (Jonathan Toppins) [2039988]
- ionic: handle mac filter overflow (Jonathan Toppins) [2039988]
- ionic: refactor ionic_lif_addr to remove a layer (Jonathan Toppins) [2039988]
- ionic: sync the filters in the work task (Jonathan Toppins) [2039988]
- ionic: flatten calls to set-rx-mode (Jonathan Toppins) [2039988]
- ionic: remove old work task types (Jonathan Toppins) [2039988]
- ionic: add function tag to debug string (Jonathan Toppins) [2039988]
- ionic: enable rxhash only with multiple queues (Jonathan Toppins) [2039988]
- ionic: block some ethtool operations when fw in reset (Jonathan Toppins) [2039988]
- ionic: remove unneeded comp union fields (Jonathan Toppins) [2039988]
- ionic: increment num-vfs before configure (Jonathan Toppins) [2039988]
- ionic: use fewer inits on the buf_info struct (Jonathan Toppins) [2039988]
- ionic: init reconfig err to 0 (Jonathan Toppins) [2039988]
- ionic: print firmware version on identify (Jonathan Toppins) [2039988]
- ionic: monitor fw status generation (Jonathan Toppins) [2039988]
- ionic: minimize resources when under kdump (Jonathan Toppins) [2039988]
- ionic: drop useless check of PCI driver data validity (Jonathan Toppins) [2039988]

* Mon Feb 21 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-62.rt21.63.el9]
- Revert "Merge: blktrace: switch trace spinlock to a raw spinlock" (Juri Lelli)
- Revert "Merge: ext4: fix potential NULL pointer dereference in ext4_fill_super()" (Juri Lelli)
- ibmvnic: remove unused defines (Diego Domingos) [2047921]
- ibmvnic: Update driver return codes (Diego Domingos) [2047921]
- powerpc/fadump: opt out from freeing pages on cma activation failure (Diego Domingos) [2040289]
- mm/cma: provide option to opt out from exposing pages on activation failure (Diego Domingos) [2040289]
- firmware: smccc: Fix check for ARCH_SOC_ID not implemented (Vitaly Kuznetsov) [2052908]
- rcu: Tighten rcu_advance_cbs_nowake() checks (Daniel Vacek) [2026991]
- redhat/configs: Disable CONFIG_MACINTOSH_DRIVERS (Prarit Bhargava) [2053028]
- ibmvnic: remove unused ->wait_capability (Diego Domingos) [2047928]
- ibmvnic: don't spin in tasklet (Diego Domingos) [2047928]
- ibmvnic: init ->running_cap_crqs early (Diego Domingos) [2047928]
- ibmvnic: Allow extra failures before disabling (Diego Domingos) [2047928]
- s390/pv: fix the forcing of the swiotlb (Thomas Huth) [2051581]
- scsi: vmw_pvscsi: Set residual data length conditionally (Cathy Avery) [2048178]
- selinux: fix double free of cond_list on error paths (Ondrej Mosnacek) [2052439]
- selinux: fix NULL-pointer dereference when hashtab allocation fails (Ondrej Mosnacek) [2052436]
- isdn: cpai: check ctr->cnr to avoid array index out of bound (Chris von Recklinghausen) [2016492] {CVE-2021-43389}
- mm/hwpoison: fix unpoison_memory() (Aristeu Rozanski) [1972220]
- mm/hwpoison: remove MF_MSG_BUDDY_2ND and MF_MSG_POISONED_HUGE (Aristeu Rozanski) [1972220]
- mm/hwpoison: mf_mutex for soft offline and unpoison (Aristeu Rozanski) [1972220]
- mm/hwpoison: clear MF_COUNT_INCREASED before retrying get_any_page() (Aristeu Rozanski) [1972220]
- mm, hwpoison: fix condition in free hugetlb page path (Aristeu Rozanski) [1972220]
- filemap: remove PageHWPoison check from next_uptodate_page() (Aristeu Rozanski) [1972220]
- mm: hwpoison: handle non-anonymous THP correctly (Aristeu Rozanski) [1972220]
- mm: hwpoison: refactor refcount check handling (Aristeu Rozanski) [1972220]
- mm: filemap: coding style cleanup for filemap_map_pmd() (Aristeu Rozanski) [1972220]
- scsi: bnx2fc: Make bnx2fc_recv_frame() mp safe (John Meneghini) [2031648]
- scsi: bnx2fc: Flush destroy_work queue before calling bnx2fc_interface_put() (John Meneghini) [2006606]
- redhat/configs: Enable CONFIG_TEST_BPF (Viktor Malik) [2035168]
- ext4: fix potential NULL pointer dereference in ext4_fill_super() (Lukas Czerner) [2051466]
- netfilter: ipset: Emit deprecation warning at set creation time (Phil Sutter) [2048194]
- redhat: move CONFIG_ARM64_MTE to aarch64 config directory (Herton R. Krzesinski)
- cgroup/cpuset: Fix "suspicious RCU usage" lockdep warning (Waiman Long) [1996015]
- cpuset: Fix the bug that subpart_cpus updated wrongly in update_cpumask() (Waiman Long) [1996015]
- net ticp:fix a kernel-infoleak in __tipc_sendmsg() (Xin Long) [2050039]
- tipc: discard MSG_CRYPTO msgs when key_exchange_enabled is not set (Xin Long) [2050039]
- tipc: delete the unlikely branch in tipc_aead_encrypt (Xin Long) [2050039]
- blktrace: switch trace spinlock to a raw spinlock (Wander Lairson Costa) [2047971]
- NFSv4.1: handle NFS4ERR_NOSPC by CREATE_SESSION (Steve Dickson) [2027447]
- igb: fix deadlock caused by taking RTNL in RPM resume path (Corinna Vinschen) [2040312]
- igb: Fix removal of unicast MAC filters of VFs (Corinna Vinschen) [2040312]
- igb: fix netpoll exit with traffic (Corinna Vinschen) [2040312]
- igb: unbreak I2C bit-banging on i350 (Corinna Vinschen) [2040312]
- igb: Avoid memcpy() over-reading of ETH_SS_STATS (Corinna Vinschen) [2040312]
- igb: Add counter to i21x doublecheck (Corinna Vinschen) [2040312]
- net: create netdev->dev_addr assignment helpers (Josef Oskera) [2030720]

* Thu Feb 17 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-61.rt21.62.el9]
- Enable KUNIT tests for redhat kernel-modules-internal (Nico Pache) [2048326]
- kasan: test: fix compatibility with FORTIFY_SOURCE (Nico Pache) [2048326]
- kasan: test: silence intentional read overflow warnings (Nico Pache) [2048326]
- kasan: test: bypass __alloc_size checks (Nico Pache) [2048326]
- mm/damon/vaddr-test: split a test function having >1024 bytes frame size (Nico Pache) [2048326]
- lib: Introduce CONFIG_MEMCPY_KUNIT_TEST (Nico Pache) [2048326]
- nvme-rdma: fix possible use-after-free in transport error_recovery work (Chris Leech) [1994618 2033414]
- nvme-tcp: fix possible use-after-free in transport error_recovery work (Chris Leech) [1994618 2033414]
- nvme: fix a possible use-after-free in controller reset during load (Chris Leech) [1994618 2033414]
- redhat/configs: enable CONFIG_CMA on aarch64 as tech-preview (David Hildenbrand) [2043141]
- redhat/configs: simplify CONFIG_CMA_AREAS (David Hildenbrand) [2043141]
- redhat/configs: simplify CONFIG_CMA_DEBUG (David Hildenbrand) [2043141]
- redhat/configs: simplify CONFIG_CMA_DEBUGFS (David Hildenbrand) [2043141]
- bpf: Fix kernel address leakage in atomic fetch (Jiri Olsa) [2046636] {CVE-2021-4203}
- IB/rdmavt: Validate remote_addr during loopback atomic tests (Kamal Heib) [2032114]
- [s390] scsi: zfcp: Fix failed recovery on gone remote port with non-NPIV FCP devices (Mete Durlu) [2049016]
- [s390] s390/cpumf: Support for CPU Measurement Sampling Facility LS bit (Mete Durlu) [2048979]
- [s390] s390/cpumf: Support for CPU Measurement Facility CSVN 7 (Mete Durlu) [2048979]
- net: openvswitch: Fix ct_state nat flags for conns arriving from tc (Antoine Tenart) [2045048]
- net: openvswitch: Fix matching zone id for invalid conns arriving from tc (Antoine Tenart) [2045048]
- net/sched: flow_dissector: Fix matching on zone id for invalid conns (Antoine Tenart) [2045048]
- net/sched: Extend qdisc control block with tc control block (Antoine Tenart) [2045048]
- openvswitch: fix sparse warning incorrect type (Antoine Tenart) [2045048]
- openvswitch: fix alignment issues (Antoine Tenart) [2045048]
- openvswitch: update kdoc OVS_DP_ATTR_PER_CPU_PIDS (Antoine Tenart) [2045048]
- openvswitch: Introduce per-cpu upcall dispatch (Antoine Tenart) [2045048]
- netfilter: fix regression in looped (broad|multi)cast's MAC handling (Florian Westphal) [2044272]
- selftests: nft_concat_range: add test for reload with no element add/del (Florian Westphal) [2044272]
- selftests: netfilter: Add correctness test for mac,net set type (Florian Westphal) [2044272]
- netfilter: conntrack: don't increment invalid counter on NF_REPEAT (Florian Westphal) [2044272]
- netfilter: nft_set_pipapo: allocate pcpu scratch maps on clone (Florian Westphal) [2044272]
- netfilter: nft_payload: do not update layer 4 checksum when mangling fragments (Florian Westphal) [2044272]
- netfilter: bridge: add support for pppoe filtering (Florian Westphal) [2044272]
- netfilter: nf_tables: fix use-after-free in nft_set_catchall_destroy() (Florian Westphal) [2044272]
- netfilter: conntrack: annotate data-races around ct->timeout (Florian Westphal) [2044272]
- netfilter: nft_exthdr: break evaluation if setting TCP option fails (Florian Westphal) [2044272]
- nft_set_pipapo: Fix bucket load in AVX2 lookup routine for six 8-bit groups (Florian Westphal) [2044272]
- tracing: Tag trace_percpu_buffer as a percpu pointer (Jerome Marchand) [2035164]
- tracing: Fix check for trace_percpu_buffer validity in get_trace_buf() (Jerome Marchand) [2035164]
- selftests: cgroup: Test open-time cgroup namespace usage for migration checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- selftests: cgroup: Test open-time credential usage for migration checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- selftests: cgroup: Make cg_create() use 0755 for permission instead of 0644 (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- cgroup: Use open-time cgroup namespace for process migration perm checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- cgroup: Allocate cgroup_file_ctx for kernfs_open_file->priv (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- cgroup: Use open-time credentials for process migraton perm checks (Chris von Recklinghausen) [2035768] {CVE-2021-4197}
- x86/sched: Decrease further the priorities of SMT siblings (Prarit Bhargava) [1971926]

* Wed Feb 16 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-60.rt21.61.el9]
- Revert "Merge: NVMe command id changes for use-after-free CQE detection" (Juri Lelli)
- net: Write lock dev_base_lock without disabling bottom halves. (Luis Claudio R. Goncalves) [2016279]
- crypto: jitter - add oversampling of noise source (Herbert Xu) [2036816]
- Revert "ipv6: Honor all IPv6 PIO Valid Lifetime values" (Guillaume Nault) [2027560]
- Change "-auto" suffix to fix CI automotive pipeline issues (Julio Faracco)
- nvme: drop unused variable ctrl in nvme_setup_cmd (John Meneghini) [2044616]
- nvme: increment request genctr on completion (John Meneghini) [2044616]
- nvme-pci: Fix abort command id (John Meneghini) [2044616]
- nvme: add command id quirk for apple controllers (John Meneghini) [2044616]
- nvme: move nvme_multi_css into nvme.h (John Meneghini) [2044616]
- nvme: code command_id with a genctr for use-after-free validation (John Meneghini) [2044616]
- nvme-pci: limit maximum queue depth to 4095 (John Meneghini) [2044616]
- selftests: Calculate udpgso segment count without header adjustment (Xin Long) [2044129]
- udp: using datalen to cap ipv6 udp max gso segments (Xin Long) [2044129]
- inet_diag: fix kernel-infoleak for UDP sockets (Xin Long) [2044129]
- udp: using datalen to cap max gso segments (Xin Long) [2044129]
- sctp: hold endpoint before calling cb in sctp_transport_lookup_process (Xin Long) [2043823]
- sctp: use call_rcu to free endpoint (Xin Long) [2043823]
- sctp: move hlist_node and hashent out of sctp_ep_common (Xin Long) [2043823]
- sctp: make the raise timer more simple and accurate (Xin Long) [2043823]
- nfsd: fix use-after-free due to delegation race (Benjamin Coddington) [1991929]
- bonding: Fix extraction of ports from the packet headers (Jonathan Toppins) [2042548]
- bonding: fix ad_actor_system option setting to default (Jonathan Toppins) [2042548]
- bonding: make tx_rebalance_counter an atomic (Jonathan Toppins) [2042548]
- bonding: Fix a use-after-free problem when bond_sysfs_slave_add() failed (Jonathan Toppins) [2042548]
- bonding: 3ad: pass parameter bond_params by reference (Jonathan Toppins) [2042548]
- bonding: complain about missing route only once for A/B ARP probes (Jonathan Toppins) [2042548]
- bonding: improve nl error msg when device can't be enslaved because of IFF_MASTER (Jonathan Toppins) [2042548]
- bonding: combine netlink and console error messages (Jonathan Toppins) [2042548]
- net, bonding: Refactor bond_xmit_hash for use with xdp_buff (Jonathan Toppins) [2042548]
- net: bonding: bond_alb: Remove the dependency on ipx network layer (Jonathan Toppins) [2042548]
- bonding: add new option lacp_active (Jonathan Toppins) [1951951 2042548]
- bonding: 3ad: fix the concurrency between __bond_release_one() and bond_3ad_state_machine_handler() (Jonathan Toppins) [2042548]
- fget: clarify and improve __fget_files() implementation (Miklos Szeredi) [2030418] {CVE-2021-4083}
- fget: check that the fd still exists after getting a ref to it (Miklos Szeredi) [2030418] {CVE-2021-4083}
- ipv6: Continue processing multipath route even if gateway attribute is invalid (Hangbin Liu) [2041401]
- ipv6: Check attribute length for RTA_GATEWAY when deleting multipath route (Hangbin Liu) [2041401]
- ipv6: Do cleanup if attribute validation fails in multipath route (Hangbin Liu) [2041401]
- ipv6: Check attribute length for RTA_GATEWAY in multipath route (Hangbin Liu) [2041401]
- ipv6: fix memory leak in fib6_rule_suppress (Hangbin Liu) [2041401]
- net: nexthop: reduce rcu synchronizations when replacing resilient groups (Hangbin Liu) [2041401]
- net: nexthop: release IPv6 per-cpu dsts when replacing a nexthop group (Hangbin Liu) [2041401]
- net: ipv6: add fib6_nh_release_dsts stub (Hangbin Liu) [2041401]
- ipv6: fix typos in __ip6_finish_output() (Hangbin Liu) [2041401]
- igbvf: Refactor trace (Corinna Vinschen) [2040322]
- igbvf: fix double free in `igbvf_probe` (Corinna Vinschen) [2040322]
- bnx2x: Fix enabling network interfaces without VFs (Manish Chopra) [1998304]
- tun: fix bonding active backup with arp monitoring (Jonathan Toppins) [2050837]

* Tue Feb 15 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-59.rt21.60.el9]
- mm/memcg: Pass a bool to refill_stock() (Leah Leshchinsky) [2028891]
- mm/memcg: Enable on PREEMPT_RT again. (Leah Leshchinsky) [2028891]
- mm/memcg: Remove 'page' parameter to mem_cgroup_charge_statistics() (Leah Leshchinsky) [2028891]
- redhat: configs: explicitly unset CONFIG_DAMON (Rafael Aquini) [2028891]
- mm/memory_hotplug: restrict CONFIG_MEMORY_HOTPLUG to 64 bit (Rafael Aquini) [2028891]
- mm/memory_hotplug: remove CONFIG_MEMORY_HOTPLUG_SPARSE (Rafael Aquini) [2028891]
- mm/memory_hotplug: remove CONFIG_X86_64_ACPI_NUMA dependency from CONFIG_MEMORY_HOTPLUG (Rafael Aquini) [2028891]
- memory-hotplug.rst: document the "auto-movable" online policy (Rafael Aquini) [2028891]
- memory-hotplug.rst: fix wrong /sys/module/memory_hotplug/parameters/ path (Rafael Aquini) [2028891]
- memory-hotplug.rst: fix two instances of "movablecore" that should be "movable_node" (Rafael Aquini) [2028891]
- selftest/vm: fix ksm selftest to run with different NUMA topologies (Rafael Aquini) [2028891]
- mm/vmalloc: introduce alloc_pages_bulk_array_mempolicy to accelerate memory allocation (Rafael Aquini) [2028891]
- memcg: unify memcg stat flushing (Rafael Aquini) [2028891]
- memcg: flush stats only if updated (Rafael Aquini) [2028891]
- mm/swapfile: fix an integer overflow in swap_show() (Rafael Aquini) [2028891]
- mm/gup: further simplify __gup_device_huge() (Rafael Aquini) [2028891]
- kasan: test: add memcpy test that avoids out-of-bounds write (Rafael Aquini) [2028891]
- tools/testing/selftests/vm/split_huge_page_test.c: fix application of sizeof to pointer (Rafael Aquini) [2028891]
- mm/damon/core-test: fix wrong expectations for 'damon_split_regions_of()' (Rafael Aquini) [2028891]
- mm: khugepaged: skip huge page collapse for special files (Rafael Aquini) [2028891]
- mm, thp: bail out early in collapse_file for writeback page (Rafael Aquini) [2028891]
- mm/vmalloc: fix numa spreading for large hash tables (Rafael Aquini) [2028891]
- mm/secretmem: avoid letting secretmem_users drop to zero (Rafael Aquini) [2028891]
- mm/oom_kill.c: prevent a race between process_mrelease and exit_mmap (Rafael Aquini) [2028891]
- mm: filemap: check if THP has hwpoisoned subpage for PMD page fault (Rafael Aquini) [2028891]
- mm: hwpoison: remove the unnecessary THP check (Rafael Aquini) [2028891]
- memcg: page_alloc: skip bulk allocator for __GFP_ACCOUNT (Rafael Aquini) [2028891]
- secretmem: Prevent secretmem_users from wrapping to zero (Rafael Aquini) [2028891]
- Revert "mm/secretmem: use refcount_t instead of atomic_t" (Rafael Aquini) [2028891]
- memblock: exclude MEMBLOCK_NOMAP regions from kmemleak (Rafael Aquini) [2028891]
- Revert "memblock: exclude NOMAP regions from kmemleak" (Rafael Aquini) [2028891]
- mm/thp: decrease nr_thps in file's mapping on THP split (Rafael Aquini) [2028891]
- mm/secretmem: fix NULL page->mapping dereference in page_is_secretmem() (Rafael Aquini) [2028891]
- mm, slub: fix incorrect memcg slab count for bulk free (Rafael Aquini) [2028891]
- mm, slub: fix potential use-after-free in slab_debugfs_fops (Rafael Aquini) [2028891]
- mm, slub: fix potential memoryleak in kmem_cache_open() (Rafael Aquini) [2028891]
- mm, slub: fix mismatch between reconstructed freelist depth and cnt (Rafael Aquini) [2028891]
- mm, slub: fix two bugs in slab_debug_trace_open() (Rafael Aquini) [2028891]
- mm/mempolicy: do not allow illegal MPOL_F_NUMA_BALANCING | MPOL_LOCAL in mbind() (Rafael Aquini) [2028891]
- memblock: check memory total_size (Rafael Aquini) [2028891]
- mm/migrate: fix CPUHP state to update node demotion order (Rafael Aquini) [2028891]
- mm/migrate: add CPU hotplug to demotion #ifdef (Rafael Aquini) [2028891]
- mm/migrate: optimize hotplug-time demotion order updates (Rafael Aquini) [2028891]
- userfaultfd: fix a race between writeprotect and exit_mmap() (Rafael Aquini) [2028891]
- mm/userfaultfd: selftests: fix memory corruption with thp enabled (Rafael Aquini) [2028891]
- memblock: exclude NOMAP regions from kmemleak (Rafael Aquini) [2028891]
- misc: fastrpc: Add missing lock before accessing find_vma() (Rafael Aquini) [2028891]
- mm: fix uninitialized use in overcommit_policy_handler (Rafael Aquini) [2028891]
- mm/memory_failure: fix the missing pte_unmap() call (Rafael Aquini) [2028891]
- kasan: always respect CONFIG_KASAN_STACK (Rafael Aquini) [2028891]
- mm/debug: sync up latest migrate_reason to migrate_reason_names (Rafael Aquini) [2028891]
- mm/debug: sync up MR_CONTIG_RANGE and MR_LONGTERM_PIN (Rafael Aquini) [2028891]
- mm: fs: invalidate bh_lrus for only cold path (Rafael Aquini) [2028891]
- mm/shmem.c: fix judgment error in shmem_is_huge() (Rafael Aquini) [2028891]
- mm/damon: don't use strnlen() with known-bogus source length (Rafael Aquini) [2028891]
- kasan: fix Kconfig check of CC_HAS_WORKING_NOSANITIZE_ADDRESS (Rafael Aquini) [2028891]
- mm, hwpoison: add is_free_buddy_page() in HWPoisonHandlable() (Rafael Aquini) [2028891]
- memcg: flush lruvec stats in the refault (Rafael Aquini) [2028891]
- netfilter: nf_tables: Fix oversized kvmalloc() calls (Rafael Aquini) [2028891]
- mm: Fully initialize invalidate_lock, amend lock class later (Rafael Aquini) [2028891]
- tools/bootconfig: Define memblock_free_ptr() to fix build error (Rafael Aquini) [2028891]
- memblock: introduce saner 'memblock_free_ptr()' interface (Leah Leshchinsky) [2028891]
- bpf: Add oversize check before call kvcalloc() (Rafael Aquini) [2028891]
- netfilter: ipset: Fix oversized kvmalloc() calls (Rafael Aquini) [2028891]
- bpf, mm: Fix lockdep warning triggered by stack_map_get_build_id_offset() (Rafael Aquini) [2028891]
- tools headers UAPI: Sync files changed by new process_mrelease syscall and the removal of some compat entry points (Rafael Aquini) [2028891]
- arm64: kdump: Skip kmemleak scan reserved memory for kdump (Rafael Aquini) [2028891]
- mm/mempolicy: fix a race between offset_il_node and mpol_rebind_task (Rafael Aquini) [2028891]
- mm/kmemleak: allow __GFP_NOLOCKDEP passed to kmemleak's gfp (Rafael Aquini) [2028891]
- mmap_lock: change trace and locking order (Rafael Aquini) [2028891]
- mm/page_alloc.c: avoid accessing uninitialized pcp page migratetype (Rafael Aquini) [2028891]
- mm,vmscan: fix divide by zero in get_scan_count (Rafael Aquini) [2028891]
- mm/hugetlb: initialize hugetlb_usage in mm_init (Rafael Aquini) [2028891]
- mm/hmm: bypass devmap pte when all pfn requested flags are fulfilled (Rafael Aquini) [2028891]
- arch: remove compat_alloc_user_space (Rafael Aquini) [2028891]
- compat: remove some compat entry points (Rafael Aquini) [2028891]
- mm: simplify compat numa syscalls (Rafael Aquini) [2028891]
- mm: simplify compat_sys_move_pages (Rafael Aquini) [2028891]
- kexec: avoid compat_alloc_user_space (Rafael Aquini) [2028891]
- kexec: move locking into do_kexec_load (Rafael Aquini) [2028891]
- mm: migrate: change to use bool type for 'page_was_mapped' (Rafael Aquini) [2028891]
- mm: migrate: fix the incorrect function name in comments (Rafael Aquini) [2028891]
- mm: migrate: introduce a local variable to get the number of pages (Rafael Aquini) [2028891]
- mm/vmstat: protect per cpu variables with preempt disable on RT (Rafael Aquini) [2028891]
- mm/workingset: correct kernel-doc notations (Rafael Aquini) [2028891]
- percpu: remove export of pcpu_base_addr (Rafael Aquini) [2028891]
- MAINTAINERS: update for DAMON (Rafael Aquini) [2028891]
- mm/damon: add user space selftests (Rafael Aquini) [2028891]
- mm/damon: add kunit tests (Rafael Aquini) [2028891]
- Documentation: add documents for DAMON (Rafael Aquini) [2028891]
- mm/damon/dbgfs: support multiple contexts (Rafael Aquini) [2028891]
- mm/damon/dbgfs: export kdamond pid to the user space (Rafael Aquini) [2028891]
- mm/damon: implement a debugfs-based user space interface (Rafael Aquini) [2028891]
- mm/damon: add a tracepoint (Rafael Aquini) [2028891]
- mm/damon: implement primitives for the virtual memory address spaces (Rafael Aquini) [2028891]
- mm/idle_page_tracking: make PG_idle reusable (Rafael Aquini) [2028891]
- mm/damon: adaptively adjust regions (Rafael Aquini) [2028891]
- mm/damon/core: implement region-based sampling (Rafael Aquini) [2028891]
- mm: introduce Data Access MONitor (DAMON) (Rafael Aquini) [2028891]
- kfence: test: fail fast if disabled at boot (Rafael Aquini) [2028891]
- kfence: show cpu and timestamp in alloc/free info (Rafael Aquini) [2028891]
- mm/secretmem: use refcount_t instead of atomic_t (Rafael Aquini) [2028891]
- mm: introduce PAGEFLAGS_MASK to replace ((1UL << NR_PAGEFLAGS) - 1) (Rafael Aquini) [2028891]
- mm: in_irq() cleanup (Rafael Aquini) [2028891]
- mm/early_ioremap.c: remove redundant early_ioremap_shutdown() (Rafael Aquini) [2028891]
- mm: don't allow executable ioremap mappings (Rafael Aquini) [2028891]
- mm: move ioremap_page_range to vmalloc.c (Rafael Aquini) [2028891]
- mm: remove redundant compound_head() calling (Rafael Aquini) [2028891]
- mm/memory_hotplug: use helper zone_is_zone_device() to simplify the code (Rafael Aquini) [2028891]
- mm/memory_hotplug: improved dynamic memory group aware "auto-movable" online policy (Rafael Aquini) [2028891]
- mm/memory_hotplug: memory group aware "auto-movable" online policy (Rafael Aquini) [2028891]
- virtio-mem: use a single dynamic memory group for a single virtio-mem device (Rafael Aquini) [2028891]
- dax/kmem: use a single static memory group for a single probed unit (Rafael Aquini) [2028891]
- ACPI: memhotplug: use a single static memory group for a single memory device (Rafael Aquini) [2028891]
- mm/memory_hotplug: track present pages in memory groups (Rafael Aquini) [2028891]
- drivers/base/memory: introduce "memory groups" to logically group memory blocks (Rafael Aquini) [2028891]
- mm/memory_hotplug: introduce "auto-movable" online policy (Rafael Aquini) [2028891]
- mm: track present early pages per zone (Rafael Aquini) [2028891]
- ACPI: memhotplug: memory resources cannot be enabled yet (Rafael Aquini) [2028891]
- mm/memory_hotplug: remove nid parameter from remove_memory() and friends (Rafael Aquini) [2028891]
- mm/memory_hotplug: remove nid parameter from arch_remove_memory() (Rafael Aquini) [2028891]
- mm/memory_hotplug: use "unsigned long" for PFN in zone_for_pfn_range() (Rafael Aquini) [2028891]
- mm: memory_hotplug: cleanup after removal of pfn_valid_within() (Rafael Aquini) [2028891]
- mm: remove pfn_valid_within() and CONFIG_HOLES_IN_ZONE (Rafael Aquini) [2028891]
- memory-hotplug.rst: complete admin-guide overhaul (Rafael Aquini) [2028891]
- memory-hotplug.rst: remove locking details from admin-guide (Rafael Aquini) [2028891]
- Revert "memcg: enable accounting for pollfd and select bits arrays" (Rafael Aquini) [2028891]
- Revert "memcg: enable accounting for file lock caches" (Rafael Aquini) [2028891]
- Revert "mm/gup: remove try_get_page(), call try_get_compound_head() directly" (Rafael Aquini) [2028891]
- binfmt: a.out: Fix bogus semicolon (Rafael Aquini) [2028891]
- mm/madvise: add MADV_WILLNEED to process_madvise() (Rafael Aquini) [2028891]
- mm/vmstat: remove unneeded return value (Rafael Aquini) [2028891]
- mm/vmstat: simplify the array size calculation (Rafael Aquini) [2028891]
- mm/vmstat: correct some wrong comments (Rafael Aquini) [2028891]
- mm/percpu,c: remove obsolete comments of pcpu_chunk_populated() (Rafael Aquini) [2028891]
- selftests: vm: add COW time test for KSM pages (Rafael Aquini) [2028891]
- selftests: vm: add KSM merging time test (Rafael Aquini) [2028891]
- mm: KSM: fix data type (Rafael Aquini) [2028891]
- selftests: vm: add KSM merging across nodes test (Rafael Aquini) [2028891]
- selftests: vm: add KSM zero page merging test (Rafael Aquini) [2028891]
- selftests: vm: add KSM unmerge test (Rafael Aquini) [2028891]
- selftests: vm: add KSM merge test (Rafael Aquini) [2028891]
- mm/migrate: correct kernel-doc notation (Rafael Aquini) [2028891]
- mm: wire up syscall process_mrelease (Rafael Aquini) [2028891]
- mm: introduce process_mrelease system call (Rafael Aquini) [2028891]
- memblock: make memblock_find_in_range method private (Rafael Aquini) [2028891]
- mm/mempolicy.c: use in_task() in mempolicy_slab_node() (Rafael Aquini) [2028891]
- mm/mempolicy: unify the create() func for bind/interleave/prefer-many policies (Rafael Aquini) [2028891]
- mm/mempolicy: advertise new MPOL_PREFERRED_MANY (Rafael Aquini) [2028891]
- mm/hugetlb: add support for mempolicy MPOL_PREFERRED_MANY (Rafael Aquini) [2028891]
- mm/memplicy: add page allocation function for MPOL_PREFERRED_MANY policy (Rafael Aquini) [2028891]
- mm/mempolicy: add MPOL_PREFERRED_MANY for multiple preferred nodes (Rafael Aquini) [2028891]
- mm/mempolicy: use readable NUMA_NO_NODE macro instead of magic number (Rafael Aquini) [2028891]
- mm: compaction: support triggering of proactive compaction by user (Rafael Aquini) [2028891]
- mm: compaction: optimize proactive compaction deferrals (Rafael Aquini) [2028891]
- mm, vmscan: guarantee drop_slab_node() termination (Rafael Aquini) [2028891]
- mm/vmscan: add 'else' to remove check_pending label (Rafael Aquini) [2028891]
- mm/vmscan: remove unneeded return value of kswapd_run() (Rafael Aquini) [2028891]
- mm/vmscan: remove misleading setting to sc->priority (Rafael Aquini) [2028891]
- mm/vmscan: remove the PageDirty check after MADV_FREE pages are page_ref_freezed (Rafael Aquini) [2028891]
- mm/vmpressure: replace vmpressure_to_css() with vmpressure_to_memcg() (Rafael Aquini) [2028891]
- mm/migrate: add sysfs interface to enable reclaim migration (Rafael Aquini) [2028891]
- mm/vmscan: never demote for memcg reclaim (Rafael Aquini) [2028891]
- mm/vmscan: Consider anonymous pages without swap (Rafael Aquini) [2028891]
- mm/vmscan: add helper for querying ability to age anonymous pages (Rafael Aquini) [2028891]
- mm/vmscan: add page demotion counter (Rafael Aquini) [2028891]
- mm/migrate: demote pages during reclaim (Rafael Aquini) [2028891]
- mm/migrate: enable returning precise migrate_pages() success count (Rafael Aquini) [2028891]
- mm/migrate: update node demotion order on hotplug events (Rafael Aquini) [2028891]
- mm/numa: automatically generate node migration order (Rafael Aquini) [2028891]
- selftests/vm/userfaultfd: wake after copy failure (Rafael Aquini) [2028891]
- userfaultfd: prevent concurrent API initialization (Rafael Aquini) [2028891]
- userfaultfd: change mmap_changing to atomic (Rafael Aquini) [2028891]
- hugetlb: fix hugetlb cgroup refcounting during vma split (Rafael Aquini) [2028891]
- hugetlb: before freeing hugetlb page set dtor to appropriate value (Rafael Aquini) [2028891]
- hugetlb: drop ref count earlier after page allocation (Rafael Aquini) [2028891]
- hugetlb: simplify prep_compound_gigantic_page ref count racing code (Rafael Aquini) [2028891]
- mm: fix panic caused by __page_handle_poison() (Rafael Aquini) [2028891]
- mm: hwpoison: dump page for unhandlable page (Rafael Aquini) [2028891]
- doc: hwpoison: correct the support for hugepage (Rafael Aquini) [2028891]
- mm: hwpoison: don't drop slab caches for offlining non-LRU page (Rafael Aquini) [2028891]
- mm/hwpoison: fix some obsolete comments (Rafael Aquini) [2028891]
- mm/hwpoison: change argument struct page **hpagep to *hpage (Rafael Aquini) [2028891]
- mm/hwpoison: fix potential pte_unmap_unlock pte error (Rafael Aquini) [2028891]
- mm/hwpoison: remove unneeded variable unmap_success (Rafael Aquini) [2028891]
- mm/page_isolation: tracing: trace all test_pages_isolated failures (Rafael Aquini) [2028891]
- mm/page_alloc.c: use in_task() (Rafael Aquini) [2028891]
- mm/page_alloc: make alloc_node_mem_map() __init rather than __ref (Rafael Aquini) [2028891]
- mm/page_alloc.c: fix 'zone_id' may be used uninitialized in this function warning (Rafael Aquini) [2028891]
- memblock: stop poisoning raw allocations (Rafael Aquini) [2028891]
- mm: introduce memmap_alloc() to unify memory map allocation (Rafael Aquini) [2028891]
- mm/page_alloc: always initialize memory map for the holes (Rafael Aquini) [2028891]
- kasan: test: avoid corrupting memory in kasan_rcu_uaf (Rafael Aquini) [2028891]
- kasan: test: avoid corrupting memory in copy_user_test (Rafael Aquini) [2028891]
- kasan: test: clean up ksize_uaf (Rafael Aquini) [2028891]
- kasan: test: only do kmalloc_uaf_memset for generic mode (Rafael Aquini) [2028891]
- kasan: test: disable kmalloc_memmove_invalid_size for HW_TAGS (Rafael Aquini) [2028891]
- kasan: test: avoid corrupting memory via memset (Rafael Aquini) [2028891]
- kasan: test: avoid writing invalid memory (Rafael Aquini) [2028891]
- kasan: test: rework kmalloc_oob_right (Rafael Aquini) [2028891]
- mm/kasan: move kasan.fault to mm/kasan/report.c (Rafael Aquini) [2028891]
- mm/vmalloc: fix wrong behavior in vread (Rafael Aquini) [2028891]
- lib/test_vmalloc.c: add a new 'nr_pages' parameter (Rafael Aquini) [2028891]
- mm/vmalloc: remove gfpflags_allow_blocking() check (Rafael Aquini) [2028891]
- mm/vmalloc: use batched page requests in bulk-allocator (Rafael Aquini) [2028891]
- mm/sparse: clarify pgdat_to_phys (Rafael Aquini) [2028891]
- include/linux/mmzone.h: avoid a warning in sparse memory support (Rafael Aquini) [2028891]
- mm/sparse: set SECTION_NID_SHIFT to 6 (Rafael Aquini) [2028891]
- mm: sparse: remove __section_nr() function (Rafael Aquini) [2028891]
- mm: sparse: pass section_nr to find_memory_block (Rafael Aquini) [2028891]
- mm: sparse: pass section_nr to section_mark_present (Rafael Aquini) [2028891]
- mm/bootmem_info.c: mark __init on register_page_bootmem_info_section (Rafael Aquini) [2028891]
- mm/mremap: fix memory account on do_munmap() failure (Rafael Aquini) [2028891]
- remap_file_pages: Use vma_lookup() instead of find_vma() (Rafael Aquini) [2028891]
- mm/pagemap: add mmap_assert_locked() annotations to find_vma*() (Rafael Aquini) [2028891]
- mm: change fault_in_pages_* to have an unsigned size parameter (Rafael Aquini) [2028891]
- mm,do_huge_pmd_numa_page: remove unnecessary TLB flushing code (Rafael Aquini) [2028891]
- mm: remove flush_kernel_dcache_page (Rafael Aquini) [2028891]
- scatterlist: replace flush_kernel_dcache_page with flush_dcache_page (Rafael Aquini) [2028891]
- mmc: mmc_spi: replace flush_kernel_dcache_page with flush_dcache_page (Rafael Aquini) [2028891]
- mmc: JZ4740: remove the flush_kernel_dcache_page call in jz4740_mmc_read_data (Rafael Aquini) [2028891]
- selftests: Fix spelling mistake "cann't" -> "cannot" (Rafael Aquini) [2028891]
- selftests/vm: use kselftest skip code for skipped tests (Rafael Aquini) [2028891]
- memcg: make memcg->event_list_lock irqsafe (Rafael Aquini) [2028891]
- memcg: fix up drain_local_stock comment (Rafael Aquini) [2028891]
- mm, memcg: save some atomic ops when flush is already true (Rafael Aquini) [2028891]
- mm, memcg: remove unused functions (Rafael Aquini) [2028891]
- mm: memcontrol: set the correct memcg swappiness restriction (Rafael Aquini) [2028891]
- memcg: replace in_interrupt() by !in_task() in active_memcg() (Rafael Aquini) [2028891]
- memcg: cleanup racy sum avoidance code (Rafael Aquini) [2028891]
- memcg: enable accounting for ldt_struct objects (Rafael Aquini) [2028891]
- memcg: enable accounting for posix_timers_cache slab (Rafael Aquini) [2028891]
- memcg: enable accounting for signals (Rafael Aquini) [2028891]
- memcg: enable accounting for new namesapces and struct nsproxy (Rafael Aquini) [2028891]
- memcg: enable accounting for fasync_cache (Rafael Aquini) [2028891]
- memcg: enable accounting for file lock caches (Rafael Aquini) [2028891]
- memcg: enable accounting for pollfd and select bits arrays (Rafael Aquini) [2028891]
- memcg: enable accounting for mnt_cache entries (Rafael Aquini) [2028891]
- memcg: charge fs_context and legacy_fs_context (Rafael Aquini) [2028891]
- memcg: infrastructure to flush memcg stats (Rafael Aquini) [2028891]
- memcg: switch lruvec stats to rstat (Rafael Aquini) [2028891]
- mm, memcg: inline swap-related functions to improve disabled memcg config (Rafael Aquini) [2028891]
- mm, memcg: inline mem_cgroup_{charge/uncharge} to improve disabled memcg config (Rafael Aquini) [2028891]
- mm, memcg: add mem_cgroup_disabled checks in vmpressure and swap-related functions (Rafael Aquini) [2028891]
- huge tmpfs: decide stat.st_blksize by shmem_is_huge() (Rafael Aquini) [2028891]
- huge tmpfs: shmem_is_huge(vma, inode, index) (Rafael Aquini) [2028891]
- huge tmpfs: SGP_NOALLOC to stop collapse_file() on race (Rafael Aquini) [2028891]
- huge tmpfs: move shmem_huge_enabled() upwards (Rafael Aquini) [2028891]
- huge tmpfs: revert shmem's use of transhuge_vma_enabled() (Rafael Aquini) [2028891]
- huge tmpfs: remove shrinklist addition from shmem_setattr() (Rafael Aquini) [2028891]
- huge tmpfs: fix split_huge_page() after FALLOC_FL_KEEP_SIZE (Rafael Aquini) [2028891]
- huge tmpfs: fix fallocate(vanilla) advance over huge pages (Rafael Aquini) [2028891]
- shmem: shmem_writepage() split unlikely i915 THP (Rafael Aquini) [2028891]
- shmem: include header file to declare swap_info (Rafael Aquini) [2028891]
- shmem: remove unneeded function forward declaration (Rafael Aquini) [2028891]
- shmem: remove unneeded header file (Rafael Aquini) [2028891]
- shmem: remove unneeded variable ret (Rafael Aquini) [2028891]
- mm/gup: remove try_get_page(), call try_get_compound_head() directly (Rafael Aquini) [2028891]
- mm/gup: small refactoring: simplify try_grab_page() (Rafael Aquini) [2028891]
- mm/gup: documentation corrections for gup/pup (Rafael Aquini) [2028891]
- mm: gup: use helper PAGE_ALIGNED in populate_vma_page_range() (Rafael Aquini) [2028891]
- mm: gup: fix potential pgmap refcnt leak in __gup_device_huge() (Rafael Aquini) [2028891]
- mm: gup: remove useless BUG_ON in __get_user_pages() (Rafael Aquini) [2028891]
- mm: gup: remove unneed local variable orig_refs (Rafael Aquini) [2028891]
- mm: gup: remove set but unused local variable major (Rafael Aquini) [2028891]
- mm: delete unused get_kernel_page() (Rafael Aquini) [2028891]
- include/linux/buffer_head.h: fix boolreturn.cocci warnings (Rafael Aquini) [2028891]
- fs, mm: fix race in unlinking swapfile (Rafael Aquini) [2028891]
- fs: inode: count invalidated shadow pages in pginodesteal (Rafael Aquini) [2028891]
- fs: drop_caches: fix skipping over shadow cache inodes (Rafael Aquini) [2028891]
- fs: update documentation of get_write_access() and friends (Rafael Aquini) [2028891]
- filesystems/locking: fix Malformed table warning (Rafael Aquini) [2028891]
- writeback: memcg: simplify cgroup_writeback_by_id (Rafael Aquini) [2028891]
- writeback: use READ_ONCE for unlocked reads of writeback stats (Rafael Aquini) [2028891]
- writeback: rename domain_update_bandwidth() (Rafael Aquini) [2028891]
- writeback: fix bandwidth estimate for spiky workload (Rafael Aquini) [2028891]
- writeback: reliably update bandwidth estimation (Rafael Aquini) [2028891]
- writeback: track number of inodes under writeback (Rafael Aquini) [2028891]
- writeback: make the laptop_mode prototypes available unconditionally (Rafael Aquini) [2028891]
- mm: remove irqsave/restore locking from contexts with irqs enabled (Rafael Aquini) [2028891]
- mm: add kernel_misc_reclaimable in show_free_areas (Rafael Aquini) [2028891]
- mm: report a more useful address for reclaim acquisition (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: fix corrupted page flag (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: remove unused code (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PGD and P4D modifying tests (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PUD modifying tests (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PMD modifying tests (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PTE modifying tests (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in migration and thp tests (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in soft_dirty and swap tests (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in protnone and devmap tests (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in leaf and savewrite tests (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in basic tests (Rafael Aquini) [2028891]
- mm/debug_vm_pgtable: introduce struct pgtable_debug_args (Rafael Aquini) [2028891]
- mm: ignore MAP_DENYWRITE in ksys_mmap_pgoff() (Rafael Aquini) [2028891]
- mm: remove VM_DENYWRITE (Rafael Aquini) [2028891]
- binfmt: remove in-tree usage of MAP_DENYWRITE (Rafael Aquini) [2028891]
- kernel/fork: always deny write access to current MM exe_file (Rafael Aquini) [2028891]
- kernel/fork: factor out replacing the current MM exe_file (Rafael Aquini) [2028891]
- binfmt: don't use MAP_DENYWRITE when loading shared libraries via uselib() (Rafael Aquini) [2028891]
- ARM: 9115/1: mm/maccess: fix unaligned copy_{from,to}_kernel_nofault (Rafael Aquini) [2028891]
- net-memcg: pass in gfp_t mask to mem_cgroup_charge_skmem() (Leah Leshchinsky) [2028891]
- memblock: Check memory add/cap ordering (Rafael Aquini) [2028891]
- memblock: Add missing debug code to memblock_add_node() (Rafael Aquini) [2028891]
- mm: don't allow oversized kvmalloc() calls (Rafael Aquini) [2028891]
- mm: Add kvrealloc() (Rafael Aquini) [2028891]
- mm: hide laptop_mode_wb_timer entirely behind the BDI API (Rafael Aquini) [2028891]
- mm: Add functions to lock invalidate_lock for two mappings (Rafael Aquini) [2028891]
- mm: Protect operations adding pages to page cache with invalidate_lock (Rafael Aquini) [2028891]
- mm: Fix comments mentioning i_mutex (Rafael Aquini) [2028891]
- exit/bdflush: Remove the deprecated bdflush system call (Rafael Aquini) [2028891]
- [rt] revert c9s MR151: "mm/memcg: Remove MEMCG config dependency on PREEMPT_RT" (Leah Leshchinsky) [2028891]

* Mon Feb 14 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-59.rt21.59.el9]
- gfs2: Fix gfs2_release for non-writers regression (Bob Peterson) [2030397]
- gfs2: gfs2_create_inode rework (Andreas Gruenbacher) [2002803]
- gfs2: gfs2_inode_lookup rework (Andreas Gruenbacher) [2002803]
- gfs2: gfs2_inode_lookup cleanup (Andreas Gruenbacher) [2002803]
- gfs2: Fix remote demote of weak glock holders (Andreas Gruenbacher) [1958140]
- gfs2: Fix unused value warning in do_gfs2_set_flags() (Andreas Gruenbacher) [1958140]
- gfs2: Fix glock_hash_walk bugs (Andreas Gruenbacher) [2008541]
- gfs2: Cancel remote delete work asynchronously (Bob Peterson) [2002803]
- gfs2: set glock object after nq (Bob Peterson) [1998303]
- gfs2: remove RDF_UPTODATE flag (Bob Peterson) [1998303]
- gfs2: Eliminate GIF_INVALID flag (Bob Peterson) [1998303]
- gfs2: Fix atomic bug in gfs2_instantiate (Andreas Gruenbacher) [1998303]
- gfs2: fix GL_SKIP node_scope problems (Bob Peterson) [1998303]
- gfs2: split glock instantiation off from do_promote (Bob Peterson) [1998303]
- gfs2: further simplify do_promote (Bob Peterson) [1998303]
- gfs2: re-factor function do_promote (Bob Peterson) [1998303]
- gfs2: Remove 'first' trace_gfs2_promote argument (Andreas Gruenbacher) [1998303]
- gfs2: change go_lock to go_instantiate (Bob Peterson) [1998303]
- gfs2: dump glocks from gfs2_consist_OBJ_i (Bob Peterson) [1998303]
- gfs2: dequeue iopen holder in gfs2_inode_lookup error (Bob Peterson) [2006870]
- gfs2: Save ip from gfs2_glock_nq_init (Bob Peterson) [1998303]
- gfs2: Allow append and immutable bits to coexist (Bob Peterson) [1998303]
- gfs2: Switch some BUG_ON to GLOCK_BUG_ON for debug (Bob Peterson) [1998303]
- gfs2: move GL_SKIP check from glops to do_promote (Bob Peterson) [1998303]
- gfs2: Add GL_SKIP holder flag to dump_holder (Bob Peterson) [1998303]
- gfs2: remove redundant check in gfs2_rgrp_go_lock (Bob Peterson) [1998303]
- gfs2: Fix mmap + page fault deadlocks for direct I/O (Andreas Gruenbacher) [1958140]
- iov_iter: Introduce nofault flag to disable page faults (Andreas Gruenbacher) [1958140]
- gup: Introduce FOLL_NOFAULT flag to disable page faults (Andreas Gruenbacher) [1958140]
- iomap: Add done_before argument to iomap_dio_rw (Andreas Gruenbacher) [1958140]
- iomap: Support partial direct I/O on user copy failures (Andreas Gruenbacher) [1958140]
- iomap: Fix iomap_dio_rw return value for user copies (Andreas Gruenbacher) [1958140]
- iomap: support reading inline data from non-zero pos (Andreas Gruenbacher) [1958140]
- gfs2: Only dereference i->iov when iter_is_iovec(i) (Andreas Gruenbacher) [1958140]
- gfs2: Prevent endless loops in gfs2_file_buffered_write (Andreas Gruenbacher) [1958140]
- gfs2: Fix mmap + page fault deadlocks for buffered I/O (Andreas Gruenbacher) [1958140]
- gfs2: Eliminate ip->i_gh (Andreas Gruenbacher) [1958140]
- gfs2: Move the inode glock locking to gfs2_file_buffered_write (Andreas Gruenbacher) [1958140]
- gfs2: Fix "Introduce flag for glock holder auto-demotion" (Andreas Gruenbacher) [1958140]
- gfs2: Introduce flag for glock holder auto-demotion (Bob Peterson) [1958140]
- gfs2: Clean up function may_grant (Andreas Gruenbacher) [1958140]
- gfs2: Add wrapper for iomap_file_buffered_write (Andreas Gruenbacher) [1958140]
- iov_iter: Introduce fault_in_iov_iter_writeable (Andreas Gruenbacher) [1958140]
- iov_iter: Turn iov_iter_fault_in_readable into fault_in_iov_iter_readable (Andreas Gruenbacher) [1958140]
- gup: Turn fault_in_pages_{readable,writeable} into fault_in_{readable,writeable} (Andreas Gruenbacher) [1958140]
- powerpc/kvm: Fix kvm_use_magic_page (Andreas Gruenbacher) [1958140]
- iov_iter: Fix iov_iter_get_pages{,_alloc} page fault return value (Andreas Gruenbacher) [1958140]
- gfs2: Fix length of holes reported at end-of-file (Andreas Gruenbacher) [2029955]
- gfs2: release iopen glock early in evict (Bob Peterson) [2009406]
- gfs2: Switch to may_setattr in gfs2_setattr (Bob Peterson) [2029947]
- fs: Move notify_change permission checks into may_setattr (Bob Peterson) [2029947]
- gfs2: Remove redundant check from gfs2_glock_dq (Bob Peterson) [2030090]
- gfs2: Delay withdraw from atomic context (Bob Peterson) [2030090]
- gfs2: nit: gfs2_drop_inode shouldn't return bool (Bob Peterson) [2030090]
- gfs2: Eliminate vestigial HIF_FIRST (Bob Peterson) [2030090]
- gfs2: Make recovery error more readable (Bob Peterson) [2030090]
- gfs2: Don't release and reacquire local statfs bh (Bob Peterson) [2030090]
- gfs2: init system threads before freeze lock (Bob Peterson) [2030090]
- gfs2: tiny cleanup in gfs2_log_reserve (Bob Peterson) [2030090]
- gfs2: trivial clean up of gfs2_ail_error (Bob Peterson) [2030090]
- gfs2: be more verbose replaying invalid rgrp blocks (Bob Peterson) [2030090]
- iomap: remove the iomap arguments to ->page_{prepare,done} (Andreas Gruenbacher) [1958140]
- gfs2: Fix glock recursion in freeze_go_xmote_bh (Bob Peterson) [2030090]
- gfs2: Fix memory leak of object lsi on error return path (Andreas Gruenbacher) [2030090]
- x86/sgx: Fix minor documentation issues (Vladis Dronov) [1920028]
- selftests/sgx: Add test for multiple TCS entry (Vladis Dronov) [1920028]
- selftests/sgx: Enable multiple thread support (Vladis Dronov) [1920028]
- selftests/sgx: Add page permission and exception test (Vladis Dronov) [1920028]
- selftests/sgx: Rename test properties in preparation for more enclave tests (Vladis Dronov) [1920028]
- selftests/sgx: Provide per-op parameter structs for the test enclave (Vladis Dronov) [1920028]
- selftests/sgx: Add a new kselftest: Unclobbered_vdso_oversubscribed (Vladis Dronov) [1920028]
- selftests/sgx: Move setup_test_encl() to each TEST_F() (Vladis Dronov) [1920028]
- selftests/sgx: Encpsulate the test enclave creation (Vladis Dronov) [1920028]
- selftests/sgx: Dump segments and /proc/self/maps only on failure (Vladis Dronov) [1920028]
- selftests/sgx: Create a heap for the test enclave (Vladis Dronov) [1920028]
- selftests/sgx: Make data measurement for an enclave segment optional (Vladis Dronov) [1920028]
- selftests/sgx: Assign source for each segment (Vladis Dronov) [1920028]
- selftests/sgx: Fix a benign linker warning (Vladis Dronov) [1920028]
- x86/sgx: Fix free page accounting (Vladis Dronov) [1920028]
- x86/sgx: Add check for SGX pages to ghes_do_memory_failure() (Vladis Dronov) [1920028]
- x86/sgx: Add hook to error injection address validation (Vladis Dronov) [1920028]
- x86/sgx: Hook arch_memory_failure() into mainline code (Vladis Dronov) [1920028]
- x86/sgx: Add SGX infrastructure to recover from poison (Vladis Dronov) [1920028]
- x86/sgx: Initial poison handling for dirty and free pages (Vladis Dronov) [1920028]
- x86/sgx: Add infrastructure to identify SGX EPC pages (Vladis Dronov) [1920028]
- x86/sgx: Add new sgx_epc_page flag bit to mark free pages (Vladis Dronov) [1920028]

* Fri Feb 11 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-58.rt21.58.el9]
- KVM: nVMX: Allow VMREAD when Enlightened VMCS is in use (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Implement evmcs_field_offset() suitable for handle_vmread() (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Rename vmcs_to_field_offset{,_table} (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: eVMCS: Filter out VM_EXIT_SAVE_VMX_PREEMPTION_TIMER (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Also filter MSR_IA32_VMX_TRUE_PINBASED_CTLS when eVMCS (Vitaly Kuznetsov) [2027639]
- KVM: nVMX: Use INVALID_GPA for pointers used in nVMX. (Vitaly Kuznetsov) [2027639]
- x86/kvm: Always inline evmcs_write64() (Vitaly Kuznetsov) [2027639]
- [s390] s390/pci: move pseudo-MMIO to prevent MIO overlap (Mete Durlu) [2047755]
- CI: Update the RHEL9-private pipeline names to new schema (Veronika Kabatova)
- CI: Sync RHEL9-RT-baseline with c9s-RT-baseline (Veronika Kabatova)
- CI: Add kpet_tree_family to RT check config (Veronika Kabatova)
- selftests/bpf: Enlarge select() timeout for test_maps (Felix Maurer) [2032718]
- netfilter: nft_reject_bridge: Fix for missing reply from prerouting (Phil Sutter) [2044848]
- gre: Don't accidentally set RTO_ONLINK in gre_fill_metadata_dst() (Guillaume Nault) [2047202]
- net: fix use-after-free in tw_timer_handler (Guillaume Nault) [2047202]
- inet: use #ifdef CONFIG_SOCK_RX_QUEUE_MAPPING consistently (Guillaume Nault) [2047202]
- ipv4: convert fib_num_tclassid_users to atomic_t (Guillaume Nault) [2047202]
- vfs: fs_context: fix up param length parsing in legacy_parse_param (Carlos Maiolino) [2040587] {CVE-2022-0185}
- sched/pelt: Relax the sync of load_sum with load_avg (Phil Auld) [2045052]
- sched/pelt: Relax the sync of runnable_sum with runnable_avg (Phil Auld) [2045052]
- sched/pelt: Continue to relax the sync of util_sum with util_avg (Phil Auld) [2045052]
- sched/pelt: Relax the sync of util_sum with util_avg (Phil Auld) [2045052]
- pinctrl: amd: Fix wakeups when IRQ is shared with SCI (Renjith Pananchikkal) [2039350]
- platform/x86: amd-pmc: only use callbacks for suspend (David Arcari) [2016041]
- platform/x86: amd-pmc: Add support for AMD Smart Trace Buffer (David Arcari) [2016041]
- platform/x86: amd-pmc: Simplify error handling and store the pci_dev in amd_pmc_dev structure (David Arcari) [2016041]
- platform/x86: amd-pmc: Fix s2idle failures on certain AMD laptops (David Arcari) [2016041]
- platform/x86: amd-pmc: Make CONFIG_AMD_PMC depend on RTC_CLASS (David Arcari) [2016041]
- platform/x86: amd-pmc: Drop check for valid alarm time (David Arcari) [2016041]
- platform/x86: amd-pmc: Downgrade dev_info message to dev_dbg (David Arcari) [2016041]
- platform/x86: amd-pmc: fix compilation without CONFIG_RTC_SYSTOHC_DEVICE (David Arcari) [2016041]
- platform/x86: amd-pmc: Add special handling for timer based S0i3 wakeup (David Arcari) [2016041]
- platform/x86: amd-pmc: adjust arguments for `amd_pmc_send_cmd` (David Arcari) [2016041]
- platform/x86: amd-pmc: Add alternative acpi id for PMC controller (David Arcari) [2016041]
- platform/x86: amd-pmc: Add a message to print resume time info (David Arcari) [2016041]
- platform/x86: amd-pmc: Send command to dump data after clearing OS_HINT (David Arcari) [2016041]
- platform/x86: amd-pmc: Fix compilation when CONFIG_DEBUGFS is disabled (David Arcari) [2016041]
- platform/x86: amd-pmc: Export Idlemask values based on the APU (David Arcari) [2016041]
- platform/x86: amd-pmc: Check s0i3 cycle status (David Arcari) [2016041]
- platform/x86: amd-pmc: Increase the response register timeout (David Arcari) [2016041]
- mm/page_alloc.c: do not warn allocation failure on zone DMA if no managed pages (Baoquan He) [2024381]
- dma/pool: create dma atomic pool only if dma zone has managed pages (Baoquan He) [2024381]
- mm_zone: add function to check if managed dma zone exists (Baoquan He) [2024381]
- PCI: hv: Add arm64 Hyper-V vPCI support (Vitaly Kuznetsov) [2024852]
- PCI: hv: Make the code arch neutral by adding arch specific interfaces (Vitaly Kuznetsov) [2024852]
- PCI: hv: Remove unnecessary use of %%hx (Vitaly Kuznetsov) [2024852]

* Wed Feb 09 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-57.rt21.57.el9]
- block: assign bi_bdev for cloned bios in blk_rq_prep_clone (Benjamin Marzinski) [2026948]
- dm sysfs: use default_groups in kobj_type (Benjamin Marzinski) [2043224]
- dm space map common: add bounds check to sm_ll_lookup_bitmap() (Benjamin Marzinski) [2043224]
- dm btree: add a defensive bounds check to insert_at() (Benjamin Marzinski) [2043224]
- dm btree remove: change a bunch of BUG_ON() calls to proper errors (Benjamin Marzinski) [2043224]
- dm btree spine: eliminate duplicate le32_to_cpu() in node_check() (Benjamin Marzinski) [2043224]
- dm btree spine: remove extra node_check function declaration (Benjamin Marzinski) [2043224]
- redhat: drop the RELEASED_KERNEL switch (Herton R. Krzesinski) [2037084 2045327]
- redhat: switch the kernel package to use certs from system-sb-certs (Herton R. Krzesinski) [2037084 2045327]
- mptcp: disable by default (Davide Caratti) [2044392]
- sch_api: Don't skip qdisc attach on ingress (Davide Caratti) [2044560]
- flow_offload: return EOPNOTSUPP for the unsupported mpls action type (Davide Caratti) [2044560]
- sch_cake: do not call cake_destroy() from cake_init() (Davide Caratti) [2044560]
- net/sched: fq_pie: prevent dismantle issue (Davide Caratti) [2044560]
- vrf: Reset IPCB/IP6CB when processing outbound pkts in vrf dev xmit (Antoine Tenart) [2044252]
- qla2xxx: Add new messaging (Ewan D. Milne) [2039070]
- nvme-fc: remove freeze/unfreeze around update_nr_hw_queues (Ewan D. Milne) [2030051]
- nvme-fc: avoid race between time out and tear down (Ewan D. Milne) [2030051]
- nvme-fc: update hardware queues before using them (Ewan D. Milne) [2030051]
- lpfc: Add new messaging (Ewan D. Milne) [2039068]
- tee: handle lookup of shm with reference count 0 (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- dma-buf: move dma-buf symbols into the DMA_BUF module namespace (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- tee: add sec_world_id to struct tee_shm (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/i915/selftests: Do not use import_obj uninitialized (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gem: Provide drm_gem_fb_{vmap,vunmap}() (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm: Define DRM_FORMAT_MAX_PLANES (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/i915/gem: Correct the locking and pin pattern for dma-buf (v8) (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gm12u320: Use framebuffer dma-buf helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gud: Use framebuffer dma-buf helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/udl: Use framebuffer dma-buf helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- drm/gem: Provide drm_gem_fb_{begin,end}_cpu_access() helpers (Chris von Recklinghausen) [2030754] {CVE-2021-44733}
- dmaengine: idxd: Add wq occupancy information to sysfs attribute Bugzilla: https://bugzilla.redhat.com/show_bug.cgi?id=1971888 Upstream Status: kernel/git/torvalds/linux.git (Julia Denham)
- arch/x86: KABI structs and array padding (Prarit Bhargava) [2033081]
- hpsa: add new messaging (Tomas Henzl) [2028575]
- aacraid: add new messaging (Tomas Henzl) [2028574]
- mptsas: add new messaging (Tomas Henzl) [2027741]
- megaraid_sas: add new messaging (Tomas Henzl) [2027741]
- mpt3sas: Add new messaging (Tomas Henzl) [2027741]
- scsi: mpi3mr: Use scnprintf() instead of snprintf() (Tomas Henzl) [1876005]
- scsi: mpi3mr: Clean up mpi3mr_print_ioc_info() (Tomas Henzl) [1876005]
- scsi: mpi3mr: Set up IRQs in resume path (Tomas Henzl) [1876005]
- scsi: mpi3mr: Use the proper SCSI midlayer interfaces for PI (Tomas Henzl) [1876005]

* Tue Feb 08 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-56.rt21.56.el9]
- KVM: VMX: switch blocked_vcpu_on_cpu_lock to raw spinlock (Marcelo Tosatti) [2034007]
- x86/hyperv: Properly deal with empty cpumasks in hyperv_flush_tlb_multi() (Vitaly Kuznetsov) [2035993]
- tcp: add missing htmldocs for skb->ll_node and sk->defer_list (Antoine Tenart) [2041382]
- net: move early demux fields close to sk_refcnt (Antoine Tenart) [2041382]
- tcp: defer skb freeing after socket lock is released (Antoine Tenart) [2041382]
- net: shrink struct sock by 8 bytes (Antoine Tenart) [2041382]
- ipv6: shrink struct ipcm6_cookie (Antoine Tenart) [2041382]
- net: remove sk_route_nocaps (Antoine Tenart) [2041382]
- net: remove sk_route_forced_caps (Antoine Tenart) [2041382]
- net: use sk_is_tcp() in more places (Antoine Tenart) [2041382]
- bpf, sockmap: Use stricter sk state checks in sk_lookup_assign (Antoine Tenart) [2041382]
- ipv6: move inet6_sk(sk)->rx_dst_cookie to sk->sk_rx_dst_cookie (Antoine Tenart) [2041382]
- tcp: move inet->rx_dst_ifindex to sk->sk_rx_dst_ifindex (Antoine Tenart) [2041382]
- [RHEL-9.0] IPMI Add RH_KABI_RESERVE to kABI sensitive structs (Tony Camuso) [2042031]
- configs: disable CONFIG_CRAMFS (Abhi Das) [2041184]
- ppp: ensure minimum packet size in ppp_write() (Guillaume Nault) [2042936]
- [pci] PCI: Add reserved fields to 'struct pci_sriov' (Myron Stowe) [2039086]
- [include] PCI: Add reserved fields to 'struct pci_driver' (Myron Stowe) [2039086]
- [include] PCI: Add reserved fields to 'struct pci_bus' (Myron Stowe) [2039086]
- [include] PCI: Add reserved fields, and extension, to 'struct pci_dev' (Myron Stowe) [2039086]
- PCI: ACPI: Check parent pointer in acpi_pci_find_companion() (Myron Stowe) [2039086]
- PCI/ACPI: Don't reset a fwnode set by OF (Myron Stowe) [2039086]
- PCI: Make saved capability state private to core (Myron Stowe) [2039086]
- PCI: Change the type of probe argument in reset functions (Myron Stowe) [2039086]
- PCI: Add support for ACPI _RST reset method (Myron Stowe) [2039086]
- PCI: Setup ACPI fwnode early and at the same time with OF (Myron Stowe) [2039086]
- PCI: Use acpi_pci_power_manageable() (Myron Stowe) [2039086]
- PCI: Add pci_set_acpi_fwnode() to set ACPI_COMPANION (Myron Stowe) [2039086]
- PCI: Allow userspace to query and set device reset mechanism (Myron Stowe) [2039086]
- PCI: Remove reset_fn field from pci_dev (Myron Stowe) [2039086]
- PCI: Add array to track reset method ordering (Myron Stowe) [2039086]
- PCI: Add pcie_reset_flr() with 'probe' argument (Myron Stowe) [2039086]
- PCI: Cache PCIe Device Capabilities register (Myron Stowe) [2039086]
- PCI: Allow PASID on fake PCIe devices without TLP prefixes (Myron Stowe) [2039086]
- clocksource: Reduce the default clocksource_watchdog() retries to 2 (Waiman Long) [2027463]
- clocksource: Avoid accidental unstable marking of clocksources (Waiman Long) [2027463]
- Revert "clocksource: Increase WATCHDOG_MAX_SKEW" (Waiman Long) [2027463]
- PCI: Add pcie_ptm_enabled() (Petr Oros) [2037314]
- Revert "PCI: Make pci_enable_ptm() private" (Petr Oros) [2037314]
- iommu/vt-d: Fix unmap_pages support (Jerry Snitselaar) [2027762]

* Mon Feb 07 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-55.rt21.55.el9]
- selftests: netfilter: switch to socat for tests using -q option (Hangbin Liu) [2041409]
- selftests: net: udpgro_fwd.sh: explicitly checking the available ping feature (Hangbin Liu) [2041409]
- selftests: net: using ping6 for IPv6 in udpgro_fwd.sh (Hangbin Liu) [2041409]
- selftests: net: Fix a typo in udpgro_fwd.sh (Hangbin Liu) [2041409]
- selftests/net: udpgso_bench_tx: fix dst ip argument (Hangbin Liu) [2041409]
- selftest/net/forwarding: declare NETIFS p9 p10 (Hangbin Liu) [2041409]
- selftests: Fix IPv6 address bind tests (Hangbin Liu) [2041409]
- selftests: Fix raw socket bind tests with VRF (Hangbin Liu) [2041409]
- selftests: Add duplicate config only for MD5 VRF tests (Hangbin Liu) [2041409]
- selftests: icmp_redirect: pass xfail=0 to log_test() (Hangbin Liu) [2041409]
- selftests: net: Correct ping6 expected rc from 2 to 1 (Hangbin Liu) [2041409]
- selftests/fib_tests: Rework fib_rp_filter_test() (Hangbin Liu) [2041409]
- selftests: net: Correct case name (Hangbin Liu) [2041409]
- redhat/configs: Enable CONFIG_PCI_P2PDMA (Myron Stowe) [1923862]
- nvme: drop scan_lock and always kick requeue list when removing namespaces (Gopal Tiwari) [2038783]
- ACPI: CPPC: Add NULL pointer check to cppc_get_perf() (David Arcari) [2025291]
- cpufreq: intel_pstate: Clear HWP Status during HWP Interrupt enable (David Arcari) [2025291]
- cpufreq: intel_pstate: Fix unchecked MSR 0x773 access (David Arcari) [2025291]
- cpufreq: intel_pstate: Clear HWP desired on suspend/shutdown and offline (David Arcari) [2025291]
- cpufreq: intel_pstate: Fix cpu->pstate.turbo_freq initialization (David Arcari) [2025291]
- cpufreq: intel_pstate: Process HWP Guaranteed change notification (David Arcari) [2025291]
- cpufreq: intel_pstate: Override parameters if HWP forced by BIOS (David Arcari) [2025291]
- cpufreq: intel_pstate: hybrid: Rework HWP calibration (David Arcari) [2025291]
- Revert "cpufreq: intel_pstate: Process HWP Guaranteed change notification" (David Arcari) [2025291]
- cpufreq: intel_pstate: Process HWP Guaranteed change notification (David Arcari) [2025291]
- cpufreq: Replace deprecated CPU-hotplug functions (David Arcari) [2025291]
- ACPI: CPPC: Introduce cppc_get_nominal_perf() (David Arcari) [2025291]
- Change s390x CONFIG_NODES_SHIFT from 4 to 1 (Prarit Bhargava) [2018568]
- Build CONFIG_SPI_PXA2XX as a module on x86 (Prarit Bhargava) [2018568]
- Turn on CONFIG_CPU_FREQ_GOV_SCHEDUTIL for x86 (Prarit Bhargava) [2018568]
- Turn CONFIG_DEVMEM back off for aarch64 (Prarit Bhargava) [2018568]
- New configs in drivers/media (Prarit Bhargava) [2018568]
- Manually add pending items that need to be set due to mismatch (Prarit Bhargava) [2018568]
- Build CRYPTO_SHA3_*_S390 inline for s390 zfcpdump (Prarit Bhargava) [2018568]
- configs: Remove pending CONFIG_CHELSIO_IPSEC_INLINE file (Prarit Bhargava) [2018568]
- New configs in arch/powerpc (Prarit Bhargava) [2018568]
- New configs in lib/Kconfig.debug (Prarit Bhargava) [2018568]
- New configs in drivers/vhost (Prarit Bhargava) [2018568]
- New configs in drivers/pinctrl (Prarit Bhargava) [2018568]
- New configs in drivers/gpu (Prarit Bhargava) [2018568]
- New configs in drivers/gpio (Prarit Bhargava) [2018568]
- New configs in drivers/block (Prarit Bhargava) [2018568]
- New configs in crypto/Kconfig (Prarit Bhargava) [2018568]
- New configs in drivers/acpi (Prarit Bhargava) [2018568]
- New configs in arch/arm64 (Prarit Bhargava) [2018568]
- New configs in arch/Kconfig (Prarit Bhargava) [2018568]
- AUTOMATIC: New configs (Prarit Bhargava) [2018568]
- Clean up pending common (Prarit Bhargava) [2018568]

* Fri Feb 04 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-54.rt21.54.el9]
- iwlwifi: mvm: read 6E enablement flags from DSM and pass to FW (Íñigo Huguet) [2033354]
- ath11k: add string type to search board data in board-2.bin for WCN6855 (Íñigo Huguet) [2033354]
- mt76: enable new device MT7921E (Íñigo Huguet) [2033354]
- cfg80211: correct bridge/4addr mode check (Íñigo Huguet) [2033354]
- cfg80211: fix management registrations locking (Íñigo Huguet) [2033354]
- cfg80211: scan: fix RCU in cfg80211_add_nontrans_list() (Íñigo Huguet) [2033354]
- mac80211: mesh: fix HE operation element length check (Íñigo Huguet) [2033354]
- mwifiex: avoid null-pointer-subtraction warning (Íñigo Huguet) [2033354]
- Revert "brcmfmac: use ISO3166 country code and 0 rev as fallback" (Íñigo Huguet) [2033354]
- iwlwifi: pcie: add configuration of a Wi-Fi adapter on Dell XPS 15 (Íñigo Huguet) [2033354]
- mac80211: Fix Ptk0 rekey documentation (Íñigo Huguet) [2033354]
- mac80211: check return value of rhashtable_init (Íñigo Huguet) [2033354]
- mac80211: fix use-after-free in CCMP/GCMP RX (Íñigo Huguet) [2033354]
- drivers: net: mhi: fix error path in mhi_net_newlink (Íñigo Huguet) [2033354]
- mac80211-hwsim: fix late beacon hrtimer handling (Íñigo Huguet) [2033354]
- mac80211: mesh: fix potentially unaligned access (Íñigo Huguet) [2033354]
- mac80211: limit injected vht mcs/nss in ieee80211_parse_tx_radiotap (Íñigo Huguet) [2033354]
- mac80211: Drop frames from invalid MAC address in ad-hoc mode (Íñigo Huguet) [2033354]
- mac80211: Fix ieee80211_amsdu_aggregate frag_tail bug (Íñigo Huguet) [2033354]
- Revert "mac80211: do not use low data rates for data frames with no ack flag" (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: missing unlock in iwl_mvm_wowlan_program_keys() (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: Fix off by ones in iwl_mvm_wowlan_get_rsc_v5_data() (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Fix possible NULL dereference (Íñigo Huguet) [2033354]
- iwl: fix debug printf format strings (Íñigo Huguet) [2033354]
- iwlwifi: pnvm: Fix a memory leak in 'iwl_pnvm_get_from_fs()' (Íñigo Huguet) [2033354]
- iwlwifi: bump FW API to 66 for AX devices (Íñigo Huguet) [2033354]
- iwlwifi Add support for ax201 in Samsung Galaxy Book Flex2 Alpha (Íñigo Huguet) [2033354]
- iwlwifi: mvm: add rtnl_lock() in iwl_mvm_start_get_nvm() (Íñigo Huguet) [2033354]
- net: qrtr: revert check in qrtr_endpoint_post() (Íñigo Huguet) [2033354]
- net: qrtr: make checks in qrtr_endpoint_post() stricter (Íñigo Huguet) [2033354]
- intel: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2033354]
- mwifiex: pcie: add reset_d3cold quirk for Surface gen4+ devices (Íñigo Huguet) [2033354]
- mwifiex: pcie: add DMI-based quirk implementation for Surface devices (Íñigo Huguet) [2033354]
- brcmfmac: pcie: fix oops on failure to resume and reprobe (Íñigo Huguet) [2033354]
- wilc1000: Convert module-global "isinit" to device-specific variable (Íñigo Huguet) [2033354]
- brcmfmac: Add WPA3 Personal with FT to supported cipher suites (Íñigo Huguet) [2033354]
- rtlwifi: rtl8192de: Fix initialization of place in _rtl92c_phy_get_rightchnlplace() (Íñigo Huguet) [2033354]
- rtw88: add quirk to disable pci caps on HP Pavilion 14-ce0xxx (Íñigo Huguet) [2033354]
- ath9k: fix sleeping in atomic context (Íñigo Huguet) [2033354]
- ath9k: fix OOB read ar9300_eeprom_restore_internal (Íñigo Huguet) [2033354]
- iwlwifi: mvm: don't use FW key ID in beacon protection (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Fix scan channel flags settings (Íñigo Huguet) [2033354]
- iwlwifi: mvm: support broadcast TWT alone (Íñigo Huguet) [2033354]
- iwlwifi: mvm: introduce iwl_stored_beacon_notif_v3 (Íñigo Huguet) [2033354]
- iwlwifi: move get pnvm file name to a separate function (Íñigo Huguet) [2033354]
- iwlwifi: mvm: add support for responder config command version 9 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: add support for range request command version 13 (Íñigo Huguet) [2033354]
- iwlwifi: allow debug init in RF-kill (Íñigo Huguet) [2033354]
- iwlwifi: mvm: don't schedule the roc_done_wk if it is already running (Íñigo Huguet) [2033354]
- iwlwifi: yoyo: support for new DBGI_SRAM region (Íñigo Huguet) [2033354]
- iwlwifi: add 'Rx control frame to MBSSID' HE capability (Íñigo Huguet) [2033354]
- iwlwifi: fw: fix debug dump data declarations (Íñigo Huguet) [2033354]
- iwlwifi: api: remove datamember from struct (Íñigo Huguet) [2033354]
- iwlwifi: fix __percpu annotation (Íñigo Huguet) [2033354]
- iwlwifi: pcie: avoid dma unmap/remap in crash dump (Íñigo Huguet) [2033354]
- iwlwifi: acpi: fill in SAR tables with defaults (Íñigo Huguet) [2033354]
- iwlwifi: acpi: fill in WGDS table with defaults (Íñigo Huguet) [2033354]
- iwlwifi: bump FW API to 65 for AX devices (Íñigo Huguet) [2033354]
- iwlwifi: acpi: support reading and storing WGDS revision 2 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: load regdomain at INIT stage (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Read the PPAG and SAR tables at INIT stage (Íñigo Huguet) [2033354]
- iwlwifi: mvm: trigger WRT when no beacon heard (Íñigo Huguet) [2033354]
- iwlwifi: fw: correctly limit to monitor dump (Íñigo Huguet) [2033354]
- iwlwifi: skip first element in the WTAS ACPI table (Íñigo Huguet) [2033354]
- iwlwifi: mvm: support version 11 of wowlan statuses notification (Íñigo Huguet) [2033354]
- iwlwifi: convert flat GEO profile table to a struct version (Íñigo Huguet) [2033354]
- iwlwifi: remove unused ACPI_WGDS_TABLE_SIZE definition (Íñigo Huguet) [2033354]
- iwlwifi: support reading and storing EWRD revisions 1 and 2 (Íñigo Huguet) [2033354]
- iwlwifi: acpi: support reading and storing WRDS revision 1 and 2 (Íñigo Huguet) [2033354]
- iwlwifi: pass number of chains and sub-bands to iwl_sar_set_profile() (Íñigo Huguet) [2033354]
- iwlwifi: remove ACPI_SAR_NUM_TABLES definition (Íñigo Huguet) [2033354]
- iwlwifi: convert flat SAR profile table to a struct version (Íñigo Huguet) [2033354]
- iwlwifi: rename ACPI_SAR_NUM_CHAIN_LIMITS to ACPI_SAR_NUM_CHAINS (Íñigo Huguet) [2033354]
- iwlwifi: mvm: fix access to BSS elements (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Refactor setting of SSIDs for 6GHz scan (Íñigo Huguet) [2033354]
- iwlwifi: mvm: silently drop encrypted frames for unknown station (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: implement RSC command version 5 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: make key reprogramming iteration optional (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: add separate key iteration for GTK type (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: refactor TSC/RSC configuration (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: remove fixed cmd_flags argument (Íñigo Huguet) [2033354]
- iwlwifi: mvm: d3: separate TKIP data from key iteration (Íñigo Huguet) [2033354]
- iwlwifi: mvm: simplify __iwl_mvm_set_sta_key() (Íñigo Huguet) [2033354]
- iwlwifi: mvm: support new station key API (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Fix umac scan request probe parameters (Íñigo Huguet) [2033354]
- iwlwifi: pcie: implement Bz reset flow (Íñigo Huguet) [2033354]
- iwlwifi: implement Bz NMI behaviour (Íñigo Huguet) [2033354]
- iwlwifi: pcie: implement Bz device startup (Íñigo Huguet) [2033354]
- iwlwifi: read MAC address from correct place on Bz (Íñigo Huguet) [2033354]
- iwlwifi: give Bz devices their own name (Íñigo Huguet) [2033354]
- iwlwifi: split off Bz devices into their own family (Íñigo Huguet) [2033354]
- iwlwifi: yoyo: cleanup internal buffer allocation in D3 (Íñigo Huguet) [2033354]
- iwlwifi: mvm: treat MMPDUs in iwl_mvm_mac_tx() as bcast (Íñigo Huguet) [2033354]
- iwlwifi: mvm: clean up number of HW queues (Íñigo Huguet) [2033354]
- iwlwifi: mvm: avoid static queue number aliasing (Íñigo Huguet) [2033354]
- iwlwifi: use DEFINE_MUTEX() for mutex lock (Íñigo Huguet) [2033354]
- iwlwifi: remove trailing semicolon in macro definition (Íñigo Huguet) [2033354]
- iwlwifi: mvm: fix a memory leak in iwl_mvm_mac_ctxt_beacon_changed (Íñigo Huguet) [2033354]
- iwlwifi: mvm: fix old-style static const declaration (Íñigo Huguet) [2033354]
- iwlwifi: mvm: remove check for vif in iwl_mvm_vif_from_mac80211() (Íñigo Huguet) [2033354]
- iwlwifi: pcie: remove spaces from queue names (Íñigo Huguet) [2033354]
- iwlwifi: mvm: restrict FW SMPS request (Íñigo Huguet) [2033354]
- iwlwifi: mvm: set replay counter on key install (Íñigo Huguet) [2033354]
- iwlwifi: mvm: remove trigger EAPOL time event (Íñigo Huguet) [2033354]
- iwlwifi: iwl-dbg-tlv: add info about loading external dbg bin (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Add support for hidden network scan on 6GHz band (Íñigo Huguet) [2033354]
- iwlwifi: mvm: Do not use full SSIDs in 6GHz scan (Íñigo Huguet) [2033354]
- iwlwifi: print PNVM complete notification status in hexadecimal (Íñigo Huguet) [2033354]
- iwlwifi: pcie: dump error on FW reset handshake failures (Íñigo Huguet) [2033354]
- iwlwifi: prepare for synchronous error dumps (Íñigo Huguet) [2033354]
- iwlwifi: pcie: free RBs during configure (Íñigo Huguet) [2033354]
- iwlwifi: pcie: optimise struct iwl_rx_mem_buffer layout (Íñigo Huguet) [2033354]
- iwlwifi: mvm: avoid FW restart while shutting down (Íñigo Huguet) [2033354]
- iwlwifi: nvm: enable IEEE80211_HE_PHY_CAP10_HE_MU_M1RU_MAX_LTF (Íñigo Huguet) [2033354]
- iwlwifi: mvm: set BROADCAST_TWT_SUPPORTED in MAC policy (Íñigo Huguet) [2033354]
- iwlwifi: iwl-nvm-parse: set STBC flags for HE phy capabilities (Íñigo Huguet) [2033354]
- cfg80211: use wiphy DFS domain if it is self-managed (Íñigo Huguet) [2033354]
- mac80211: parse transmit power envelope element (Íñigo Huguet) [2033354]
- ieee80211: add definition for transmit power envelope element (Íñigo Huguet) [2033354]
- ieee80211: add definition of regulatory info in 6 GHz operation information (Íñigo Huguet) [2033354]
- mac80211: introduce individual TWT support in AP mode (Íñigo Huguet) [2033354]
- ieee80211: add TWT element definitions (Íñigo Huguet) [2033354]
- brcmsmac: make array addr static const, makes object smaller (Íñigo Huguet) [2033354]
- rtw88: Remove unnecessary check code (Íñigo Huguet) [2033354]
- rtw88: wow: fix size access error of probe request (Íñigo Huguet) [2033354]
- rtw88: wow: report wow reason through mac80211 api (Íñigo Huguet) [2033354]
- rtw88: wow: build wow function only if CONFIG_PM is on (Íñigo Huguet) [2033354]
- rtw88: refine the setting of rsvd pages for different firmware (Íñigo Huguet) [2033354]
- rtw88: use read_poll_timeout instead of fixed sleep (Íñigo Huguet) [2033354]
- rtw88: 8822ce: set CLKREQ# signal to low during suspend (Íñigo Huguet) [2033354]
- rtw88: change beacon filter default mode (Íñigo Huguet) [2033354]
- rtw88: 8822c: add tx stbc support under HT mode (Íñigo Huguet) [2033354]
- rtw88: adjust the log level for failure of tx report (Íñigo Huguet) [2033354]
- rtl8xxxu: Fix the handling of TX A-MPDU aggregation (Íñigo Huguet) [2033354]
- rtl8xxxu: disable interrupt_in transfer for 8188cu and 8192cu (Íñigo Huguet) [2033354]
- mwifiex: make arrays static const, makes object smaller (Íñigo Huguet) [2033354]
- mwifiex: usb: Replace one-element array with flexible-array member (Íñigo Huguet) [2033354]
- mwifiex: drop redundant null-pointer check in mwifiex_dnld_cmd_to_fw() (Íñigo Huguet) [2033354]
- wilc1000: remove redundant code (Íñigo Huguet) [2033354]
- wilc1000: use devm_clk_get_optional() (Íñigo Huguet) [2033354]
- wilc1000: dispose irq on failure path (Íñigo Huguet) [2033354]
- wilc1000: use goto labels on error path (Íñigo Huguet) [2033354]
- rtlwifi: rtl8192de: make arrays static const, makes object smaller (Íñigo Huguet) [2033354]
- rtlwifi: rtl8192de: Remove redundant variable initializations (Íñigo Huguet) [2033354]
- ray_cs: Split memcpy() to avoid bounds check warning (Íñigo Huguet) [2033354]
- ray_cs: use %%*ph to print small buffer (Íñigo Huguet) [2033354]
- brcmfmac: add 43752 SDIO ids and initialization (Íñigo Huguet) [2033354]
- brcmfmac: Set SDIO workqueue as WQ_HIGHPRI (Íñigo Huguet) [2033354]
- brcmfmac: use separate firmware for 43430 revision 2 (Íñigo Huguet) [2033354]
- brcmfmac: support chipsets with different core enumeration space (Íñigo Huguet) [2033354]
- brcmfmac: add xtlv support to firmware interface layer (Íñigo Huguet) [2033354]
- brcmfmac: increase core revision column aligning core list (Íñigo Huguet) [2033354]
- brcmfmac: use different error value for invalid ram base address (Íñigo Huguet) [2033354]
- brcmfmac: firmware: Fix firmware loading (Íñigo Huguet) [2033354]
- cfg80211: fix BSS color notify trace enum confusion (Íñigo Huguet) [2033354]
- mac80211: Fix insufficient headroom issue for AMSDU (Íñigo Huguet) [2033354]
- mac80211: add support for BSS color change (Íñigo Huguet) [2033354]
- nl80211: add support for BSS coloring (Íñigo Huguet) [2033354]
- mac80211: Use flex-array for radiotap header bitmap (Íñigo Huguet) [2033354]
- mac80211: radiotap: Use BIT() instead of shifts (Íñigo Huguet) [2033354]
- mac80211: Remove unnecessary variable and label (Íñigo Huguet) [2033354]
- mac80211: include <linux/rbtree.h> (Íñigo Huguet) [2033354]
- mac80211: Fix monitor MTU limit so that A-MSDUs get through (Íñigo Huguet) [2033354]
- mac80211: remove unnecessary NULL check in ieee80211_register_hw() (Íñigo Huguet) [2033354]
- mac80211: Reject zero MAC address in sta_info_insert_check() (Íñigo Huguet) [2033354]
- bus: mhi: core: Improve debug messages for power up (Íñigo Huguet) [2033354]
- bus: mhi: core: Replace DMA allocation wrappers with original APIs (Íñigo Huguet) [2033354]
- bus: mhi: core: Add range checks for BHI and BHIe (Íñigo Huguet) [2033354]
- bus: mhi: pci_generic: Set register access length for MHI driver (Íñigo Huguet) [2033354]
- ath11k: set register access length for MHI driver (Íñigo Huguet) [2033354]
- bus: mhi: Add MMIO region length to controller structure (Íñigo Huguet) [2033354]
- bus: mhi: core: Set BHI and BHIe pointers to NULL in clean-up (Íñigo Huguet) [2033354]
- bus: mhi: core: Set BHI/BHIe offsets on power up preparation (Íñigo Huguet) [2033354]
- bus: mhi: pci_generic: Add Cinterion MV31-W PCIe to MHI (Íñigo Huguet) [2033354]
- net: mhi: Remove MBIM protocol (Íñigo Huguet) [2033354]
- brcmfmac: firmware: Allow per-board firmware binaries (Íñigo Huguet) [2033354]
- net: mhi: Improve MBIM packet counting (Íñigo Huguet) [2033354]
- bus: mhi: pci-generic: configurable network interface MRU (Íñigo Huguet) [2033354]
- ath11k: Remove some duplicate code (Íñigo Huguet) [2033354]
- ath: switch from 'pci_' to 'dma_' API (Íñigo Huguet) [2033354]

* Thu Feb 03 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-53.rt21.53.el9]
- Revert "Merge: ext4, jbd2 update for RHEL9.0" (Juri Lelli)
- quota: correct error number in free_dqentry() (Lukas Czerner) [2041793]
- quota: check block number when reading the block in quota file (Lukas Czerner) [2041793]
- ext4: don't use the orphan list when migrating an inode (Lukas Czerner) [2041486]
- ext4: use BUG_ON instead of if condition followed by BUG (Lukas Czerner) [2041486]
- ext4: fix a copy and paste typo (Lukas Czerner) [2041777]
- ext4: set csum seed in tmp inode while migrating to extents (Lukas Czerner) [2041486]
- ext4: remove unnecessary 'offset' assignment (Lukas Czerner) [2041486]
- ext4: remove redundant o_start statement (Lukas Czerner) [2041486]
- ext4: drop an always true check (Lukas Czerner) [2041486]
- ext4: remove unused assignments (Lukas Czerner) [2041486]
- ext4: remove redundant statement (Lukas Czerner) [2041486]
- ext4: remove useless resetting io_end_size in mpage_process_page() (Lukas Czerner) [2041486]
- ext4: allow to change s_last_trim_minblks via sysfs (Lukas Czerner) [2041486]
- ext4: change s_last_trim_minblks type to unsigned long (Lukas Czerner) [2041486]
- ext4: implement support for get/set fs label (Lukas Czerner) [2041486]
- ext4: only set EXT4_MOUNT_QUOTA when journalled quota file is specified (Lukas Czerner) [2041777]
- ext4: don't use kfree() on rcu protected pointer sbi->s_qf_names (Lukas Czerner) [2041486]
- ext4: avoid trim error on fs with small groups (Lukas Czerner) [2041486]
- ext4: fix an use-after-free issue about data=journal writeback mode (Lukas Czerner) [2041486]
- ext4: fix null-ptr-deref in '__ext4_journal_ensure_credits' (Lukas Czerner) [2041486]
- ext4: initialize err_blk before calling __ext4_get_inode_loc (Lukas Czerner) [2041486]
- ext4: fix a possible ABBA deadlock due to busy PA (Lukas Czerner) [2041486]
- ext4: replace snprintf in show functions with sysfs_emit (Lukas Czerner) [2041486]
- ext4: make sure to reset inode lockdep class when quota enabling fails (Lukas Czerner) [2041486]
- ext4: make sure quota gets properly shutdown on error (Lukas Czerner) [2041486]
- ext4: Fix BUG_ON in ext4_bread when write quota data (Lukas Czerner) [2041486]
- ext4: destroy ext4_fc_dentry_cachep kmemcache on module removal (Lukas Czerner) [2041486]
- ext4: fast commit may miss tracking unwritten range during ftruncate (Lukas Czerner) [2041486]
- ext4: use ext4_ext_remove_space() for fast commit replay delete range (Lukas Czerner) [2041486]
- ext4: fix fast commit may miss tracking range for FALLOC_FL_ZERO_RANGE (Lukas Czerner) [2041486]
- ext4: update fast commit TODOs (Lukas Czerner) [2041486]
- ext4: simplify updating of fast commit stats (Lukas Czerner) [2041486]
- ext4: drop ineligible txn start stop APIs (Lukas Czerner) [2041486]
- ext4: use ext4_journal_start/stop for fast commit transactions (Lukas Czerner) [2041486]
- ext4: fix i_version handling on remount (Lukas Czerner) [2041777]
- ext4: remove lazytime/nolazytime mount options handled by MS_LAZYTIME (Lukas Czerner) [2041777]
- ext4: don't fail remount if journalling mode didn't change (Lukas Czerner) [2041777]
- ext4: Remove unused match_table_t tokens (Lukas Czerner) [2041777]
- ext4: switch to the new mount api (Lukas Czerner) [2041777]
- ext4: change token2str() to use ext4_param_specs (Lukas Czerner) [2041777]
- ext4: clean up return values in handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: Completely separate options parsing and sb setup (Lukas Czerner) [2041777]
- ext4: get rid of super block and sbi from handle_mount_ops() (Lukas Czerner) [2041777]
- ext4: check ext2/3 compatibility outside handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: move quota configuration out of handle_mount_opt() (Lukas Czerner) [2041777]
- ext4: Allow sb to be NULL in ext4_msg() (Lukas Czerner) [2041777]
- ext4: Change handle_mount_opt() to use fs_parameter (Lukas Czerner) [2041777]
- ext4: move option validation to a separate function (Lukas Czerner) [2041777]
- ext4: Add fs parameter specifications for mount options (Lukas Czerner) [2041777]
- fs_parse: allow parameter value to be empty (Lukas Czerner) [2041777]
- ext4: fix error code saved on super block during file system abort (Lukas Czerner) [2041486]
- ext4: inline data inode fast commit replay fixes (Lukas Czerner) [2041486]
- ext4: commit inline data during fast commit (Lukas Czerner) [2041486]
- ext4: scope ret locally in ext4_try_to_trim_range() (Lukas Czerner) [2041486]
- ext4: remove an unused variable warning with CONFIG_QUOTA=n (Lukas Czerner) [2041486]
- ext4: fix boolreturn.cocci warnings in fs/ext4/name.c (Lukas Czerner) [2041486]
- ext4: prevent getting empty inode buffer (Lukas Czerner) [2041486]
- ext4: move ext4_fill_raw_inode() related functions (Lukas Czerner) [2041486]
- ext4: factor out ext4_fill_raw_inode() (Lukas Czerner) [2041486]
- ext4: prevent partial update of the extent blocks (Lukas Czerner) [2035878]
- ext4: check for inconsistent extents between index and leaf block (Lukas Czerner) [2035878]
- ext4: check for out-of-order index extents in ext4_valid_extent_entries() (Lukas Czerner) [2035878]
- ext4: convert from atomic_t to refcount_t on ext4_io_end->count (Lukas Czerner) [2041486]
- ext4: refresh the ext4_ext_path struct after dropping i_data_sem. (Lukas Czerner) [2041486]
- ext4: ensure enough credits in ext4_ext_shift_path_extents (Lukas Czerner) [2041486]
- ext4: correct the left/middle/right debug message for binsearch (Lukas Czerner) [2041486]
- ext4: fix lazy initialization next schedule time computation in more granular unit (Lukas Czerner) [2041486]
- ext4: recheck buffer uptodate bit under buffer lock (Lukas Czerner) [2041486]
- ext4: fix potential infinite loop in ext4_dx_readdir() (Lukas Czerner) [2041486]
- ext4: flush s_error_work before journal destroy in ext4_fill_super (Lukas Czerner) [2041486]
- ext4: fix loff_t overflow in ext4_max_bitmap_size() (Lukas Czerner) [2041486]
- ext4: fix reserved space counter leakage (Lukas Czerner) [2041486]
- ext4: limit the number of blocks in one ADD_RANGE TLV (Lukas Czerner) [2041486]
- ext4: remove extent cache entries when truncating inline data (Lukas Czerner) [2041486]
- ext4: drop unnecessary journal handle in delalloc write (Lukas Czerner) [2041486]
- ext4: factor out write end code of inline file (Lukas Czerner) [2041486]
- ext4: correct the error path of ext4_write_inline_data_end() (Lukas Czerner) [2041486]
- ext4: check and update i_disksize properly (Lukas Czerner) [2041486]
- ext4: add error checking to ext4_ext_replay_set_iblocks() (Lukas Czerner) [2041486]
- ext4: make the updating inode data procedure atomic (Lukas Czerner) [2041486]
- ext4: remove an unnecessary if statement in __ext4_get_inode_loc() (Lukas Czerner) [2041486]
- ext4: move inode eio simulation behind io completeion (Lukas Czerner) [2041486]
- ext4: Improve scalability of ext4 orphan file handling (Lukas Czerner) [2041486]
- ext4: Speedup ext4 orphan inode handling (Lukas Czerner) [2041486]
- ext4: Move orphan inode handling into a separate file (Lukas Czerner) [2041486]
- jbd2: add sparse annotations for add_transaction_credits() (Lukas Czerner) [2041486]
- ext4: Support for checksumming from journal triggers (Lukas Czerner) [2041486]
- ext4: fix sparse warnings (Lukas Czerner) [2041486]
- ext4: fix race writing to an inline_data file while its xattrs are changing (Lukas Czerner) [2003461]
- ext4: Make sure quota files are not grabbed accidentally (Lukas Czerner) [2041486]
- ext4: fix e2fsprogs checksum failure for mounted filesystem (Lukas Czerner) [2022859]
- ext4: if zeroout fails fall back to splitting the extent node (Lukas Czerner) [2041486]
- ext4: reduce arguments of ext4_fc_add_dentry_tlv (Lukas Czerner) [2041486]
- ext4: remove the repeated comment of ext4_trim_all_free (Lukas Czerner) [2041486]
- ext4: add new helper interface ext4_try_to_trim_range() (Lukas Czerner) [2041486]
- ext4: remove the 'group' parameter of ext4_trim_extent (Lukas Czerner) [2041486]
- jbd2: clean up two gcc -Wall warnings in recovery.c (Lukas Czerner) [2041486]
- jbd2: fix clang warning in recovery.c (Lukas Czerner) [2041486]
- jbd2: fix portability problems caused by unaligned accesses (Lukas Czerner) [2041486]
- ext4: Convert to use mapping->invalidate_lock (Lukas Czerner) [2041486]
- [rt] mm/page_alloc.c: add remote version of new local_lock interface and enable remote draining (Marcelo Tosatti) [1992951]

* Wed Feb 02 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-52.rt21.52.el9]
- KVM: arm64: Avoid setting the upper 32 bits of TCR_EL2 and CPTR_EL2 to 1 (Andrew Jones) [2009341]
- KVM: arm64: Extract ESR_ELx.EC only (Andrew Jones) [2009341]
- KVM: selftests: Build the memslot tests for arm64 (Andrew Jones) [2009341]
- KVM: selftests: Make memslot_perf_test arch independent (Andrew Jones) [2009341]
- selftests: KVM: Fix kvm device helper ioctl assertions (Andrew Jones) [2009341]
- KVM: arm64: selftests: arch_timer: Support vCPU migration (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add arch_timer test (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add host support for vGIC (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add basic GICv3 support (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add light-weight spinlock support (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add guest support to get the vcpuid (Andrew Jones) [2009341]
- KVM: arm64: selftests: Maintain consistency for vcpuid type (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add support to disable and enable local IRQs (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add basic support to generate delays (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add basic support for arch_timers (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add support for cpu_relax (Andrew Jones) [2009341]
- KVM: arm64: selftests: Introduce ARM64_SYS_KVM_REG (Andrew Jones) [2009341]
- tools: arm64: Import sysreg.h (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add MMIO readl/writel support (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add init ITS device test (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add test for legacy GICv3 REDIST base partially above IPA range (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add tests for GIC redist/cpuif partially above IPA range (Andrew Jones) [2009341]
- KVM: arm64: selftests: Add some tests for GICv2 in vgic_init (Andrew Jones) [2009341]
- KVM: arm64: selftests: Make vgic_init/vm_gic_create version agnostic (Andrew Jones) [2009341]
- KVM: arm64: selftests: Make vgic_init gic version agnostic (Andrew Jones) [2009341]
- KVM: arm64: vgic: Drop vgic_check_ioaddr() (Andrew Jones) [2009341]
- KVM: arm64: vgic-v3: Check ITS region is not above the VM IPA size (Andrew Jones) [2009341]
- KVM: arm64: vgic-v2: Check cpu interface region is not above the VM IPA size (Andrew Jones) [2009341]
- KVM: arm64: vgic-v3: Check redist region is not above the VM IPA size (Andrew Jones) [2009341]
- kvm: arm64: vgic: Introduce vgic_check_iorange (Andrew Jones) [2009341]
- KVM: arm64: Release mmap_lock when using VM_SHARED with MTE (Andrew Jones) [2009341]
- KVM: arm64: Report corrupted refcount at EL2 (Andrew Jones) [2009341]
- KVM: arm64: Fix host stage-2 PGD refcount (Andrew Jones) [2009341]
- KVM: arm64: Fix PMU probe ordering (Andrew Jones) [2009341]
- KVM: arm64: nvhe: Fix missing FORCE for hyp-reloc.S build rule (Andrew Jones) [2009341]
- arm64: Do not trap PMSNEVFR_EL1 (Andrew Jones) [2009341]
- KVM: arm64: Trim guest debug exception handling (Andrew Jones) [2009341]
- KVM: arm64: Minor optimization of range_is_memory (Andrew Jones) [2009341]
- KVM: arm64: Upgrade trace_kvm_arm_set_dreg32() to 64bit (Andrew Jones) [2009341]
- KVM: arm64: Add config register bit definitions (Andrew Jones) [2009341]
- KVM: arm64: Track value of cptr_el2 in struct kvm_vcpu_arch (Andrew Jones) [2009341]
- KVM: arm64: Keep mdcr_el2's value as set by __init_el2_debug (Andrew Jones) [2009341]
- KVM: arm64: Restore mdcr_el2 from vcpu (Andrew Jones) [2009341]
- KVM: arm64: Refactor sys_regs.h,c for nVHE reuse (Andrew Jones) [2009341]
- KVM: arm64: Fix names of config register fields (Andrew Jones) [2009341]
- KVM: arm64: MDCR_EL2 is a 64-bit register (Andrew Jones) [2009341]
- KVM: arm64: Remove trailing whitespace in comment (Andrew Jones) [2009341]
- KVM: arm64: placeholder to check if VM is protected (Andrew Jones) [2009341]
- KVM: arm64: Upgrade VMID accesses to {READ,WRITE}_ONCE (Andrew Jones) [2009341]
- KVM: arm64: Unify stage-2 programming behind __load_stage2() (Andrew Jones) [2009341]
- KVM: arm64: Move kern_hyp_va() usage in __load_guest_stage2() into the callers (Andrew Jones) [2009341]
- KVM: arm64: vgic: Resample HW pending state on deactivation (Andrew Jones) [2009341]
- KVM: arm64: vgic: Drop WARN from vgic_get_irq (Andrew Jones) [2009341]
- KVM: arm64: Use generic KVM xfer to guest work function (Andrew Jones) [2009341]
- entry: KVM: Allow use of generic KVM entry w/o full generic support (Andrew Jones) [2009341]
- KVM: arm64: Record number of signal exits as a vCPU stat (Andrew Jones) [2009341]
- selftests: KVM: Introduce psci_cpu_on_test (Andrew Jones) [2009341]
- KVM: arm64: Enforce reserved bits for PSCI target affinities (Andrew Jones) [2009341]
- KVM: arm64: Handle PSCI resets before userspace touches vCPU state (Andrew Jones) [2009341]
- KVM: arm64: Fix read-side race on updates to vcpu reset state (Andrew Jones) [2009341]
- KVM: arm64: Make hyp_panic() more robust when protected mode is enabled (Andrew Jones) [2009341]
- KVM: arm64: Drop unused REQUIRES_VIRT (Andrew Jones) [2009341]
- KVM: arm64: Drop check_kvm_target_cpu() based percpu probe (Andrew Jones) [2009341]
- KVM: arm64: Drop init_common_resources() (Andrew Jones) [2009341]
- KVM: arm64: Use ARM64_MIN_PARANGE_BITS as the minimum supported IPA (Andrew Jones) [2009341]
- arm64/mm: Add remaining ID_AA64MMFR0_PARANGE_ macros (Andrew Jones) [2009341]
- KVM: arm64: Return -EPERM from __pkvm_host_share_hyp() (Andrew Jones) [2009341]
- KVM: arm64: Restrict IPA size to maximum 48 bits on 4K and 16K page size (Andrew Jones) [2009341]
- arm64/mm: Define ID_AA64MMFR0_TGRAN_2_SHIFT (Andrew Jones) [2009341]
- KVM: arm64: perf: Replace '0xf' instances with ID_AA64DFR0_PMUVER_IMP_DEF (Andrew Jones) [2009341]
- KVM: arm64: Make __pkvm_create_mappings static (Andrew Jones) [2009341]
- KVM: arm64: Restrict EL2 stage-1 changes in protected mode (Andrew Jones) [2009341]
- KVM: arm64: Refactor protected nVHE stage-1 locking (Andrew Jones) [2009341]
- KVM: arm64: Remove __pkvm_mark_hyp (Andrew Jones) [2009341]
- KVM: arm64: Mark host bss and rodata section as shared (Andrew Jones) [2009341]
- KVM: arm64: Enable retrieving protections attributes of PTEs (Andrew Jones) [2009341]
- KVM: arm64: Introduce addr_is_memory() (Andrew Jones) [2009341]
- KVM: arm64: Expose pkvm_hyp_id (Andrew Jones) [2009341]
- KVM: arm64: Expose host stage-2 manipulation helpers (Andrew Jones) [2009341]
- KVM: arm64: Add helpers to tag shared pages in SW bits (Andrew Jones) [2009341]
- KVM: arm64: Allow populating software bits (Andrew Jones) [2009341]
- KVM: arm64: Enable forcing page-level stage-2 mappings (Andrew Jones) [2009341]
- KVM: arm64: Tolerate re-creating hyp mappings to set software bits (Andrew Jones) [2009341]
- KVM: arm64: Don't overwrite software bits with owner id (Andrew Jones) [2009341]
- KVM: arm64: Rename KVM_PTE_LEAF_ATTR_S2_IGNORED (Andrew Jones) [2009341]
- KVM: arm64: Optimize host memory aborts (Andrew Jones) [2009341]
- KVM: arm64: Expose page-table helpers (Andrew Jones) [2009341]
- KVM: arm64: Provide the host_stage2_try() helper macro (Andrew Jones) [2009341]
- KVM: arm64: Introduce hyp_assert_lock_held() (Andrew Jones) [2009341]
- redhat: configs: Disable NVHE_EL2_DEBUG (Andrew Jones) [2009341]
- KVM: arm64: Add hyp_spin_is_locked() for basic locking assertions at EL2 (Andrew Jones) [2009341]
- KVM: arm64: Unregister HYP sections from kmemleak in protected mode (Andrew Jones) [2009341]
- arm64: Move .hyp.rodata outside of the _sdata.._edata range (Andrew Jones) [2009341]
- KVM: arm64: Fix comments related to GICv2 PMR reporting (Andrew Jones) [2009341]
- KVM: arm64: Count VMID-wide TLB invalidations (Andrew Jones) [2009341]
- KVM: arm64: Remove PMSWINC_EL0 shadow register (Andrew Jones) [2009341]
- KVM: arm64: Disabling disabled PMU counters wastes a lot of time (Andrew Jones) [2009341]
- KVM: arm64: Drop unnecessary masking of PMU registers (Andrew Jones) [2009341]
- KVM: arm64: Narrow PMU sysreg reset values to architectural requirements (Andrew Jones) [2009341]
- KVM: arm64: Introduce helper to retrieve a PTE and its level (Andrew Jones) [2009341]
- KVM: Remove kvm_is_transparent_hugepage() and PageTransCompoundMap() (Andrew Jones) [2009341]
- KVM: arm64: Avoid mapping size adjustment on permission fault (Andrew Jones) [2009341]
- KVM: arm64: Walk userspace page tables to compute the THP mapping size (Andrew Jones) [2009341]

* Tue Feb 01 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-51.rt21.51.el9]
- selftests: bpf: Fix bind on used port (Felix Maurer) [2043528]
- Add packaged but empty /lib/modules/<kver>/systemtap (Herton R. Krzesinski) [2012908]
- powerpc/bpf: Update ldimm64 instructions during extra pass (Yauheni Kaliuta) [2040549]
- RDMA/irdma: Don't arm the CQ more than two times if no CE for this CQ (Kamal Heib) [2039426]
- RDMA/irdma: Report correct WC errors (Kamal Heib) [2039426]
- RDMA/irdma: Fix a potential memory allocation issue in 'irdma_prm_add_pble_mem()' (Kamal Heib) [2039426]
- RDMA/irdma: Fix a user-after-free in add_pble_prm (Kamal Heib) [2039426]
- RDMA/irdma: Do not hold qos mutex twice on QP resume (Kamal Heib) [2039426]
- RDMA/irdma: Set VLAN in UD work completion correctly (Kamal Heib) [2039426]
- RDMA/irdma: Process extended CQ entries correctly (Kamal Heib) [2039426]
- RDMA/irdma: Report correct WC error when there are MW bind errors (Kamal Heib) [2039426]
- RDMA/irdma: Report correct WC error when transport retry counter is exceeded (Kamal Heib) [2039426]
- RDMA/irdma: Validate number of CQ entries on create CQ (Kamal Heib) [2039426]
- RDMA/irdma: Skip CQP ring during a reset (Kamal Heib) [2039426]
- redhat/configs: Enable CONFIG_DM_MULTIPATH_HST (Benjamin Marzinski) [2000835]
- RDMA/core: Don't infoleak GRH fields (Kamal Heib) [2036599]
- RDMA/uverbs: Check for null return of kmalloc_array (Kamal Heib) [2036599]
- RDMA/sa_query: Use strscpy_pad instead of memcpy to copy a string (Kamal Heib) [2036599]
- RDMA/cma: Ensure rdma_addr_cancel() happens before issuing more requests (Kamal Heib) [2036599]
- RDMA/cma: Fix listener leak in rdma_cma_listen_on_all() failure (Kamal Heib) [2036599]
- IB/cma: Do not send IGMP leaves for sendonly Multicast groups (Kamal Heib) [2036599]
- IB/core: Remove deprecated current_seq comments (Kamal Heib) [2036599]
- RDMA/iwcm: Release resources if iw_cm module initialization fails (Kamal Heib) [2036599]
- sched: padding for user_struct for KABI (Phil Auld) [2033084]
- sched: padding for signal_struct in linux/sched/signal.h (Phil Auld) [2033084]
- sched: padding for struct rq and related (Phil Auld) [2033084]
- sched: Padding for sched_domain and root_domain (Phil Auld) [2033084]
- sched: Padding for task_struct and related in include/linux/sched.h (Phil Auld) [2033084]
- hwmon: (k10temp) Support up to 12 CCDs on AMD Family of processors (David Arcari) [2022526]
- hwmon: (k10temp) Add support for AMD Family 19h Models 10h-1Fh and A0h-AFh (David Arcari) [2022526]
- hwmon: (k10temp) Remove unused definitions (David Arcari) [2022526]
- x86/amd_nb: Add AMD Family 19h Models (10h-1Fh) and (A0h-AFh) PCI IDs (David Arcari) [2022526]
- hwmon: (k10temp) Remove residues of current and voltage (David Arcari) [2022526]
- tipc: check for null after calling kmemdup (Xin Long) [2024993]
- tipc: only accept encrypted MSG_CRYPTO msgs (Xin Long) [2024993]
- tipc: constify dev_addr passing (Xin Long) [2024993]
- tipc: increase timeout in tipc_sk_enqueue() (Xin Long) [2024993]
- tipc: clean up inconsistent indenting (Xin Long) [2024993]
- redhat: configs: add CONFIG_NTB and related items (John Linville) [1874186]

* Mon Jan 31 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-50.rt21.50.el9]
- net: fix possible NULL deref in sock_reserve_memory (Paolo Abeni) [2028420]
- mptcp: fix per socket endpoint accounting (Paolo Abeni) [2028420]
- mptcp: Check reclaim amount before reducing allocation (Paolo Abeni) [2028420]
- mptcp: fix a DSS option writing error (Paolo Abeni) [2028420]
- mptcp: fix opt size when sending DSS + MP_FAIL (Paolo Abeni) [2028420]
- mptcp: clean up harmless false expressions (Paolo Abeni) [2028420]
- selftests: mptcp: try to set mptcp ulp mode in different sk states (Paolo Abeni) [2028420]
- mptcp: enforce HoL-blocking estimation (Paolo Abeni) [2028420]
- mptcp: fix deadlock in __mptcp_push_pending() (Paolo Abeni) [2028420]
- mptcp: clear 'kern' flag from fallback sockets (Paolo Abeni) [2028420]
- mptcp: remove tcp ulp setsockopt support (Paolo Abeni) [2028420]
- mptcp: never allow the PM to close a listener subflow (Paolo Abeni) [2028420]
- selftests: mptcp: remove duplicate include in mptcp_inq.c (Paolo Abeni) [2028420]
- mptcp: support TCP_CORK and TCP_NODELAY (Paolo Abeni) [2028420]
- mptcp: expose mptcp_check_and_set_pending (Paolo Abeni) [2028420]
- tcp: expose __tcp_sock_set_cork and __tcp_sock_set_nodelay (Paolo Abeni) [2028420]
- selftests: mptcp: check IP_TOS in/out are the same (Paolo Abeni) [2028420]
- mptcp: getsockopt: add support for IP_TOS (Paolo Abeni) [2028420]
- mptcp: allow changing the "backup" bit by endpoint id (Paolo Abeni) [2028420]
- selftests: mptcp: add inq test case (Paolo Abeni) [2028420]
- mptcp: add SIOCINQ, OUTQ and OUTQNSD ioctls (Paolo Abeni) [2028420]
- selftests: mptcp: add TCP_INQ support (Paolo Abeni) [2028420]
- mptcp: add TCP_INQ cmsg support (Paolo Abeni) [2028420]
- mptcp: use delegate action to schedule 3rd ack retrans (Paolo Abeni) [2028420]
- mptcp: fix delack timer (Paolo Abeni) [2028420]
- selftests: mptcp: add tproxy test case (Paolo Abeni) [2028420]
- mptcp: sockopt: add SOL_IP freebind & transparent options (Paolo Abeni) [2028420]
- mptcp: Support for IP_TOS for MPTCP setsockopt() (Paolo Abeni) [2028420]
- ipv4: Exposing __ip_sock_set_tos() in ip.h (Paolo Abeni) [2028420]
- selftests: mptcp: more stable simult_flows tests (Paolo Abeni) [2028420]
- selftests: mptcp: fix proto type in link_failure tests (Paolo Abeni) [2028420]
- mptcp: fix corrupt receiver key in MPC + data + checksum (Paolo Abeni) [2028420]
- mptcp: drop unused sk in mptcp_push_release (Paolo Abeni) [2028420]
- mptcp: allocate fwd memory separately on the rx and tx path (Paolo Abeni) [2028420]
- net: introduce sk_forward_alloc_get() (Paolo Abeni) [2028420]
- tcp: define macros for a couple reclaim thresholds (Paolo Abeni) [2028420]
- net: add new socket option SO_RESERVE_MEM (Paolo Abeni) [2028420]
- mptcp: Make mptcp_pm_nl_mp_prio_send_ack() static (Paolo Abeni) [2028420]
- mptcp: increase default max additional subflows to 2 (Paolo Abeni) [2028420]
- mptcp: Avoid NULL dereference in mptcp_getsockopt_subflow_addrs() (Paolo Abeni) [2028420]
- mptcp: fix possible stall on recvmsg() (Paolo Abeni) [2028420]
- mptcp: use batch snmp operations in mptcp_seq_show() (Paolo Abeni) [2028420]
- net: snmp: inline snmp_get_cpu_field() (Paolo Abeni) [2028420]
- net: introduce and use lock_sock_fast_nested() (Paolo Abeni) [2028420]
- net: core: Correct the sock::sk_lock.owned lockdep annotations (Paolo Abeni) [2028420]
- mptcp: re-arm retransmit timer if data is pending (Paolo Abeni) [2028420]
- mptcp: remove tx_pending_data (Paolo Abeni) [2028420]
- mptcp: use lockdep_assert_held_once() instead of open-coding it (Paolo Abeni) [2028420]
- mptcp: use OPTIONS_MPTCP_MPC (Paolo Abeni) [2028420]
- mptcp: do not shrink snd_nxt when recovering (Paolo Abeni) [2028420]
- mptcp: allow changing the 'backup' bit when no sockets are open (Paolo Abeni) [2028420]
- mptcp: don't return sockets in foreign netns (Paolo Abeni) [2028420]
- tcp: remove sk_{tr}x_skb_cache (Paolo Abeni) [2028420]
- tcp: make tcp_build_frag() static (Paolo Abeni) [2028420]
- mptcp: stop relying on tcp_tx_skb_cache (Paolo Abeni) [2028420]
- tcp: expose the tcp_mark_push() and tcp_skb_entail() helpers (Paolo Abeni) [2028420]
- selftests: mptcp: add mptcp getsockopt test cases (Paolo Abeni) [2028420]
- mptcp: add MPTCP_SUBFLOW_ADDRS getsockopt support (Paolo Abeni) [2028420]
- mptcp: add MPTCP_TCPINFO getsockopt support (Paolo Abeni) [2028420]
- mptcp: add MPTCP_INFO getsockopt (Paolo Abeni) [2028420]
- mptcp: add new mptcp_fill_diag helper (Paolo Abeni) [2028420]
- mptcp: Only send extra TCP acks in eligible socket states (Paolo Abeni) [2028420]
- selftests: mptcp: clean tmp files in simult_flows (Paolo Abeni) [2028420]
- mptcp: ensure tx skbs always have the MPTCP ext (Paolo Abeni) [2028420]
- mptcp: fix possible divide by zero (Paolo Abeni) [2028420]
- mptcp: Fix duplicated argument in protocol.h (Paolo Abeni) [2028420]
- mptcp: make the locking tx schema more readable (Paolo Abeni) [2028420]
- mptcp: optimize the input options processing (Paolo Abeni) [2028420]
- mptcp: consolidate in_opt sub-options fields in a bitmask (Paolo Abeni) [2028420]
- mptcp: better binary layout for mptcp_options_received (Paolo Abeni) [2028420]
- mptcp: do not set unconditionally csum_reqd on incoming opt (Paolo Abeni) [2028420]
- selftests: mptcp: add MP_FAIL mibs check (Paolo Abeni) [2028420]
- mptcp: add the mibs for MP_FAIL (Paolo Abeni) [2028420]
- mptcp: send out MP_FAIL when data checksum fails (Paolo Abeni) [2028420]
- mptcp: MP_FAIL suboption receiving (Paolo Abeni) [2028420]
- mptcp: MP_FAIL suboption sending (Paolo Abeni) [2028420]
- mptcp: shrink mptcp_out_options struct (Paolo Abeni) [2028420]
- mptcp: optimize out option generation (Paolo Abeni) [2028420]
- selftests: mptcp: add_addr and echo race test (Paolo Abeni) [2028420]
- mptcp: remove MPTCP_ADD_ADDR_IPV6 and MPTCP_ADD_ADDR_PORT (Paolo Abeni) [2028420]
- mptcp: build ADD_ADDR/echo-ADD_ADDR option according pm.add_signal (Paolo Abeni) [2028420]
- mptcp: fix ADD_ADDR and RM_ADDR maybe flush addr_signal each other (Paolo Abeni) [2028420]
- mptcp: make MPTCP_ADD_ADDR_SIGNAL and MPTCP_ADD_ADDR_ECHO separate (Paolo Abeni) [2028420]
- mptcp: move drop_other_suboptions check under pm lock (Paolo Abeni) [2028420]
- selftests: mptcp: delete uncontinuous removing ids (Paolo Abeni) [2028420]
- selftests: mptcp: add fullmesh testcases (Paolo Abeni) [2028420]
- selftests: mptcp: set and print the fullmesh flag (Paolo Abeni) [2028420]
- mptcp: local addresses fullmesh (Paolo Abeni) [2028420]
- mptcp: remote addresses fullmesh (Paolo Abeni) [2028420]
- mptcp: drop flags and ifindex arguments (Paolo Abeni) [2028420]
- selftests: mptcp: add testcase for active-back (Paolo Abeni) [2028420]
- mptcp: backup flag from incoming MPJ ack option (Paolo Abeni) [2028420]
- mptcp: add mibs for stale subflows processing (Paolo Abeni) [2028420]
- mptcp: faster active backup recovery (Paolo Abeni) [2028420]
- mptcp: cleanup sysctl data and helpers (Paolo Abeni) [2028420]
- mptcp: handle pending data on closed subflow (Paolo Abeni) [2028420]
- mptcp: less aggressive retransmission strategy (Paolo Abeni) [2028420]
- mptcp: more accurate timeout (Paolo Abeni) [2028420]
- ionic: no devlink_unregister if not registered (Petr Oros) [2032260]
- devlink: fix netns refcount leak in devlink_nl_cmd_reload() (Petr Oros) [2032260]
- devlink: Don't throw an error if flash notification sent before devlink visible (Petr Oros) [2032260]
- devlink: make all symbols GPL-only (Petr Oros) [2032260]
- devlink: Simplify internal devlink params implementation (Petr Oros) [2032260]
- devlink: Clean not-executed param notifications (Petr Oros) [2032260]
- devlink: Delete obsolete parameters publish API (Petr Oros) [2032260]
- devlink: Remove extra device_lock assert checks (Petr Oros) [2032260]
- devlink: Delete reload enable/disable interface (Petr Oros) [2032260]
- net/mlx5: Set devlink reload feature bit for supported devices only (Petr Oros) [2032260]
- devlink: Allow control devlink ops behavior through feature mask (Petr Oros) [2032260]
- devlink: Annotate devlink API calls (Petr Oros) [2032260]
- devlink: Move netdev_to_devlink helpers to devlink.c (Petr Oros) [2032260]
- devlink: Reduce struct devlink exposure (Petr Oros) [2032260]
- devlink: report maximum number of snapshots with regions (Petr Oros) [2032260]
- devlink: Add missed notifications iterators (Petr Oros) [2032260]
- netdevsim: Move devlink registration to be last devlink command (Petr Oros) [2032260]
- qed: Move devlink registration to be last devlink command (Petr Oros) [2032260]
- ionic: Move devlink registration to be last devlink command (Petr Oros) [2032260]
- nfp: Move delink_register to be last command (Petr Oros) [2032260]
- mlxsw: core: Register devlink instance last (Petr Oros) [2032260]
- net/mlx5: Accept devlink user input after driver initialization complete (Petr Oros) [2032260]
- net/mlx4: Move devlink_register to be the last initialization command (Petr Oros) [2032260]
- ice: Open devlink when device is ready (Petr Oros) [2032260]
- net: hinic: Open device for the user access when it is ready (Petr Oros) [2032260]
- bnxt_en: Register devlink instance at the end devlink configuration (Petr Oros) [2032260]
- devlink: Notify users when objects are accessible (Petr Oros) [2032260]
- net/mlx5: Fix rdma aux device on devlink reload (Petr Oros) [2032260]
- qed: Don't ignore devlink allocation failures (Petr Oros) [2032260]
- ice: Delete always true check of PF pointer (Petr Oros) [2032260]
- devlink: Remove single line function obfuscations (Petr Oros) [2032260]
- devlink: Delete not used port parameters APIs (Petr Oros) [2032260]
- bnxt_en: Properly remove port parameter support (Petr Oros) [2032260]
- bnxt_en: Check devlink allocation and registration status (Petr Oros) [2032260]
- devlink: Make devlink_register to be void (Petr Oros) [2032260]
- devlink: Delete not-used devlink APIs (Petr Oros) [2032260]
- devlink: Delete not-used single parameter notification APIs (Petr Oros) [2032260]
- net/mlx5: Publish and unpublish all devlink parameters at once (Petr Oros) [2032260]
- devlink: Use xarray to store devlink instances (Petr Oros) [2032260]
- devlink: Count struct devlink consumers (Petr Oros) [2032260]
- devlink: Remove check of always valid devlink pointer (Petr Oros) [2032260]
- devlink: Simplify devlink_pernet_pre_exit call (Petr Oros) [2032260]
- net/mlx5: Support enable_vnet devlink dev param (Petr Oros) [2032260]
- net/mlx5: Support enable_rdma devlink dev param (Petr Oros) [2032260]
- net/mlx5: Support enable_eth devlink dev param (Petr Oros) [2032260]
- net/mlx5: Fix unpublish devlink parameters (Petr Oros) [2032260]
- devlink: Add APIs to publish, unpublish individual parameter (Petr Oros) [2032260]
- devlink: Add API to register and unregister single parameter (Petr Oros) [2032260]
- devlink: Create a helper function for one parameter registration (Petr Oros) [2032260]
- devlink: Add new "enable_vnet" generic device param (Petr Oros) [2032260]
- devlink: Add new "enable_rdma" generic device param (Petr Oros) [2032260]
- devlink: Add new "enable_eth" generic device param (Petr Oros) [2032260]
- devlink: Fix port_type_set function pointer check (Petr Oros) [2032260]
- devlink: Set device as early as possible (Petr Oros) [2032260]
- devlink: Simplify devlink port API calls (Petr Oros) [2032260]
- devlink: Allocate devlink directly in requested net namespace (Petr Oros) [2032260]
- devlink: Remove duplicated registration check (Petr Oros) [2032260]
- netdevsim: Protect both reload_down and reload_up paths (Petr Oros) [2032260]
- netdevsim: Forbid devlink reload when adding or deleting ports (Petr Oros) [2032260]
- net/mlx5: Don't rely on always true registered field (Petr Oros) [2032260]
- ionic: cleanly release devlink instance (Petr Oros) [2032260]
- selftests: net: bridge: fix typo in vlan_filtering dependency test (Ivan Vecera) [2037335]
- selftests: net: bridge: add test for vlan_filtering dependency (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_router tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast query and query response interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_querier_interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_membership_interval test (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_startup_query_count/interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast_last_member_count/interval tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast igmp/mld version tests (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast querier test (Ivan Vecera) [2037335]
- selftests: net: bridge: add vlan mcast snooping control test (Ivan Vecera) [2037335]
- net: bridge: mcast: fix br_multicast_ctx_vlan_global_disabled helper (Ivan Vecera) [2037335]
- net: bridge: mcast: add and enforce startup query interval minimum (Ivan Vecera) [2037335]
- net: bridge: mcast: add and enforce query interval minimum (Ivan Vecera) [2037335]
- net: bridge: fix ioctl old_deviceless bridge argument (Ivan Vecera) [2037335]
- net: bridge: Use array_size() helper in copy_to_user() (Ivan Vecera) [2037335]
- net: bridge: fix uninitialized variables when BRIDGE_CFM is disabled (Ivan Vecera) [2037335]
- net: bridge: mcast: use multicast_membership_interval for IGMPv3 (Ivan Vecera) [2037335]
- net: bridge: fix under estimation in br_get_linkxstats_size() (Ivan Vecera) [2037335]
- net: bridge: use nla_total_size_64bit() in br_get_linkxstats_size() (Ivan Vecera) [2037335]
- net: bridge: mcast: Associate the seqcount with its protecting lock. (Ivan Vecera) [2037335]
- net: bridge: mcast: fix vlan port router deadlock (Ivan Vecera) [2037335]
- net: bridge: use mld2r_ngrec instead of icmpv6_dataun (Ivan Vecera) [2037335]
- net: bridge: change return type of br_handle_ingress_vlan_tunnel (Ivan Vecera) [2037335]
- net: bridge: vlan: convert mcast router global option to per-vlan entry (Ivan Vecera) [2037335]
- net: bridge: mcast: br_multicast_set_port_router takes multicast context as argument (Ivan Vecera) [2037335]
- net: bridge: mcast: toggle also host vlan state in br_multicast_toggle_vlan (Ivan Vecera) [2037335]
- net: bridge: mcast: use the correct vlan group helper (Ivan Vecera) [2037335]
- net: bridge: vlan: account for router port lists when notifying (Ivan Vecera) [2037335]
- net: bridge: vlan: enable mcast snooping for existing master vlans (Ivan Vecera) [2037335]
- net: bridge: mcast: account for ipv6 size when dumping querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: drop sizeof for nest attribute's zero size (Ivan Vecera) [2037335]
- net: bridge: mcast: don't dump querier state if snooping is disabled (Ivan Vecera) [2037335]
- net: bridge: vlan: dump mcast ctx querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: dump ipv6 querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: dump ipv4 querier state (Ivan Vecera) [2037335]
- net: bridge: mcast: consolidate querier selection for ipv4 and ipv6 (Ivan Vecera) [2037335]
- net: bridge: mcast: make sure querier port/address updates are consistent (Ivan Vecera) [2037335]
- net: bridge: mcast: record querier port device ifindex instead of pointer (Ivan Vecera) [2037335]
- net: bridge: vlan: use br_rports_fill_info() to export mcast router ports (Ivan Vecera) [2037335]
- net: bridge: mcast: use the proper multicast context when dumping router ports (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast router global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast querier global option (Ivan Vecera) [2037335]
- net: bridge: mcast: querier and query state affect only current context type (Ivan Vecera) [2037335]
- net: bridge: mcast: move querier state to the multicast context (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast startup query interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast query response interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast query interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast querier interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast membership interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast last member interval global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast startup query count global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast last member count global option (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for mcast igmp/mld version global options (Ivan Vecera) [2037335]
- net: bridge: vlan: fix global vlan option range dumping (Ivan Vecera) [2037335]
- net: make switchdev_bridge_port_{,unoffload} loosely coupled with the bridge (Ivan Vecera) [2037335]
- net: bridge: switchdev: fix incorrect use of FDB flags when picking the dst device (Ivan Vecera) [2037335]
- net: bridge: switchdev: treat local FDBs the same as entries towards the bridge (Ivan Vecera) [2037335]
- net: bridge: switchdev: replay the entire FDB for each port (Ivan Vecera) [2037335]
- net: bridge: add a helper for retrieving port VLANs from the data path (Ivan Vecera) [2037335]
- net: bridge: update BROPT_VLAN_ENABLED before notifying switchdev in br_vlan_filter_toggle (Ivan Vecera) [2037335]
- net: bridge: fix build when setting skb->offload_fwd_mark with CONFIG_NET_SWITCHDEV=n (Ivan Vecera) [2037335]
- net: bridge: switchdev: allow the TX data plane forwarding to be offloaded (Ivan Vecera) [2037335]
- net: switchdev: fix FDB entries towards foreign ports not getting propagated to us (Ivan Vecera) [2037335]
- net: bridge: move the switchdev object replay helpers to "push" mode (Ivan Vecera) [2037335]
- net: bridge: guard the switchdev replay helpers against a NULL notifier block (Ivan Vecera) [2037335]
- net: bridge: switchdev: let drivers inform which bridge ports are offloaded (Ivan Vecera) [2037335]
- net: bridge: switchdev: recycle unused hwdoms (Ivan Vecera) [2037335]
- net: bridge: disambiguate offload_fwd_mark (Ivan Vecera) [2037335]
- net: bridge: multicast: add context support for host-joined groups (Ivan Vecera) [2037335]
- net: bridge: multicast: add mdb context support (Ivan Vecera) [2037335]
- net: bridge: multicast: fix igmp/mld port context null pointer dereferences (Ivan Vecera) [2037335]
- net: switchdev: recurse into __switchdev_handle_fdb_del_to_device (Ivan Vecera) [2037335]
- net: switchdev: remove stray semicolon in switchdev_handle_fdb_del_to_device shim (Ivan Vecera) [2037335]
- net: bridge: vlan: add mcast snooping control (Ivan Vecera) [2037335]
- net: bridge: vlan: notify when global options change (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for dumping global vlan options (Ivan Vecera) [2037335]
- net: bridge: vlan: add support for global options (Ivan Vecera) [2037335]
- net: bridge: multicast: include router port vlan id in notifications (Ivan Vecera) [2037335]
- net: bridge: multicast: add vlan querier and query support (Ivan Vecera) [2037335]
- net: bridge: multicast: check if should use vlan mcast ctx (Ivan Vecera) [2037335]
- net: bridge: multicast: use the port group to port context helper (Ivan Vecera) [2037335]
- net: bridge: multicast: add helper to get port mcast context from port group (Ivan Vecera) [2037335]
- net: bridge: add vlan mcast snooping knob (Ivan Vecera) [2037335]
- net: bridge: multicast: add vlan state initialization and control (Ivan Vecera) [2037335]
- net: bridge: vlan: add global and per-port multicast context (Ivan Vecera) [2037335]
- net: bridge: multicast: use multicast contexts instead of bridge or port (Ivan Vecera) [2037335]
- net: bridge: multicast: factor out bridge multicast context (Ivan Vecera) [2037335]
- net: bridge: multicast: factor out port multicast context (Ivan Vecera) [2037335]
- net: switchdev: introduce a fanout helper for SWITCHDEV_FDB_{ADD,DEL}_TO_DEVICE (Ivan Vecera) [2037335]
- net: switchdev: introduce helper for checking dynamically learned FDB entries (Ivan Vecera) [2037335]
- kernel: Add redhat code (Prarit Bhargava) [2047259]
- nvme: Mark NVMe over FC Target support unmaintained (Prarit Bhargava) [2019379]
- hdlc_fr: Mark driver unmaintained (Prarit Bhargava) [2019379]
- sfc: Mark siena driver unmaintained (Prarit Bhargava) [2019379]
- qla3xxx: Mark driver unmaintained (Prarit Bhargava) [2019379]
- netxen: Mark nic driver unmaintained (Prarit Bhargava) [2019379]
- redhat/configs: Disable ethoc driver (Prarit Bhargava) [2019379]
- redhat/configs: Disable dnet driver (Prarit Bhargava) [2019379]
- drivers/pci/pci-driver.c: Fix if/ifdef typo (Prarit Bhargava) [2019379]
- kernel/rh_taint.c: Update to new messaging (Prarit Bhargava) [2019379]

* Thu Jan 27 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-49.rt21.49.el9]
- net: skb: use kfree_skb_reason() in __udp4_lib_rcv() (Antoine Tenart) [2041931]
- net: skb: use kfree_skb_reason() in tcp_v4_rcv() (Antoine Tenart) [2041931]
- net: skb: introduce kfree_skb_reason() (Antoine Tenart) [2041931]
- net: add kerneldoc comment for sk_peer_lock (Guillaume Nault) [2037783]
- af_unix: fix races in sk_peer_pid and sk_peer_cred accesses (Guillaume Nault) [2037783] {CVE-2021-4203}
- netfilter: nat: force port remap to prevent shadowing well-known ports (Florian Westphal) [2006169] {CVE-2021-3773}
- netfilter: conntrack: tag conntracks picked up in local out hook (Florian Westphal) [2006169]
- selftests: nft_nat: switch port shadow test cases to socat (Florian Westphal) [2006169]
- selftests: nft_nat: Simplify port shadow notrack test (Florian Westphal) [2006169]
- selftests: nft_nat: Improve port shadow test stability (Florian Westphal) [2006169]
- selftests: nft_nat: add udp hole punch test case (Florian Westphal) [2006169]
- net: Remove redundant if statements (Petr Oros) [2037315]
- netdevice: add the case if dev is NULL (Petr Oros) [2037315]
- redhat: fix the exclusion of rhdocs changes entries in the changelog (Herton R. Krzesinski)
- get_maintainer.conf: Update with new location of RHMAINTAINERS (Prarit Bhargava)
- redhat: make pathspec exclusion compatible with old git versions (Herton R. Krzesinski)
- redhat/scripts: Update merge-subtrees.sh with new subtree location (Prarit Bhargava)
- tree: remove existing redhat/rhdocs subtree in 9.0 (Prarit Bhargava)
- CI: Use realtime_check_baseline template (Veronika Kabatova)
- powerpc/fadump: Fix inaccurate CPU state info in vmcore generated with panic (Gustavo Walbon) [2025518]
- powerpc: handle kdump appropriately with crash_kexec_post_notifiers option (Gustavo Walbon) [2025518]
- powerpc/pseries: use slab context cpumask allocation in CPU hotplug init (Waiman Long) [2019671]
- powerpc/pseries: Fix build error when NUMA=n (Waiman Long) [2019671]
- powerpc/smp: Use existing L2 cache_map cpumask to find L3 cache siblings (Diego Domingos) [2039639]
- powerpc/cacheinfo: Remove the redundant get_shared_cpu_map() (Diego Domingos) [2039639]
- powerpc/cacheinfo: Lookup cache by dt node and thread-group id (Diego Domingos) [2039639]
- powerpc: select CPUMASK_OFFSTACK if NR_CPUS >= 8192 (Diego Domingos) [2039163]
- powerpc: remove cpu_online_cores_map function (Diego Domingos) [2039163]
- adding support for c9s automotive coverage build (bgrech)
- CI: Use tagged containers (Veronika Kabatova)
- xfs: map unwritten blocks in XFS_IOC_{ALLOC,FREE}SP just like fallocate (Carlos Maiolino) [2034871] {CVE-2021-4155}
- selftests/powerpc: skip tests for unavailable mitigations. (Diego Domingos) [2021389]
- selftests/powerpc: Use date instead of EPOCHSECONDS in mitigation-patching.sh (Diego Domingos) [2021389]
- ip6_vti: initialize __ip6_tnl_parm struct in vti6_siocdevprivate (William Zhao) [2037810]
- KVM: x86: Wait for IPIs to be delivered when handling Hyper-V TLB flush hypercall (Vitaly Kuznetsov) [2036570]
- net: vlan: fix underflow for the real_dev refcnt (Balazs Nemeth) [2030036]
- net: vlan: fix a UAF in vlan_dev_real_dev() (Balazs Nemeth) [2030036]

* Tue Jan 25 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-48.rt21.48.el9]
- net: mana: Add RX fencing (Mohammed Gamal) [2030357]
- net: mana: Add XDP support (Mohammed Gamal) [2030357]
- net: mana: Fix memory leak in mana_hwc_create_wq (Mohammed Gamal) [2030357]
- net: mana: Fix spelling mistake "calledd" -> "called" (Mohammed Gamal) [2030357]
- ibmvnic: drop bad optimization in reuse_tx_pools() (Diego Domingos) [2014236]
- ibmvnic: drop bad optimization in reuse_rx_pools() (Diego Domingos) [2014236]
- ibmvnic: Reuse tx pools when possible (Diego Domingos) [2014236]
- ibmvnic: Reuse rx pools when possible (Diego Domingos) [2014236]
- ibmvnic: Reuse LTB when possible (Diego Domingos) [2014236]
- ibmvnic: init_tx_pools move loop-invariant code (Diego Domingos) [2014236]
- ibmvnic: Use/rename local vars in init_tx_pools (Diego Domingos) [2014236]
- ibmvnic: Use/rename local vars in init_rx_pools (Diego Domingos) [2014236]
- ibmvnic: Consolidate code in replenish_rx_pool() (Diego Domingos) [2014236]
- ibmvnic: Fix up some comments and messages (Diego Domingos) [2014236]
- ibmvnic: Use bitmap for LTB map_ids (Diego Domingos) [2014236]
- [s390] s390/qeth: fix deadlock during failing recovery (Mete Durlu) [1869669]
- [s390] s390/qeth: Fix deadlock in remove_discipline (Mete Durlu) [1869669]
- [s390] s390/qeth: fix NULL deref in qeth_clear_working_pool_list() (Mete Durlu) [1869669]
- [s390] s390/qeth: Update MACs of LEARNING_SYNC device (Mete Durlu) [1869669]
- [s390] s390/qeth: Switchdev event handler (Mete Durlu) [1869669]
- [s390] s390/qeth: Register switchdev event handler (Mete Durlu) [1869669]
- [s390] s390/qdio: propagate error when cancelling a ccw fails (Mete Durlu) [1869669]
- [s390] s390/qdio: improve roll-back after error on ESTABLISH ccw (Mete Durlu) [1869669]
- [s390] s390/qdio: cancel the ESTABLISH ccw after timeout (Mete Durlu) [1869669]
- [s390] s390/qdio: fix roll-back after timeout on ESTABLISH ccw (Mete Durlu) [1869669]
- [s390] s390/qeth: remove OSN support (Mete Durlu) [1869669]
- [s390] s390: add HWCAP_S390_PCI_MIO to ELF hwcaps (Mete Durlu) [2030640]
- [s390] s390: make PCI mio support a machine flag (Mete Durlu) [2030640]
- ima: silence measurement list hexdump during kexec (Bruno Meneguele) [2034157]
- scsi: lpfc: Update lpfc version to 14.0.0.4 (Dick Kennedy) [2034278]
- scsi: lpfc: Add additional debugfs support for CMF (Dick Kennedy) [2034278]
- scsi: lpfc: Cap CMF read bytes to MBPI (Dick Kennedy) [2034278]
- scsi: lpfc: Adjust CMF total bytes and rxmonitor (Dick Kennedy) [2034278]
- scsi: lpfc: Trigger SLI4 firmware dump before doing driver cleanup (Dick Kennedy) [2034278]
- scsi: lpfc: Fix NPIV port deletion crash (Dick Kennedy) [2034278]
- scsi: lpfc: Fix lpfc_force_rscn ndlp kref imbalance (Dick Kennedy) [2034278]
- scsi: lpfc: Change return code on I/Os received during link bounce (Dick Kennedy) [2034278]
- scsi: lpfc: Fix leaked lpfc_dmabuf mbox allocations with NPIV (Dick Kennedy) [2034278]
- scsi: lpfc: Fix non-recovery of remote ports following an unsolicited LOGO (Dick Kennedy) [2039036]
- mm/memcg: Exclude mem_cgroup pointer from kABI signature computation (Waiman Long) [2036995]
- From: Steve Dickson <steved@redhat.com> (Steve Dickson) [2016699]

* Mon Jan 24 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-47.rt21.47.el9]
- Revert "Merge: virtio: support virtio-mem on x86-64 as tech-preview" (Juri Lelli)
- nvmet: register discovery subsystem as 'current' (John Meneghini) [2021672]
- nvme: add new discovery log page entry definitions (John Meneghini) [2021672]
- nvmet: switch check for subsystem type (John Meneghini) [2021672]
- nvme: display correct subsystem NQN (John Meneghini) [2021672]
- nvme: Add connect option 'discovery' (John Meneghini) [2021672]
- nvme: expose subsystem type in sysfs attribute 'subsystype' (John Meneghini) [2021672]
- nvmet: set 'CNTRLTYPE' in the identify controller data (John Meneghini) [2021672]
- nvmet: add nvmet_is_disc_subsys() helper (John Meneghini) [2021672]
- nvme: add CNTRLTYPE definitions for 'identify controller' (John Meneghini) [2021672]
- nvmet: make discovery NQN configurable (John Meneghini) [2021672]
- nitro_enclaves: Use get_user_pages_unlocked() call to handle mmap assert (Vitaly Kuznetsov) [2034619]
- include/linux/pci.h: Exclude struct hotplug_slot from KABI (Prarit Bhargava) [2034338]
- virtio/vsock: fix the transport to work with VMADDR_CID_ANY (Stefano Garzarella) [2026949]
- vhost/vsock: cleanup removing `len` variable (Stefano Garzarella) [2026949]
- vhost/vsock: fix incorrect used length reported to the guest (Stefano Garzarella) [2026949]
- vsock: prevent unnecessary refcnt inc for nonblocking connect (Stefano Garzarella) [2026949]
- vsock_diag_test: remove free_sock_stat() call in test_no_sockets (Stefano Garzarella) [2026949]
- vsock: Enable y2038 safe timeval for timeout (Stefano Garzarella) [2026949]
- vsock: Refactor vsock_*_getsockopt to resemble sock_getsockopt (Stefano Garzarella) [2026949]
- vsock_test: update message bounds test for MSG_EOR (Stefano Garzarella) [2026949]
- af_vsock: rename variables in receive loop (Stefano Garzarella) [2026949]
- virtio/vsock: support MSG_EOR bit processing (Stefano Garzarella) [2026949]
- vhost/vsock: support MSG_EOR bit processing (Stefano Garzarella) [2026949]
- virtio/vsock: add 'VIRTIO_VSOCK_SEQ_EOR' bit. (Stefano Garzarella) [2026949]
- virtio/vsock: rename 'EOR' to 'EOM' bit. (Stefano Garzarella) [2026949]
- include/linux/irq*.h: Pad irq structs for KABI (Prarit Bhargava) [2034264]
- include/linux/fwnode.h: Exclude fwnode structs from KABI (Prarit Bhargava) [2033388]
- bpf: Fix toctou on read-only map's constant scalar tracking (Jiri Olsa) [2029198] {CVE-2021-4001}
- ACPI: tables: FPDT: Do not print FW_BUG message if record types are reserved (Mark Langsdorf) [2000202]
- redhat: support virtio-mem on x86-64 as tech-preview (David Hildenbrand) [2014492]
- proc/vmcore: fix clearing user buffer by properly using clear_user() (David Hildenbrand) [2014492]
- virtio-mem: support VIRTIO_MEM_F_UNPLUGGED_INACCESSIBLE (David Hildenbrand) [2014492]
- virtio-mem: disallow mapping virtio-mem memory via /dev/mem (David Hildenbrand) [2014492]
- kernel/resource: disallow access to exclusive system RAM regions (David Hildenbrand) [2014492]
- kernel/resource: clean up and optimize iomem_is_exclusive() (David Hildenbrand) [2014492]
- virtio-mem: kdump mode to sanitize /proc/vmcore access (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_remove() into virtio_mem_deinit_hotplug() (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_probe() into virtio_mem_init_hotplug() (David Hildenbrand) [2014492]
- virtio-mem: factor out hotplug specifics from virtio_mem_init() into virtio_mem_init_hotplug() (David Hildenbrand) [2014492]
- proc/vmcore: convert oldmem_pfn_is_ram callback to more generic vmcore callbacks (David Hildenbrand) [2014492]
- proc/vmcore: let pfn_is_ram() return a bool (David Hildenbrand) [2014492]
- x86/xen: print a warning when HVMOP_get_mem_type fails (David Hildenbrand) [2014492]
- x86/xen: simplify xen_oldmem_pfn_is_ram() (David Hildenbrand) [2014492]
- x86/xen: update xen_oldmem_pfn_is_ram() documentation (David Hildenbrand) [2014492]

* Fri Jan 21 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-46.rt21.46.el9]
- crypto: qat - fix definition of ring reset results (Vladis Dronov) [2015145]
- crypto: qat - add support for compression for 4xxx (Vladis Dronov) [2015145]
- crypto: qat - allow detection of dc capabilities for 4xxx (Vladis Dronov) [2015145]
- crypto: qat - add PFVF support to enable the reset of ring pairs (Vladis Dronov) [2015145]
- crypto: qat - add PFVF support to the GEN4 host driver (Vladis Dronov) [2015145]
- crypto: qat - config VFs based on ring-to-svc mapping (Vladis Dronov) [2015145]
- crypto: qat - exchange ring-to-service mappings over PFVF (Vladis Dronov) [2015145]
- crypto: qat - support fast ACKs in the PFVF protocol (Vladis Dronov) [2015145]
- crypto: qat - exchange device capabilities over PFVF (Vladis Dronov) [2015145]
- crypto: qat - introduce support for PFVF block messages (Vladis Dronov) [2015145]
- crypto: qat - store the ring-to-service mapping (Vladis Dronov) [2015145]
- crypto: qat - store the PFVF protocol version of the endpoints (Vladis Dronov) [2015145]
- crypto: qat - improve the ACK timings in PFVF send (Vladis Dronov) [2015145]
- crypto: qat - leverage read_poll_timeout in PFVF send (Vladis Dronov) [2015145]
- crypto: qat - leverage bitfield.h utils for PFVF messages (Vladis Dronov) [2015145]
- crypto: qat - abstract PFVF messages with struct pfvf_message (Vladis Dronov) [2015145]
- crypto: qat - set PFVF_MSGORIGIN just before sending (Vladis Dronov) [2015145]
- crypto: qat - make PFVF send and receive direction agnostic (Vladis Dronov) [2015145]
- crypto: qat - make PFVF message construction direction agnostic (Vladis Dronov) [2015145]
- crypto: qat - add the adf_get_pmisc_base() helper function (Vladis Dronov) [2015145]
- crypto: qat - support the reset of ring pairs on PF (Vladis Dronov) [2015145]
- crypto: qat - extend crypto capability detection for 4xxx (Vladis Dronov) [2015145]
- crypto: qat - set COMPRESSION capability for QAT GEN2 (Vladis Dronov) [2015145]
- crypto: qat - set CIPHER capability for QAT GEN2 (Vladis Dronov) [2015145]
- crypto: qat - get compression extended capabilities (Vladis Dronov) [2015145]
- crypto: qat - improve logging of PFVF messages (Vladis Dronov) [2015145]
- crypto: qat - fix VF IDs in PFVF log messages (Vladis Dronov) [2015145]
- crypto: qat - do not rely on min version (Vladis Dronov) [2015145]
- crypto: qat - refactor pfvf version request messages (Vladis Dronov) [2015145]
- crypto: qat - pass the PF2VF responses back to the callers (Vladis Dronov) [2015145]
- crypto: qat - use enums for PFVF protocol codes (Vladis Dronov) [2015145]
- crypto: qat - reorganize PFVF protocol definitions (Vladis Dronov) [2015145]
- crypto: qat - reorganize PFVF code (Vladis Dronov) [2015145]
- crypto: qat - abstract PFVF receive logic (Vladis Dronov) [2015145]
- crypto: qat - abstract PFVF send function (Vladis Dronov) [2015145]
- crypto: qat - differentiate between pf2vf and vf2pf offset (Vladis Dronov) [2015145]
- crypto: qat - add pfvf_ops (Vladis Dronov) [2015145]
- crypto: qat - relocate PFVF disabled function (Vladis Dronov) [2015145]
- crypto: qat - relocate PFVF VF related logic (Vladis Dronov) [2015145]
- crypto: qat - relocate PFVF PF related logic (Vladis Dronov) [2015145]
- crypto: qat - handle retries due to collisions in adf_iov_putmsg() (Vladis Dronov) [2015145]
- crypto: qat - split PFVF message decoding from handling (Vladis Dronov) [2015145]
- crypto: qat - re-enable interrupts for legacy PFVF messages (Vladis Dronov) [2015145]
- crypto: qat - change PFVF ACK behaviour (Vladis Dronov) [2015145]
- crypto: qat - move interrupt code out of the PFVF handler (Vladis Dronov) [2015145]
- crypto: qat - move VF message handler to adf_vf2pf_msg.c (Vladis Dronov) [2015145]
- crypto: qat - move vf2pf interrupt helpers (Vladis Dronov) [2015145]
- crypto: qat - refactor PF top half for PFVF (Vladis Dronov) [2015145]
- crypto: qat - fix undetected PFVF timeout in ACK loop (Vladis Dronov) [2015145]
- crypto: qat - do not handle PFVF sources for qat_4xxx (Vladis Dronov) [2015145]
- crypto: qat - simplify adf_enable_aer() (Vladis Dronov) [2015145]
- crypto: qat - share adf_enable_pf2vf_comms() from adf_pf2vf_msg.c (Vladis Dronov) [2015145]
- crypto: qat - extract send and wait from adf_vf2pf_request_version() (Vladis Dronov) [2015145]
- crypto: qat - add VF and PF wrappers to common send function (Vladis Dronov) [2015145]
- crypto: qat - rename pfvf collision constants (Vladis Dronov) [2015145]
- crypto: qat - move pfvf collision detection values (Vladis Dronov) [2015145]
- crypto: qat - make pfvf send message direction agnostic (Vladis Dronov) [2015145]
- crypto: qat - use hweight for bit counting (Vladis Dronov) [2015145]
- crypto: qat - remove duplicated logic across GEN2 drivers (Vladis Dronov) [2015145]
- crypto: qat - fix handling of VF to PF interrupts (Vladis Dronov) [2015145]
- crypto: qat - remove unnecessary collision prevention step in PFVF (Vladis Dronov) [2015145]
- crypto: qat - disregard spurious PFVF interrupts (Vladis Dronov) [2015145]
- crypto: qat - detect PFVF collision after ACK (Vladis Dronov) [2015145]
- crypto: qat - power up 4xxx device (Vladis Dronov) [2015145]
- crypto: qat - remove unneeded packed attribute (Vladis Dronov) [2015145]
- crypto: qat - free irq in case of failure (Vladis Dronov) [2015145]
- crypto: qat - free irqs only if allocated (Vladis Dronov) [2015145]
- crypto: qat - remove unmatched CPU affinity to cluster IRQ (Vladis Dronov) [2015145]
- crypto: qat - replace deprecated MSI API (Vladis Dronov) [2015145]
- crypto: qat - store vf.compatible flag (Vladis Dronov) [2015145]
- crypto: qat - do not export adf_iov_putmsg() (Vladis Dronov) [2015145]
- crypto: qat - flush vf workqueue at driver removal (Vladis Dronov) [2015145]
- crypto: qat - remove the unnecessary get_vintmsk_offset() (Vladis Dronov) [2015145]
- crypto: qat - fix naming of PF/VF enable functions (Vladis Dronov) [2015145]
- crypto: qat - complete all the init steps before service notification (Vladis Dronov) [2015145]
- crypto: qat - move IO virtualization functions (Vladis Dronov) [2015145]
- crypto: qat - fix naming for init/shutdown VF to PF notifications (Vladis Dronov) [2015145]
- crypto: qat - protect interrupt mask CSRs with a spinlock (Vladis Dronov) [2015145]
- crypto: qat - move pf2vf interrupt [en|dis]able to adf_vf_isr.c (Vladis Dronov) [2015145]
- crypto: qat - fix reuse of completion variable (Vladis Dronov) [2015145]
- crypto: qat - remove intermediate tasklet for vf2pf (Vladis Dronov) [2015145]
- crypto: qat - rename compatibility version definition (Vladis Dronov) [2015145]
- crypto: qat - prevent spurious MSI interrupt in PF (Vladis Dronov) [2015145]
- crypto: qat - prevent spurious MSI interrupt in VF (Vladis Dronov) [2015145]
- crypto: qat - handle both source of interrupt in VF ISR (Vladis Dronov) [2015145]
- crypto: qat - do not ignore errors from enable_vf2pf_comms() (Vladis Dronov) [2015145]
- crypto: qat - enable interrupts only after ISR allocation (Vladis Dronov) [2015145]
- crypto: qat - remove empty sriov_configure() (Vladis Dronov) [2015145]
- crypto: qat - use proper type for vf_mask (Vladis Dronov) [2015145]
- crypto: qat - fix a typo in a comment (Vladis Dronov) [2015145]
- crypto: qat - disable AER if an error occurs in probe functions (Vladis Dronov) [2015145]
- crypto: qat - set DMA mask to 48 bits for Gen2 (Vladis Dronov) [2015145]
- crypto: qat - simplify code and axe the use of a deprecated API (Vladis Dronov) [2015145]

* Wed Jan 19 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-45.rt21.45.el9]
- printk: Fix merge leftovers (Juri Lelli)
- workqueue, kasan: avoid alloc_pages() when recording stack (Phil Auld) [2022894]
- kasan: generic: introduce kasan_record_aux_stack_noalloc() (Phil Auld) [2022894]
- kasan: common: provide can_alloc in kasan_save_stack() (Phil Auld) [2022894]
- lib/stackdepot: introduce __stack_depot_save() (Phil Auld) [2022894]
- lib/stackdepot: remove unused function argument (Phil Auld) [2022894]
- lib/stackdepot: include gfp.h (Phil Auld) [2022894]
- workqueue: Introduce show_one_worker_pool and show_one_workqueue. (Phil Auld) [2022894]
- workqueue: make sysfs of unbound kworker cpumask more clever (Phil Auld) [2022894]
- workqueue: fix state-dump console deadlock (Phil Auld) [2022894]
- workqueue: Remove unused WORK_NO_COLOR (Phil Auld) [2022894]
- workqueue: Assign a color to barrier work items (Phil Auld) [2022894]
- workqueue: Mark barrier work with WORK_STRUCT_INACTIVE (Phil Auld) [2022894]
- workqueue: Change the code of calculating work_flags in insert_wq_barrier() (Phil Auld) [2022894]
- workqueue: Change arguement of pwq_dec_nr_in_flight() (Phil Auld) [2022894]
- workqueue: Rename "delayed" (delayed by active management) to "inactive" (Phil Auld) [2022894]
- workqueue: Replace deprecated ida_simple_*() with ida_alloc()/ida_free() (Phil Auld) [2022894]
- workqueue: Fix typo in comments (Phil Auld) [2022894]
- workqueue: Fix possible memory leaks in wq_numa_init() (Phil Auld) [2022894]
- nvme: avoid race in shutdown namespace removal (Ewan D. Milne) [2014529]
- powerpc/xmon: Dump XIVE information for online-only processors. (Steve Best) [2037642]
- ipv4: make exception cache less predictible (Antoine Tenart) [2015112] {CVE-2021-20322}
- [s390] s390/cio: make ccw_device_dma_* more robust (Claudio Imbrenda) [1997541]
- [s390] s390/pci: add s390_iommu_aperture kernel parameter (Claudio Imbrenda) [2034134]
- [s390] s390/pci: fix zpci_zdev_put() on reserve (Claudio Imbrenda) [2034132]
- [s390] s390/pci: cleanup resources only if necessary (Claudio Imbrenda) [2034132]
- [s390] s390/sclp: fix Secure-IPL facility detection (Claudio Imbrenda) [2034116]
- Revert "[redhat] Generate a crashkernel.default for each kernel build" (Coiby Xu) [2034490]
- ibmvnic: Process crqs after enabling interrupts (Diego Domingos) [2020021]
- ibmvnic: delay complete() (Diego Domingos) [2020021]
- ibmvnic: don't stop queue in xmit (Diego Domingos) [2019988]
- bpf/selftests: disable test failing on RHEL9 (Viktor Malik) [2006315]
- bpf/selftests: disable a verifier test for powerpc (Viktor Malik) [2032734]
- bpf/selftests: allow disabling tests (Viktor Malik) [2036656]
- kernel/crash_core: suppress unknown crashkernel parameter warning (Philipp Rudo) [2026570]
- mm/vmalloc: do not adjust the search size for alignment overhead (David Hildenbrand) [2029493]
- Bluetooth: fix use-after-free error in lock_sock_nested() (Gopal Tiwari) [2005691]
- lib: zstd: Don't add -O3 to cflags (Neal Gompa) [2034834]
- lib: zstd: Don't inline functions in zstd_opt.c (Neal Gompa) [2034834]
- lib: zstd: Fix unused variable warning (Neal Gompa) [2034834]
- lib: zstd: Add cast to silence clang's -Wbitwise-instead-of-logical (Neal Gompa) [2034834]
- MAINTAINERS: Add maintainer entry for zstd (Neal Gompa) [2034834]
- lib: zstd: Upgrade to latest upstream zstd version 1.4.10 (Neal Gompa) [2034834]
- lib: zstd: Add decompress_sources.h for decompress_unzstd (Neal Gompa) [2034834]
- lib: zstd: Add kernel-specific API (Neal Gompa) [2034834]

* Tue Jan 18 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-44.rt21.44.el9]
- dm btree remove: fix use after free in rebalance_children() (Benjamin Marzinski) [2031198]
- dm table: log table creation error code (Benjamin Marzinski) [2031198]
- dm: make workqueue names device-specific (Benjamin Marzinski) [2031198]
- dm writecache: Make use of the helper macro kthread_run() (Benjamin Marzinski) [2031198]
- dm crypt: Make use of the helper macro kthread_run() (Benjamin Marzinski) [2031198]
- dm: Remove redundant flush_workqueue() calls (Benjamin Marzinski) [2031198]
- dm crypt: log aead integrity violations to audit subsystem (Benjamin Marzinski) [2031198]
- dm integrity: log audit events for dm-integrity target (Benjamin Marzinski) [2031198]
- dm: introduce audit event module for device mapper (Benjamin Marzinski) [2031198]
- dm: fix mempool NULL pointer race when completing IO (Benjamin Marzinski) [2031198]
- dm rq: don't queue request to blk-mq during DM suspend (Benjamin Marzinski) [2031198]
- dm clone: make array 'descs' static (Benjamin Marzinski) [2031198]
- dm verity: skip redundant verity_handle_err() on I/O errors (Benjamin Marzinski) [2031198]
- dm crypt: use in_hardirq() instead of deprecated in_irq() (Benjamin Marzinski) [2031198]
- dm ima: update dm documentation for ima measurement support (Benjamin Marzinski) [2031198]
- dm ima: update dm target attributes for ima measurements (Benjamin Marzinski) [2031198]
- dm ima: add a warning in dm_init if duplicate ima events are not measured (Benjamin Marzinski) [2031198]
- dm ima: prefix ima event name related to device mapper with dm_ (Benjamin Marzinski) [2031198]
- dm ima: add version info to dm related events in ima log (Benjamin Marzinski) [2031198]
- dm ima: prefix dm table hashes in ima log with hash algorithm (Benjamin Marzinski) [2031198]
- dm crypt: Avoid percpu_counter spinlock contention in crypt_page_alloc() (Benjamin Marzinski) [2031198]
- dm: add documentation for IMA measurement support (Benjamin Marzinski) [2031198]
- dm: update target status functions to support IMA measurement (Benjamin Marzinski) [2031198]
- dm ima: measure data on device rename (Benjamin Marzinski) [2031198]
- dm ima: measure data on table clear (Benjamin Marzinski) [2031198]
- dm ima: measure data on device remove (Benjamin Marzinski) [2031198]
- dm ima: measure data on device resume (Benjamin Marzinski) [2031198]
- dm ima: measure data on table load (Benjamin Marzinski) [2031198]
- dm writecache: add event counters (Benjamin Marzinski) [2031198]
- dm writecache: report invalid return from writecache_map helpers (Benjamin Marzinski) [2031198]
- dm writecache: further writecache_map() cleanup (Benjamin Marzinski) [2031198]
- dm writecache: factor out writecache_map_remap_origin() (Benjamin Marzinski) [2031198]
- dm writecache: split up writecache_map() to improve code readability (Benjamin Marzinski) [2031198]
- redhat: Pull in openssl-devel as a build dependency correctly (Neal Gompa) [2034670]
- redhat/configs: Enable ThinkLMI support (Mark Pearson) [2030770]
- platform/x86: think-lmi: Abort probe on analyze failure (Mark Pearson) [2030770]
- platform/x86: think-lmi: add debug_cmd (Mark Pearson) [2030770]
- include/linux/timer.h: Pad timer_list struct for KABI (Prarit Bhargava) [2034452]
- kernel: Include RHEL Ecosystem message (Prarit Bhargava) [2033650]
- include/linux/ioport.h: Pad resource struct for KABI (Prarit Bhargava) [2033475]
- include/linux/hrtimer.h: Pad hrtimer struct for KABI (Prarit Bhargava) [2033473]
- redhat/configs: Add explicit values for ZRAM_DEF_COMP_LZ4* configs (Neal Gompa) [2032758]
- redhat/configs: Enable CONFIG_CRYPTO_ZSTD (Neal Gompa) [2032758]
- redhat/configs: Migrate defaults for ZRAM from pending-common to common (Neal Gompa) [2032758]
- Enable iSER on s390x (Stefan Schulze Frielinghaus) [1965279]

* Mon Jan 17 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-43.rt21.43.el9]
- mm: COW: restore full accuracy in page reuse (Andrea Arcangeli) [1958742]
- mm: thp: replace the page lock with the seqlock for the THP mapcount (Andrea Arcangeli) [1958742]
- mm: COW: skip the page lock in the COW copy path (Andrea Arcangeli) [1958742]
- mm: gup: gup_must_unshare() use can_read_pin_swap_page() (Andrea Arcangeli) [1958742]
- mm: hugetlbfs: gup: gup_must_unshare(): enable hugetlbfs (Andrea Arcangeli) [1958742]
- mm: hugetlbfs: FOLL_FAULT_UNSHARE (Andrea Arcangeli) [1958742]
- mm: hugetlbfs: COR: copy-on-read fault (Andrea Arcangeli) [1958742]
- mm: gup: FOLL_UNSHARE RHEL (Andrea Arcangeli) [1958742]
- mm: gup: FOLL_NOUNSHARE: optimize follow_page (Andrea Arcangeli) [1958742]
- mm: gup: FOLL_UNSHARE (Andrea Arcangeli) [1958742]
- mm: gup: gup_must_unshare() (Andrea Arcangeli) [1958742]
- mm: gup: COR: copy-on-read fault (Andrea Arcangeli) [1958742]
- mm: thp: introduce page_trans_huge_anon_shared (Andrea Arcangeli) [1958742]
- mm: thp: stabilize the THP mapcount in page_remove_anon_compound_rmap (Andrea Arcangeli) [1958742]
- mm: thp: make the THP mapcount atomic with a seqlock (Andrea Arcangeli) [1958742]
- mm: thp: consolidate mapcount logic on THP split (David Hildenbrand) [1958742]
- powerpc/xive: Change IRQ domain to a tree domain (Daniel Henrique Barboza) [2008723]
- tcp: fix page frag corruption on page fault (Paolo Abeni) [2028276]
- sock: fix /proc/net/sockstat underflow in sk_clone_lock() (Paolo Abeni) [2028276]
- net: add and use skb_unclone_keeptruesize() helper (Paolo Abeni) [2028276]
- net: stream: don't purge sk_error_queue in sk_stream_kill_queues() (Paolo Abeni) [2028276]
- net, neigh: Fix NTF_EXT_LEARNED in combination with NTF_USE (Paolo Abeni) [2028276]
- net-sysfs: initialize uid and gid before calling net_ns_get_ownership (Paolo Abeni) [2028276]
- net: Prevent infinite while loop in skb_tx_hash() (Paolo Abeni) [2028276]
- napi: fix race inside napi_enable (Paolo Abeni) [2028276]
- skb_expand_head() adjust skb->truesize incorrectly (Paolo Abeni) [2028276]
- bpf: use skb_expand_head in bpf_out_neigh_v4/6 (Paolo Abeni) [2028276]
- ax25: use skb_expand_head (Paolo Abeni) [2028276]
- vrf: fix NULL dereference in vrf_finish_output() (Paolo Abeni) [2028276]
- vrf: use skb_expand_head in vrf_finish_output (Paolo Abeni) [2028276]
- ipv4: use skb_expand_head in ip_finish_output2 (Paolo Abeni) [2028276]
- ipv6: use skb_expand_head in ip6_xmit (Paolo Abeni) [2028276]
- ipv6: use skb_expand_head in ip6_finish_output2 (Paolo Abeni) [2028276]
- skbuff: introduce skb_expand_head() (Paolo Abeni) [2028276]
- net/af_unix: fix a data-race in unix_dgram_poll (Paolo Abeni) [2028276]
- net: don't unconditionally copy_from_user a struct ifreq for socket ioctls (Paolo Abeni) [2028276]
- devlink: Clear whole devlink_flash_notify struct (Paolo Abeni) [2028276]
- devlink: Break parameter notification sequence to be before/after unload/load driver (Paolo Abeni) [2028276]
- vhost_net: fix OoB on sendmsg() failure. (Paolo Abeni) [2026821]
- printk: restore flushing of NMI buffers on remote CPUs after NMI backtraces (Prarit Bhargava) [2023082]
- lib/nmi_backtrace: Serialize even messages about idle CPUs (Prarit Bhargava) [2023082]
- printk: syslog: close window between wait and read (Prarit Bhargava) [2023082]
- printk: convert @syslog_lock to mutex (Prarit Bhargava) [2023082]
- printk: remove NMI tracking (Prarit Bhargava) [2023082]
- printk: remove safe buffers (Prarit Bhargava) [2023082]
- printk: track/limit recursion (Prarit Bhargava) [2023082]
- lib/nmi_backtrace: explicitly serialize banner and regs (Prarit Bhargava) [2023082]

* Fri Jan 14 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-42.rt21.42.el9]
- scsi: smartpqi: Update version to 2.1.12-055 (Don Brace) [1869853]
- scsi: smartpqi: Add 3252-8i PCI id (Don Brace) [1869853]
- scsi: smartpqi: Fix duplicate device nodes for tape changers (Don Brace) [1869853]
- scsi: smartpqi: Fix boot failure during LUN rebuild (Don Brace) [1869853]
- scsi: smartpqi: Add extended report physical LUNs (Don Brace) [1869853]
- scsi: smartpqi: Avoid failing I/Os for offline devices (Don Brace) [1869853]
- scsi: smartpqi: Add TEST UNIT READY check for SANITIZE operation (Don Brace) [1869853]
- scsi: smartpqi: Update LUN reset handler (Don Brace) [1869853]
- scsi: smartpqi: Capture controller reason codes (Don Brace) [1869853]
- scsi: smartpqi: Add controller handshake during kdump (Don Brace) [1869853]
- scsi: smartpqi: Update device removal management (Don Brace) [1869853]
- scsi: smartpqi: Replace one-element array with flexible-array member (Don Brace) [1869853]
- scsi: smartpqi: Fix an error code in pqi_get_raid_map() (Don Brace) [1869853]
- scsi: smartpqi: Update version to 2.1.10-020 (Don Brace) [1869853]
- scsi: smartpqi: Fix ISR accessing uninitialized data (Don Brace) [1869853]
- scsi: smartpqi: Add PCI IDs for new ZTE controllers (Don Brace) [1869853]
- scsi: smartpqi: Add PCI ID for new ntcom controller (Don Brace) [1869853]
- scsi: smartpqi: Add SCSI cmd info for resets (Don Brace) [1869853]
- scsi: smartpqi: Change Kconfig menu entry to Microchip (Don Brace) [1869853]
- scsi: smartpqi: Change driver module macros to Microchip (Don Brace) [1869853]
- scsi: smartpqi: Update copyright notices (Don Brace) [1869853]
- scsi: smartpqi: Add PCI IDs for H3C P4408 controllers (Don Brace) [1869853]
- powerpc/module_64: Fix livepatching for RO modules (Joe Lawrence) [2019205]
- net-sysfs: try not to restart the syscall if it will fail eventually (Antoine Tenart) [2030634]
- CI: Enable realtime checks for baselines (Veronika Kabatova)
- CI: Cleanup residue from ARK (Veronika Kabatova)
- redhat: ignore ksamples and kselftests on the badfuncs rpminspect test (Herton R. Krzesinski)
- redhat: disable upstream check for rpminspect (Herton R. Krzesinski)
- redhat/configs: Enable CONFIG_CRYPTO_BLAKE2B (Neal Gompa) [2031547]
- selftests: netfilter: switch zone stress to socat (Florian Westphal) [2030759]
- netfilter: conntrack: set on IPS_ASSURED if flows enters internal stream state (Florian Westphal) [2030759]
- netfilter: conntrack: serialize hash resizes and cleanups (Florian Westphal) [2030759]
- selftests: netfilter: add zone stress test with colliding tuples (Florian Westphal) [2030759]
- selftests: netfilter: add selftest for directional zone support (Florian Westphal) [2030759]
- netfilter: conntrack: include zone id in tuple hash again (Florian Westphal) [2030759]
- netfilter: conntrack: make max chain length random (Florian Westphal) [2030759]
- netfilter: refuse insertion if chain has grown too large (Florian Westphal) [2030759]
- netfilter: conntrack: switch to siphash (Florian Westphal) [2030759]
- netfilter: conntrack: sanitize table size default settings (Florian Westphal) [2030759]
- redhat: configs: increase CONFIG_DEBUG_KMEMLEAK_MEM_POOL_SIZE (Rafael Aquini) [2008118]
- iommu/dma: Fix incorrect error return on iommu deferred attach (Jerry Snitselaar) [2030394]
- RDMA/siw: Mark Software iWARP Driver as tech-preview (Kamal Heib) [2023416]
- genirq: Fix kernel doc indentation (Prarit Bhargava) [2023084]
- genirq: Change force_irqthreads to a static key (Prarit Bhargava) [2023084]
- genirq: Clarify documentation for request_threaded_irq() (Prarit Bhargava) [2023084]

* Fri Jan 14 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-41.rt21.41.el9]
- redhat: Restore configs in use with RT (Juri Lelli)
- af_unix: Return errno instead of NULL in unix_create1(). (Balazs Nemeth) [2030037]
- s390/ftrace: remove preempt_disable()/preempt_enable() pair (Wander Lairson Costa) [1938117]
- ftrace: do CPU checking after preemption disabled (Wander Lairson Costa) [1938117]
- ftrace: disable preemption when recursion locked (Wander Lairson Costa) [1938117]
- redhat: build and include memfd to kernel-selftests-internal (Aristeu Rozanski) [2027506]
- netfilter: flowtable: fix IPv6 tunnel addr match (Florian Westphal) [2028203]
- netfilter: ipvs: Fix reuse connection if RS weight is 0 (Florian Westphal) [2028203]
- netfilter: ctnetlink: do not erase error code with EINVAL (Florian Westphal) [2028203]
- netfilter: ctnetlink: fix filtering with CTA_TUPLE_REPLY (Florian Westphal) [2028203]
- netfilter: nfnetlink_queue: fix OOB when mac header was cleared (Florian Westphal) [2028203]
- netfilter: core: Fix clang warnings about unused static inlines (Florian Westphal) [2028203]
- netfilter: nft_dynset: relax superfluous check on set updates (Florian Westphal) [2028203]
- netfilter: nf_tables: skip netdev events generated on netns removal (Florian Westphal) [2028203]
- netfilter: Kconfig: use 'default y' instead of 'm' for bool config option (Florian Westphal) [2028203]
- netfilter: xt_IDLETIMER: fix panic that occurs when timer_type has garbage value (Florian Westphal) [2028203]
- netfilter: nf_tables: honor NLM_F_CREATE and NLM_F_EXCL in event notification (Florian Westphal) [2028203]
- netfilter: nf_tables: reverse order in rule replacement expansion (Florian Westphal) [2028203]
- netfilter: nf_tables: add position handle in event notification (Florian Westphal) [2028203]
- netfilter: conntrack: fix boot failure with nf_conntrack.enable_hooks=1 (Florian Westphal) [2028203]
- netfilter: log: work around missing softdep backend module (Florian Westphal) [2028203]
- netfilter: nf_tables: unlink table before deleting it (Florian Westphal) [2028203]
- ipvs: check that ip_vs_conn_tab_bits is between 8 and 20 (Florian Westphal) [2028203]
- netfilter: nft_ct: protect nft_ct_pcpu_template_refcnt with mutex (Florian Westphal) [2028203]
- netfilter: ipvs: make global sysctl readonly in non-init netns (Antoine Tenart) [2008417]
- net/sched: sch_ets: don't remove idle classes from the round-robin list (Davide Caratti) [2025552]
- net/sched: store the last executed chain also for clsact egress (Davide Caratti) [2025552]
- net: sched: act_mirred: drop dst for the direction from egress to ingress (Davide Caratti) [2025552]
- net/sched: sch_ets: don't peek at classes beyond 'nbands' (Davide Caratti) [2025552]
- net/sched: sch_ets: properly init all active DRR list handles (Davide Caratti) [2025552]
- net: Fix offloading indirect devices dependency on qdisc order creation (Davide Caratti) [2025552]
- net/core: Remove unused field from struct flow_indr_dev (Davide Caratti) [2025552]
- net/sched: sch_taprio: fix undefined behavior in ktime_mono_to_any (Davide Caratti) [2025552]
- net/sched: act_ct: Fix byte count on fragmented packets (Davide Caratti) [2025552]
- mqprio: Correct stats in mqprio_dump_class_stats(). (Davide Caratti) [2025552]
- net/sched: sch_taprio: properly cancel timer from taprio_destroy() (Davide Caratti) [2025552]
- net_sched: fix NULL deref in fifo_set_limit() (Davide Caratti) [2025552]
- net: sched: flower: protect fl_walk() with rcu (Davide Caratti) [2025552]
- fq_codel: reject silly quantum parameters (Davide Caratti) [2025552]
- net: sched: Fix qdisc_rate_table refcount leak when get tcf_block failed (Davide Caratti) [2025552]
- sch_htb: Fix inconsistency when leaf qdisc creation fails (Davide Caratti) [2025552]
- redhat/configs: Add two new CONFIGs (Prarit Bhargava) [2022993]
- redhat/configs: Remove dead CONFIG files (Prarit Bhargava) [2022993]
- redhat/configs/evaluate_configs: Add find dead configs option (Prarit Bhargava) [2022993]

* Fri Jan 14 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-40.rt21.40.el9]
- cpu/hotplug: Remove deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- livepatch: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- coresight: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- hwmon: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- tracing: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- padata: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- crypto: virtio - Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- platform/x86: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- powerpc: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/mce/inject: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/microcode: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/mtrr: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- x86/mmiotrace: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- workqueue: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- net/iucv: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- s390/sclp: replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- s390: replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- net: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- virtio_net: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- ACPI: processor: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- PM: sleep: s2idle: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- cpufreq: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- powercap: intel_rapl: Replace deprecated CPU-hotplug functions (Prarit Bhargava) [2023079]
- sgi-xpc: Replace deprecated CPU-hotplug functions. (Prarit Bhargava) [2023079]
- Input: i8042 - Add quirk for Fujitsu Lifebook T725 (Neal Gompa) [2019937]
- sctp: remove unreachable code from sctp_sf_violation_chunk() (Xin Long) [2024909]
- sctp: return true only for pathmtu update in sctp_transport_pl_toobig (Xin Long) [2024909]
- sctp: subtract sctphdr len in sctp_transport_pl_hlen (Xin Long) [2024909]
- sctp: reset probe_timer in sctp_transport_pl_update (Xin Long) [2024909]
- sctp: allow IP fragmentation when PLPMTUD enters Error state (Xin Long) [2024909]
- sctp: fix transport encap_port update in sctp_vtag_verify (Xin Long) [2024909]
- sctp: account stream padding length for reconf chunk (Xin Long) [2024909]
- sctp: break out if skb_header_pointer returns NULL in sctp_rcv_ootb (Xin Long) [2024909]
- sctp: add vtag check in sctp_sf_ootb (Xin Long) [2003494] {CVE-2021-3772}
- sctp: add vtag check in sctp_sf_do_8_5_1_E_sa (Xin Long) [2003494] {CVE-2021-3772}
- sctp: add vtag check in sctp_sf_violation (Xin Long) [2003494] {CVE-2021-3772}
- sctp: fix the processing for COOKIE_ECHO chunk (Xin Long) [2003494] {CVE-2021-3772}
- sctp: fix the processing for INIT_ACK chunk (Xin Long) [2003494] {CVE-2021-3772}
- sctp: fix the processing for INIT chunk (Xin Long) [2003494] {CVE-2021-3772}
- sctp: use init_tag from inithdr for ABORT chunk (Xin Long) [2003494] {CVE-2021-3772}
- drm/nouveau: clean up all clients on device removal (Karol Herbst) [1911185] {CVE-2020-27820}
- drm/nouveau: Add a dedicated mutex for the clients list (Karol Herbst) [1911185] {CVE-2020-27820}
- drm/nouveau: use drm_dev_unplug() during device removal (Karol Herbst) [1911185] {CVE-2020-27820}
- redhat/configs: NFS: disable UDP, insecure enctypes (Benjamin Coddington) [1952863]

* Thu Jan 13 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-39.rt21.39.el9]
- cpuidle: pseries: Do not cap the CEDE0 latency in fixup_cede0_latency() (Gustavo Walbon) [2029870]
- cpuidle: pseries: Fixup CEDE0 latency only for POWER10 onwards (Gustavo Walbon) [2029870]
- powerpc/mce: Fix access error in mce handler (Gustavo Walbon) [2027829]
- powerpc/pseries/mobility: ignore ibm, platform-facilities updates (Gustavo Walbon) [2023438]
- KVM: SVM: Do not terminate SEV-ES guests on GHCB validation failure (Vitaly Kuznetsov) [1961151]
- KVM: SEV: Fall back to vmalloc for SEV-ES scratch area if necessary (Vitaly Kuznetsov) [1961151]
- KVM: SEV: Return appropriate error codes if SEV-ES scratch setup fails (Vitaly Kuznetsov) [1961151]
- KVM: SEV: Refactor out sev_es_state struct (Vitaly Kuznetsov) [1961151]
- redhat/configs: enable DWARF5 feature if toolchain supports it (Lianbo Jiang) [2009205]
- init: make unknown command line param message clearer (Andrew Halaney) [2004361]
- Bluetooth: btusb: Add one more Bluetooth part for WCN6855 (Gopal Tiwari) [2020943]
- Bluetooth: btusb: Add the new support IDs for WCN6855 (Gopal Tiwari) [2020943]
- Bluetooth: btusb: re-definition for board_id in struct qca_version (Gopal Tiwari) [2020943]
- Bluetooth: btusb: Add support using different nvm for variant WCN6855 controller (Gopal Tiwari) [2020943]
- cgroup: Make rebind_subsystems() disable v2 controllers all at once (Waiman Long) [1986734]
- bnxt_en: Event handler for PPS events (Ken Cox) [1990151]
- bnxt_en: 1PPS functions to configure TSIO pins (Ken Cox) [1990151]
- bnxt_en: 1PPS support for 5750X family chips (Ken Cox) [1990151]
- bnxt_en: Do not read the PTP PHC during chip reset (Ken Cox) [1990151]
- bnxt_en: Move bnxt_ptp_init() from bnxt_open() back to bnxt_init_one() (Ken Cox) [1990151]

* Thu Jan 13 2022 Juri Lelli <juri.lelli@redhat.com> [5.14.0-38.rt21.38.el9]
- x86/fpu/signal: Initialize sw_bytes in save_xstate_epilog() (David Arcari) [2004190]
- iommu/vt-d: Remove unused PASID_DISABLED (David Arcari) [2004190]
- Add CONFIG_STRICT_SIGALTSTACK_SIZE (David Arcari) [2004190]
- selftests/x86/amx: Add context switch test (David Arcari) [2004190]
- selftests/x86/amx: Add test cases for AMX state management (David Arcari) [2004190]
- x86/signal: Use fpu::__state_user_size for sigalt stack validation (David Arcari) [2004190]
- x86/signal: Implement sigaltstack size validation (David Arcari) [2004190]
- signal: Add an optional check for altstack size (David Arcari) [2004190]
- tools arch x86: Sync the msr-index.h copy with the kernel sources (David Arcari) [2004190]
- tools headers cpufeatures: Sync with the kernel sources (David Arcari) [2004190]
- tools headers UAPI: Sync arch prctl headers with the kernel sources (David Arcari) [2004190]
- x86/fpu: Optimize out sigframe xfeatures when in init state (David Arcari) [2004190]
- Documentation/x86: Add documentation for using dynamic XSTATE features (David Arcari) [2004190]
- x86/fpu: Include vmalloc.h for vzalloc() (David Arcari) [2004190]
- x86/fpu/amx: Enable the AMX feature in 64-bit mode (David Arcari) [2004190]
- x86/msr-index: Add MSRs for XFD (David Arcari) [2004190]
- x86/cpufeatures: Add eXtended Feature Disabling (XFD) feature bit (David Arcari) [2004190]
- x86/fpu: Add XFD handling for dynamic states (David Arcari) [2004190]
- x86/fpu: Calculate the default sizes independently (David Arcari) [2004190]
- x86/fpu/amx: Define AMX state components and have it used for boot-time checks (David Arcari) [2004190]
- x86/fpu/xstate: Prepare XSAVE feature table for gaps in state component numbers (David Arcari) [2004190]
- x86/fpu/xstate: Add fpstate_realloc()/free() (David Arcari) [2004190]
- x86/fpu/xstate: Add XFD #NM handler (David Arcari) [2004190]
- x86/fpu: Update XFD state where required (David Arcari) [2004190]
- x86/fpu: Add sanity checks for XFD (David Arcari) [2004190]
- x86/fpu: Add XFD state to fpstate (David Arcari) [2004190]
- x86/fpu: Reset permission and fpstate on exec() (David Arcari) [2004190]
- x86/fpu: Prepare fpu_clone() for dynamically enabled features (David Arcari) [2004190]
- x86/process: Clone FPU in copy_thread() (David Arcari) [2004190]
- x86/fpu/signal: Prepare for variable sigframe length (David Arcari) [2004190]
- x86/fpu: Add basic helpers for dynamically enabled features (David Arcari) [2004190]
- x86/arch_prctl: Add controls for dynamic XSTATE components (David Arcari) [2004190]
- x86/fpu: Add fpu_state_config::legacy_features (David Arcari) [2004190]
- x86/fpu: Add members to struct fpu to cache permission information (David Arcari) [2004190]
- x86/fpu/xstate: Provide xstate_calculate_size() (David Arcari) [2004190]
- x86/fpu: Remove old KVM FPU interface (David Arcari) [2004190]
- x86/kvm: Convert FPU handling to a single swap buffer (David Arcari) [2004190]
- x86/fpu: Provide infrastructure for KVM FPU cleanup (David Arcari) [2004190]
- x86/fpu: Prepare for sanitizing KVM FPU code (David Arcari) [2004190]
- x86/fpu/xstate: Move remaining xfeature helpers to core (David Arcari) [2004190]
- x86/fpu: Rework restore_regs_from_fpstate() (David Arcari) [2004190]
- x86/fpu: Mop up xfeatures_mask_uabi() (David Arcari) [2004190]
- x86/fpu: Move xstate feature masks to fpu_*_cfg (David Arcari) [2004190]
- x86/fpu: Move xstate size to fpu_*_cfg (David Arcari) [2004190]
- x86/fpu/xstate: Cleanup size calculations (David Arcari) [2004190]
- x86/fpu: Cleanup fpu__init_system_xstate_size_legacy() (David Arcari) [2004190]
- x86/fpu: Provide struct fpu_config (David Arcari) [2004190]
- x86/fpu/signal: Use fpstate for size and features (David Arcari) [2004190]
- x86/fpu/xstate: Use fpstate for copy_uabi_to_xstate() (David Arcari) [2004190]
- x86/fpu: Use fpstate in __copy_xstate_to_uabi_buf() (David Arcari) [2004190]
- x86/fpu: Use fpstate in fpu_copy_kvm_uabi_to_fpstate() (David Arcari) [2004190]
- x86/fpu/xstate: Use fpstate for xsave_to_user_sigframe() (David Arcari) [2004190]
- x86/fpu/xstate: Use fpstate for os_xsave() (David Arcari) [2004190]
- x86/fpu: Use fpstate::size (David Arcari) [2004190]
- x86/fpu: Add size and mask information to fpstate (David Arcari) [2004190]
- x86/process: Move arch_thread_struct_whitelist() out of line (David Arcari) [2004190]
- x86/fpu: Remove fpu::state (David Arcari) [2004190]
- x86/KVM: Convert to fpstate (David Arcari) [2004190]
- x86/math-emu: Convert to fpstate (David Arcari) [2004190]
- x86/fpu/core: Convert to fpstate (David Arcari) [2004190]
- x86/fpu/signal: Convert to fpstate (David Arcari) [2004190]
- x86/fpu/regset: Convert to fpstate (David Arcari) [2004190]
- x86/fpu: Convert tracing to fpstate (David Arcari) [2004190]
- x86/fpu: Replace KVMs xstate component clearing (David Arcari) [2004190]
- x86/fpu: Convert restore_fpregs_from_fpstate() to struct fpstate (David Arcari) [2004190]
- x86/fpu: Convert fpstate_init() to struct fpstate (David Arcari) [2004190]
- x86/fpu: Provide struct fpstate (David Arcari) [2004190]
- x86/fpu: Replace KVMs home brewed FPU copy to user (David Arcari) [2004190]
- x86/fpu: Provide a proper function for ex_handler_fprestore() (David Arcari) [2004190]
- x86/fpu: Replace the includes of fpu/internal.h (David Arcari) [2004190]
- x86/fpu: Mop up the internal.h leftovers (David Arcari) [2004190]
- x86/fpu: Remove internal.h dependency from fpu/signal.h (David Arcari) [2004190]
- x86/fpu: Move fpstate functions to api.h (David Arcari) [2004190]
- x86/fpu: Move mxcsr related code to core (David Arcari) [2004190]
- x86/sev: Include fpu/xcr.h (David Arcari) [2004190]
- x86/fpu: Move fpregs_restore_userregs() to core (David Arcari) [2004190]
- x86/fpu: Make WARN_ON_FPU() private (David Arcari) [2004190]
- x86/fpu: Move legacy ASM wrappers to core (David Arcari) [2004190]
- x86/fpu: Move os_xsave() and os_xrstor() to core (David Arcari) [2004190]
- x86/fpu: Make os_xrstor_booting() private (David Arcari) [2004190]
- x86/fpu: Clean up CPU feature tests (David Arcari) [2004190]
- x86/fpu: Move context switch and exit to user inlines into sched.h (David Arcari) [2004190]
- x86/fpu: Mark fpu__init_prepare_fx_sw_frame() as __init (David Arcari) [2004190]
- x86/fpu: Rework copy_xstate_to_uabi_buf() (David Arcari) [2004190]
- x86/fpu: Replace KVMs home brewed FPU copy from user (David Arcari) [2004190]
- x86/fpu: Move KVMs FPU swapping to FPU core (David Arcari) [2004190]
- x86/fpu/xstate: Mark all init only functions __init (David Arcari) [2004190]
- x86/fpu/xstate: Provide and use for_each_xfeature() (David Arcari) [2004190]
- x86/fpu: Cleanup xstate xcomp_bv initialization (David Arcari) [2004190]
- x86/fpu: Do not inherit FPU context for kernel and IO worker threads (David Arcari) [2004190]
- x86/fpu: Remove pointless memset in fpu_clone() (David Arcari) [2004190]
- x86/fpu: Cleanup the on_boot_cpu clutter (David Arcari) [2004190]
- x86/fpu: Restrict xsaves()/xrstors() to independent states (David Arcari) [2004190]
- x86/fpu: Update stale comments (David Arcari) [2004190]
- x86/fpu: Remove pointless argument from switch_fpu_finish() (David Arcari) [2004190]
- iommu/vt-d: Clean up unused PASID updating functions (David Arcari) [2004190]
- x86/fpu: Mask out the invalid MXCSR bits properly (David Arcari) [2004190]
- x86/fpu: Restore the masking out of reserved MXCSR bits (David Arcari) [2004190]
- x86/fpu/signal: Fix missed conversion to correct boolean retval in save_xstate_epilog() (David Arcari) [2004190]
- x86/fpu/signal: Change return code of restore_fpregs_from_user() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return code of check_xstate_in_sigframe() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of __fpu_restore_sig() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of fpu__restore_sig() to boolean (David Arcari) [2004190]
- x86/signal: Change return type of restore_sigcontext() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of copy_fpregs_to_sigframe() helpers to boolean (David Arcari) [2004190]
- x86/fpu/signal: Change return type of copy_fpstate_to_sigframe() to boolean (David Arcari) [2004190]
- x86/fpu/signal: Move xstate clearing out of copy_fpregs_to_sigframe() (David Arcari) [2004190]
- x86/fpu/signal: Move header zeroing out of xsave_to_user_sigframe() (David Arcari) [2004190]
- x86/fpu/signal: Clarify exception handling in restore_fpregs_from_user() (David Arcari) [2004190]
- x86/fpu: Use EX_TYPE_FAULT_MCE_SAFE for exception fixups (David Arcari) [2004190]
- x86/extable: Provide EX_TYPE_DEFAULT_MCE_SAFE and EX_TYPE_FAULT_MCE_SAFE (David Arcari) [2004190]
- x86/extable: Rework the exception table mechanics (David Arcari) [2004190]
- x86/mce: Deduplicate exception handling (David Arcari) [2004190]
- x86/extable: Get rid of redundant macros (David Arcari) [2004190]
- x86/extable: Tidy up redundant handler functions (David Arcari) [2004190]

* Thu Jan 13 2022 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [5.14.0-37.rt21.37.el9]
- sched,x86: Don't use cluster topology for x86 hybrid CPUs (Phil Auld) [2020279]
- sched/uclamp: Fix rq->uclamp_max not set on first enqueue (Phil Auld) [2020279]
- preempt/dynamic: Fix setup_preempt_mode() return value (Phil Auld) [2020279]
- sched/cputime: Fix getrusage(RUSAGE_THREAD) with nohz_full (Phil Auld) [2020279 2029640]
- sched/scs: Reset task stack state in bringup_cpu() (Phil Auld) [2020279]
- Enable CONFIG_SCHED_CLUSTER for RHEL (Phil Auld) [2020279]
- arch_topology: Fix missing clear cluster_cpumask in remove_cpu_topology() (Phil Auld) [2020279]
- mm: move node_reclaim_distance to fix NUMA without SMP (Phil Auld) [2020279]
- sched/core: Mitigate race cpus_share_cache()/update_top_cache_domain() (Phil Auld) [2020279]
- sched/fair: Prevent dead task groups from regaining cfs_rq's (Phil Auld) [2020279]
- x86/smp: Factor out parts of native_smp_prepare_cpus() (Phil Auld) [2020279]
- sched,x86: Fix L2 cache mask (Phil Auld) [2020279]
- sched/fair: Cleanup newidle_balance (Phil Auld) [2020279]
- sched/fair: Remove sysctl_sched_migration_cost condition (Phil Auld) [2020279]
- sched/fair: Wait before decaying max_newidle_lb_cost (Phil Auld) [2020279]
- sched/fair: Skip update_blocked_averages if we are defering load balance (Phil Auld) [2020279]
- sched/fair: Account update_blocked_averages in newidle_balance cost (Phil Auld) [2020279]
- sched/core: Remove rq_relock() (Phil Auld) [2020279]
- sched: Improve wake_up_all_idle_cpus() take #2 (Phil Auld) [2020279]
- sched: Disable -Wunused-but-set-variable (Phil Auld) [2020279]
- irq_work: Handle some irq_work in a per-CPU thread on PREEMPT_RT (Phil Auld) [2020279]
- irq_work: Also rcuwait for !IRQ_WORK_HARD_IRQ on PREEMPT_RT (Phil Auld) [2020279]
- irq_work: Allow irq_work_sync() to sleep if irq_work() no IRQ support. (Phil Auld) [2020279]
- sched/rt: Annotate the RT balancing logic irqwork as IRQ_WORK_HARD_IRQ (Phil Auld) [2020279]
- sched: Fix DEBUG && !SCHEDSTATS warn (Phil Auld) [2020279]
- sched/numa: Fix a few comments (Phil Auld) [2020279]
- sched/numa: Remove the redundant member numa_group::fault_cpus (Phil Auld) [2020279]
- sched/numa: Replace hard-coded number by a define in numa_task_group() (Phil Auld) [2020279]
- sched: Remove pointless preemption disable in sched_submit_work() (Phil Auld) [2020279]
- sched: Move mmdrop to RCU on RT (Phil Auld) [2020279]
- sched: Move kprobes cleanup out of finish_task_switch() (Phil Auld) [2020279]
- sched: Disable TTWU_QUEUE on RT (Phil Auld) [2020279]
- sched: Limit the number of task migrations per batch on RT (Phil Auld) [2020279]
- sched/fair: Removed useless update of p->recent_used_cpu (Phil Auld) [2020279]
- sched: Add cluster scheduler level for x86 (Phil Auld) [1921343 2020279]
- x86/cpu: Add get_llc_id() helper function (Phil Auld) [2020279]
- x86/smp: Add a per-cpu view of SMT state (Phil Auld) [2020279]
- sched: Add cluster scheduler level in core and related Kconfig for ARM64 (Phil Auld) [2020279]
- topology: Represent clusters of CPUs within a die (Phil Auld) [2020279]
- topology: use bin_attribute to break the size limitation of cpumap ABI (Phil Auld) [2020279]
- cpumask: Omit terminating null byte in cpumap_print_{list,bitmask}_to_buf (Phil Auld) [2020279]
- cpumask: introduce cpumap_print_list/bitmask_to_buf to support large bitmask and list (Phil Auld) [2020279]
- sched: Make cookie functions static (Phil Auld) [2020279]
- sched,livepatch: Use wake_up_if_idle() (Phil Auld) [2020279]
- sched: Simplify wake_up_*idle*() (Phil Auld) [2020279]
- sched,livepatch: Use task_call_func() (Phil Auld) [2020279]
- sched,rcu: Rework try_invoke_on_locked_down_task() (Phil Auld) [2020279]
- sched: Improve try_invoke_on_locked_down_task() (Phil Auld) [2020279]
- kernel/sched: Fix sched_fork() access an invalid sched_task_group (Phil Auld) [2020279]
- sched/topology: Remove unused numa_distance in cpu_attach_domain() (Phil Auld) [2020279]
- sched: Remove unused inline function __rq_clock_broken() (Phil Auld) [2020279]
- sched/fair: Consider SMT in ASYM_PACKING load balance (Phil Auld) [2020279]
- sched/fair: Carve out logic to mark a group for asymmetric packing (Phil Auld) [2020279]
- sched/fair: Provide update_sg_lb_stats() with sched domain statistics (Phil Auld) [2020279]
- sched/fair: Optimize checking for group_asym_packing (Phil Auld) [2020279]
- sched/topology: Introduce sched_group::flags (Phil Auld) [2020279]
- sched/dl: Support schedstats for deadline sched class (Phil Auld) [2020279]
- sched/dl: Support sched_stat_runtime tracepoint for deadline sched class (Phil Auld) [2020279]
- sched/rt: Support schedstats for RT sched class (Phil Auld) [2020279]
- sched/rt: Support sched_stat_runtime tracepoint for RT sched class (Phil Auld) [2020279]
- sched: Introduce task block time in schedstats (Phil Auld) [2020279]
- sched: Make schedstats helpers independent of fair sched class (Phil Auld) [2020279]
- sched: Make struct sched_statistics independent of fair sched class (Phil Auld) [2020279]
- sched/fair: Use __schedstat_set() in set_next_entity() (Phil Auld) [2020279]
- kselftests/sched: cleanup the child processes (Phil Auld) [2020279]
- sched/fair: Add document for burstable CFS bandwidth (Phil Auld) [2020279]
- sched/fair: Add cfs bandwidth burst statistics (Phil Auld) [2020279]
- fs/proc/uptime.c: Fix idle time reporting in /proc/uptime (Phil Auld) [2020279]
- sched: Switch wait_task_inactive to HRTIMER_MODE_REL_HARD (Phil Auld) [2020279]
- sched/core: Simplify core-wide task selection (Phil Auld) [2020279]
- sched/fair: Trigger nohz.next_balance updates when a CPU goes NOHZ-idle (Phil Auld) [2020279]
- sched/fair: Add NOHZ balancer flag for nohz.next_balance updates (Phil Auld) [2020279]
- sched: adjust sleeper credit for SCHED_IDLE entities (Phil Auld) [2020279]
- sched: reduce sched slice for SCHED_IDLE entities (Phil Auld) [2020279]
- sched: Account number of SCHED_IDLE entities on each cfs_rq (Phil Auld) [2020279]
- wait: use LIST_HEAD_INIT() to initialize wait_queue_head (Phil Auld) [2020279]
- kthread: Move prio/affinite change into the newly created thread (Phil Auld) [2020279]

* Wed Dec 22 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-36.rt21.36.el9]
- drivers: base: cacheinfo: Get rid of DEFINE_SMP_CALL_CACHE_FUNCTION() (Vitaly Kuznetsov) [2031644]
- hugetlbfs: flush TLBs correctly after huge_pmd_unshare (Rafael Aquini) [2026378] {CVE-2021-4002}
- bareudp: Add extack support to bareudp_configure() (Guillaume Nault) [2032483]
- bareudp: Move definition of struct bareudp_conf to bareudp.c (Guillaume Nault) [2032483]
- bareudp: Remove bareudp_dev_create() (Guillaume Nault) [2032483]
- scsi: core: Fix shost->cmd_per_lun calculation in scsi_add_host_with_dma() (Cathy Avery) [2030468]
- net: fix GRO skb truesize update (Paolo Abeni) [2028927]
- sk_buff: avoid potentially clearing 'slow_gro' field (Paolo Abeni) [2028927]
- veth: use skb_prepare_for_gro() (Paolo Abeni) [2028927]
- skbuff: allow 'slow_gro' for skb carring sock reference (Paolo Abeni) [2028927]
- net: optimize GRO for the common case. (Paolo Abeni) [2028927]
- sk_buff: track extension status in slow_gro (Paolo Abeni) [2028927]
- sk_buff: track dst status in slow_gro (Paolo Abeni) [2028927]
- sk_buff: introduce 'slow_gro' flags (Paolo Abeni) [2028927]
- selftests: net: veth: add tests for set_channel (Paolo Abeni) [2028927]
- veth: create by default nr_possible_cpus queues (Paolo Abeni) [2028927]
- veth: implement support for set_channel ethtool op (Paolo Abeni) [2028927]
- veth: factor out initialization helper (Paolo Abeni) [2028927]
- veth: always report zero combined channels (Paolo Abeni) [2028927]
- [kernel] bpf: set default value for bpf_jit_harden (Jiri Olsa) [2028734]
- scsi: ibmvfc: Fix up duplicate response detection (Steve Best) [2028709]
- kabi: Add kABI macros for enum type (Čestmír Kalina) [2024595]
- kabi: expand and clarify documentation of aux structs (Čestmír Kalina) [2024595]
- kabi: introduce RH_KABI_USE_AUX_PTR (Čestmír Kalina) [2024595]
- kabi: rename RH_KABI_SIZE_AND_EXTEND to AUX (Čestmír Kalina) [2024595]
- kabi: more consistent _RH_KABI_SIZE_AND_EXTEND (Čestmír Kalina) [2024595]
- kabi: use fixed field name for extended part (Čestmír Kalina) [2024595]
- kabi: fix dereference in RH_KABI_CHECK_EXT (Čestmír Kalina) [2024595]
- kabi: fix RH_KABI_SET_SIZE macro (Čestmír Kalina) [2024595]
- kabi: expand and clarify documentation (Čestmír Kalina) [2024595]
- kabi: make RH_KABI_USE replace any number of reserved fields (Čestmír Kalina) [2024595]
- kabi: rename RH_KABI_USE2 to RH_KABI_USE_SPLIT (Čestmír Kalina) [2024595]
- kabi: change RH_KABI_REPLACE2 to RH_KABI_REPLACE_SPLIT (Čestmír Kalina) [2024595]
- kabi: change RH_KABI_REPLACE_UNSAFE to RH_KABI_BROKEN_REPLACE (Čestmír Kalina) [2024595]
- kabi: introduce RH_KABI_ADD_MODIFIER (Čestmír Kalina) [2024595]
- kabi: Include kconfig.h (Čestmír Kalina) [2024595]
- kabi: macros for intentional kABI breakage (Čestmír Kalina) [2024595]
- kabi: fix the note about terminating semicolon (Čestmír Kalina) [2024595]
- kabi: introduce RH_KABI_HIDE_INCLUDE and RH_KABI_FAKE_INCLUDE (Čestmír Kalina) [2024595]

* Tue Dec 21 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-35.rt21.35.el9]
- drm/hyperv: Fix device removal on Gen1 VMs (Mohammed Gamal) [2018067]
- wireguard: device: reset peer src endpoint when netns exits (Hangbin Liu) [1967796]
- nvmet: use IOCB_NOWAIT only if the filesystem supports it (Chris Leech) [2022054]
- nvmet-tcp: fix incomplete data digest send (Chris Leech) [2022054]
- nvmet-tcp: fix memory leak when performing a controller reset (Chris Leech) [2022054]
- nvmet-tcp: add an helper to free the cmd buffers (Chris Leech) [2022054]
- nvmet-tcp: fix a race condition between release_queue and io_work (Chris Leech) [2022054]
- nvmet-tcp: fix use-after-free when a port is removed (Chris Leech) [2022054]
- nvmet-rdma: fix use-after-free when a port is removed (Chris Leech) [2022054]
- nvmet: fix use-after-free when a port is removed (Chris Leech) [2022054]
- nvmet-tcp: fix header digest verification (Chris Leech) [2022054]
- nvmet-tcp: fix data digest pointer calculation (Chris Leech) [2022054]
- nvmet-tcp: fix a memory leak when releasing a queue (Chris Leech) [2022054]
- nvmet: fix a width vs precision bug in nvmet_subsys_attr_serial_show() (Chris Leech) [2022054]
- nvmet: fixup buffer overrun in nvmet_subsys_attr_serial() (Chris Leech) [2022054]
- nvmet: return bool from nvmet_passthru_ctrl and nvmet_is_passthru_req (Chris Leech) [2022054]
- nvmet: looks at the passthrough controller when initializing CAP (Chris Leech) [2022054]
- nvmet: check that host sqsize does not exceed ctrl MQES (Chris Leech) [2022054]
- nvmet: avoid duplicate qid in connect cmd (Chris Leech) [2022054]
- nvmet: pass back cntlid on successful completion (Chris Leech) [2022054]
- nvmet: remove redundant assignments of variable status (Chris Leech) [2022054]
- nvme-fabrics: ignore invalid fast_io_fail_tmo values (Chris Leech) [2022054]
- nvme-tcp: fix memory leak when freeing a queue (Chris Leech) [2022054]
- nvme-tcp: validate R2T PDU in nvme_tcp_handle_r2t() (Chris Leech) [2022054]
- nvme-tcp: fix data digest pointer calculation (Chris Leech) [2022054]
- nvme-tcp: fix possible req->offset corruption (Chris Leech) [2022054]
- nvme-tcp: fix H2CData PDU send accounting (again) (Chris Leech) [2022054]
- nvme: fix per-namespace chardev deletion (Chris Leech) [2022054]
- nvme: keep ctrl->namespaces ordered (Chris Leech) [2022054]
- nvme-tcp: fix incorrect h2cdata pdu offset accounting (Chris Leech) [2022054]
- nvme-tcp: fix io_work priority inversion (Chris Leech) [2022054]
- nvme-multipath: fix ANA state updates when a namespace is not present (Chris Leech) [2022054]
- nvme: update keep alive interval when kato is modified (Chris Leech) [2022054]
- nvme-tcp: Do not reset transport on data digest errors (Chris Leech) [2022054]
- nvme-rdma: don't update queue count when failing to set io queues (Chris Leech) [2022054]
- nvme-tcp: don't update queue count when failing to set io queues (Chris Leech) [2022054]
- nvme-tcp: pair send_mutex init with destroy (Chris Leech) [2022054]
- nvme-tcp: don't check blk_mq_tag_to_rq when receiving pdu data (Chris Leech) [2022054]
- ovl: fix missing negative dentry check in ovl_rename() (Miklos Szeredi) [2011181]
- selftests/bpf/xdp_redirect_multi: Limit the tests in netns (Hangbin Liu) [2008895]
- selftests/bpf/xdp_redirect_multi: Give tcpdump a chance to terminate cleanly (Hangbin Liu) [2008895]
- selftests/bpf/xdp_redirect_multi: Use arping to accurate the arp number (Hangbin Liu) [2008895]
- selftests/bpf/xdp_redirect_multi: Put the logs to tmp folder (Hangbin Liu) [2008895]

* Mon Dec 20 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-34.rt21.34.el9]
- Revert "Merge: block: update to v5.16" (Juri Lelli)
- nvdimm/pmem: cleanup the disk if pmem_release_disk() is yet assigned (Ming Lei) [2018403]
- nvdimm/pmem: stop using q_usage_count as external pgmap refcount (Ming Lei) [2018403]
- libnvdimm/pmem: Fix crash triggered when I/O in-flight during unbind (Ming Lei) [2018403]
- nvdimm/pmem: fix creating the dax group (Ming Lei) [2018403]
- md: fix a lock order reversal in md_alloc (Ming Lei) [2018403]
- tools headers UAPI: Sync linux/fs.h with the kernel sources (Ming Lei) [2018403]
- Documentation: raise minimum supported version of GCC to 5.1 (Ming Lei) [2018403]
- loop: Use pr_warn_once() for loop_control_remove() warning (Ming Lei) [2018403]
- zram: only make zram_wb_devops for CONFIG_ZRAM_WRITEBACK (Ming Lei) [2018403]
- block: call rq_qos_done() before ref check in batch completions (Ming Lei) [2018403]
- block: fix parameter not described warning (Ming Lei) [2018403]
- block: avoid to touch unloaded module instance when opening bdev (Ming Lei) [2018403]
- block: Hold invalidate_lock in BLKRESETZONE ioctl (Ming Lei) [2018403]
- block: Hold invalidate_lock in BLKZEROOUT ioctl (Ming Lei) [2018403]
- block: Hold invalidate_lock in BLKDISCARD ioctl (Ming Lei) [2018403]
- blk-mq: don't insert FUA request with data into scheduler queue (Ming Lei) [2018403]
- blk-cgroup: fix missing put device in error path from blkg_conf_pref() (Ming Lei) [2018403]
- block: avoid to quiesce queue in elevator_init_mq (Ming Lei) [2018403]
- Revert "mark pstore-blk as broken" (Ming Lei) [2018403]
- blk-mq: cancel blk-mq dispatch work in both blk_cleanup_queue and disk_release() (Ming Lei) [2018403]
- block: fix missing queue put in error path (Ming Lei) [2018403]
- block: Check ADMIN before NICE for IOPRIO_CLASS_RT (Ming Lei) [2018403]
- blk-mq: fix filesystem I/O request allocation (Ming Lei) [2018403]
- blkcg: Remove extra blkcg_bio_issue_init (Ming Lei) [2018403]
- blk-mq: rename blk_attempt_bio_merge (Ming Lei) [2018403]
- blk-mq: don't grab ->q_usage_counter in blk_mq_sched_bio_merge (Ming Lei) [2018403]
- block: fix kerneldoc for disk_register_independent_access__ranges() (Ming Lei) [2018403]
- block: use enum type for blk_mq_alloc_data->rq_flags (Ming Lei) [2018403]
- bcache: Revert "bcache: use bvec_virt" (Ming Lei) [2018403]
- ataflop: Add missing semicolon to return statement (Ming Lei) [2018403]
- floppy: address add_disk() error handling on probe (Ming Lei) [2018403]
- ataflop: address add_disk() error handling on probe (Ming Lei) [2018403]
- block: update __register_blkdev() probe documentation (Ming Lei) [2018403]
- ataflop: remove ataflop_probe_lock mutex (Ming Lei) [2018403]
- mtd/ubi/block: add error handling support for add_disk() (Ming Lei) [2018403]
- block/sunvdc: add error handling support for add_disk() (Ming Lei) [2018403]
- z2ram: add error handling support for add_disk() (Ming Lei) [2018403]
- loop: Remove duplicate assignments (Ming Lei) [2018403]
- drbd: Fix double free problem in drbd_create_device (Ming Lei) [2018403]
- bcache: fix use-after-free problem in bcache_device_free() (Ming Lei) [2018403]
- zram: replace fsync_bdev with sync_blockdev (Ming Lei) [2018403]
- zram: avoid race between zram_remove and disksize_store (Ming Lei) [2018403]
- zram: don't fail to remove zram during unloading module (Ming Lei) [2018403]
- zram: fix race between zram_reset_device() and disksize_store() (Ming Lei) [2018403]
- nbd: error out if socket index doesn't match in nbd_handle_reply() (Ming Lei) [2018403]
- nbd: Fix hungtask when nbd_config_put (Ming Lei) [2018403]
- nbd: Fix incorrect error handle when first_minor is illegal in nbd_dev_add (Ming Lei) [2018403]
- nbd: fix possible overflow for 'first_minor' in nbd_dev_add() (Ming Lei) [2018403]
- nbd: fix max value for 'first_minor' (Ming Lei) [2018403]
- block/brd: add error handling support for add_disk() (Ming Lei) [2018403]
- ps3vram: add error handling support for add_disk() (Ming Lei) [2018403]
- ps3disk: add error handling support for add_disk() (Ming Lei) [2018403]
- zram: add error handling support for add_disk() (Ming Lei) [2018403]
- nvme: wait until quiesce is done (Ming Lei) [2018403]
- scsi: make sure that request queue queiesce and unquiesce balanced (Ming Lei) [2018403]
- scsi: avoid to quiesce sdev->request_queue two times (Ming Lei) [2018403]
- blk-mq: add one API for waiting until quiesce is done (Ming Lei) [2018403]
- blk-mq: don't free tags if the tag_set is used by other device in queue initialztion (Ming Lei) [2018403]
- block: fix device_add_disk() kobject_create_and_add() error handling (Ming Lei) [2018403]
- block: ensure cached plug request matches the current queue (Ming Lei) [2018403]
- block: move queue enter logic into blk_mq_submit_bio() (Ming Lei) [2018403]
- block: make bio_queue_enter() fast-path available inline (Ming Lei) [2018403]
- block: split request allocation components into helpers (Ming Lei) [2018403]
- block: have plug stored requests hold references to the queue (Ming Lei) [2018403]
- blk-mq: update hctx->nr_active in blk_mq_end_request_batch() (Ming Lei) [2018403]
- blk-mq: add RQF_ELV debug entry (Ming Lei) [2018403]
- blk-mq: only try to run plug merge if request has same queue with incoming bio (Ming Lei) [2018403]
- block: move RQF_ELV setting into allocators (Ming Lei) [2018403]
- dm: don't stop request queue after the dm device is suspended (Ming Lei) [2018403]
- block: replace always false argument with 'false' (Ming Lei) [2018403]
- block: assign correct tag before doing prefetch of request (Ming Lei) [2018403]
- blk-mq: fix redundant check of !e expression (Ming Lei) [2018403]
- block: use new bdev_nr_bytes() helper for blkdev_{read,write}_iter() (Ming Lei) [2018403]
- block: add a loff_t cast to bdev_nr_bytes (Ming Lei) [2018403]
- null_blk: Fix handling of submit_queues and poll_queues attributes (Ming Lei) [2018403]
- block: ataflop: Fix warning comparing pointer to 0 (Ming Lei) [2018403]
- bcache: replace snprintf in show functions with sysfs_emit (Ming Lei) [2018403]
- bcache: move uapi header bcache.h to bcache code directory (Ming Lei) [2018403]
- block: ataflop: more blk-mq refactoring fixes (Ming Lei) [2018403]
- block: remove support for cryptoloop and the xor transfer (Ming Lei) [2018403]
- mtd: add add_disk() error handling (Ming Lei) [2018403]
- rnbd: add error handling support for add_disk() (Ming Lei) [2018403]
- um/drivers/ubd_kern: add error handling support for add_disk() (Ming Lei) [2018403]
- m68k/emu/nfblock: add error handling support for add_disk() (Ming Lei) [2018403]
- xen-blkfront: add error handling support for add_disk() (Ming Lei) [2018403]
- bcache: add error handling support for add_disk() (Ming Lei) [2018403]
- dm: add add_disk() error handling (Ming Lei) [2018403]
- block: aoe: fixup coccinelle warnings (Ming Lei) [2018403]
- bcache: remove bch_crc64_update (Ming Lei) [2018403]
- bcache: use bvec_kmap_local in bch_data_verify (Ming Lei) [2018403]
- bcache: remove the backing_dev_name field from struct cached_dev (Ming Lei) [2018403]
- bcache: remove the cache_dev_name field from struct cache (Ming Lei) [2018403]
- bcache: move calc_cached_dev_sectors to proper place on backing device detach (Ming Lei) [2018403]
- bcache: fix error info in register_bcache() (Ming Lei) [2018403]
- bcache: reserve never used bits from bkey.high (Ming Lei) [2018403]
- md: bcache: Fix spelling of 'acquire' (Ming Lei) [2018403]
- s390/dasd: fix possibly missed path verification (Ming Lei) [2018403]
- s390/dasd: fix missing path conf_data after failed allocation (Ming Lei) [2018403]
- s390/dasd: summarize dasd configuration data in a separate structure (Ming Lei) [2018403]
- s390/dasd: move dasd_eckd_read_fc_security (Ming Lei) [2018403]
- s390/dasd: split up dasd_eckd_read_conf (Ming Lei) [2018403]
- s390/dasd: fix kernel doc comment (Ming Lei) [2018403]
- s390/dasd: handle request magic consistently as unsigned int (Ming Lei) [2018403]
- nbd: Fix use-after-free in pid_show (Ming Lei) [2018403]
- block: ataflop: fix breakage introduced at blk-mq refactoring (Ming Lei) [2018403]
- nbd: fix uaf in nbd_handle_reply() (Ming Lei) [2018403]
- nbd: partition nbd_read_stat() into nbd_read_reply() and nbd_handle_reply() (Ming Lei) [2018403]
- nbd: clean up return value checking of sock_xmit() (Ming Lei) [2018403]
- nbd: don't start request if nbd_queue_rq() failed (Ming Lei) [2018403]
- nbd: check sock index in nbd_read_stat() (Ming Lei) [2018403]
- nbd: make sure request completion won't concurrent (Ming Lei) [2018403]
- nbd: don't handle response without a corresponding request message (Ming Lei) [2018403]
- mtip32xx: Remove redundant 'flush_workqueue()' calls (Ming Lei) [2018403]
- swim3: add missing major.h include (Ming Lei) [2018403]
- sx8: fix an error code in carm_init_one() (Ming Lei) [2018403]
- pf: fix error codes in pf_init_unit() (Ming Lei) [2018403]
- pcd: fix error codes in pcd_init_unit() (Ming Lei) [2018403]
- xtensa/platforms/iss/simdisk: add error handling support for add_disk() (Ming Lei) [2018403]
- block/ataflop: add error handling support for add_disk() (Ming Lei) [2018403]
- block/ataflop: provide a helper for cleanup up an atari disk (Ming Lei) [2018403]
- block/ataflop: add registration bool before calling del_gendisk() (Ming Lei) [2018403]
- block/ataflop: use the blk_cleanup_disk() helper (Ming Lei) [2018403]
- swim: add error handling support for add_disk() (Ming Lei) [2018403]
- swim: add a floppy registration bool which triggers del_gendisk() (Ming Lei) [2018403]
- swim: add helper for disk cleanup (Ming Lei) [2018403]
- swim: simplify using blk_cleanup_disk() on swim_remove() (Ming Lei) [2018403]
- amiflop: add error handling support for add_disk() (Ming Lei) [2018403]
- floppy: add error handling support for add_disk() (Ming Lei) [2018403]
- floppy: fix calling platform_device_unregister() on invalid drives (Ming Lei) [2018403]
- floppy: use blk_cleanup_disk() (Ming Lei) [2018403]
- floppy: fix add_disk() assumption on exit due to new developments (Ming Lei) [2018403]
- block/swim3: add error handling support for add_disk() (Ming Lei) [2018403]
- rbd: add add_disk() error handling (Ming Lei) [2018403]
- cdrom/gdrom: add error handling support for add_disk() (Ming Lei) [2018403]
- pf: add error handling support for add_disk() (Ming Lei) [2018403]
- block/sx8: add error handling support for add_disk() (Ming Lei) [2018403]
- block/rsxx: add error handling support for add_disk() (Ming Lei) [2018403]
- pktcdvd: add error handling support for add_disk() (Ming Lei) [2018403]
- mtip32xx: add error handling support for add_disk() (Ming Lei) [2018403]
- pd: add error handling support for add_disk() (Ming Lei) [2018403]
- pcd: capture errors on cdrom_register() (Ming Lei) [2018403]
- pcd: fix ordering of unregister_cdrom() (Ming Lei) [2018403]
- pcd: add error handling support for add_disk() (Ming Lei) [2018403]
- pd: cleanup initialization (Ming Lei) [2018403]
- pf: cleanup initialization (Ming Lei) [2018403]
- pcd: cleanup initialization (Ming Lei) [2018403]
- pcd: move the identify buffer into pcd_identify (Ming Lei) [2018403]
- n64cart: add error handling support for add_disk() (Ming Lei) [2018403]
- drbd: add error handling support for add_disk() (Ming Lei) [2018403]
- aoe: add error handling support for add_disk() (Ming Lei) [2018403]
- nbd: add error handling support for add_disk() (Ming Lei) [2018403]
- loop: add error handling support for add_disk() (Ming Lei) [2018403]
- null_blk: poll queue support (Ming Lei) [2018403]
- block: simplify the block device syncing code (Ming Lei) [2018403]
- fat: use sync_blockdev_nowait (Ming Lei) [2018403]
- btrfs: use sync_blockdev (Ming Lei) [2018403]
- xen-blkback: use sync_blockdev (Ming Lei) [2018403]
- block: remove __sync_blockdev (Ming Lei) [2018403]
- fs: remove __sync_filesystem (Ming Lei) [2018403]
- cdrom: Remove redundant variable and its assignment (Ming Lei) [2018403]
- cdrom: docs: reformat table in Documentation/userspace-api/ioctl/cdrom.rst (Ming Lei) [2018403]
- drivers/cdrom: improved ioctl for media change detection (Ming Lei) [2018403]
- partitions/ibm: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- partitions/efi: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- block/ioctl: use bdev_nr_sectors and bdev_nr_bytes (Ming Lei) [2018403]
- block: cache inode size in bdev (Ming Lei) [2018403]
- udf: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- reiserfs: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- ntfs: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- jfs: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- ext4: use sb_bdev_nr_blocks (Ming Lei) [2018403]
- block: add a sb_bdev_nr_blocks helper (Ming Lei) [2018403]
- block: use bdev_nr_bytes instead of open coding it in blkdev_fallocate (Ming Lei) [2018403]
- squashfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- reiserfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- pstore/blk: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- nilfs2: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- nfs/blocklayout: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- jfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- hfsplus: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- hfs: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- fat: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- cramfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- btrfs: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- affs: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- fs: simplify init_page_buffers (Ming Lei) [2018403]
- fs: use bdev_nr_bytes instead of open coding it in blkdev_max_block (Ming Lei) [2018403]
- target/iblock: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- nvmet: use bdev_nr_bytes instead of open coding it (Ming Lei) [2018403]
- md: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- dm: use bdev_nr_sectors and bdev_nr_bytes instead of open coding them (Ming Lei) [2018403]
- drbd: use bdev_nr_sectors instead of open coding it (Ming Lei) [2018403]
- bcache: remove bdev_sectors (Ming Lei) [2018403]
- block: add a bdev_nr_bytes helper (Ming Lei) [2018403]
- block: move the SECTOR_SIZE related definitions to blk_types.h (Ming Lei) [2018403]
- blk-mq-debugfs: Show active requests per queue for shared tags (Ming Lei) [2018403]
- block: improve readability of blk_mq_end_request_batch() (Ming Lei) [2018403]
- virtio-blk: Use blk_validate_block_size() to validate block size (Ming Lei) [2018403]
- loop: Use blk_validate_block_size() to validate block size (Ming Lei) [2018403]
- nbd: Use blk_validate_block_size() to validate block size (Ming Lei) [2018403]
- block: Add a helper to validate the block size (Ming Lei) [2018403]
- block: re-flow blk_mq_rq_ctx_init() (Ming Lei) [2018403]
- block: prefetch request to be initialized (Ming Lei) [2018403]
- block: pass in blk_mq_tags to blk_mq_rq_ctx_init() (Ming Lei) [2018403]
- block: add rq_flags to struct blk_mq_alloc_data (Ming Lei) [2018403]
- block: add async version of bio_set_polled (Ming Lei) [2018403]
- block: kill DIO_MULTI_BIO (Ming Lei) [2018403]
- block: kill unused polling bits in __blkdev_direct_IO() (Ming Lei) [2018403]
- block: avoid extra iter advance with async iocb (Ming Lei) [2018403]
- block: Add independent access ranges support (Ming Lei) [2018403]
- blk-mq: don't issue request directly in case that current is to be blocked (Ming Lei) [2018403]
- sbitmap: silence data race warning (Ming Lei) [2018403]
- blk-cgroup: synchronize blkg creation against policy deactivation (Ming Lei) [2018403]
- block: refactor bio_iov_bvec_set() (Ming Lei) [2018403]
- block: add single bio async direct IO helper (Ming Lei) [2018403]
- sched: make task_struct->plug always defined (Ming Lei) [2018403]
- blk-mq-sched: Don't reference queue tagset in blk_mq_sched_tags_teardown() (Ming Lei) [2018403]
- block: fix req_bio_endio append error handling (Ming Lei) [2018403]
- blk-crypto: update inline encryption documentation (Ming Lei) [2018403]
- blk-crypto: rename blk_keyslot_manager to blk_crypto_profile (Ming Lei) [2018403]
- blk-crypto: rename keyslot-manager files to blk-crypto-profile (Ming Lei) [2018403]
- blk-crypto-fallback: properly prefix function and struct names (Ming Lei) [2018403]
- nbd: Use invalidate_disk() helper on disconnect (Ming Lei) [2018403]
- loop: Remove the unnecessary bdev checks and unused bdev variable (Ming Lei) [2018403]
- loop: Use invalidate_disk() helper to invalidate gendisk (Ming Lei) [2018403]
- block: Add invalidate_disk() helper to invalidate the gendisk (Ming Lei) [2018403]
- block: kill extra rcu lock/unlock in queue enter (Ming Lei) [2018403]
- percpu_ref: percpu_ref_tryget_live() version holding RCU (Ming Lei) [2018403]
- block: convert fops.c magic constants to SHIFT_SECTOR (Ming Lei) [2018403]
- block: clean up blk_mq_submit_bio() merging (Ming Lei) [2018403]
- block: optimise boundary blkdev_read_iter's checks (Ming Lei) [2018403]
- fs: bdev: fix conflicting comment from lookup_bdev (Ming Lei) [2018403]
- blk-mq: Fix blk_mq_tagset_busy_iter() for shared tags (Ming Lei) [2018403]
- block: cleanup the flush plug helpers (Ming Lei) [2018403]
- block: optimise blk_flush_plug_list (Ming Lei) [2018403]
- blk-mq: move blk_mq_flush_plug_list to block/blk-mq.h (Ming Lei) [2018403]
- blk-mq: only flush requests from the plug in blk_mq_submit_bio (Ming Lei) [2018403]
- block: remove inaccurate requeue check (Ming Lei) [2018403]
- block: inline a part of bio_release_pages() (Ming Lei) [2018403]
- block: don't bloat enter_queue with percpu_ref (Ming Lei) [2018403]
- block: optimise req_bio_endio() (Ming Lei) [2018403]
- block: convert leftovers to bdev_get_queue (Ming Lei) [2018403]
- block: turn macro helpers into inline functions (Ming Lei) [2018403]
- blk-mq: support concurrent queue quiesce/unquiesce (Ming Lei) [2018403]
- nvme: loop: clear NVME_CTRL_ADMIN_Q_STOPPED after admin queue is reallocated (Ming Lei) [2018403]
- nvme: paring quiesce/unquiesce (Ming Lei) [2018403]
- nvme: prepare for pairing quiescing and unquiescing (Ming Lei) [2018403]
- nvme: apply nvme API to quiesce/unquiesce admin queue (Ming Lei) [2018403]
- nvme: add APIs for stopping/starting admin queue (Ming Lei) [2018403]
- block, bfq: fix UAF problem in bfqg_stats_init() (Ming Lei) [2018403]
- block: inline fast path of driver tag allocation (Ming Lei) [2018403]
- blk-mq: don't handle non-flush requests in blk_insert_flush (Ming Lei) [2018403]
- block: attempt direct issue of plug list (Ming Lei) [2018403]
- block: change plugging to use a singly linked list (Ming Lei) [2018403]
- blk-wbt: prevent NULL pointer dereference in wb_timer_fn (Ming Lei) [2018403]
- block: align blkdev_dio inlined bio to a cacheline (Ming Lei) [2018403]
- block: move blk_mq_tag_to_rq() inline (Ming Lei) [2018403]
- block: get rid of plug list sorting (Ming Lei) [2018403]
- block: return whether or not to unplug through boolean (Ming Lei) [2018403]
- block: don't call blk_status_to_errno in blk_update_request (Ming Lei) [2018403]
- block: move bdev_read_only() into the header (Ming Lei) [2018403]
- block: fix too broad elevator check in blk_mq_free_request() (Ming Lei) [2018403]
- block: add support for blk_mq_end_request_batch() (Ming Lei) [2018403]
- sbitmap: add helper to clear a batch of tags (Ming Lei) [2018403]
- block: add a struct io_comp_batch argument to fops->iopoll() (Ming Lei) [2018403]
- block: provide helpers for rq_list manipulation (Ming Lei) [2018403]
- block: remove some blk_mq_hw_ctx debugfs entries (Ming Lei) [2018403]
- block: remove debugfs blk_mq_ctx dispatched/merged/completed attributes (Ming Lei) [2018403]
- block: cache rq_flags inside blk_mq_rq_ctx_init() (Ming Lei) [2018403]
- block: blk_mq_rq_ctx_init cache ctx/q/hctx (Ming Lei) [2018403]
- block: skip elevator fields init for non-elv queue (Ming Lei) [2018403]
- block: store elevator state in request (Ming Lei) [2018403]
- block: only mark bio as tracked if it really is tracked (Ming Lei) [2018403]
- block: improve layout of struct request (Ming Lei) [2018403]
- block: move update request helpers into blk-mq.c (Ming Lei) [2018403]
- block: remove useless caller argument to print_req_error() (Ming Lei) [2018403]
- block: don't bother iter advancing a fully done bio (Ming Lei) [2018403]
- block: convert the rest of block to bdev_get_queue (Ming Lei) [2018403]
- block: use bdev_get_queue() in blk-core.c (Ming Lei) [2018403]
- block: use bdev_get_queue() in bio.c (Ming Lei) [2018403]
- block: use bdev_get_queue() in bdev.c (Ming Lei) [2018403]
- block: cache request queue in bdev (Ming Lei) [2018403]
- block: handle fast path of bio splitting inline (Ming Lei) [2018403]
- block: use flags instead of bit fields for blkdev_dio (Ming Lei) [2018403]
- block: cache bdev in struct file for raw bdev IO (Ming Lei) [2018403]
- block: don't allow writing to the poll queue attribute (Ming Lei) [2018403]
- block: switch polling to be bio based (Ming Lei) [2018403]
- block: define 'struct bvec_iter' as packed (Ming Lei) [2018403]
- block: use SLAB_TYPESAFE_BY_RCU for the bio slab (Ming Lei) [2018403]
- block: rename REQ_HIPRI to REQ_POLLED (Ming Lei) [2018403]
- io_uring: don't sleep when polling for I/O (Ming Lei) [2018403]
- block: replace the spin argument to blk_iopoll with a flags argument (Ming Lei) [2018403]
- blk-mq: remove blk_qc_t_valid (Ming Lei) [2018403]
- blk-mq: remove blk_qc_t_to_tag and blk_qc_t_is_internal (Ming Lei) [2018403]
- blk-mq: factor out a "classic" poll helper (Ming Lei) [2018403]
- blk-mq: factor out a blk_qc_to_hctx helper (Ming Lei) [2018403]
- io_uring: fix a layering violation in io_iopoll_req_issued (Ming Lei) [2018403]
- block: don't try to poll multi-bio I/Os in __blkdev_direct_IO (Ming Lei) [2018403]
- direct-io: remove blk_poll support (Ming Lei) [2018403]
- block: only check previous entry for plug merge attempt (Ming Lei) [2018403]
- block: move CONFIG_BLOCK guard to top Makefile (Ming Lei) [2018403]
- block: move menu "Partition type" to block/partitions/Kconfig (Ming Lei) [2018403]
- block: simplify Kconfig files (Ming Lei) [2018403]
- block: remove redundant =y from BLK_CGROUP dependency (Ming Lei) [2018403]
- block: improve batched tag allocation (Ming Lei) [2018403]
- sbitmap: add __sbitmap_queue_get_batch() (Ming Lei) [2018403]
- blk-mq: optimise *end_request non-stat path (Ming Lei) [2018403]
- block: mark bio_truncate static (Ming Lei) [2018403]
- block: move bio_get_{first,last}_bvec out of bio.h (Ming Lei) [2018403]
- block: mark __bio_try_merge_page static (Ming Lei) [2018403]
- block: move bio_full out of bio.h (Ming Lei) [2018403]
- block: fold bio_cur_bytes into blk_rq_cur_bytes (Ming Lei) [2018403]
- block: move bio_mergeable out of bio.h (Ming Lei) [2018403]
- block: don't include <linux/ioprio.h> in <linux/bio.h> (Ming Lei) [2018403]
- block: remove BIO_BUG_ON (Ming Lei) [2018403]
- blk-mq: inline hot part of __blk_mq_sched_restart (Ming Lei) [2018403]
- block: inline hot paths of blk_account_io_*() (Ming Lei) [2018403]
- block: merge block_ioctl into blkdev_ioctl (Ming Lei) [2018403]
- block: move the *blkdev_ioctl declarations out of blkdev.h (Ming Lei) [2018403]
- block: unexport blkdev_ioctl (Ming Lei) [2018403]
- block: don't dereference request after flush insertion (Ming Lei) [2018403]
- blk-mq: cleanup blk_mq_submit_bio (Ming Lei) [2018403]
- blk-mq: cleanup and rename __blk_mq_alloc_request (Ming Lei) [2018403]
- block: pre-allocate requests if plug is started and is a batch (Ming Lei) [2018403]
- block: bump max plugged deferred size from 16 to 32 (Ming Lei) [2018403]
- block: inherit request start time from bio for BLK_CGROUP (Ming Lei) [2018403]
- block: move blk-throtl fast path inline (Ming Lei) [2018403]
- blk-mq: Change shared sbitmap naming to shared tags (Ming Lei) [2018403]
- blk-mq: Stop using pointers for blk_mq_tags bitmap tags (Ming Lei) [2018403]
- blk-mq: Use shared tags for shared sbitmap support (Ming Lei) [2018403]
- blk-mq: Refactor and rename blk_mq_free_map_and_{requests->rqs}() (Ming Lei) [2018403]
- blk-mq: Add blk_mq_alloc_map_and_rqs() (Ming Lei) [2018403]
- blk-mq: Add blk_mq_tag_update_sched_shared_sbitmap() (Ming Lei) [2018403]
- blk-mq: Don't clear driver tags own mapping (Ming Lei) [2018403]
- blk-mq: Pass driver tags to blk_mq_clear_rq_mapping() (Ming Lei) [2018403]
- blk-mq-sched: Rename blk_mq_sched_free_{requests -> rqs}() (Ming Lei) [2018403]
- blk-mq-sched: Rename blk_mq_sched_alloc_{tags -> map_and_rqs}() (Ming Lei) [2018403]
- blk-mq: Invert check in blk_mq_update_nr_requests() (Ming Lei) [2018403]
- blk-mq: Relocate shared sbitmap resize in blk_mq_update_nr_requests() (Ming Lei) [2018403]
- block: Rename BLKDEV_MAX_RQ -> BLKDEV_DEFAULT_RQ (Ming Lei) [2018403]
- blk-mq: Change rqs check in blk_mq_free_rqs() (Ming Lei) [2018403]
- block: print the current process in handle_bad_sector (Ming Lei) [2018403]
- block/mq-deadline: Prioritize high-priority requests (Ming Lei) [2018403]
- block/mq-deadline: Stop using per-CPU counters (Ming Lei) [2018403]
- block/mq-deadline: Add an invariant check (Ming Lei) [2018403]
- block/mq-deadline: Improve request accounting further (Ming Lei) [2018403]
- block: move struct request to blk-mq.h (Ming Lei) [2018403]
- block: move integrity handling out of <linux/blkdev.h> (Ming Lei) [2018403]
- block: move a few merge helpers out of <linux/blkdev.h> (Ming Lei) [2018403]
- block: drop unused includes in <linux/genhd.h> (Ming Lei) [2018403]
- block: drop unused includes in <linux/blkdev.h> (Ming Lei) [2018403]
- block: move elevator.h to block/ (Ming Lei) [2018403]
- block: remove the struct blk_queue_ctx forward declaration (Ming Lei) [2018403]
- block: remove the cmd_size field from struct request_queue (Ming Lei) [2018403]
- block: remove the unused blk_queue_state enum (Ming Lei) [2018403]
- block: remove the unused rq_end_sector macro (Ming Lei) [2018403]
- sched: move the <linux/blkdev.h> include out of kernel/sched/sched.h (Ming Lei) [2018403]
- kernel: remove spurious blkdev.h includes (Ming Lei) [2018403]
- arch: remove spurious blkdev.h includes (Ming Lei) [2018403]
- mm: remove spurious blkdev.h includes (Ming Lei) [2018403]
- mm: don't include <linux/blkdev.h> in <linux/backing-dev.h> (Ming Lei) [2018403]
- mm: don't include <linux/blk-cgroup.h> in <linux/backing-dev.h> (Ming Lei) [2018403]
- mm: don't include <linux/blk-cgroup.h> in <linux/writeback.h> (Ming Lei) [2018403]
- block: nbd: add sanity check for first_minor (Ming Lei) [2018403]
- mmc: core: Store pointer to bio_crypt_ctx in mmc_request (Ming Lei) [2018403]
- iomap: simplify iomap_add_to_ioend (Ming Lei) [2018403]
- iomap: simplify iomap_readpage_actor (Ming Lei) [2018403]
- io_uring: don't halt iopoll too early (Ming Lei) [2018403]
- block: Fix partition check for host-aware zoned block devices (Ming Lei) [2018403]
- block: schedule queue restart after BLK_STS_ZONE_RESOURCE (Ming Lei) [2018403]
- block: drain queue after disk is removed from sysfs (Ming Lei) [2018403]
- block: fix incorrect references to disk objects (Ming Lei) [2018403]
- blk-cgroup: blk_cgroup_bio_start() should use irq-safe operations on blkg->iostat_cpu (Ming Lei) [2018403]
- block, bfq: reset last_bfqq_created on group change (Ming Lei) [2018403]
- block: warn when putting the final reference on a registered disk (Ming Lei) [2018403]
- brd: reduce the brd_devices_mutex scope (Ming Lei) [2018403]
- kyber: avoid q->disk dereferences in trace points (Ming Lei) [2018403]
- block: keep q_usage_counter in atomic mode after del_gendisk (Ming Lei) [2018403]
- block: drain file system I/O on del_gendisk (Ming Lei) [2018403]
- block: split bio_queue_enter from blk_queue_enter (Ming Lei) [2018403]
- block: factor out a blk_try_enter_queue helper (Ming Lei) [2018403]
- block: call submit_bio_checks under q_usage_counter (Ming Lei) [2018403]
- block/rnbd-clt-sysfs: fix a couple uninitialized variable bugs (Ming Lei) [2018403]
- block: decode QUEUE_FLAG_HCTX_ACTIVE in debugfs output (Ming Lei) [2018403]
- block: genhd: fix double kfree() in __alloc_disk_node() (Ming Lei) [2018403]
- nbd: use shifts rather than multiplies (Ming Lei) [2018403]
- Revert "block, bfq: honor already-setup queue merges" (Ming Lei) [2018403]
- block: hold ->invalidate_lock in blkdev_fallocate (Ming Lei) [2018403]
- blktrace: Fix uaf in blk_trace access after removing by sysfs (Ming Lei) [2018403]
- block: don't call rq_qos_ops->done_bio if the bio isn't tracked (Ming Lei) [2018403]
- blk-cgroup: fix UAF by grabbing blkcg lock before destroying blkg pd (Ming Lei) [2018403]
- blkcg: fix memory leak in blk_iolatency_init (Ming Lei) [2018403]
- block: flush the integrity workqueue in blk_integrity_unregister (Ming Lei) [2018403]
- block: check if a profile is actually registered in blk_integrity_unregister (Ming Lei) [2018403]
- blk-mq: avoid to iterate over stale request (Ming Lei) [2018403]
- n64cart: fix return value check in n64cart_probe() (Ming Lei) [2018403]
- blk-mq: allow 4x BLK_MAX_REQUEST_COUNT at blk_plug for multiple_queues (Ming Lei) [2018403]
- block: move fs/block_dev.c to block/bdev.c (Ming Lei) [2018403]
- block: split out operations on block special files (Ming Lei) [2018403]
- blk-throttle: fix UAF by deleteing timer in blk_throtl_exit() (Ming Lei) [2018403]
- block: genhd: don't call blkdev_show() with major_names_lock held (Ming Lei) [2018403]
- cdrom: update uniform CD-ROM maintainership in MAINTAINERS file (Ming Lei) [2018403]
- loop: reduce the loop_ctl_mutex scope (Ming Lei) [2018403]
- bio: fix kerneldoc documentation for bio_alloc_kiocb() (Ming Lei) [2018403]
- block, bfq: honor already-setup queue merges (Ming Lei) [2018403]
- block/mq-deadline: Move dd_queued() to fix defined but not used warning (Ming Lei) [2018403]
- bio: improve kerneldoc documentation for bio_alloc_kiocb() (Ming Lei) [2018403]
- block: provide bio_clear_hipri() helper (Ming Lei) [2018403]
- block: use the percpu bio cache in __blkdev_direct_IO (Ming Lei) [2018403]
- io_uring: enable use of bio alloc cache (Ming Lei) [2018403]
- block: clear BIO_PERCPU_CACHE flag if polling isn't supported (Ming Lei) [2018403]
- bio: add allocation cache abstraction (Ming Lei) [2018403]
- fs: add kiocb alloc cache flag (Ming Lei) [2018403]
- bio: optimize initialization of a bio (Ming Lei) [2018403]
- Revert "floppy: reintroduce O_NDELAY fix" (Ming Lei) [2018403]
- nbd: remove nbd->destroy_complete (Ming Lei) [2018403]
- nbd: only return usable devices from nbd_find_unused (Ming Lei) [2018403]
- nbd: set nbd->index before releasing nbd_index_mutex (Ming Lei) [2018403]
- nbd: prevent IDR lookups from finding partially initialized devices (Ming Lei) [2018403]
- nbd: reset NBD to NULL when restarting in nbd_genl_connect (Ming Lei) [2018403]
- nbd: add missing locking to the nbd_dev_add error path (Ming Lei) [2018403]
- params: lift param_set_uint_minmax to common code (Ming Lei) [2018403]
- nbd: reduce the nbd_index_mutex scope (Ming Lei) [2018403]
- nbd: refactor device search and allocation in nbd_genl_connect (Ming Lei) [2018403]
- nbd: return the allocated nbd_device from nbd_dev_add (Ming Lei) [2018403]
- nbd: remove nbd_del_disk (Ming Lei) [2018403]
- nbd: refactor device removal (Ming Lei) [2018403]
- nbd: do del_gendisk() asynchronously for NBD_DESTROY_ON_DISCONNECT (Ming Lei) [2018403]
- nbd: add the check to prevent overflow in __nbd_ioctl() (Ming Lei) [2018403]
- xen-blkfront: Remove redundant assignment to variable err (Ming Lei) [2018403]
- block/rnbd: Use sysfs_emit instead of s*printf function for sysfs show (Ming Lei) [2018403]
- block/rnbd-clt: Use put_cpu_ptr after get_cpu_ptr (Ming Lei) [2018403]
- sg: pass the device name to blk_trace_setup (Ming Lei) [2018403]
- block, bfq: cleanup the repeated declaration (Ming Lei) [2018403]
- blk-crypto: fix check for too-large dun_bytes (Ming Lei) [2018403]
- blk-zoned: allow BLKREPORTZONE without CAP_SYS_ADMIN (Ming Lei) [2018403]
- blk-zoned: allow zone management send operations without CAP_SYS_ADMIN (Ming Lei) [2018403]
- block: mark blkdev_fsync static (Ming Lei) [2018403]
- block: refine the disk_live check in del_gendisk (Ming Lei) [2018403]
- mmc: sdhci-tegra: Enable MMC_CAP2_ALT_GPT_TEGRA (Ming Lei) [2018403]
- mmc: block: Support alternative_gpt_sector() operation (Ming Lei) [2018403]
- partitions/efi: Support non-standard GPT location (Ming Lei) [2018403]
- block: Add alternative_gpt_sector() operation (Ming Lei) [2018403]
- bio: fix page leak bio_add_hw_page failure (Ming Lei) [2018403]
- block: remove CONFIG_DEBUG_BLOCK_EXT_DEVT (Ming Lei) [2018403]
- block: remove a pointless call to MINOR() in device_add_disk (Ming Lei) [2018403]
- null_blk: add error handling support for add_disk() (Ming Lei) [2018403]
- virtio_blk: add error handling support for add_disk() (Ming Lei) [2018403]
- block: add error handling for device_add_disk / add_disk (Ming Lei) [2018403]
- block: return errors from disk_alloc_events (Ming Lei) [2018403]
- block: return errors from blk_integrity_add (Ming Lei) [2018403]
- block: call blk_register_queue earlier in device_add_disk (Ming Lei) [2018403]
- block: call blk_integrity_add earlier in device_add_disk (Ming Lei) [2018403]
- block: create the bdi link earlier in device_add_disk (Ming Lei) [2018403]
- block: call bdev_add later in device_add_disk (Ming Lei) [2018403]
- block: fold register_disk into device_add_disk (Ming Lei) [2018403]
- block: add a sanity check for a live disk in del_gendisk (Ming Lei) [2018403]
- block: add an explicit ->disk backpointer to the request_queue (Ming Lei) [2018403]
- block: hold a request_queue reference for the lifetime of struct gendisk (Ming Lei) [2018403]
- block: pass a request_queue to __blk_alloc_disk (Ming Lei) [2018403]
- block: remove the minors argument to __alloc_disk_node (Ming Lei) [2018403]
- block: remove alloc_disk and alloc_disk_node (Ming Lei) [2018403]
- block: cleanup the lockdep handling in *alloc_disk (Ming Lei) [2018403]
- sg: do not allocate a gendisk (Ming Lei) [2018403]
- st: do not allocate a gendisk (Ming Lei) [2018403]
- nvme: use blk_mq_alloc_disk (Ming Lei) [2018403]
- block: add back the bd_holder_dir reference in bd_link_disk_holder (Ming Lei) [2018403]
- block: fix default IO priority handling (Ming Lei) [2018403]
- block: Introduce IOPRIO_NR_LEVELS (Ming Lei) [2018403]
- block: fix IOPRIO_PRIO_CLASS() and IOPRIO_PRIO_VALUE() macros (Ming Lei) [2018403]
- block: change ioprio_valid() to an inline function (Ming Lei) [2018403]
- block: improve ioprio class description comment (Ming Lei) [2018403]
- block: bfq: fix bfq_set_next_ioprio_data() (Ming Lei) [2018403]
- block: unexport blk_register_queue (Ming Lei) [2018403]
- blk-cgroup: stop using seq_get_buf (Ming Lei) [2018403]
- blk-cgroup: refactor blkcg_print_stat (Ming Lei) [2018403]
- nvme: use bvec_virt (Ming Lei) [2018403]
- dcssblk: use bvec_virt (Ming Lei) [2018403]
- dasd: use bvec_virt (Ming Lei) [2018403]
- ps3vram: use bvec_virt (Ming Lei) [2018403]
- ubd: use bvec_virt (Ming Lei) [2018403]
- sd: use bvec_virt (Ming Lei) [2018403]
- bcache: use bvec_virt (Ming Lei) [2018403]
- virtio_blk: use bvec_virt (Ming Lei) [2018403]
- rbd: use bvec_virt (Ming Lei) [2018403]
- squashfs: use bvec_virt (Ming Lei) [2018403]
- dm-integrity: use bvec_virt (Ming Lei) [2018403]
- dm-ebs: use bvec_virt (Ming Lei) [2018403]
- dm: make EBS depend on !HIGHMEM (Ming Lei) [2018403]
- block: use bvec_virt in bio_integrity_{process,free} (Ming Lei) [2018403]
- bvec: add a bvec_virt helper (Ming Lei) [2018403]
- block: ensure the bdi is freed after inode_detach_wb (Ming Lei) [2018403]
- block: free the extended dev_t minor later (Ming Lei) [2018403]
- blk-throtl: optimize IOPS throttle for large IO scenarios (Ming Lei) [2018403]
- block: pass a gendisk to bdev_resize_partition (Ming Lei) [2018403]
- block: pass a gendisk to bdev_del_partition (Ming Lei) [2018403]
- block: pass a gendisk to bdev_add_partition (Ming Lei) [2018403]
- block: store a gendisk in struct parsed_partitions (Ming Lei) [2018403]
- block: remove GENHD_FL_UP (Ming Lei) [2018403]
- bcache: move the del_gendisk call out of bcache_device_free (Ming Lei) [2018403]
- bcache: add proper error unwinding in bcache_device_init (Ming Lei) [2018403]
- sx8: use the internal state machine to check if del_gendisk needs to be called (Ming Lei) [2018403]
- nvme: replace the GENHD_FL_UP check in nvme_mpath_shutdown_disk (Ming Lei) [2018403]
- nvme: remove the GENHD_FL_UP check in nvme_ns_remove (Ming Lei) [2018403]
- mmc: block: cleanup gendisk creation (Ming Lei) [2018403]
- mmc: block: let device_add_disk create disk attributes (Ming Lei) [2018403]
- block: move some macros to blkdev.h (Ming Lei) [2018403]
- block: return ELEVATOR_DISCARD_MERGE if possible (Ming Lei) [2018403]
- block: remove the bd_bdi in struct block_device (Ming Lei) [2018403]
- block: move the bdi from the request_queue to the gendisk (Ming Lei) [2018403]
- block: add a queue_has_disk helper (Ming Lei) [2018403]
- block: pass a gendisk to blk_queue_update_readahead (Ming Lei) [2018403]
- block: remove support for delayed queue registrations (Ming Lei) [2018403]
- dm: delay registering the gendisk (Ming Lei) [2018403]
- dm: move setting md->type into dm_setup_md_queue (Ming Lei) [2018403]
- dm: cleanup cleanup_mapped_device (Ming Lei) [2018403]
- block: support delayed holder registration (Ming Lei) [2018403]
- block: look up holders by bdev (Ming Lei) [2018403]
- block: remove the extra kobject reference in bd_link_disk_holder (Ming Lei) [2018403]
- block: make the block holder code optional (Ming Lei) [2018403]
- loop: Select I/O scheduler 'none' from inside add_disk() (Ming Lei) [2018403]
- blk-mq: Introduce the BLK_MQ_F_NO_SCHED_BY_DEFAULT flag (Ming Lei) [2018403]
- block: remove blk-mq-sysfs dead code (Ming Lei) [2018403]
- loop: raise media_change event (Ming Lei) [2018403]
- block: add a helper to raise a media changed event (Ming Lei) [2018403]
- block: export diskseq in sysfs (Ming Lei) [2018403]
- block: add ioctl to read the disk sequence number (Ming Lei) [2018403]
- block: export the diskseq in uevents (Ming Lei) [2018403]
- block: add disk sequence number (Ming Lei) [2018403]
- block: remove cmdline-parser.c (Ming Lei) [2018403]
- block: remove disk_name() (Ming Lei) [2018403]
- block: simplify disk name formatting in check_partition (Ming Lei) [2018403]
- block: simplify printing the device names disk_stack_limits (Ming Lei) [2018403]
- block: use the %%pg format specifier in show_partition (Ming Lei) [2018403]
- block: use the %%pg format specifier in printk_all_partitions (Ming Lei) [2018403]
- block: reduce stack usage in diskstats_show (Ming Lei) [2018403]
- block: remove bdput (Ming Lei) [2018403]
- block: remove bdgrab (Ming Lei) [2018403]
- loop: don't grab a reference to the block device (Ming Lei) [2018403]
- block: change the refcounting for partitions (Ming Lei) [2018403]
- block: allocate bd_meta_info later in add_partitions (Ming Lei) [2018403]
- block: unhash the whole device inode earlier (Ming Lei) [2018403]
- block: assert the locking state in delete_partition (Ming Lei) [2018403]
- block: use bvec_kmap_local in bio_integrity_process (Ming Lei) [2018403]
- block: use bvec_kmap_local in t10_pi_type1_{prepare,complete} (Ming Lei) [2018403]
- block: use memcpy_from_bvec in __blk_queue_bounce (Ming Lei) [2018403]
- block: use memcpy_from_bvec in bio_copy_kern_endio_read (Ming Lei) [2018403]
- block: use memcpy_to_bvec in copy_to_high_bio_irq (Ming Lei) [2018403]
- block: rewrite bio_copy_data_iter to use bvec_kmap_local and memcpy_to_bvec (Ming Lei) [2018403]
- block: remove bvec_kmap_irq and bvec_kunmap_irq (Ming Lei) [2018403]
- ps3disk: use memcpy_{from,to}_bvec (Ming Lei) [2018403]
- dm-writecache: use bvec_kmap_local instead of bvec_kmap_irq (Ming Lei) [2018403]
- rbd: use memzero_bvec (Ming Lei) [2018403]
- block: use memzero_page in zero_fill_bio (Ming Lei) [2018403]
- bvec: add memcpy_{from,to}_bvec and memzero_bvec helper (Ming Lei) [2018403]
- bvec: add a bvec_kmap_local helper (Ming Lei) [2018403]
- bvec: fix the include guards for bvec.h (Ming Lei) [2018403]
- MIPS: don't include <linux/genhd.h> in <asm/mach-rc32434/rb.h> (Ming Lei) [2018403]
- ioprio: move user space relevant ioprio bits to UAPI includes (Ming Lei) [2018403]
- Revert "virtio-blk: Add validation for block size in config space" (Ming Lei) [2018403]
- virtio-blk: remove unneeded "likely" statements (Ming Lei) [2018403]
- Revert "blk-mq: avoid to iterate over stale request" (Ming Lei) [2018403]
- Revert "block: return ELEVATOR_DISCARD_MERGE if possible" (Ming Lei) [2018403]

* Fri Dec 17 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-33.rt21.33.el9]
- s390/kexec: handle R_390_PLT32DBL rela in arch_kexec_apply_relocations_add() (Philipp Rudo) [2023155]
- s390/kexec_file: fix error handling when applying relocations (Philipp Rudo) [2023155]
- s390/kexec_file: print some more error messages (Philipp Rudo) [2023155]
- udp: Validate checksum in udp_read_sock() (Xin Long) [2026952]
- net: udp: correct the document for udp_mem (Xin Long) [2026952]
- net: udp6: replace __UDP_INC_STATS() with __UDP6_INC_STATS() (Xin Long) [2026952]
- net: prefer socket bound to interface when not in VRF (Xin Long) [2026952]
- udp6: allow SO_MARK ctrl msg to affect routing (Xin Long) [2026952]
- net: udp: annotate data race around udp_sk(sk)->corkflag (Xin Long) [2026952]
- net/ipv4/udp_tunnel_core.c: remove superfluous header files from udp_tunnel_core.c (Xin Long) [2026952]
- udp_tunnel: Fix udp_tunnel_nic work-queue type (Xin Long) [2026952]
- selftests: add a test case for mirred egress to ingress (Hangbin Liu) [2025461]
- selftests/net: udpgso_bench_rx: fix port argument (Hangbin Liu) [2025461]
- selftests: net: test_vxlan_under_vrf: fix HV connectivity test (Hangbin Liu) [2025461]
- selftests: net: tls: remove unused variable and code (Hangbin Liu) [2025461]
- selftests/net: Fix reuseport_bpf_numa by skipping unavailable nodes (Hangbin Liu) [2025461]
- selftests: net: switch to socat in the GSO GRE test (Hangbin Liu) [2025461]
- selftests: net: properly support IPv6 in GSO GRE test (Hangbin Liu) [2025461]
- kselftests/net: add missed vrf_strict_mode_test.sh test to Makefile (Hangbin Liu) [2025461]
- kselftests/net: add missed setup_loopback.sh/setup_veth.sh to Makefile (Hangbin Liu) [2025461]
- kselftests/net: add missed icmp.sh test to Makefile (Hangbin Liu) [2025461]
- selftests: udp: test for passing SO_MARK as cmsg (Hangbin Liu) [2025461]
- selftests/net: update .gitignore with newly added tests (Hangbin Liu) [2025461]
- selftests: net: bridge: update IGMP/MLD membership interval value (Hangbin Liu) [2025461]
- selftests: lib: forwarding: allow tests to not require mz and jq (Hangbin Liu) [2025461]
- fcnal-test: kill hanging ping/nettest binaries on cleanup (Hangbin Liu) [2025461]
- selftests: net/fcnal: Test --{force,no}-bind-key-ifindex (Hangbin Liu) [2025461]
- selftests: nettest: Add --{force,no}-bind-key-ifindex (Hangbin Liu) [2025461]
- selftests: forwarding: Add IPv6 GRE hierarchical tests (Hangbin Liu) [2025461]
- selftests: forwarding: Add IPv6 GRE flat tests (Hangbin Liu) [2025461]
- testing: selftests: tc_common: Add tc_check_at_least_x_packets() (Hangbin Liu) [2025461]
- testing: selftests: forwarding.config.sample: Add tc flag (Hangbin Liu) [2025461]
- selftests: net: fib_nexthops: Wait before checking reported idle time (Hangbin Liu) [2025461]
- selftest: net: fix typo in altname test (Hangbin Liu) [2025461]
- selftests: add simple GSO GRE test (Hangbin Liu) [2025461]
- selftests/net: allow GRO coalesce test on veth (Hangbin Liu) [2025461]
- selftests/net: Use kselftest skip code for skipped tests (Hangbin Liu) [2025461]
- tools/net: Use bitwise instead of arithmetic operator for flags (Hangbin Liu) [2025461]
- selftests: vrf: Add test for SNAT over VRF (Hangbin Liu) [2025461]
- selftests/net: GRO coalesce test (Hangbin Liu) [2025461]
- selftests/net: remove min gso test in packet_snd (Hangbin Liu) [2025461]
- tipc: fix size validations for the MSG_CRYPTO type (Xin Long) [2020513] {CVE-2021-43267}
- redhat/configs: enable CONFIG_RD_ZSTD for rhel (Tao Liu) [2020132]
- powerpc/security: Use a mutex for interrupt exit code patching (Steve Best) [2019202]
- EDAC/mce_amd: Do not load edac_mce_amd module on guests (Aristeu Rozanski) [2000778]

* Thu Dec 16 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-32.rt21.32.el9]
- Revert "Merge: mm: update generic MM code to upstream v5.15" (Juri Lelli)
- redhat: configs: explicitly unset CONFIG_DAMON (Rafael Aquini) [2023396]
- mm/memory_hotplug: restrict CONFIG_MEMORY_HOTPLUG to 64 bit (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove CONFIG_MEMORY_HOTPLUG_SPARSE (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove CONFIG_X86_64_ACPI_NUMA dependency from CONFIG_MEMORY_HOTPLUG (Rafael Aquini) [2023396]
- memory-hotplug.rst: document the "auto-movable" online policy (Rafael Aquini) [2023396]
- memory-hotplug.rst: fix wrong /sys/module/memory_hotplug/parameters/ path (Rafael Aquini) [2023396]
- memory-hotplug.rst: fix two instances of "movablecore" that should be "movable_node" (Rafael Aquini) [2023396]
- selftest/vm: fix ksm selftest to run with different NUMA topologies (Rafael Aquini) [2023396]
- mm/vmalloc: introduce alloc_pages_bulk_array_mempolicy to accelerate memory allocation (Rafael Aquini) [2023396]
- memcg: unify memcg stat flushing (Rafael Aquini) [2023396]
- memcg: flush stats only if updated (Rafael Aquini) [2023396]
- mm/swapfile: fix an integer overflow in swap_show() (Rafael Aquini) [2023396]
- mm/gup: further simplify __gup_device_huge() (Rafael Aquini) [2023396]
- kasan: test: add memcpy test that avoids out-of-bounds write (Rafael Aquini) [2023396]
- tools/testing/selftests/vm/split_huge_page_test.c: fix application of sizeof to pointer (Rafael Aquini) [2023396]
- mm/damon/core-test: fix wrong expectations for 'damon_split_regions_of()' (Rafael Aquini) [2023396]
- mm: khugepaged: skip huge page collapse for special files (Rafael Aquini) [2023396]
- mm, thp: bail out early in collapse_file for writeback page (Rafael Aquini) [2023396]
- mm/vmalloc: fix numa spreading for large hash tables (Rafael Aquini) [2023396]
- mm/secretmem: avoid letting secretmem_users drop to zero (Rafael Aquini) [2023396]
- mm/oom_kill.c: prevent a race between process_mrelease and exit_mmap (Rafael Aquini) [2023396]
- mm: filemap: check if THP has hwpoisoned subpage for PMD page fault (Rafael Aquini) [2023396]
- mm: hwpoison: remove the unnecessary THP check (Rafael Aquini) [2023396]
- memcg: page_alloc: skip bulk allocator for __GFP_ACCOUNT (Rafael Aquini) [2023396]
- secretmem: Prevent secretmem_users from wrapping to zero (Rafael Aquini) [2023396]
- Revert "mm/secretmem: use refcount_t instead of atomic_t" (Rafael Aquini) [2023396]
- memblock: exclude MEMBLOCK_NOMAP regions from kmemleak (Rafael Aquini) [2023396]
- Revert "memblock: exclude NOMAP regions from kmemleak" (Rafael Aquini) [2023396]
- mm/thp: decrease nr_thps in file's mapping on THP split (Rafael Aquini) [2023396]
- mm/secretmem: fix NULL page->mapping dereference in page_is_secretmem() (Rafael Aquini) [2023396]
- mm, slub: fix incorrect memcg slab count for bulk free (Rafael Aquini) [2023396]
- mm, slub: fix potential use-after-free in slab_debugfs_fops (Rafael Aquini) [2023396]
- mm, slub: fix potential memoryleak in kmem_cache_open() (Rafael Aquini) [2023396]
- mm, slub: fix mismatch between reconstructed freelist depth and cnt (Rafael Aquini) [2023396]
- mm, slub: fix two bugs in slab_debug_trace_open() (Rafael Aquini) [2023396]
- mm/mempolicy: do not allow illegal MPOL_F_NUMA_BALANCING | MPOL_LOCAL in mbind() (Rafael Aquini) [2023396]
- memblock: check memory total_size (Rafael Aquini) [2023396]
- mm/migrate: fix CPUHP state to update node demotion order (Rafael Aquini) [2023396]
- mm/migrate: add CPU hotplug to demotion #ifdef (Rafael Aquini) [2023396]
- mm/migrate: optimize hotplug-time demotion order updates (Rafael Aquini) [2023396]
- userfaultfd: fix a race between writeprotect and exit_mmap() (Rafael Aquini) [2023396]
- mm/userfaultfd: selftests: fix memory corruption with thp enabled (Rafael Aquini) [2023396]
- memblock: exclude NOMAP regions from kmemleak (Rafael Aquini) [2023396]
- misc: fastrpc: Add missing lock before accessing find_vma() (Rafael Aquini) [2023396]
- mm: fix uninitialized use in overcommit_policy_handler (Rafael Aquini) [2023396]
- mm/memory_failure: fix the missing pte_unmap() call (Rafael Aquini) [2023396]
- kasan: always respect CONFIG_KASAN_STACK (Rafael Aquini) [2023396]
- mm/debug: sync up latest migrate_reason to migrate_reason_names (Rafael Aquini) [2023396]
- mm/debug: sync up MR_CONTIG_RANGE and MR_LONGTERM_PIN (Rafael Aquini) [2023396]
- mm: fs: invalidate bh_lrus for only cold path (Rafael Aquini) [2023396]
- mm/shmem.c: fix judgment error in shmem_is_huge() (Rafael Aquini) [2023396]
- mm/damon: don't use strnlen() with known-bogus source length (Rafael Aquini) [2023396]
- kasan: fix Kconfig check of CC_HAS_WORKING_NOSANITIZE_ADDRESS (Rafael Aquini) [2023396]
- mm, hwpoison: add is_free_buddy_page() in HWPoisonHandlable() (Rafael Aquini) [2023396]
- memcg: flush lruvec stats in the refault (Rafael Aquini) [2023396]
- netfilter: nf_tables: Fix oversized kvmalloc() calls (Rafael Aquini) [2023396]
- mm: Fully initialize invalidate_lock, amend lock class later (Rafael Aquini) [2023396]
- tools/bootconfig: Define memblock_free_ptr() to fix build error (Rafael Aquini) [2023396]
- memblock: introduce saner 'memblock_free_ptr()' interface (Rafael Aquini) [2023396]
- bpf: Add oversize check before call kvcalloc() (Rafael Aquini) [2023396]
- netfilter: ipset: Fix oversized kvmalloc() calls (Rafael Aquini) [2023396]
- bpf, mm: Fix lockdep warning triggered by stack_map_get_build_id_offset() (Rafael Aquini) [2023396]
- tools headers UAPI: Sync files changed by new process_mrelease syscall and the removal of some compat entry points (Rafael Aquini) [2023396]
- arm64: kdump: Skip kmemleak scan reserved memory for kdump (Rafael Aquini) [2023396]
- mm/mempolicy: fix a race between offset_il_node and mpol_rebind_task (Rafael Aquini) [2023396]
- mm/kmemleak: allow __GFP_NOLOCKDEP passed to kmemleak's gfp (Rafael Aquini) [2023396]
- mmap_lock: change trace and locking order (Rafael Aquini) [2023396]
- mm/page_alloc.c: avoid accessing uninitialized pcp page migratetype (Rafael Aquini) [2023396]
- mm,vmscan: fix divide by zero in get_scan_count (Rafael Aquini) [2023396]
- mm/hugetlb: initialize hugetlb_usage in mm_init (Rafael Aquini) [2023396]
- mm/hmm: bypass devmap pte when all pfn requested flags are fulfilled (Rafael Aquini) [2023396]
- arch: remove compat_alloc_user_space (Rafael Aquini) [2023396]
- compat: remove some compat entry points (Rafael Aquini) [2023396]
- mm: simplify compat numa syscalls (Rafael Aquini) [2023396]
- mm: simplify compat_sys_move_pages (Rafael Aquini) [2023396]
- kexec: avoid compat_alloc_user_space (Rafael Aquini) [2023396]
- kexec: move locking into do_kexec_load (Rafael Aquini) [2023396]
- mm: migrate: change to use bool type for 'page_was_mapped' (Rafael Aquini) [2023396]
- mm: migrate: fix the incorrect function name in comments (Rafael Aquini) [2023396]
- mm: migrate: introduce a local variable to get the number of pages (Rafael Aquini) [2023396]
- mm/vmstat: protect per cpu variables with preempt disable on RT (Rafael Aquini) [2023396]
- mm/workingset: correct kernel-doc notations (Rafael Aquini) [2023396]
- percpu: remove export of pcpu_base_addr (Rafael Aquini) [2023396]
- MAINTAINERS: update for DAMON (Rafael Aquini) [2023396]
- mm/damon: add user space selftests (Rafael Aquini) [2023396]
- mm/damon: add kunit tests (Rafael Aquini) [2023396]
- Documentation: add documents for DAMON (Rafael Aquini) [2023396]
- mm/damon/dbgfs: support multiple contexts (Rafael Aquini) [2023396]
- mm/damon/dbgfs: export kdamond pid to the user space (Rafael Aquini) [2023396]
- mm/damon: implement a debugfs-based user space interface (Rafael Aquini) [2023396]
- mm/damon: add a tracepoint (Rafael Aquini) [2023396]
- mm/damon: implement primitives for the virtual memory address spaces (Rafael Aquini) [2023396]
- mm/idle_page_tracking: make PG_idle reusable (Rafael Aquini) [2023396]
- mm/damon: adaptively adjust regions (Rafael Aquini) [2023396]
- mm/damon/core: implement region-based sampling (Rafael Aquini) [2023396]
- mm: introduce Data Access MONitor (DAMON) (Rafael Aquini) [2023396]
- kfence: test: fail fast if disabled at boot (Rafael Aquini) [2023396]
- kfence: show cpu and timestamp in alloc/free info (Rafael Aquini) [2023396]
- mm/secretmem: use refcount_t instead of atomic_t (Rafael Aquini) [2023396]
- mm: introduce PAGEFLAGS_MASK to replace ((1UL << NR_PAGEFLAGS) - 1) (Rafael Aquini) [2023396]
- mm: in_irq() cleanup (Rafael Aquini) [2023396]
- highmem: don't disable preemption on RT in kmap_atomic() (Rafael Aquini) [2023396]
- mm/early_ioremap.c: remove redundant early_ioremap_shutdown() (Rafael Aquini) [2023396]
- mm: don't allow executable ioremap mappings (Rafael Aquini) [2023396]
- mm: move ioremap_page_range to vmalloc.c (Rafael Aquini) [2023396]
- mm: remove redundant compound_head() calling (Rafael Aquini) [2023396]
- mm/memory_hotplug: use helper zone_is_zone_device() to simplify the code (Rafael Aquini) [2023396]
- mm/memory_hotplug: improved dynamic memory group aware "auto-movable" online policy (Rafael Aquini) [2023396]
- mm/memory_hotplug: memory group aware "auto-movable" online policy (Rafael Aquini) [2023396]
- virtio-mem: use a single dynamic memory group for a single virtio-mem device (Rafael Aquini) [2023396]
- dax/kmem: use a single static memory group for a single probed unit (Rafael Aquini) [2023396]
- ACPI: memhotplug: use a single static memory group for a single memory device (Rafael Aquini) [2023396]
- mm/memory_hotplug: track present pages in memory groups (Rafael Aquini) [2023396]
- drivers/base/memory: introduce "memory groups" to logically group memory blocks (Rafael Aquini) [2023396]
- mm/memory_hotplug: introduce "auto-movable" online policy (Rafael Aquini) [2023396]
- mm: track present early pages per zone (Rafael Aquini) [2023396]
- ACPI: memhotplug: memory resources cannot be enabled yet (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove nid parameter from remove_memory() and friends (Rafael Aquini) [2023396]
- mm/memory_hotplug: remove nid parameter from arch_remove_memory() (Rafael Aquini) [2023396]
- mm/memory_hotplug: use "unsigned long" for PFN in zone_for_pfn_range() (Rafael Aquini) [2023396]
- mm: memory_hotplug: cleanup after removal of pfn_valid_within() (Rafael Aquini) [2023396]
- mm: remove pfn_valid_within() and CONFIG_HOLES_IN_ZONE (Rafael Aquini) [2023396]
- memory-hotplug.rst: complete admin-guide overhaul (Rafael Aquini) [2023396]
- memory-hotplug.rst: remove locking details from admin-guide (Rafael Aquini) [2023396]
- Revert "memcg: enable accounting for pollfd and select bits arrays" (Rafael Aquini) [2023396]
- Revert "memcg: enable accounting for file lock caches" (Rafael Aquini) [2023396]
- Revert "mm/gup: remove try_get_page(), call try_get_compound_head() directly" (Rafael Aquini) [2023396]
- binfmt: a.out: Fix bogus semicolon (Rafael Aquini) [2023396]
- mm, slub: convert kmem_cpu_slab protection to local_lock (Rafael Aquini) [2023396]
- mm, slub: use migrate_disable() on PREEMPT_RT (Rafael Aquini) [2023396]
- mm, slub: protect put_cpu_partial() with disabled irqs instead of cmpxchg (Rafael Aquini) [2023396]
- mm, slub: make slab_lock() disable irqs with PREEMPT_RT (Rafael Aquini) [2023396]
- mm: slub: make object_map_lock a raw_spinlock_t (Rafael Aquini) [2023396]
- mm: slub: move flush_cpu_slab() invocations __free_slab() invocations out of IRQ context (Rafael Aquini) [2023396]
- mm, slab: split out the cpu offline variant of flush_slab() (Rafael Aquini) [2023396]
- mm, slub: don't disable irqs in slub_cpu_dead() (Rafael Aquini) [2023396]
- mm, slub: only disable irq with spin_lock in __unfreeze_partials() (Rafael Aquini) [2023396]
- mm, slub: separate detaching of partial list in unfreeze_partials() from unfreezing (Rafael Aquini) [2023396]
- mm, slub: detach whole partial list at once in unfreeze_partials() (Rafael Aquini) [2023396]
- mm, slub: discard slabs in unfreeze_partials() without irqs disabled (Rafael Aquini) [2023396]
- mm, slub: move irq control into unfreeze_partials() (Rafael Aquini) [2023396]
- mm, slub: call deactivate_slab() without disabling irqs (Rafael Aquini) [2023396]
- mm, slub: make locking in deactivate_slab() irq-safe (Rafael Aquini) [2023396]
- mm, slub: move reset of c->page and freelist out of deactivate_slab() (Rafael Aquini) [2023396]
- mm, slub: stop disabling irqs around get_partial() (Rafael Aquini) [2023396]
- mm, slub: check new pages with restored irqs (Rafael Aquini) [2023396]
- mm, slub: validate slab from partial list or page allocator before making it cpu slab (Rafael Aquini) [2023396]
- mm, slub: restore irqs around calling new_slab() (Rafael Aquini) [2023396]
- mm, slub: move disabling irqs closer to get_partial() in ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: do initial checks in ___slab_alloc() with irqs enabled (Rafael Aquini) [2023396]
- mm, slub: move disabling/enabling irqs to ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: simplify kmem_cache_cpu and tid setup (Rafael Aquini) [2023396]
- mm, slub: restructure new page checks in ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: return slab page from get_partial() and set c->page afterwards (Rafael Aquini) [2023396]
- mm, slub: dissolve new_slab_objects() into ___slab_alloc() (Rafael Aquini) [2023396]
- mm, slub: extract get_partial() from new_slab_objects() (Rafael Aquini) [2023396]
- mm, slub: remove redundant unfreeze_partials() from put_cpu_partial() (Rafael Aquini) [2023396]
- mm, slub: don't disable irq for debug_check_no_locks_freed() (Rafael Aquini) [2023396]
- mm, slub: allocate private object map for validate_slab_cache() (Rafael Aquini) [2023396]
- mm, slub: allocate private object map for debugfs listings (Rafael Aquini) [2023396]
- mm, slub: don't call flush_all() from slab_debug_trace_open() (Rafael Aquini) [2023396]
- mm/madvise: add MADV_WILLNEED to process_madvise() (Rafael Aquini) [2023396]
- mm/vmstat: remove unneeded return value (Rafael Aquini) [2023396]
- mm/vmstat: simplify the array size calculation (Rafael Aquini) [2023396]
- mm/vmstat: correct some wrong comments (Rafael Aquini) [2023396]
- mm/percpu,c: remove obsolete comments of pcpu_chunk_populated() (Rafael Aquini) [2023396]
- selftests: vm: add COW time test for KSM pages (Rafael Aquini) [2023396]
- selftests: vm: add KSM merging time test (Rafael Aquini) [2023396]
- mm: KSM: fix data type (Rafael Aquini) [2023396]
- selftests: vm: add KSM merging across nodes test (Rafael Aquini) [2023396]
- selftests: vm: add KSM zero page merging test (Rafael Aquini) [2023396]
- selftests: vm: add KSM unmerge test (Rafael Aquini) [2023396]
- selftests: vm: add KSM merge test (Rafael Aquini) [2023396]
- mm/migrate: correct kernel-doc notation (Rafael Aquini) [2023396]
- mm: wire up syscall process_mrelease (Rafael Aquini) [2023396]
- mm: introduce process_mrelease system call (Rafael Aquini) [2023396]
- memblock: make memblock_find_in_range method private (Rafael Aquini) [2023396]
- mm/mempolicy.c: use in_task() in mempolicy_slab_node() (Rafael Aquini) [2023396]
- mm/mempolicy: unify the create() func for bind/interleave/prefer-many policies (Rafael Aquini) [2023396]
- mm/mempolicy: advertise new MPOL_PREFERRED_MANY (Rafael Aquini) [2023396]
- mm/hugetlb: add support for mempolicy MPOL_PREFERRED_MANY (Rafael Aquini) [2023396]
- mm/memplicy: add page allocation function for MPOL_PREFERRED_MANY policy (Rafael Aquini) [2023396]
- mm/mempolicy: add MPOL_PREFERRED_MANY for multiple preferred nodes (Rafael Aquini) [2023396]
- mm/mempolicy: use readable NUMA_NO_NODE macro instead of magic number (Rafael Aquini) [2023396]
- mm: compaction: support triggering of proactive compaction by user (Rafael Aquini) [2023396]
- mm: compaction: optimize proactive compaction deferrals (Rafael Aquini) [2023396]
- mm, vmscan: guarantee drop_slab_node() termination (Rafael Aquini) [2023396]
- mm/vmscan: add 'else' to remove check_pending label (Rafael Aquini) [2023396]
- mm/vmscan: remove unneeded return value of kswapd_run() (Rafael Aquini) [2023396]
- mm/vmscan: remove misleading setting to sc->priority (Rafael Aquini) [2023396]
- mm/vmscan: remove the PageDirty check after MADV_FREE pages are page_ref_freezed (Rafael Aquini) [2023396]
- mm/vmpressure: replace vmpressure_to_css() with vmpressure_to_memcg() (Rafael Aquini) [2023396]
- mm/migrate: add sysfs interface to enable reclaim migration (Rafael Aquini) [2023396]
- mm/vmscan: never demote for memcg reclaim (Rafael Aquini) [2023396]
- mm/vmscan: Consider anonymous pages without swap (Rafael Aquini) [2023396]
- mm/vmscan: add helper for querying ability to age anonymous pages (Rafael Aquini) [2023396]
- mm/vmscan: add page demotion counter (Rafael Aquini) [2023396]
- mm/migrate: demote pages during reclaim (Rafael Aquini) [2023396]
- mm/migrate: enable returning precise migrate_pages() success count (Rafael Aquini) [2023396]
- mm/migrate: update node demotion order on hotplug events (Rafael Aquini) [2023396]
- mm/numa: automatically generate node migration order (Rafael Aquini) [2023396]
- selftests/vm/userfaultfd: wake after copy failure (Rafael Aquini) [2023396]
- userfaultfd: prevent concurrent API initialization (Rafael Aquini) [2023396]
- userfaultfd: change mmap_changing to atomic (Rafael Aquini) [2023396]
- hugetlb: fix hugetlb cgroup refcounting during vma split (Rafael Aquini) [2023396]
- hugetlb: before freeing hugetlb page set dtor to appropriate value (Rafael Aquini) [2023396]
- hugetlb: drop ref count earlier after page allocation (Rafael Aquini) [2023396]
- hugetlb: simplify prep_compound_gigantic_page ref count racing code (Rafael Aquini) [2023396]
- mm: fix panic caused by __page_handle_poison() (Rafael Aquini) [2023396]
- mm: hwpoison: dump page for unhandlable page (Rafael Aquini) [2023396]
- doc: hwpoison: correct the support for hugepage (Rafael Aquini) [2023396]
- mm: hwpoison: don't drop slab caches for offlining non-LRU page (Rafael Aquini) [2023396]
- mm/hwpoison: fix some obsolete comments (Rafael Aquini) [2023396]
- mm/hwpoison: change argument struct page **hpagep to *hpage (Rafael Aquini) [2023396]
- mm/hwpoison: fix potential pte_unmap_unlock pte error (Rafael Aquini) [2023396]
- mm/hwpoison: remove unneeded variable unmap_success (Rafael Aquini) [2023396]
- mm/page_isolation: tracing: trace all test_pages_isolated failures (Rafael Aquini) [2023396]
- mm/page_alloc.c: use in_task() (Rafael Aquini) [2023396]
- mm/page_alloc: make alloc_node_mem_map() __init rather than __ref (Rafael Aquini) [2023396]
- mm/page_alloc.c: fix 'zone_id' may be used uninitialized in this function warning (Rafael Aquini) [2023396]
- memblock: stop poisoning raw allocations (Rafael Aquini) [2023396]
- mm: introduce memmap_alloc() to unify memory map allocation (Rafael Aquini) [2023396]
- mm/page_alloc: always initialize memory map for the holes (Rafael Aquini) [2023396]
- kasan: test: avoid corrupting memory in kasan_rcu_uaf (Rafael Aquini) [2023396]
- kasan: test: avoid corrupting memory in copy_user_test (Rafael Aquini) [2023396]
- kasan: test: clean up ksize_uaf (Rafael Aquini) [2023396]
- kasan: test: only do kmalloc_uaf_memset for generic mode (Rafael Aquini) [2023396]
- kasan: test: disable kmalloc_memmove_invalid_size for HW_TAGS (Rafael Aquini) [2023396]
- kasan: test: avoid corrupting memory via memset (Rafael Aquini) [2023396]
- kasan: test: avoid writing invalid memory (Rafael Aquini) [2023396]
- kasan: test: rework kmalloc_oob_right (Rafael Aquini) [2023396]
- mm/kasan: move kasan.fault to mm/kasan/report.c (Rafael Aquini) [2023396]
- mm/vmalloc: fix wrong behavior in vread (Rafael Aquini) [2023396]
- lib/test_vmalloc.c: add a new 'nr_pages' parameter (Rafael Aquini) [2023396]
- mm/vmalloc: remove gfpflags_allow_blocking() check (Rafael Aquini) [2023396]
- mm/vmalloc: use batched page requests in bulk-allocator (Rafael Aquini) [2023396]
- mm/sparse: clarify pgdat_to_phys (Rafael Aquini) [2023396]
- include/linux/mmzone.h: avoid a warning in sparse memory support (Rafael Aquini) [2023396]
- mm/sparse: set SECTION_NID_SHIFT to 6 (Rafael Aquini) [2023396]
- mm: sparse: remove __section_nr() function (Rafael Aquini) [2023396]
- mm: sparse: pass section_nr to find_memory_block (Rafael Aquini) [2023396]
- mm: sparse: pass section_nr to section_mark_present (Rafael Aquini) [2023396]
- mm/bootmem_info.c: mark __init on register_page_bootmem_info_section (Rafael Aquini) [2023396]
- mm/mremap: fix memory account on do_munmap() failure (Rafael Aquini) [2023396]
- remap_file_pages: Use vma_lookup() instead of find_vma() (Rafael Aquini) [2023396]
- mm/pagemap: add mmap_assert_locked() annotations to find_vma*() (Rafael Aquini) [2023396]
- mm: change fault_in_pages_* to have an unsigned size parameter (Rafael Aquini) [2023396]
- mm,do_huge_pmd_numa_page: remove unnecessary TLB flushing code (Rafael Aquini) [2023396]
- mm: remove flush_kernel_dcache_page (Rafael Aquini) [2023396]
- scatterlist: replace flush_kernel_dcache_page with flush_dcache_page (Rafael Aquini) [2023396]
- mmc: mmc_spi: replace flush_kernel_dcache_page with flush_dcache_page (Rafael Aquini) [2023396]
- mmc: JZ4740: remove the flush_kernel_dcache_page call in jz4740_mmc_read_data (Rafael Aquini) [2023396]
- selftests: Fix spelling mistake "cann't" -> "cannot" (Rafael Aquini) [2023396]
- selftests/vm: use kselftest skip code for skipped tests (Rafael Aquini) [2023396]
- memcg: make memcg->event_list_lock irqsafe (Rafael Aquini) [2023396]
- memcg: fix up drain_local_stock comment (Rafael Aquini) [2023396]
- mm, memcg: save some atomic ops when flush is already true (Rafael Aquini) [2023396]
- mm, memcg: remove unused functions (Rafael Aquini) [2023396]
- mm: memcontrol: set the correct memcg swappiness restriction (Rafael Aquini) [2023396]
- memcg: replace in_interrupt() by !in_task() in active_memcg() (Rafael Aquini) [2023396]
- memcg: cleanup racy sum avoidance code (Rafael Aquini) [2023396]
- memcg: enable accounting for ldt_struct objects (Rafael Aquini) [2023396]
- memcg: enable accounting for posix_timers_cache slab (Rafael Aquini) [2023396]
- memcg: enable accounting for signals (Rafael Aquini) [2023396]
- memcg: enable accounting for new namesapces and struct nsproxy (Rafael Aquini) [2023396]
- memcg: enable accounting for fasync_cache (Rafael Aquini) [2023396]
- memcg: enable accounting for file lock caches (Rafael Aquini) [2023396]
- memcg: enable accounting for pollfd and select bits arrays (Rafael Aquini) [2023396]
- memcg: enable accounting for mnt_cache entries (Rafael Aquini) [2023396]
- memcg: charge fs_context and legacy_fs_context (Rafael Aquini) [2023396]
- memcg: infrastructure to flush memcg stats (Rafael Aquini) [2023396]
- memcg: switch lruvec stats to rstat (Rafael Aquini) [2023396]
- mm, memcg: inline swap-related functions to improve disabled memcg config (Rafael Aquini) [2023396]
- mm, memcg: inline mem_cgroup_{charge/uncharge} to improve disabled memcg config (Rafael Aquini) [2023396]
- mm, memcg: add mem_cgroup_disabled checks in vmpressure and swap-related functions (Rafael Aquini) [2023396]
- huge tmpfs: decide stat.st_blksize by shmem_is_huge() (Rafael Aquini) [2023396]
- huge tmpfs: shmem_is_huge(vma, inode, index) (Rafael Aquini) [2023396]
- huge tmpfs: SGP_NOALLOC to stop collapse_file() on race (Rafael Aquini) [2023396]
- huge tmpfs: move shmem_huge_enabled() upwards (Rafael Aquini) [2023396]
- huge tmpfs: revert shmem's use of transhuge_vma_enabled() (Rafael Aquini) [2023396]
- huge tmpfs: remove shrinklist addition from shmem_setattr() (Rafael Aquini) [2023396]
- huge tmpfs: fix split_huge_page() after FALLOC_FL_KEEP_SIZE (Rafael Aquini) [2023396]
- huge tmpfs: fix fallocate(vanilla) advance over huge pages (Rafael Aquini) [2023396]
- shmem: shmem_writepage() split unlikely i915 THP (Rafael Aquini) [2023396]
- shmem: include header file to declare swap_info (Rafael Aquini) [2023396]
- shmem: remove unneeded function forward declaration (Rafael Aquini) [2023396]
- shmem: remove unneeded header file (Rafael Aquini) [2023396]
- shmem: remove unneeded variable ret (Rafael Aquini) [2023396]
- shmem: use raw_spinlock_t for ->stat_lock (Rafael Aquini) [2023396]
- mm/gup: remove try_get_page(), call try_get_compound_head() directly (Rafael Aquini) [2023396]
- mm/gup: small refactoring: simplify try_grab_page() (Rafael Aquini) [2023396]
- mm/gup: documentation corrections for gup/pup (Rafael Aquini) [2023396]
- mm: gup: use helper PAGE_ALIGNED in populate_vma_page_range() (Rafael Aquini) [2023396]
- mm: gup: fix potential pgmap refcnt leak in __gup_device_huge() (Rafael Aquini) [2023396]
- mm: gup: remove useless BUG_ON in __get_user_pages() (Rafael Aquini) [2023396]
- mm: gup: remove unneed local variable orig_refs (Rafael Aquini) [2023396]
- mm: gup: remove set but unused local variable major (Rafael Aquini) [2023396]
- mm: delete unused get_kernel_page() (Rafael Aquini) [2023396]
- include/linux/buffer_head.h: fix boolreturn.cocci warnings (Rafael Aquini) [2023396]
- fs, mm: fix race in unlinking swapfile (Rafael Aquini) [2023396]
- fs: inode: count invalidated shadow pages in pginodesteal (Rafael Aquini) [2023396]
- fs: drop_caches: fix skipping over shadow cache inodes (Rafael Aquini) [2023396]
- fs: update documentation of get_write_access() and friends (Rafael Aquini) [2023396]
- filesystems/locking: fix Malformed table warning (Rafael Aquini) [2023396]
- writeback: memcg: simplify cgroup_writeback_by_id (Rafael Aquini) [2023396]
- writeback: use READ_ONCE for unlocked reads of writeback stats (Rafael Aquini) [2023396]
- writeback: rename domain_update_bandwidth() (Rafael Aquini) [2023396]
- writeback: fix bandwidth estimate for spiky workload (Rafael Aquini) [2023396]
- writeback: reliably update bandwidth estimation (Rafael Aquini) [2023396]
- writeback: track number of inodes under writeback (Rafael Aquini) [2023396]
- writeback: make the laptop_mode prototypes available unconditionally (Rafael Aquini) [2023396]
- mm: remove irqsave/restore locking from contexts with irqs enabled (Rafael Aquini) [2023396]
- mm: add kernel_misc_reclaimable in show_free_areas (Rafael Aquini) [2023396]
- mm: report a more useful address for reclaim acquisition (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: fix corrupted page flag (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: remove unused code (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PGD and P4D modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PUD modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PMD modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in PTE modifying tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in migration and thp tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in soft_dirty and swap tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in protnone and devmap tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in leaf and savewrite tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: use struct pgtable_debug_args in basic tests (Rafael Aquini) [2023396]
- mm/debug_vm_pgtable: introduce struct pgtable_debug_args (Rafael Aquini) [2023396]
- mm: ignore MAP_DENYWRITE in ksys_mmap_pgoff() (Rafael Aquini) [2023396]
- mm: remove VM_DENYWRITE (Rafael Aquini) [2023396]
- binfmt: remove in-tree usage of MAP_DENYWRITE (Rafael Aquini) [2023396]
- kernel/fork: always deny write access to current MM exe_file (Rafael Aquini) [2023396]
- kernel/fork: factor out replacing the current MM exe_file (Rafael Aquini) [2023396]
- binfmt: don't use MAP_DENYWRITE when loading shared libraries via uselib() (Rafael Aquini) [2023396]
- ARM: 9115/1: mm/maccess: fix unaligned copy_{from,to}_kernel_nofault (Rafael Aquini) [2023396]
- net-memcg: pass in gfp_t mask to mem_cgroup_charge_skmem() (Rafael Aquini) [2023396]
- memblock: Check memory add/cap ordering (Rafael Aquini) [2023396]
- memblock: Add missing debug code to memblock_add_node() (Rafael Aquini) [2023396]
- mm: don't allow oversized kvmalloc() calls (Rafael Aquini) [2023396]
- mm: Add kvrealloc() (Rafael Aquini) [2023396]
- mm: hide laptop_mode_wb_timer entirely behind the BDI API (Rafael Aquini) [2023396]
- mm: Add functions to lock invalidate_lock for two mappings (Rafael Aquini) [2023396]
- mm: Protect operations adding pages to page cache with invalidate_lock (Rafael Aquini) [2023396]
- mm: Fix comments mentioning i_mutex (Rafael Aquini) [2023396]
- exit/bdflush: Remove the deprecated bdflush system call (Rafael Aquini) [2023396]

* Wed Dec 15 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-31.rt21.31.el9]
- Disable CONFIG_DEBUG_PREEMPT to restore performance (Phil Auld) [2030877]
- tcp: seq_file: Avoid skipping sk during tcp_seek_last_pos (Paolo Abeni) [2028279]
- tcp: fix tp->undo_retrans accounting in tcp_sacktag_one() (Paolo Abeni) [2028279]
- tcp: md5: Fix overlap between vrf and non-vrf keys (Paolo Abeni) [2028279]
- tcp: don't free a FIN sk_buff in tcp_remove_empty_skb() (Paolo Abeni) [2028279]
- tcp: Fix uninitialized access in skb frags array for Rx 0cp. (Paolo Abeni) [2028279]
- tcp_cubic: fix spurious Hystart ACK train detections for not-cwnd-limited flows (Paolo Abeni) [2028279]
- Revert "ibmvnic: check failover_pending in login response" (Steve Best) [2010612]
- ibmvnic: check failover_pending in login response (Steve Best) [2010612]
- ibmvnic: check failover_pending in login response (Steve Best) [2010612]
- kernfs: don't create a negative dentry if inactive node exists (Ian Kent) [2004858]
- kernfs: also call kernfs_set_rev() for positive dentry (Ian Kent) [2004858]
- kernfs: dont call d_splice_alias() under kernfs node lock (Ian Kent) [2004858]
- kernfs: use i_lock to protect concurrent inode updates (Ian Kent) [2004858]
- kernfs: switch kernfs to use an rwsem (Ian Kent) [2004858]
- kernfs: use VFS negative dentry caching (Ian Kent) [2004858]
- kernfs: add a revision to identify directory node changes (Ian Kent) [2004858]
- drm/hyperv: Fix double mouse pointers (Vitaly Kuznetsov) [1999697]
- Revert "watchdog: iTCO_wdt: Account for rebooting on second timeout" (Frantisek Sumsal) [2020918]
- watchdog: iTCO_wdt: Fix detection of SMI-off case (Frantisek Sumsal) [2020918]
- redhat/kernel.spec.template: enable dependencies generation (Eugene Syromiatnikov) [1975927]
- redhat: configs: Update configs for vmware (Kamal Heib) [1991676 2009344]
- redhat/configs: Enable CONFIG_DRM_VMWGFX on aarch64 (Michel Dänzer) [1992253]
- mm/memcg: Remove MEMCG config dependency on PREEMPT_RT (Leah Leshchinsky) [2001776]
- mm/memcg: get_obj_stock can be called from hard interrupt context (Leah Leshchinsky) [2001776]
- mm: memcontrol: use the local_lock on all accesses to per-CPU memcg_stock (Leah Leshchinsky) [2001776]
- memcontrol: Add an argument to refill_stock() to indicate locking (Leah Leshchinsky) [2001776]
- mm/memcontrol: Replace local_irq_disable with local locks (Leah Leshchinsky) [2001776]
- mm/memcontrol: Don't call schedule_work_on in preemption disabled context (Leah Leshchinsky) [2001776]
- mm: memcontrol: Provide a local_lock for per-CPU memcg_stock (Leah Leshchinsky) [2001776]
- mm/memcontrol: Disable preemption in __mod_memcg_lruvec_state() (Leah Leshchinsky) [2001776]

* Tue Dec 14 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-30.rt21.30.el9]
- selftests: KVM: avoid failures due to reserved HyperTransport region (Vitaly Kuznetsov) [2009338]
- KVM: X86: Fix when shadow_root_level=5 && guest root_level<4 (Vitaly Kuznetsov) [2009338]
- KVM: x86: inhibit APICv when KVM_GUESTDBG_BLOCKIRQ active (Vitaly Kuznetsov) [2009338]
- KVM: x86/xen: Fix get_attr of KVM_XEN_ATTR_TYPE_SHARED_INFO (Vitaly Kuznetsov) [2009338]
- KVM: x86: Use rw_semaphore for APICv lock to allow vCPU parallelism (Vitaly Kuznetsov) [2009338]
- KVM: selftests: test KVM_GUESTDBG_BLOCKIRQ (Vitaly Kuznetsov) [2009338]
- x86/sgx/virt: implement SGX_IOC_VEPC_REMOVE ioctl (Vitaly Kuznetsov) [2009338]
- x86/sgx/virt: extract sgx_vepc_remove_page (Vitaly Kuznetsov) [2009338]
- KVM: x86: Do not mark all registers as avail/dirty during RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Complete prefetch for trailing SPTEs for direct, legacy MMU (Vitaly Kuznetsov) [2009338]
- KVM: x86: SVM: don't set VMLOAD/VMSAVE intercepts on vCPU reset (Vitaly Kuznetsov) [2009338]
- selftests: kvm: fix mismatched fclose() after popen() (Vitaly Kuznetsov) [2009338]
- KVM: selftests: set CPUID before setting sregs in vcpu creation (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Unregister posted interrupt wakeup handler on hardware unsetup (Vitaly Kuznetsov) [2009338]
- Revert "x86/kvm: fix vcpu-id indexed array sizes" (Vitaly Kuznetsov) [2009338]
- KVM: X86: Cache CR3 in prev_roots when PCID is disabled (Vitaly Kuznetsov) [2009338]
- KVM: X86: Fix tlb flush for tdp in kvm_invalidate_pcid() (Vitaly Kuznetsov) [2009338]
- KVM: X86: Don't reset mmu context when toggling X86_CR4_PGE (Vitaly Kuznetsov) [2009338]
- KVM: X86: Don't reset mmu context when X86_CR4_PCIDE 1->0 (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: kvm_faultin_pfn has to return false if pfh is returned (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Drop a redundant, broken remote TLB flush (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Drop a redundant remote TLB flush in kvm_zap_gfn_range() (Vitaly Kuznetsov) [2009338]
- KVM: x86: Take srcu lock in post_kvm_run_save() (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: fix another issue with string I/O VMGEXITs (Vitaly Kuznetsov) [2009338]
- KVM: x86/xen: Fix kvm_xen_has_interrupt() sleeping in kvm_vcpu_block() (Vitaly Kuznetsov) [2009338]
- KVM: x86: switch pvclock_gtod_sync_lock to a raw spinlock (Vitaly Kuznetsov) [2009338]
- tools headers UAPI: Sync x86's asm/kvm.h with the kernel sources (Vitaly Kuznetsov) [2009338]
- tools headers UAPI: Sync linux/kvm.h with the kernel sources (Vitaly Kuznetsov) [2009338]
- KVM: kvm_stat: do not show halt_wait_ns (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: go over the sev_pio_data buffer in multiple passes if needed (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: keep INS functions together (Vitaly Kuznetsov) [2009338]
- KVM: x86: remove unnecessary arguments from complete_emulator_pio_in (Vitaly Kuznetsov) [2009338]
- KVM: x86: split the two parts of emulator_pio_in (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: clean up kvm_sev_es_ins/outs (Vitaly Kuznetsov) [2009338]
- KVM: x86: leave vcpu->arch.pio.count alone in emulator_pio_in_out (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: rename guest_ins_data to sev_pio_data (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Flush cache on non-coherent systems before RECEIVE_UPDATE_DATA (Vitaly Kuznetsov) [2009338]
- KVM: MMU: Reset mmu->pkru_mask to avoid stale data (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: promptly process interrupts delivered while in guest mode (Vitaly Kuznetsov) [2009338]
- KVM: x86: check for interrupts before deciding whether to exit the fast path (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: reduce ghcb_sa_len to 32 bits (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove redundant handling of bus lock vmexit (Vitaly Kuznetsov) [2009338]
- KVM: x86: WARN if APIC HW/SW disable static keys are non-zero on unload (Vitaly Kuznetsov) [2009338]
- Revert "KVM: x86: Open code necessary bits of kvm_lapic_set_base() at vCPU RESET" (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: Set guest_state_protected after VMSA update (Vitaly Kuznetsov) [2009338]
- KVM: X86: fix lazy allocation of rmaps (Vitaly Kuznetsov) [2009338]
- KVM: SEV-ES: fix length of string I/O (Vitaly Kuznetsov) [2009338]
- kvm: fix objtool relocation warning (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Ensure all migrations are performed when test is affined (Vitaly Kuznetsov) [2009338]
- KVM: x86: Swap order of CPUID entry "index" vs. "significant flag" checks (Vitaly Kuznetsov) [2009338]
- x86/kvmclock: Move this_cpu_pvti into kvmclock.h (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Don't clobber XMM register when read (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Fix a TSX_CTRL_CPUID_CLEAR field mask issue (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Explicitly use movq to read xmm registers (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Call ucall_init when setting up in rseq_test (Vitaly Kuznetsov) [2009338]
- KVM: Remove tlbs_dirty (Vitaly Kuznetsov) [2009338]
- KVM: X86: Synchronize the shadow pagetable before link it (Vitaly Kuznetsov) [2009338]
- KVM: X86: Fix missed remote tlb flush in rmap_write_protect() (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: don't copy virt_ext from vmcb12 (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: test eax for 4K alignment for GP errata workaround (Vitaly Kuznetsov) [2009338]
- KVM: x86: selftests: test simultaneous uses of V_IRQ from L1 and L0 (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: restore int_vector in svm_clear_vintr (Vitaly Kuznetsov) [2009338]
- kvm: x86: Add AMD PMU MSRs to msrs_to_save_all[] (Vitaly Kuznetsov) [2009338]
- KVM: x86: nVMX: re-evaluate emulation_required on nested VM exit (Vitaly Kuznetsov) [2009338]
- KVM: x86: nVMX: don't fail nested VM entry on invalid guest state if !from_vmentry (Vitaly Kuznetsov) [2009338]
- KVM: x86: VMX: synthesize invalid VM exit when emulating invalid guest state (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: refactor svm_leave_smm and smm_enter_smm (Vitaly Kuznetsov) [2009338]
- KVM: x86: SVM: call KVM_REQ_GET_NESTED_STATE_PAGES on exit from SMM mode (Vitaly Kuznetsov) [2009338]
- KVM: x86: reset pdptrs_from_userspace when exiting smm (Vitaly Kuznetsov) [2009338]
- KVM: x86: nSVM: restore the L1 host state prior to resuming nested guest on SMM exit (Vitaly Kuznetsov) [2009338]
- KVM: KVM: Use cpumask_available() to check for NULL cpumask when kicking vCPUs (Vitaly Kuznetsov) [2009338]
- KVM: Clean up benign vcpu->cpu data races when kicking vCPUs (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Create a separate dirty bitmap per slot (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Refactor help message for -s backing_src (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Change backing_src flag to -s in demand_paging_test (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Allow some commands for mirror VM (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Update svm_vm_copy_asid_from for SEV-ES (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Fix nested bus lock VM exit (Vitaly Kuznetsov) [2009338]
- KVM: x86: Identify vCPU0 by its vcpu_idx instead of its vCPUs array entry (Vitaly Kuznetsov) [2009338]
- KVM: x86: Query vcpu->vcpu_idx directly and drop its accessor (Vitaly Kuznetsov) [2009338]
- kvm: fix wrong exception emulation in check_rdtsc (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Pin guest memory for write for RECEIVE_UPDATE_DATA (Vitaly Kuznetsov) [2009338]
- KVM: SVM: fix missing sev_decommission in sev_receive_start (Vitaly Kuznetsov) [2009338]
- KVM: SEV: Acquire vcpu mutex when updating VMSA (Vitaly Kuznetsov) [2009338]
- KVM: do not shrink halt_poll_ns below grow_start (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: fix comments of handle_vmon() (Vitaly Kuznetsov) [2009338]
- KVM: x86: Handle SRCU initialization failure during page track init (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove defunct "nr_active_uret_msrs" field (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Align SMCCC call with the spec in steal_time (Vitaly Kuznetsov) [2009338]
- selftests: KVM: Fix check for !POLLIN in demand_paging_test (Vitaly Kuznetsov) [2009338]
- KVM: x86: Clear KVM's cached guest CR3 at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: Mark all registers as avail/dirty at vCPU creation (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Add a test for KVM_RUN+rseq to detect task migration bugs (Vitaly Kuznetsov) [2009338]
- tools: Move x86 syscall number fallbacks to .../uapi/ (Vitaly Kuznetsov) [2009338]
- KVM: rseq: Update rseq when processing NOTIFY_RESUME on xfer to KVM guest (Vitaly Kuznetsov) [2009338]
- selftests: kvm: fix get_run_delay() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009338]
- selftests: kvm: move get_run_delay() into lib/test_util (Vitaly Kuznetsov) [2009338]
- selftests:kvm: fix get_trans_hugepagesz() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009338]
- selftests:kvm: fix get_warnings_count() ignoring fscanf() return warn (Vitaly Kuznetsov) [2009338]
- tools: rename bitmap_alloc() to bitmap_zalloc() (Vitaly Kuznetsov) [2009338]
- KVM: Drop unused kvm_dirty_gfn_invalid() (Vitaly Kuznetsov) [2009338]
- KVM: x86: Update vCPU's hv_clock before back to guest when tsc_offset is adjusted (Vitaly Kuznetsov) [2009338]
- KVM: MMU: mark role_regs and role accessors as maybe unused (Vitaly Kuznetsov) [2009338]
- x86/kvm: Don't enable IRQ when IRQ enabled in kvm_wait (Vitaly Kuznetsov) [2009338]
- KVM: stats: Add VM stat for remote tlb flush requests (Vitaly Kuznetsov) [2009338]
- KVM: Remove unnecessary export of kvm_{inc,dec}_notifier_count() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Move lpage_disallowed_link further "down" in kvm_mmu_page (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Relocate kvm_mmu_page.tdp_mmu_page for better cache locality (Vitaly Kuznetsov) [2009338]
- Revert "KVM: x86: mmu: Add guest physical address check in translate_gpa()" (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Remove unused field mmio_cached in struct kvm_mmu_page (Vitaly Kuznetsov) [2009338]
- kvm: x86: Increase KVM_SOFT_MAX_VCPUS to 710 (Vitaly Kuznetsov) [2009338]
- kvm: x86: Increase MAX_VCPUS to 1024 (Vitaly Kuznetsov) [2009338]
- kvm: x86: Set KVM_MAX_VCPU_ID to 4*KVM_MAX_VCPUS (Vitaly Kuznetsov) [2009338]
- KVM: VMX: avoid running vmx_handle_exit_irqoff in case of emulation (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Don't freak out if pml5_root is NULL on 4-level host (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Add 5-level page table support for SVM (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Support shadowing NPT when 5-level paging is enabled in host (Vitaly Kuznetsov) [2009338]
- KVM: x86: Allow CPU to force vendor-specific TDP level (Vitaly Kuznetsov) [2009338]
- KVM: x86: clamp host mapping level to max_level in kvm_mmu_max_mapping_level (Vitaly Kuznetsov) [2009338]
- KVM: x86: implement KVM_GUESTDBG_BLOCKIRQ (Vitaly Kuznetsov) [2009338]
- KVM: SVM: split svm_handle_invalid_exit (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Drop 'shared' param from tdp_mmu_link_page() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Add detailed page size stats (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Avoid collision with !PRESENT SPTEs in TDP MMU lpage stats (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Remove redundant spte present check in mmu_set_spte (Vitaly Kuznetsov) [2009338]
- KVM: stats: Add halt polling related histogram stats (Vitaly Kuznetsov) [2009338]
- KVM: stats: Add halt_wait_ns stats for all architectures (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Add checks for histogram stats bucket_size field (Vitaly Kuznetsov) [2009338]
- KVM: stats: Update doc for histogram statistics (Vitaly Kuznetsov) [2009338]
- KVM: stats: Support linear and logarithmic histogram statistics (Vitaly Kuznetsov) [2009338]
- KVM: SVM: AVIC: drop unsupported AVIC base relocation code (Vitaly Kuznetsov) [2009338]
- KVM: SVM: call avic_vcpu_load/avic_vcpu_put when enabling/disabling AVIC (Vitaly Kuznetsov) [2009338]
- KVM: SVM: move check for kvm_vcpu_apicv_active outside of avic_vcpu_{put|load} (Vitaly Kuznetsov) [2009338]
- KVM: SVM: avoid refreshing avic if its state didn't change (Vitaly Kuznetsov) [2009338]
- KVM: SVM: remove svm_toggle_avic_for_irq_window (Vitaly Kuznetsov) [2009338]
- KVM: x86: hyper-v: Deactivate APICv only when AutoEOI feature is in use (Vitaly Kuznetsov) [2009338]
- KVM: SVM: add warning for mistmatch between AVIC vcpu state and AVIC inhibition (Vitaly Kuznetsov) [2009338]
- KVM: x86: APICv: fix race in kvm_request_apicv_update on SVM (Vitaly Kuznetsov) [2009338]
- KVM: x86: don't disable APICv memslot when inhibited (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: allow APICv memslot to be enabled but invisible (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: allow kvm_faultin_pfn to return page fault handling code (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: rename try_async_pf to kvm_faultin_pfn (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: bump mmu notifier count in kvm_zap_gfn_range (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: add comment explaining arguments to kvm_zap_gfn_range (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: fix parameters to kvm_flush_remote_tlbs_with_address (Vitaly Kuznetsov) [2009338]
- Revert "KVM: x86/mmu: Allow zap gfn range to operate under the mmu read lock" (Vitaly Kuznetsov) [2009338]
- KVM: X86: Introduce mmu_rmaps_stat per-vm debugfs file (Vitaly Kuznetsov) [2009338]
- KVM: X86: Introduce kvm_mmu_slot_lpages() helpers (Vitaly Kuznetsov) [2009338]
- KVM: Allow to have arch-specific per-vm debugfs files (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Unconditionally clear nested.pi_pending on nested VM-Enter (Vitaly Kuznetsov) [2009338]
- KVM: x86: Clean up redundant ROL16(val, n) macro definition (Vitaly Kuznetsov) [2009338]
- KVM: x86: Move declaration of kvm_spurious_fault() to x86.h (Vitaly Kuznetsov) [2009338]
- KVM: x86: Kill off __ex() and __kvm_handle_fault_on_reboot() (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Hide VMCS control calculators in vmx.c (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Drop caching of KVM's desired sec exec controls for vmcs01 (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Pull KVM L0's desired controls directly from vmcs01 (Vitaly Kuznetsov) [2009338]
- KVM: stats: remove dead stores (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Reset DR6 only when KVM_DEBUGREG_WONT_EXIT (Vitaly Kuznetsov) [2009338]
- KVM: X86: Set host DR6 only on VMX and for KVM_DEBUGREG_WONT_EXIT (Vitaly Kuznetsov) [2009338]
- KVM: X86: Remove unneeded KVM_DEBUGREG_RELOAD (Vitaly Kuznetsov) [2009338]
- x86: Fix typo s/ECLR/ELCR/ for the PIC register (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Move vcpu_args_set into perf_test_util (Vitaly Kuznetsov) [2009338]
- KVM: selftests: Support multiple slots in dirty_log_perf_test (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Rename __gfn_to_rmap to gfn_to_rmap (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Leverage vcpu->last_used_slot for rmap_add and rmap_recycle (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Leverage vcpu->last_used_slot in tdp_mmu_map_handle_target_level (Vitaly Kuznetsov) [2009338]
- KVM: Cache the last used slot index per vCPU (Vitaly Kuznetsov) [2009338]
- KVM: Move last_used_slot logic out of search_memslots (Vitaly Kuznetsov) [2009338]
- KVM: xen: do not use struct gfn_to_hva_cache (Vitaly Kuznetsov) [2009338]
- KVM: x86/pmu: Introduce pmc->is_paused to reduce the call time of perf interfaces (Vitaly Kuznetsov) [2009338]
- KVM: X86: Optimize zapping rmap (Vitaly Kuznetsov) [2009338]
- KVM: X86: Optimize pte_list_desc with per-array counter (Vitaly Kuznetsov) [2009338]
- KVM: X86: MMU: Tune PTE_LIST_EXT to be bigger (Vitaly Kuznetsov) [2009338]
- KVM: const-ify all relevant uses of struct kvm_memory_slot (Vitaly Kuznetsov) [2009338]
- KVM: Don't take mmu_lock for range invalidation unless necessary (Vitaly Kuznetsov) [2009338]
- KVM: Block memslot updates across range_start() and range_end() (Vitaly Kuznetsov) [2009338]
- KVM: nSVM: remove useless kvm_clear_*_queue (Vitaly Kuznetsov) [2009338]
- KVM: x86: Preserve guest's CR0.CD/NW on INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Drop redundant clearing of vcpu->arch.hflags at INIT/RESET (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Emulate #INIT in response to triple fault shutdown (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Move RESET-only VMWRITE sequences to init_vmcs() (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove redundant write to set vCPU as active at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Smush x2APIC MSR bitmap adjustments into single function (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove unnecessary initialization of msr_bitmap_mode (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Don't redo x2APIC MSR bitmaps when userspace filter is changed (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Remove obsolete MSR bitmap refresh at nested transitions (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove obsolete MSR bitmap refresh at vCPU RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: Move setting of sregs during vCPU RESET/INIT to common x86 (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Don't _explicitly_ reconfigure user return MSRs on vCPU INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Refresh list of user return MSRs after setting guest CPUID (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Skip pointless MSR bitmap update when setting EFER (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Stuff save->dr6 at during VMSA sync, not at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Drop redundant writes to vmcb->save.cr4 at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Tweak order of cr0/cr4/efer writes at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Don't evaluate "emulation required" on nested VM-Exit (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Skip emulation required checks during pmode/rmode transitions (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Process CR0.PG side effects after setting CR0 assets (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Skip the permission_fault() check on MMIO if CR0.PG=0 (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Pull GUEST_CR3 from the VMCS iff CR3 load exiting is disabled (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Do not clear CR3 load/store exiting bits if L1 wants 'em (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Fold ept_update_paging_mode_cr0() back into vmx_set_cr0() (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove direct write to vcpu->arch.cr0 during vCPU RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Invert handling of CR0.WP for EPT without unrestricted guest (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Don't bother writing vmcb->save.rip at vCPU RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: Move EDX initialization at vCPU RESET to common code (Vitaly Kuznetsov) [2009338]
- KVM: x86: Consolidate APIC base RESET initialization code (Vitaly Kuznetsov) [2009338]
- KVM: x86: Open code necessary bits of kvm_lapic_set_base() at vCPU RESET (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Stuff vcpu->arch.apic_base directly at vCPU RESET (Vitaly Kuznetsov) [2009338]
- KVM: x86: Set BSP bit in reset BSP vCPU's APIC base by default (Vitaly Kuznetsov) [2009338]
- KVM: x86: Don't force set BSP bit when local APIC is managed by userspace (Vitaly Kuznetsov) [2009338]
- KVM: x86: Migrate the PIT only if vcpu0 is migrated, not any BSP (Vitaly Kuznetsov) [2009338]
- KVM: x86: Remove defunct BSP "update" in local APIC reset (Vitaly Kuznetsov) [2009338]
- KVM: x86: WARN if the APIC map is dirty without an in-kernel local APIC (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Drop explicit MMU reset at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Remove explicit MMU reset in enter_rmode() (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Fall back to KVM's hardcoded value for EDX at RESET/INIT (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Require exact CPUID.0x1 match when stuffing EDX at INIT (Vitaly Kuznetsov) [2009338]
- KVM: VMX: Set EDX at INIT with CPUID.0x1, Family-Model-Stepping (Vitaly Kuznetsov) [2009338]
- KVM: SVM: Zero out GDTR.base and IDTR.base on INIT (Vitaly Kuznetsov) [2009338]
- KVM: nVMX: Set LDTR to its architecturally defined value on nested VM-Exit (Vitaly Kuznetsov) [2009338]
- KVM: x86: Flush the guest's TLB on INIT (Vitaly Kuznetsov) [2009338]
- KVM: x86: APICv: drop immediate APICv disablement on current vCPU (Vitaly Kuznetsov) [2009338]
- KVM: x86: enable TDP MMU by default (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: fast_page_fault support for the TDP MMU (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Make walk_shadow_page_lockless_{begin,end} interoperate with the TDP MMU (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Fix use of enums in trace_fast_page_fault (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Rename cr2_or_gpa to gpa in fast_page_fault (Vitaly Kuznetsov) [2009338]
- KVM: Introduce kvm_get_kvm_safe() (Vitaly Kuznetsov) [2009338]
- x86/kvm: remove non-x86 stuff from arch/x86/kvm/ioapic.h (Vitaly Kuznetsov) [2009338]
- KVM: X86: Add per-vm stat for max rmap list size (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Return old SPTE from mmu_spte_clear_track_bits() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Refactor shadow walk in __direct_map() to reduce indentation (Vitaly Kuznetsov) [2009338]
- KVM: x86: Hoist kvm_dirty_regs check out of sync_regs() (Vitaly Kuznetsov) [2009338]
- KVM: x86/mmu: Mark VM as bugged if page fault returns RET_PF_INVALID (Vitaly Kuznetsov) [2009338]
- KVM: x86: Use KVM_BUG/KVM_BUG_ON to handle bugs that are fatal to the VM (Vitaly Kuznetsov) [2009338]
- KVM: Export kvm_make_all_cpus_request() for use in marking VMs as bugged (Vitaly Kuznetsov) [2009338]
- KVM: Add infrastructure and macro to mark VM as bugged (Vitaly Kuznetsov) [2009338]
- KVM: Get rid of kvm_get_pfn() (Vitaly Kuznetsov) [2009338]
- KVM: arm64: Use get_page() instead of kvm_get_pfn() (Vitaly Kuznetsov) [2009338]
- docs: kvm: properly format code blocks and lists (Vitaly Kuznetsov) [2009338]
- docs: kvm: fix build warnings (Vitaly Kuznetsov) [2009338]

* Fri Dec 10 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-29.rt21.29.el9]
- posix-cpu-timers: Prevent spuriously armed 0-value itimer (Phil Auld) [2022896]
- hrtimer: Unbreak hrtimer_force_reprogram() (Phil Auld) [2022896]
- hrtimer: Use raw_cpu_ptr() in clock_was_set() (Phil Auld) [2022896]
- clocksource: Make clocksource watchdog test safe for slow-HZ systems (Phil Auld) [2022896]
- posix-cpu-timers: Recalc next expiration when timer_settime() ends up not queueing (Phil Auld) [2022896]
- posix-cpu-timers: Consolidate timer base accessor (Phil Auld) [2022896]
- posix-cpu-timers: Remove confusing return value override (Phil Auld) [2022896]
- posix-cpu-timers: Force next expiration recalc after itimer reset (Phil Auld) [2022896]
- posix-cpu-timers: Force next_expiration recalc after timer deletion (Phil Auld) [2022896]
- posix-cpu-timers: Assert task sighand is locked while starting cputime counter (Phil Auld) [2022896]
- posix-timers: Remove redundant initialization of variable ret (Phil Auld) [2022896]
- hrtimer: Avoid more SMP function calls in clock_was_set() (Phil Auld) [2022896]
- hrtimer: Avoid unnecessary SMP function calls in clock_was_set() (Phil Auld) [2022896]
- hrtimer: Add bases argument to clock_was_set() (Phil Auld) [2022896]
- time/timekeeping: Avoid invoking clock_was_set() twice (Phil Auld) [2022896]
- timekeeping: Distangle resume and clock-was-set events (Phil Auld) [2022896]
- timerfd: Provide timerfd_resume() (Phil Auld) [2022896]
- hrtimer: Force clock_was_set() handling for the HIGHRES=n, NOHZ=y case (Phil Auld) [2022896]
- hrtimer: Ensure timerfd notification for HIGHRES=n (Phil Auld) [2022896]
- hrtimer: Consolidate reprogramming code (Phil Auld) [2022896]
- hrtimer: Avoid double reprogramming in __hrtimer_start_range_ns() (Phil Auld) [2022896]

* Thu Dec 09 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-28.rt21.28.el9]
- rcu/tree: Protect rcu_rdp_is_offloaded() invocations on RT (Thomas Gleixner)
- rcu: Fix rcu_dynticks_curr_cpu_in_eqs() vs noinstr (Waiman Long) [2022806]
- efi: Change down_interruptible() in virt_efi_reset_system() to down_trylock() (Waiman Long) [2022806]
- Documentation: core-api/cpuhotplug: Rewrite the API section (Waiman Long) [2022806]
- docs/core-api: Modify document layout (Waiman Long) [2022806]
- futex: Avoid redundant task lookup (Waiman Long) [2022806]
- futex: Clarify comment for requeue_pi_wake_futex() (Waiman Long) [2022806]
- cgroup: Avoid compiler warnings with no subsystems (Waiman Long) [2022806]
- media/atomisp: Use lockdep instead of *mutex_is_locked() (Waiman Long) [2022806]
- debugobjects: Make them PREEMPT_RT aware (Waiman Long) [2022806]
- cgroup/cpuset: Enable event notification when partition state changes (Waiman Long) [2022806]
- cgroup: cgroup-v1: clean up kernel-doc notation (Waiman Long) [2022806]
- locking/semaphore: Add might_sleep() to down_*() family (Waiman Long) [2022806]
- static_call: Update API documentation (Waiman Long) [2022806]
- torture: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- clocksource: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- smpboot: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- rcu: Replace deprecated CPU-hotplug functions (Waiman Long) [2022806]
- genirq/affinity: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- cgroup: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- mm: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- thermal: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- md/raid5: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- perf/hw_breakpoint: Replace deprecated CPU-hotplug functions (Waiman Long) [2022806]
- perf/x86/intel: Replace deprecated CPU-hotplug functions (Waiman Long) [2022806]
- Documentation: Replace deprecated CPU-hotplug functions. (Waiman Long) [2022806]
- Documentation/atomic_t: Document forward progress expectations (Waiman Long) [2022806]
- eventfd: Make signal recursion protection a task bit (Waiman Long) [2022806]
- locking/atomic: simplify non-atomic wrappers (Waiman Long) [2022806]
- cgroup/cpuset: Fix violation of cpuset locking rule (Waiman Long) [2022806]
- cgroup/cpuset: Fix a partition bug with hotplug (Waiman Long) [2022806]
- cgroup/cpuset: Miscellaneous code cleanup (Waiman Long) [2022806]
- rcu: Mark accesses to rcu_state.n_force_qs (Waiman Long) [2022806]
- rcu: Print human-readable message for schedule() in RCU reader (Waiman Long) [2022806]
- cgroup: remove cgroup_mount from comments (Waiman Long) [2022806]
- doc: Update stallwarn.rst with recent changes (Waiman Long) [2022806]
- locking/atomic: add generic arch_*() bitops (Waiman Long) [2022806]
- locking/atomic: add arch_atomic_long*() (Waiman Long) [2022806]
- locking/atomic: centralize generated headers (Waiman Long) [2022806]
- locking/atomic: remove ARCH_ATOMIC remanants (Waiman Long) [2022806]
- locking/atomic: simplify ifdef generation (Waiman Long) [2022806]
- rcu: Fix macro name CONFIG_TASKS_RCU_TRACE (Waiman Long) [2022806]
- scftorture: Avoid NULL pointer exception on early exit (Waiman Long) [2022806]
- torture: Make kvm-test-1-run-qemu.sh check for reboot loops (Waiman Long) [2022806]
- torture: Add timestamps to kvm-test-1-run-qemu.sh output (Waiman Long) [2022806]
- torture: Don't use "test" command's "-a" argument (Waiman Long) [2022806]
- torture: Make kvm-test-1-run-batch.sh select per-scenario affinity masks (Waiman Long) [2022806]
- torture: Consistently name "qemu*" test output files (Waiman Long) [2022806]
- torture: Use numeric taskset argument in jitter.sh (Waiman Long) [2022806]
- rcutorture: Upgrade two-CPU scenarios to four CPUs (Waiman Long) [2022806]
- torture: Make kvm-test-1-run-qemu.sh apply affinity (Waiman Long) [2022806]
- torture: Don't redirect qemu-cmd comment lines (Waiman Long) [2022806]
- torture: Make kvm.sh select per-scenario affinity masks (Waiman Long) [2022806]
- torture: Put kvm.sh batch-creation awk script into a temp file (Waiman Long) [2022806]
- locking/rwsem: Remove an unused parameter of rwsem_wake() (Waiman Long) [2022806]
- rcu: Explain why rcu_all_qs() is a stub in preemptible TREE RCU (Waiman Long) [2022806]
- Documentation/atomic_t: Document cmpxchg() vs try_cmpxchg() (Waiman Long) [2022806]
- rcu: Use per_cpu_ptr to get the pointer of per_cpu variable (Waiman Long) [2022806]
- rcu: Remove useless "ret" update in rcu_gp_fqs_loop() (Waiman Long) [2022806]
- scftorture: Add RPC-like IPI tests (Waiman Long) [2022806]
- tools/nolibc: Implement msleep() (Waiman Long) [2022806]
- tools: include: nolibc: Fix a typo occured to occurred in the file nolibc.h (Waiman Long) [2022806]
- torture: Move parse-console.sh call to PATH-aware scripts (Waiman Long) [2022806]
- torture: Make kvm-recheck.sh skip kcsan.sum for build-only runs (Waiman Long) [2022806]
- rcu-tasks: Fix synchronize_rcu_rude() typo in comment (Waiman Long) [2022806]
- rcuscale: Console output claims too few grace periods (Waiman Long) [2022806]
- torture: Protect kvm-remote.sh directory trees from /tmp reaping (Waiman Long) [2022806]
- torture: Log more kvm-remote.sh information (Waiman Long) [2022806]
- torture: Make kvm-recheck-lock.sh tolerate qemu-cmd comments (Waiman Long) [2022806]
- torture: Make kvm-recheck-scf.sh tolerate qemu-cmd comments (Waiman Long) [2022806]
- rcu/doc: Add a quick quiz to explain further why we need smp_mb__after_unlock_lock() (Waiman Long) [2022806]
- rcu: Make rcu_gp_init() and rcu_gp_fqs_loop noinline to conserve stack (Waiman Long) [2022806]
- torture: Create KCSAN summaries for torture.sh runs (Waiman Long) [2022806]
- torture: Enable KCSAN summaries over groups of torture-test runs (Waiman Long) [2022806]
- rcu: Mark lockless ->qsmask read in rcu_check_boost_fail() (Waiman Long) [2022806]
- srcutiny: Mark read-side data races (Waiman Long) [2022806]
- locktorture: Count lock readers (Waiman Long) [2022806]
- locktorture: Mark statistics data races (Waiman Long) [2022806]
- docs: Fix a typo in Documentation/RCU/stallwarn.rst (Waiman Long) [2022806]
- rcu-tasks: Mark ->trc_reader_special.b.need_qs data races (Waiman Long) [2022806]
- rcu-tasks: Mark ->trc_reader_nesting data races (Waiman Long) [2022806]
- rcu-tasks: Add comments explaining task_struct strategy (Waiman Long) [2022806]
- rcu: Start timing stall repetitions after warning complete (Waiman Long) [2022806]
- rcu: Do not disable GP stall detection in rcu_cpu_stall_reset() (Waiman Long) [2022806]
- rcu/tree: Handle VM stoppage in stall detection (Waiman Long) [2022806]
- rculist: Unify documentation about missing list_empty_rcu() (Waiman Long) [2022806]
- rcu: Mark accesses in tree_stall.h (Waiman Long) [2022806]
- Documentation/RCU: Fix nested inline markup (Waiman Long) [2022806]
- rcu: Mark accesses to ->rcu_read_lock_nesting (Waiman Long) [2022806]
- Documentation/RCU: Fix emphasis markers (Waiman Long) [2022806]
- rcu: Weaken ->dynticks accesses and updates (Waiman Long) [2022806]
- rcu: Remove special bit at the bottom of the ->dynticks counter (Waiman Long) [2022806]
- rcu/nocb: Remove NOCB deferred wakeup from rcutree_dead_cpu() (Waiman Long) [2022806]
- rcu/nocb: Start moving nocb code to its own plugin file (Waiman Long) [2022806]
- rcutorture: Preempt rather than block when testing task stalls (Waiman Long) [2022806]
- rcu: Fix stall-warning deadlock due to non-release of rcu_node ->lock (Waiman Long) [2022806]
- rcu: Fix to include first blocked task in stall warning (Waiman Long) [2022806]
- torture: Make torture.sh accept --do-all and --donone (Waiman Long) [2022806]
- torture: Add clocksource-watchdog testing to torture.sh (Waiman Long) [2022806]
- refscale: Add measurement of clock readout (Waiman Long) [2022806]

* Wed Dec 08 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-27.rt21.27.el9]
- x86: change default to spec_store_bypass_disable=prctl spectre_v2_user=prctl (Wander Lairson Costa) [2002637]
- Enable PREEMPT_DYNAMIC for all but s390x (Phil Auld) [2019472]
- preempt: Restore preemption model selection configs (Phil Auld) [2019472]
- sched: Provide Kconfig support for default dynamic preempt mode (Phil Auld) [2019472]
- x86/sgx: Add TAINT_TECH_PREVIEW for virtual EPC (Wander Lairson Costa) [2025959]
- x86/sgx: mark tech preview (Wander Lairson Costa) [2025959]
- ipv6: When forwarding count rx stats on the orig netdev (Hangbin Liu) [2025457]
- ipv6: make exception cache less predictible (Hangbin Liu) [2025457]
- icmp: fix icmp_ext_echo_iio parsing in icmp_build_probe (Guillaume Nault) [2024572]
- net: prefer socket bound to interface when not in VRF (Guillaume Nault) [2024572]
- net: ipv4: Fix rtnexthop len when RTA_FLOW is present (Guillaume Nault) [2024572]
- nexthop: Fix memory leaks in nexthop notification chain listeners (Guillaume Nault) [2024572]
- nexthop: Fix division by zero while replacing a resilient group (Guillaume Nault) [2024572]
- ipv4: fix endianness issue in inet_rtm_getroute_build_skb() (Guillaume Nault) [2024572]
- crypto: ccp - Make use of the helper macro kthread_run() (Vladis Dronov) [1997595]
- crypto: ccp - Fix whitespace in sev_cmd_buffer_len() (Vladis Dronov) [1997595]
- crypto: ccp - fix resource leaks in ccp_run_aes_gcm_cmd() (Vladis Dronov) [1997595] {CVE-2021-3744 CVE-2021-3764}
- net/l2tp: Fix reference count leak in l2tp_udp_recv_core (Guillaume Nault) [2023271]
- scsi: megaraid: Clean up some inconsistent indenting (Tomas Henzl) [1879402]
- scsi: megaraid: Fix Coccinelle warning (Tomas Henzl) [1879402]
- scsi: megaraid_sas: Driver version update to 07.719.03.00-rc1 (Tomas Henzl) [1879402]
- scsi: megaraid_sas: Add helper functions for irq_context (Tomas Henzl) [1879402]
- scsi: megaraid_sas: Fix concurrent access to ISR between IRQ polling and real interrupt (Tomas Henzl) [1879402]
- tpm: ibmvtpm: Avoid error message when process gets signal while waiting (Štěpán Horáček) [1983089]
- char: tpm: cr50_i2c: convert to new probe interface (Štěpán Horáček) [1983089]
- char: tpm: Kconfig: remove bad i2c cr50 select (Štěpán Horáček) [1983089]
- redhat: Fix rpminspect spec filename test for RT (Juri Lelli)

* Tue Dec 07 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-26.rt21.26.el9]
- redhat/configs: enable CONFIG_CEPH_FSCACHE (Jeffrey Layton) [2017798]
- ceph: add a new metric to keep track of remote object copies (Jeffrey Layton) [2017798]
- libceph, ceph: move ceph_osdc_copy_from() into cephfs code (Jeffrey Layton) [2017798]
- ceph: clean-up metrics data structures to reduce code duplication (Jeffrey Layton) [2017798]
- ceph: split 'metric' debugfs file into several files (Jeffrey Layton) [2017798]
- ceph: return the real size read when it hits EOF (Jeffrey Layton) [2017798]
- ceph: properly handle statfs on multifs setups (Jeffrey Layton) [2017798]
- ceph: shut down mount on bad mdsmap or fsmap decode (Jeffrey Layton) [2017798]
- ceph: fix mdsmap decode when there are MDS's beyond max_mds (Jeffrey Layton) [2017798]
- ceph: ignore the truncate when size won't change with Fx caps issued (Jeffrey Layton) [2017798]
- ceph: don't rely on error_string to validate blocklisted session. (Jeffrey Layton) [2017798]
- ceph: just use ci->i_version for fscache aux info (Jeffrey Layton) [2017798]
- ceph: shut down access to inode when async create fails (Jeffrey Layton) [2017798]
- ceph: refactor remove_session_caps_cb (Jeffrey Layton) [2017798]
- ceph: fix auth cap handling logic in remove_session_caps_cb (Jeffrey Layton) [2017798]
- ceph: drop private list from remove_session_caps_cb (Jeffrey Layton) [2017798]
- ceph: don't use -ESTALE as special return code in try_get_cap_refs (Jeffrey Layton) [2017798]
- ceph: print inode numbers instead of pointer values (Jeffrey Layton) [2017798]
- ceph: enable async dirops by default (Jeffrey Layton) [2017798]
- libceph: drop ->monmap and err initialization (Jeffrey Layton) [2017798]
- ceph: convert to noop_direct_IO (Jeffrey Layton) [2017798]
- ceph: fix handling of "meta" errors (Jeffrey Layton) [2017798]
- ceph: skip existing superblocks that are blocklisted or shut down when mounting (Jeffrey Layton) [2017798]
- ceph: fix off by one bugs in unsafe_request_wait() (Jeffrey Layton) [2017798]
- ceph: fix dereference of null pointer cf (Jeffrey Layton) [2017798]
- ceph: drop the mdsc_get_session/put_session dout messages (Jeffrey Layton) [2017798]
- ceph: lockdep annotations for try_nonblocking_invalidate (Jeffrey Layton) [2017798]
- ceph: don't WARN if we're forcibly removing the session caps (Jeffrey Layton) [2017798]
- ceph: don't WARN if we're force umounting (Jeffrey Layton) [2017798]
- ceph: remove the capsnaps when removing caps (Jeffrey Layton) [2017798]
- ceph: request Fw caps before updating the mtime in ceph_write_iter (Jeffrey Layton) [2017798]
- ceph: reconnect to the export targets on new mdsmaps (Jeffrey Layton) [2017798]
- ceph: print more information when we can't find snaprealm (Jeffrey Layton) [2017798]
- ceph: add ceph_change_snap_realm() helper (Jeffrey Layton) [2017798]
- ceph: remove redundant initializations from mdsc and session (Jeffrey Layton) [2017798]
- ceph: cancel delayed work instead of flushing on mdsc teardown (Jeffrey Layton) [2017798]
- ceph: add a new vxattr to return auth mds for an inode (Jeffrey Layton) [2017798]
- ceph: remove some defunct forward declarations (Jeffrey Layton) [2017798]
- ceph: flush the mdlog before waiting on unsafe reqs (Jeffrey Layton) [2017798]
- ceph: flush mdlog before umounting (Jeffrey Layton) [2017798]
- ceph: make iterate_sessions a global symbol (Jeffrey Layton) [2017798]
- ceph: make ceph_create_session_msg a global symbol (Jeffrey Layton) [2017798]
- ceph: fix comment about short copies in ceph_write_end (Jeffrey Layton) [2017798]
- ceph: fix memory leak on decode error in ceph_handle_caps (Jeffrey Layton) [2017798]

* Mon Dec 06 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-25.rt21.25.el9]
- x86: Pin task-stack in __get_wchan() (Chris von Recklinghausen) [2022169]
- x86: Fix __get_wchan() for !STACKTRACE (Chris von Recklinghausen) [2022169]
- sched: Add wrapper for get_wchan() to keep task blocked (Chris von Recklinghausen) [2022169]
- x86: Fix get_wchan() to support the ORC unwinder (Chris von Recklinghausen) [2022169]
- proc: Use task_is_running() for wchan in /proc/$pid/stat (Chris von Recklinghausen) [2022169]
- leaking_addresses: Always print a trailing newline (Chris von Recklinghausen) [2022169]
- Revert "proc/wchan: use printk format instead of lookup_symbol_name()" (Chris von Recklinghausen) [2022169]
- sched: Fill unconditional hole induced by sched_entity (Chris von Recklinghausen) [2022169]
- powerpc/bpf: Fix write protecting JIT code (Jiri Olsa) [2023618]
- vfs: check fd has read access in kernel_read_file_from_fd() (Carlos Maiolino) [2022893]
- Disable idmapped mounts (Alexey Gladkov) [2018141]
- KVM: s390: Fix handle_sske page fault handling (Thomas Huth) [1870686]
- KVM: s390: Simplify SIGP Set Arch handling (Thomas Huth) [1870686]
- KVM: s390: pv: avoid stalls when making pages secure (Thomas Huth) [1870686]
- KVM: s390: pv: avoid stalls for kvm_s390_pv_init_vm (Thomas Huth) [1870686]
- KVM: s390: pv: avoid double free of sida page (Thomas Huth) [1870686]
- KVM: s390: pv: add macros for UVC CC values (Thomas Huth) [1870686]
- s390/uv: fully validate the VMA before calling follow_page() (Thomas Huth) [1870686]
- s390/gmap: don't unconditionally call pte_unmap_unlock() in __gmap_zap() (Thomas Huth) [1870686]
- s390/gmap: validate VMA in __gmap_zap() (Thomas Huth) [1870686]
- KVM: s390: preserve deliverable_mask in __airqs_kick_single_vcpu (Thomas Huth) [1870686]
- KVM: s390: index kvm->arch.idle_mask by vcpu_idx (Thomas Huth) [1870686]
- KVM: s390: clear kicked_mask before sleeping again (Thomas Huth) [1870686]
- KVM: s390: Function documentation fixes (Thomas Huth) [1870686]
- s390/mm: fix kernel doc comments (Thomas Huth) [1870686]
- KVM: s390: generate kvm hypercall functions (Thomas Huth) [1870686]
- s390/vfio-ap: replace open coded locks for VFIO_GROUP_NOTIFY_SET_KVM notification (Thomas Huth) [1870686]
- s390/vfio-ap: r/w lock for PQAP interception handler function pointer (Thomas Huth) [1870686]
- KVM: Rename lru_slot to last_used_slot (Thomas Huth) [1870686]
- s390/uv: de-duplicate checks for Protected Host Virtualization (Thomas Huth) [1870686]
- s390/boot: disable Secure Execution in dump mode (Thomas Huth) [1870686]
- s390/boot: move uv function declarations to boot/uv.h (Thomas Huth) [1870686]
- s390/boot: move all linker symbol declarations from c to h files (Thomas Huth) [1870686]
- redhat/configs: Remove CONFIG_INFINIBAND_I40IW (Kamal Heib) [1920720]

* Thu Dec 02 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-24.rt21.24.el9]
- perf test: Handle fd gaps in test__dso_data_reopen (Michael Petlan) [1937209]
- perf tests vmlinux-kallsyms: Ignore hidden symbols (Michael Petlan) [1975103]
- perf script: Fix PERF_SAMPLE_WEIGHT_STRUCT support (Michael Petlan) [2009378]
- redhat/kernel.spec.template: Link perf with --export-dynamic (Michael Petlan) [2006775]
- xfs: fix I_DONTCACHE (Carlos Maiolino) [2022435]
- virtio: write back F_VERSION_1 before validate (Thomas Huth) [2008401]
- net/tls: Fix flipped sign in tls_err_abort() calls (Sabrina Dubroca) [2022006]
- net/tls: Fix flipped sign in async_wait.err assignment (Sabrina Dubroca) [2022006]
- hyper-v: Replace uuid.h with types.h (Mohammed Gamal) [2008572]
- Drivers: hv: vmbus: Remove unused code to check for subchannels (Mohammed Gamal) [2008572]
- hv: hyperv.h: Remove unused inline functions (Mohammed Gamal) [2008572]
- asm-generic/hyperv: provide cpumask_to_vpset_noself (Mohammed Gamal) [2008572]
- asm-generic/hyperv: Add missing #include of nmi.h (Mohammed Gamal) [2008572]
- x86/hyperv: Avoid erroneously sending IPI to 'self' (Mohammed Gamal) [2008572]
- x86/hyperv: remove on-stack cpumask from hv_send_ipi_mask_allbutself (Mohammed Gamal) [2008572]
- [s390] net/smc: improved fix wait on already cleared link (Mete Durlu) [1869652]
- [s390] net/smc: fix 'workqueue leaked lock' in smc_conn_abort_work (Mete Durlu) [1869652]
- [s390] net/smc: add missing error check in smc_clc_prfx_set() (Mete Durlu) [1869652]
- cifs: enable SMB_DIRECT in RHEL9 (Ronnie Sahlberg) [1965209]
- scsi: mpt3sas: Clean up some inconsistent indenting (Tomas Henzl) [1876119]
- scsi: mpt3sas: Call cpu_relax() before calling udelay() (Tomas Henzl) [1876119]
- scsi: mpt3sas: Introduce sas_ncq_prio_supported sysfs sttribute (Tomas Henzl) [1876119]
- scsi: mpt3sas: Update driver version to 39.100.00.00 (Tomas Henzl) [1876119]
- scsi: mpt3sas: Use firmware recommended queue depth (Tomas Henzl) [1876119]
- scsi: mpt3sas: Bump driver version to 38.100.00.00 (Tomas Henzl) [1876119]
- scsi: mpt3sas: Add io_uring iopoll support (Tomas Henzl) [1876119]
- serial: 8250_lpss: Extract dw8250_do_set_termios() for common use (David Arcari) [1880032]
- serial: 8250_lpss: Enable DMA on Intel Elkhart Lake (David Arcari) [1880032]
- dmaengine: dw: Convert members to u32 in platform data (David Arcari) [1880032]
- dmaengine: dw: Simplify DT property parser (David Arcari) [1880032]
- dmaengine: dw: Remove error message from DT parsing code (David Arcari) [1880032]
- dmaengine: dw: Program xBAR hardware for Elkhart Lake (David Arcari) [1880032]
- vmxnet3: switch from 'pci_' to 'dma_' API (Kamal Heib) [2003297]
- vmxnet3: update to version 6 (Kamal Heib) [2003297]
- vmxnet3: increase maximum configurable mtu to 9190 (Kamal Heib) [2003297]
- vmxnet3: set correct hash type based on rss information (Kamal Heib) [2003297]
- vmxnet3: add support for ESP IPv6 RSS (Kamal Heib) [2003297]
- vmxnet3: remove power of 2 limitation on the queues (Kamal Heib) [2003297]
- vmxnet3: add support for 32 Tx/Rx queues (Kamal Heib) [2003297]
- vmxnet3: prepare for version 6 changes (Kamal Heib) [2003297]

* Tue Nov 30 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-23.rt21.23.el9]
- PCI/VPD: Defer VPD sizing until first access (Myron Stowe) [2021298]
- PCI/VPD: Use unaligned access helpers (Myron Stowe) [2021298]
- PCI/VPD: Clean up public VPD defines and inline functions (Myron Stowe) [2021298]
- cxgb4: Use pci_vpd_find_id_string() to find VPD ID string (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_find_id_string() (Myron Stowe) [2021298]
- PCI/VPD: Include post-processing in pci_vpd_find_tag() (Myron Stowe) [2021298]
- PCI/VPD: Stop exporting pci_vpd_find_info_keyword() (Myron Stowe) [2021298]
- PCI/VPD: Stop exporting pci_vpd_find_tag() (Myron Stowe) [2021298]
- scsi: cxlflash: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- cxgb4: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- cxgb4: Remove unused vpd_param member ec (Myron Stowe) [2021298]
- cxgb4: Validate VPD checksum with pci_vpd_check_csum() (Myron Stowe) [2021298]
- bnxt: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- bnxt: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- bnx2x: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- bnx2x: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- bnx2: Replace open-coded byte swapping with swab32s() (Myron Stowe) [2021298]
- bnx2: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- sfc: falcon: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- sfc: falcon: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- tg3: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- tg3: Validate VPD checksum with pci_vpd_check_csum() (Myron Stowe) [2021298]
- tg3: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- sfc: Search VPD with pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- sfc: Read VPD with pci_vpd_alloc() (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_check_csum() (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_find_ro_info_keyword() (Myron Stowe) [2021298]
- PCI/VPD: Add pci_vpd_alloc() (Myron Stowe) [2021298]
- PCI/VPD: Treat invalid VPD like missing VPD capability (Myron Stowe) [2021298]
- PCI/VPD: Determine VPD size in pci_vpd_init() (Myron Stowe) [2021298]
- PCI/VPD: Embed struct pci_vpd in struct pci_dev (Myron Stowe) [2021298]
- PCI/VPD: Remove struct pci_vpd.valid member (Myron Stowe) [2021298]
- PCI/VPD: Remove struct pci_vpd_ops (Myron Stowe) [2021298]
- PCI/VPD: Reorder pci_read_vpd(), pci_write_vpd() (Myron Stowe) [2021298]
- PCI/VPD: Remove struct pci_vpd.flag (Myron Stowe) [2021298]
- PCI/VPD: Make pci_vpd_wait() uninterruptible (Myron Stowe) [2021298]
- PCI/VPD: Remove pci_vpd_size() old_size argument (Myron Stowe) [2021298]
- PCI/VPD: Allow access to valid parts of VPD if some is invalid (Myron Stowe) [2021298]
- PCI/VPD: Don't check Large Resource Item Names for validity (Myron Stowe) [2021298]
- PCI/VPD: Reject resource tags with invalid size (Myron Stowe) [2021298]
- PCI/VPD: Treat initial 0xff as missing EEPROM (Myron Stowe) [2021298]
- PCI/VPD: Check Resource Item Names against those valid for type (Myron Stowe) [2021298]
- PCI/VPD: Correct diagnostic for VPD read failure (Myron Stowe) [2021298]

* Mon Nov 29 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-22.rt21.22.el9]
- Add automotive CI jobs (Michael Hofmann)
- sched/scs: Reset the shadow stack when idle_task_exit (Phil Auld) [1992256]
- sched/fair: Null terminate buffer when updating tunable_scaling (Phil Auld) [1992256]
- sched/fair: Add ancestors of unthrottled undecayed cfs_rq (Phil Auld) [1981743 1992256]
- cpufreq: schedutil: Destroy mutex before kobject_put() frees the memory (Phil Auld) [1992256]
- sched/idle: Make the idle timer expire in hard interrupt context (Phil Auld) [1992256]
- sched: Prevent balance_push() on remote runqueues (Phil Auld) [1992256]
- sched/fair: Mark tg_is_idle() an inline in the !CONFIG_FAIR_GROUP_SCHED case (Phil Auld) [1992256]
- sched/topology: Skip updating masks for non-online nodes (Phil Auld) [1992256]
- sched: Skip priority checks with SCHED_FLAG_KEEP_PARAMS (Phil Auld) [1992256]
- sched: Fix UCLAMP_FLAG_IDLE setting (Phil Auld) [1992256]
- cpufreq: schedutil: Use kobject release() method to free sugov_tunables (Phil Auld) [1992256]
- sched/deadline: Fix missing clock update in migrate_task_rq_dl() (Phil Auld) [1992256]
- sched/fair: Avoid a second scan of target in select_idle_cpu (Phil Auld) [1992256]
- sched/fair: Use prev instead of new target as recent_used_cpu (Phil Auld) [1992256]
- sched: Replace deprecated CPU-hotplug functions. (Phil Auld) [1992256]
- sched: Introduce dl_task_check_affinity() to check proposed affinity (Phil Auld) [1992256]
- sched: Allow task CPU affinity to be restricted on asymmetric systems (Phil Auld) [1992256]
- sched: Split the guts of sched_setaffinity() into a helper function (Phil Auld) [1992256]
- sched: Introduce task_struct::user_cpus_ptr to track requested affinity (Phil Auld) [1992256]
- sched: Reject CPU affinity changes based on task_cpu_possible_mask() (Phil Auld) [1992256]
- cpuset: Cleanup cpuset_cpus_allowed_fallback() use in select_fallback_rq() (Phil Auld) [1992256]
- cpuset: Honour task_cpu_possible_mask() in guarantee_online_cpus() (Phil Auld) [1992256]
- cpuset: Don't use the cpu_possible_mask as a last resort for cgroup v1 (Phil Auld) [1992256]
- sched: Introduce task_cpu_possible_mask() to limit fallback rq selection (Phil Auld) [1992256]
- sched: Cgroup SCHED_IDLE support (Phil Auld) [1992256]
- sched: Don't report SCHED_FLAG_SUGOV in sched_getattr() (Phil Auld) [1992256]
- sched/deadline: Fix reset_on_fork reporting of DL tasks (Phil Auld) [1992256]
- sched/numa: Fix is_core_idle() (Phil Auld) [1992256]
- sched: remove redundant on_rq status change (Phil Auld) [1992256]
- sched: Optimize housekeeping_cpumask() in for_each_cpu_and() (Phil Auld) [1992256]
- sched/sysctl: Move extern sysctl declarations to sched.h (Phil Auld) [1992256]
- sched/debug: Don't update sched_domain debug directories before sched_debug_init() (Phil Auld) [1992256]

* Fri Nov 26 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-21.rt21.21.el9]
- clocksource: Increase WATCHDOG_MAX_SKEW (Waiman Long) [2017164]
- x86/hpet: Use another crystalball to evaluate HPET usability (Waiman Long) [2017164]
- scsi: target: Fix the pgr/alua_support_store functions (Maurizio Lombardi) [2023439]
- redhat: fix typo and make the output more silent for dist-git sync (Herton R. Krzesinski)
- x86: ACPI: cstate: Optimize C3 entry on AMD CPUs (David Arcari) [1998526]
- scsi: lpfc: Update lpfc version to 14.0.0.3 (Dick Kennedy) [2021327]
- scsi: lpfc: Allow fabric node recovery if recovery is in progress before devloss (Dick Kennedy) [2021327]
- scsi: lpfc: Fix link down processing to address NULL pointer dereference (Dick Kennedy) [2021327]
- scsi: lpfc: Allow PLOGI retry if previous PLOGI was aborted (Dick Kennedy) [2021327]
- scsi: lpfc: Fix use-after-free in lpfc_unreg_rpi() routine (Dick Kennedy) [2021327]
- scsi: lpfc: Correct sysfs reporting of loop support after SFP status change (Dick Kennedy) [2021327]
- scsi: lpfc: Wait for successful restart of SLI3 adapter during host sg_reset (Dick Kennedy) [2021327]
- scsi: lpfc: Revert LOG_TRACE_EVENT back to LOG_INIT prior to driver_resource_setup() (Dick Kennedy) [2021327]
- x86/Kconfig: Do not enable AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT automatically (Prarit Bhargava) [2021200]
- ucounts: Move get_ucounts from cred_alloc_blank to key_change_session_keyring (Alexey Gladkov) [2018142]
- ucounts: Proper error handling in set_cred_ucounts (Alexey Gladkov) [2018142]
- ucounts: Pair inc_rlimit_ucounts with dec_rlimit_ucoutns in commit_creds (Alexey Gladkov) [2018142]
- ucounts: Fix signal ucount refcounting (Alexey Gladkov) [2018142]
- x86/cpu: Fix migration safety with X86_BUG_NULL_SEL (Vitaly Kuznetsov) [2016959]
- ip6_gre: Revert "ip6_gre: add validation for csum_start" (Guillaume Nault) [2014993]
- ip_gre: validate csum_start only on pull (Guillaume Nault) [2014993]
- redhat/configs: enable KEXEC_IMAGE_VERIFY_SIG for RHEL (Coiby Xu) [1994858]
- redhat/configs: enable KEXEC_SIG for aarch64 RHEL (Coiby Xu) [1994858]
- kernel.spec: add bpf_testmod.ko to kselftests/bpf (Viktor Malik) [2006318 2006319]
- netfilter: Add deprecation notices for xtables (Phil Sutter) [1945179]
- redhat: Add mark_driver_deprecated() (Phil Sutter) [1945179]

* Wed Nov 24 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-20.rt21.20.el9]
- powerpc/svm: Don't issue ultracalls if !mem_encrypt_active() (Herton R. Krzesinski) [2025186]

* Mon Nov 22 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-19.rt21.19.el9]
- net: core: don't call SIOCBRADD/DELIF for non-bridge devices (Ivan Vecera) [2008927]
- net: bridge: fix ioctl old_deviceless bridge argument (Ivan Vecera) [2008927]
- net: bridge: fix ioctl locking (Ivan Vecera) [2008927]
- ethtool: Fix rxnfc copy to user buffer overflow (Ivan Vecera) [2008927]
- net: bonding: move ioctl handling to private ndo operation (Ivan Vecera) [2008927]
- net: bridge: move bridge ioctls out of .ndo_do_ioctl (Ivan Vecera) [2008927]
- net: socket: return changed ifreq from SIOCDEVPRIVATE (Ivan Vecera) [2008927]
- net: split out ndo_siowandev ioctl (Ivan Vecera) [2008927]
- dev_ioctl: split out ndo_eth_ioctl (Ivan Vecera) [2008927]
- dev_ioctl: pass SIOCDEVPRIVATE data separately (Ivan Vecera) [2008927]
- wan: cosa: remove dead cosa_net_ioctl() function (Ivan Vecera) [2008927]
- wan: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- ppp: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- sb1000: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hippi: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- ip_tunnel: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- airo: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hamradio: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- cxgb3: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- qeth: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- slip/plip: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- net: usb: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- fddi: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- eql: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- tehuti: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hamachi: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- appletalk: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- bonding: use siocdevprivate (Ivan Vecera) [2008927]
- tulip: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- phonet: use siocdevprivate (Ivan Vecera) [2008927]
- bridge: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- hostap: use ndo_siocdevprivate (Ivan Vecera) [2008927]
- staging: wlan-ng: use siocdevprivate (Ivan Vecera) [2008927]
- staging: rtlwifi: use siocdevprivate (Ivan Vecera) [2008927]
- net: split out SIOCDEVPRIVATE handling from dev_ioctl (Ivan Vecera) [2008927]
- net: socket: rework compat_ifreq_ioctl() (Ivan Vecera) [2008927]
- net: socket: simplify dev_ifconf handling (Ivan Vecera) [2008927]
- net: socket: remove register_gifconf (Ivan Vecera) [2008927]
- net: socket: rework SIOC?IFMAP ioctls (Ivan Vecera) [2008927]
- ethtool: improve compat ioctl handling (Ivan Vecera) [2008927]
- compat: make linux/compat.h available everywhere (Ivan Vecera) [2008927]

* Fri Nov 19 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-18.rt21.18.el9]
- CI: Add template for baseline gcov build (c9s repos) (Michael Hofmann)
- PCI: vmd: depend on !UML (Myron Stowe) [1994932]
- PCI: vmd: Do not disable MSI-X remapping if interrupt remapping is enabled by IOMMU (Myron Stowe) [1994932]
- PCI: vmd: Assign a number to each VMD controller (Myron Stowe) [1994932]
- PCI: VMD: ACPI: Make ACPI companion lookup work for VMD bus (Myron Stowe) [1994932]
- swiotlb-xen: drop DEFAULT_NSLABS (Jerry Snitselaar) [2004348]
- swiotlb-xen: arrange to have buffer info logged (Jerry Snitselaar) [2004348]
- swiotlb-xen: drop leftover __ref (Jerry Snitselaar) [2004348]
- swiotlb-xen: limit init retries (Jerry Snitselaar) [2004348]
- swiotlb-xen: suppress certain init retries (Jerry Snitselaar) [2004348]
- swiotlb-xen: maintain slab count properly (Jerry Snitselaar) [2004348]
- swiotlb-xen: fix late init retry (Jerry Snitselaar) [2004348]
- swiotlb-xen: avoid double free (Jerry Snitselaar) [2004348]
- dma-debug: teach add_dma_entry() about DMA_ATTR_SKIP_CPU_SYNC (Jerry Snitselaar) [2004348]
- dma-debug: fix sg checks in debug_dma_map_sg() (Jerry Snitselaar) [2004348]
- dma-mapping: fix the kerneldoc for dma_map_sgtable() (Jerry Snitselaar) [2004348]
- dma-debug: prevent an error message from causing runtime problems (Jerry Snitselaar) [2004348]
- dma-mapping: fix the kerneldoc for dma_map_sg_attrs (Jerry Snitselaar) [2004348]
- iommu/vt-d: Drop "0x" prefix from PCI bus & device addresses (Jerry Snitselaar) [2004348]
- iommu: Clarify default domain Kconfig (Jerry Snitselaar) [2004348]
- iommu/vt-d: Fix a deadlock in intel_svm_drain_prq() (Jerry Snitselaar) [2004348]
- iommu/vt-d: Fix PASID leak in intel_svm_unbind_mm() (Jerry Snitselaar) [2004348]
- iommu/amd: Remove iommu_init_ga() (Jerry Snitselaar) [2004348]
- iommu/amd: Relocate GAMSup check to early_enable_iommus (Jerry Snitselaar) [2004348]
- iommu/io-pgtable: Abstract iommu_iotlb_gather access (Jerry Snitselaar) [2004348]
- iommu/vt-d: Add present bit check in pasid entry setup helpers (Jerry Snitselaar) [2004348]
- iommu/vt-d: Use pasid_pte_is_present() helper function (Jerry Snitselaar) [2004348]
- iommu/vt-d: Drop the kernel doc annotation (Jerry Snitselaar) [2004348]
- iommu/vt-d: Allow devices to have more than 32 outstanding PRs (Jerry Snitselaar) [1921363]
- iommu/vt-d: Preset A/D bits for user space DMA usage (Jerry Snitselaar) [2004348]
- iomm/vt-d: Enable Intel IOMMU scalable mode by default (Jerry Snitselaar) [2004348]
- iommu/vt-d: Refactor Kconfig a bit (Jerry Snitselaar) [2004348]
- iommu/vt-d: Remove unnecessary oom message (Jerry Snitselaar) [2004348]
- iommu/vt-d: Update the virtual command related registers (Jerry Snitselaar) [2004348]
- iommu: Allow enabling non-strict mode dynamically (Jerry Snitselaar) [2004348]
- iommu: Merge strictness and domain type configs (Jerry Snitselaar) [2004348]
- iommu: Only log strictness for DMA domains (Jerry Snitselaar) [2004348]
- iommu: Expose DMA domain strictness via sysfs (Jerry Snitselaar) [2004348]
- iommu: Express DMA strictness via the domain type (Jerry Snitselaar) [2004348]
- iommu/vt-d: Prepare for multiple DMA domain types (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Prepare for multiple DMA domain types (Jerry Snitselaar) [2004348]
- iommu/amd: Prepare for multiple DMA domain types (Jerry Snitselaar) [2004348]
- iommu: Introduce explicit type for non-strict DMA domains (Jerry Snitselaar) [2004348]
- iommu/io-pgtable: Remove non-strict quirk (Jerry Snitselaar) [2004348]
- iommu: Indicate queued flushes via gather data (Jerry Snitselaar) [2004348]
- iommu/dma: Remove redundant "!dev" checks (Jerry Snitselaar) [2004348]
- iommu/virtio: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu/vt-d: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu/amd: Drop IOVA cookie management (Jerry Snitselaar) [2004348]
- iommu: Pull IOVA cookie management into the core (Jerry Snitselaar) [2004348]
- iommu/amd: Remove stale amd_iommu_unmap_flush usage (Jerry Snitselaar) [2004348]
- iommu/amd: Use only natural aligned flushes in a VM (Jerry Snitselaar) [2004348]
- iommu/amd: Sync once for scatter-gather operations (Jerry Snitselaar) [2004348]
- iommu/amd: Tailored gather logic for AMD (Jerry Snitselaar) [2004348]
- iommu: Factor iommu_iotlb_gather_is_disjoint() out (Jerry Snitselaar) [2004348]
- iommu: Improve iommu_iotlb_gather helpers (Jerry Snitselaar) [2004348]
- iommu/amd: Do not use flush-queue when NpCache is on (Jerry Snitselaar) [2004348]
- iommu/amd: Selective flush on unmap (Jerry Snitselaar) [2004348]
- iommu/amd: Fix printing of IOMMU events when rate limiting kicks in (Jerry Snitselaar) [2004348]
- iommu/amd: Convert from atomic_t to refcount_t on pasid_state->count (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Fix missing unlock on error in arm_smmu_device_group() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Stop pre-zeroing batch commands (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Extract reusable function __arm_smmu_cmdq_skip_err() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Add and use static helper function arm_smmu_get_cmdq() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Add and use static helper function arm_smmu_cmdq_issue_cmd_with_sync() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Use command queue batching helpers to improve performance (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Optimize ->tlb_flush_walk() for qcom implementation (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Fix race condition during iommu_group creation (Jerry Snitselaar) [2004348]
- iommu: Fix race condition during default domain allocation (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Add clk_bulk_{prepare/unprepare} to system pm callbacks (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Remove some unneeded init in arm_smmu_cmdq_issue_cmdlist() (Jerry Snitselaar) [2004348]
- iommu/arm-smmu-v3: Implement the map_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/arm-smmu-v3: Implement the unmap_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/vt-d: Move clflush'es from iotlb_sync_map() to map_pages() (Jerry Snitselaar) [1971978]
- iommu/vt-d: Implement map/unmap_pages() iommu_ops callback (Jerry Snitselaar) [1971978]
- iommu/vt-d: Report real pgsize bitmap to iommu core (Jerry Snitselaar) [1971978]
- iommu: Streamline iommu_iova_to_phys() (Jerry Snitselaar) [2004348]
- iommu: Remove mode argument from iommu_set_dma_strict() (Jerry Snitselaar) [2004348]
- redhat/configs: Use new iommu default dma config options (Jerry Snitselaar) [2004348]
- iommu/amd: Add support for IOMMU default DMA mode build options (Jerry Snitselaar) [2004348]
- iommu/vt-d: Add support for IOMMU default DMA mode build options (Jerry Snitselaar) [2004348]
- iommu: Enhance IOMMU default DMA mode build options (Jerry Snitselaar) [2004348]
- iommu: Print strict or lazy mode at init time (Jerry Snitselaar) [2004348]
- iommu: Deprecate Intel and AMD cmdline methods to enable strict mode (Jerry Snitselaar) [2004348]
- iommu/arm-smmu: Implement the map_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/arm-smmu: Implement the unmap_pages() IOMMU driver callback (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm-v7s: Implement arm_v7s_map_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm-v7s: Implement arm_v7s_unmap_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm: Implement arm_lpae_map_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm: Implement arm_lpae_unmap_pages() (Jerry Snitselaar) [1971978]
- iommu/io-pgtable-arm: Prepare PTE methods for handling multiple entries (Jerry Snitselaar) [1971978]
- iommu/io-pgtable: Introduce map_pages() as a page table op (Jerry Snitselaar) [1971978]
- iommu/io-pgtable: Introduce unmap_pages() as a page table op (Jerry Snitselaar) [1971978]
- iommu: Add support for the map_pages() callback (Jerry Snitselaar) [1971978]
- iommu: Hook up '->unmap_pages' driver callback (Jerry Snitselaar) [1971978]
- iommu: Split 'addr_merge' argument to iommu_pgsize() into separate parts (Jerry Snitselaar) [1971978]
- iommu: Use bitmap to calculate page size in iommu_pgsize() (Jerry Snitselaar) [1971978]
- iommu: Add a map_pages() op for IOMMU drivers (Jerry Snitselaar) [1971978]
- iommu: Add an unmap_pages() op for IOMMU drivers (Jerry Snitselaar) [1971978]
- swiotlb: use depends on for DMA_RESTRICTED_POOL (Jerry Snitselaar) [2004348]
- swiotlb: Free tbl memory in swiotlb_exit() (Jerry Snitselaar) [2004348]
- swiotlb: Emit diagnostic in swiotlb_exit() (Jerry Snitselaar) [2004348]
- swiotlb: Convert io_default_tlb_mem to static allocation (Jerry Snitselaar) [2004348]
- swiotlb: add overflow checks to swiotlb_bounce (Jerry Snitselaar) [2004348]
- swiotlb: fix implicit debugfs declarations (Jerry Snitselaar) [2004348]
- swiotlb: Add restricted DMA pool initialization (Jerry Snitselaar) [2004348]
- redhat/configs: Add CONFIG_DMA_RESTRICTED_POOL (Jerry Snitselaar) [2004348]
- swiotlb: Add restricted DMA alloc/free support (Jerry Snitselaar) [2004348]
- swiotlb: Refactor swiotlb_tbl_unmap_single (Jerry Snitselaar) [2004348]
- swiotlb: Move alloc_size to swiotlb_find_slots (Jerry Snitselaar) [2004348]
- swiotlb: Use is_swiotlb_force_bounce for swiotlb data bouncing (Jerry Snitselaar) [2004348]
- swiotlb: Update is_swiotlb_active to add a struct device argument (Jerry Snitselaar) [2004348]
- swiotlb: Update is_swiotlb_buffer to add a struct device argument (Jerry Snitselaar) [2004348]
- swiotlb: Set dev->dma_io_tlb_mem to the swiotlb pool used (Jerry Snitselaar) [2004348]
- swiotlb: Refactor swiotlb_create_debugfs (Jerry Snitselaar) [2004348]
- swiotlb: Refactor swiotlb init functions (Jerry Snitselaar) [2004348]
- dma-mapping: make the global coherent pool conditional (Jerry Snitselaar) [2004348]
- dma-mapping: add a dma_init_global_coherent helper (Jerry Snitselaar) [2004348]
- dma-mapping: simplify dma_init_coherent_memory (Jerry Snitselaar) [2004348]
- dma-mapping: allow using the global coherent pool for !ARM (Jerry Snitselaar) [2004348]
- dma-direct: add support for dma_coherent_default_memory (Jerry Snitselaar) [2004348]
- dma-mapping: return an unsigned int from dma_map_sg{,_attrs} (Jerry Snitselaar) [2004348]
- dma-mapping: disallow .map_sg operations from returning zero on error (Jerry Snitselaar) [2004348]
- dma-mapping: return error code from dma_dummy_map_sg() (Jerry Snitselaar) [2004348]
- xen: swiotlb: return error code from xen_swiotlb_map_sg() (Jerry Snitselaar) [2004348]
- s390/pci: don't set failed sg dma_address to DMA_MAPPING_ERROR (Jerry Snitselaar) [2004348]
- s390/pci: return error code from s390_dma_map_sg() (Jerry Snitselaar) [2004348]
- powerpc/iommu: don't set failed sg dma_address to DMA_MAPPING_ERROR (Jerry Snitselaar) [2004348]
- powerpc/iommu: return error code from .map_sg() ops (Jerry Snitselaar) [2004348]
- iommu/dma: return error code from iommu_dma_map_sg() (Jerry Snitselaar) [2004348]
- iommu: return full error code from iommu_map_sg[_atomic]() (Jerry Snitselaar) [2004348]
- dma-direct: return appropriate error code from dma_direct_map_sg() (Jerry Snitselaar) [2004348]
- dma-mapping: allow map_sg() ops to return negative error codes (Jerry Snitselaar) [2004348]
- dma-debug: fix debugfs initialization order (Jerry Snitselaar) [2004348]
- dma-debug: use memory_intersects() directly (Jerry Snitselaar) [2004348]

* Wed Nov 17 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-17.rt21.17.el9]
- net: mana: Support hibernation and kexec (Mohammed Gamal) [2011883]
- net: mana: Improve the HWC error handling (Mohammed Gamal) [2011883]
- net: mana: Report OS info to the PF driver (Mohammed Gamal) [2011883]
- net: mana: Fix the netdev_err()'s vPort argument in mana_init_port() (Mohammed Gamal) [2011883]
- net: mana: Allow setting the number of queues while the NIC is down (Mohammed Gamal) [2011883]
- net: mana: Fix error handling in mana_create_rxq() (Mohammed Gamal) [2011883]
- net: mana: Use kcalloc() instead of kzalloc() (Mohammed Gamal) [2011883]
- net: mana: Prefer struct_size over open coded arithmetic (Mohammed Gamal) [2011883]
- net: mana: Add WARN_ON_ONCE in case of CQE read overflow (Mohammed Gamal) [2011883]
- net: mana: Add support for EQ sharing (Mohammed Gamal) [2011883]
- net: mana: Move NAPI from EQ to CQ (Mohammed Gamal) [2011883]
- PCI: hv: Fix sleep while in non-sleep context when removing child devices from the bus (Mohammed Gamal) [2008571]
- objtool: Remove redundant 'len' field from struct section (C. Erastus Toe) [2002440]
- objtool: Make .altinstructions section entry size consistent (C. Erastus Toe) [2002440]
- s390/topology: fix topology information when calling cpu hotplug notifiers (Phil Auld) [2003998]
- fs: remove leftover comments from mandatory locking removal (Jeffrey Layton) [2017438]
- locks: remove changelog comments (Jeffrey Layton) [2017438]
- docs: fs: locks.rst: update comment about mandatory file locking (Jeffrey Layton) [2017438]
- Documentation: remove reference to now removed mandatory-locking doc (Jeffrey Layton) [2017438]
- locks: remove LOCK_MAND flock lock support (Jeffrey Layton) [2017438]
- fs: clean up after mandatory file locking support removal (Jeffrey Layton) [2017438]
- fs: remove mandatory file locking support (Jeffrey Layton) [2017438]
- fcntl: fix potential deadlock for &fasync_struct.fa_lock (Jeffrey Layton) [2017438]
- fcntl: fix potential deadlocks for &fown_struct.lock (Jeffrey Layton) [2017438]
- KVM: s390: Enable specification exception interpretation (Thomas Huth) [2001770]
- redhat/configs: enable CONFIG_BCMGENET as module (Joel Savitz) [2011025]

* Mon Nov 15 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-16.rt21.16.el9]
- CI: Add template for baseline gcov build for RHEL (Israel Santana Aleman)
- redhat/configs: Enable Nitro Enclaves on Aarch64 (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fixes for checkpatch blank line reports (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fixes for checkpatch spell check reports (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fixes for checkpatch match open parenthesis reports (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Update copyright statement to include 2021 (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Add fix for the kernel-doc report (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Update documentation for Arm64 support (Vitaly Kuznetsov) [2001582]
- nitro_enclaves: Enable Arm64 support (Vitaly Kuznetsov) [2001582]
- redhat/configs: Enable Hyper-V support on ARM (Vitaly Kuznetsov) [1949613]
- redhat/configs: enable CONFIG_INPUT_KEYBOARD for AARCH64 (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Enable Hyper-V code to be built on ARM64 (Vitaly Kuznetsov) [1949613]
- arm64: efi: Export screen_info (Vitaly Kuznetsov) [1949613]
- arm64: hyperv: Initialize hypervisor on boot (Vitaly Kuznetsov) [1949613]
- arm64: hyperv: Add panic handler (Vitaly Kuznetsov) [1949613]
- arm64: hyperv: Add Hyper-V hypercall and register access utilities (Vitaly Kuznetsov) [1949613]
- PCI: hv: Turn on the host bridge probing on ARM64 (Vitaly Kuznetsov) [1949613]
- PCI: hv: Set up MSI domain at bridge probing time (Vitaly Kuznetsov) [1949613]
- PCI: hv: Set ->domain_nr of pci_host_bridge at probing time (Vitaly Kuznetsov) [1949613]
- PCI: hv: Generify PCI probing (Vitaly Kuznetsov) [1949613]
- arm64: PCI: Support root bridge preparation for Hyper-V (Vitaly Kuznetsov) [1949613]
- arm64: PCI: Restructure pcibios_root_bridge_prepare() (Vitaly Kuznetsov) [1949613]
- PCI: Support populating MSI domains of root buses via bridges (Vitaly Kuznetsov) [1949613]
- PCI: Introduce domain_nr in pci_host_bridge (Vitaly Kuznetsov) [1949613]
- drivers: hv: Decouple Hyper-V clock/timer code from VMbus drivers (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Move Hyper-V misc functionality to arch-neutral code (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Add arch independent default functions for some Hyper-V handlers (Vitaly Kuznetsov) [1949613]
- Drivers: hv: Make portions of Hyper-V init code be arch neutral (Vitaly Kuznetsov) [1949613]
- asm-generic/hyperv: Add missing #include of nmi.h (Vitaly Kuznetsov) [1949613]
- PCI: hv: Support for create interrupt v3 (Vitaly Kuznetsov) [1949613]
- x86_64: Enable Elkhart Lake Quadrature Encoder Peripheral support (Prarit Bhargava) [1874997]

* Thu Nov 11 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-15.rt21.15.el9]
- scsi: lpfc: Fix memory overwrite during FC-GS I/O abort handling (Dick Kennedy) [1879528]
- scsi: lpfc: Fix gcc -Wstringop-overread warning, again (Dick Kennedy) [1879528]
- scsi: lpfc: Use correct scnprintf() limit (Dick Kennedy) [1879528]
- scsi: lpfc: Fix sprintf() overflow in lpfc_display_fpin_wwpn() (Dick Kennedy) [1879528]
- scsi: lpfc: Fix compilation errors on kernels with no CONFIG_DEBUG_FS (Dick Kennedy) [1879528]
- scsi: lpfc: Fix CPU to/from endian warnings introduced by ELS processing (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 14.0.0.2 (Dick Kennedy) [1879528]
- scsi: lpfc: Improve PBDE checks during SGL processing (Dick Kennedy) [1879528]
- scsi: lpfc: Zero CGN stats only during initial driver load and stat reset (Dick Kennedy) [1879528]
- scsi: lpfc: Fix I/O block after enabling managed congestion mode (Dick Kennedy) [1879528]
- scsi: lpfc: Adjust bytes received vales during cmf timer interval (Dick Kennedy) [1879528]
- scsi: lpfc: Fix EEH support for NVMe I/O (Dick Kennedy) [1879528]
- scsi: lpfc: Fix FCP I/O flush functionality for TMF routines (Dick Kennedy) [1879528]
- scsi: lpfc: Fix NVMe I/O failover to non-optimized path (Dick Kennedy) [1879528]
- scsi: lpfc: Don't remove ndlp on PRLI errors in P2P mode (Dick Kennedy) [1879528]
- scsi: lpfc: Fix rediscovery of tape device after LIP (Dick Kennedy) [1879528]
- scsi: lpfc: Fix hang on unload due to stuck fport node (Dick Kennedy) [1879528]
- scsi: lpfc: Fix premature rpi release for unsolicited TPLS and LS_RJT (Dick Kennedy) [1879528]
- scsi: lpfc: Don't release final kref on Fport node while ABTS outstanding (Dick Kennedy) [1879528]
- scsi: lpfc: Fix list_add() corruption in lpfc_drain_txq() (Dick Kennedy) [1879528]
- scsi: fc: Add EDC ELS definition (Dick Kennedy) [1879528]
- scsi: lpfc: Copyright updates for 14.0.0.1 patches (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 14.0.0.1 (Dick Kennedy) [1879528]
- scsi: lpfc: Add bsg support for retrieving adapter cmf data (Dick Kennedy) [1879528]
- scsi: lpfc: Add cmf_info sysfs entry (Dick Kennedy) [1879528]
- scsi: lpfc: Add debugfs support for cm framework buffers (Dick Kennedy) [1879528]
- scsi: lpfc: Add support for maintaining the cm statistics buffer (Dick Kennedy) [1879528]
- scsi: lpfc: Add rx monitoring statistics (Dick Kennedy) [1879528]
- scsi: lpfc: Add support for the CM framework (Dick Kennedy) [1879528]
- scsi: lpfc: Add cmfsync WQE support (Dick Kennedy) [1879528]
- scsi: lpfc: Add support for cm enablement buffer (Dick Kennedy) [1879528]
- scsi: lpfc: Add cm statistics buffer support (Dick Kennedy) [1879528]
- scsi: lpfc: Add EDC ELS support (Dick Kennedy) [1879528]
- scsi: lpfc: Expand FPIN and RDF receive logging (Dick Kennedy) [1879528]
- scsi: lpfc: Add MIB feature enablement support (Dick Kennedy) [1879528]
- scsi: lpfc: Add SET_HOST_DATA mbox cmd to pass date/time info to firmware (Dick Kennedy) [1879528]
- scsi: lpfc: Fix possible ABBA deadlock in nvmet_xri_aborted() (Dick Kennedy) [1879528]
- scsi: lpfc: Remove redundant assignment to pointer pcmd (Dick Kennedy) [1879528]
- scsi: lpfc: Copyright updates for 14.0.0.0 patches (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 14.0.0.0 (Dick Kennedy) [1879528]
- scsi: lpfc: Add 256 Gb link speed support (Dick Kennedy) [1879528]
- scsi: lpfc: Revise Topology and RAS support checks for new adapters (Dick Kennedy) [1879528]
- scsi: lpfc: Fix cq_id truncation in rq create (Dick Kennedy) [1879528]
- scsi: lpfc: Add PCI ID support for LPe37000/LPe38000 series adapters (Dick Kennedy) [1879528]
- scsi: lpfc: Copyright updates for 12.8.0.11 patches (Dick Kennedy) [1879528]
- scsi: lpfc: Update lpfc version to 12.8.0.11 (Dick Kennedy) [1879528]
- scsi: lpfc: Skip issuing ADISC when node is in NPR state (Dick Kennedy) [1879528]
- scsi: lpfc: Skip reg_vpi when link is down for SLI3 in ADISC cmpl path (Dick Kennedy) [1879528]
- scsi: lpfc: Call discovery state machine when handling PLOGI/ADISC completions (Dick Kennedy) [1879528]
- scsi: lpfc: Delay unregistering from transport until GIDFT or ADISC completes (Dick Kennedy) [1879528]
- scsi: lpfc: Enable adisc discovery after RSCN by default (Dick Kennedy) [1879528]
- scsi: lpfc: Use PBDE feature enabled bit to determine PBDE support (Dick Kennedy) [1879528]
- scsi: lpfc: Clear outstanding active mailbox during PCI function reset (Dick Kennedy) [1879528]
- scsi: lpfc: Fix KASAN slab-out-of-bounds in lpfc_unreg_rpi() routine (Dick Kennedy) [1879528]
- scsi: lpfc: Remove REG_LOGIN check requirement to issue an ELS RDF (Dick Kennedy) [1879528]
- scsi: lpfc: Fix memory leaks in error paths while issuing ELS RDF/SCR request (Dick Kennedy) [1879528]
- scsi: lpfc: Fix NULL ptr dereference with NPIV ports for RDF handling (Dick Kennedy) [1879528]
- scsi: lpfc: Keep NDLP reference until after freeing the IOCB after ELS handling (Dick Kennedy) [1879528]
- scsi: lpfc: Fix target reset handler from falsely returning FAILURE (Dick Kennedy) [1879528]
- scsi: lpfc: Discovery state machine fixes for LOGO handling (Dick Kennedy) [1879528]
- scsi: lpfc: Fix function description comments for vmid routines (Dick Kennedy) [1879528]
- scsi: lpfc: Improve firmware download logging (Dick Kennedy) [1879528]
- scsi: lpfc: Remove use of kmalloc() in trace event logging (Dick Kennedy) [1879528]
- scsi: lpfc: Fix NVMe support reporting in log message (Dick Kennedy) [1879528]

* Thu Nov 11 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-14.rt21.14.el9]
- evm: mark evm_fixmode as __ro_after_init (Bruno Meneguele) [2017160]
- IMA: remove -Wmissing-prototypes warning (Bruno Meneguele) [2017160]
- perf flamegraph: flamegraph.py script improvements (Michael Petlan) [2010271]
- redhat/configs/evaluate_configs: insert EMPTY tags at correct place (Jan Stancek) [2015082]
- redhat/configs/evaluate_configs: walk cfgvariants line by line (Jan Stancek) [2015082]
- redhat/configs: create a separate config for gcov options (Jan Stancek) [2015082]
- redhat/kernel.spec.template: don't hardcode gcov arches (Jan Stancek) [2015082]
- i40e: fix endless loop under rtnl (Stefan Assmann) [1992939]
- selftests/bpf: Use nanosleep tracepoint in perf buffer test (Jiri Olsa) [2006310]
- selftests/bpf: Fix possible/online index mismatch in perf_buffer test (Jiri Olsa) [2006310]
- selftests/bpf: Fix perf_buffer test on system with offline cpus (Jiri Olsa) [2006310]
- KVM: x86: Fix stack-out-of-bounds memory access from ioapic_write_indirect() (Vitaly Kuznetsov) [1965145]
- selftest/bpf: Switch recursion test to use htab_map_delete_elem (Jiri Olsa) [2006313]

* Tue Nov 09 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-13.rt21.13.el9]
- futex: Remove unused variable 'vpid' in futex_proxy_trylock_atomic() (Waiman Long) [2007032]
- futex: Prevent inconsistent state and exit race (Waiman Long) [2007032]
- locking/ww_mutex: Initialize waiter.ww_ctx properly (Waiman Long) [2007032]
- futex: Return error code instead of assigning it without effect (Waiman Long) [2007032]
- locking/rwbase: Take care of ordering guarantee for fastpath reader (Waiman Long) [2007032]
- locking/rwbase: Extract __rwbase_write_trylock() (Waiman Long) [2007032]
- locking/rwbase: Properly match set_and_save_state() to restore_state() (Waiman Long) [2007032]
- locking/rtmutex: Fix ww_mutex deadlock check (Waiman Long) [2007032]
- locking/rwsem: Add missing __init_rwsem() for PREEMPT_RT (Waiman Long) [2007032]
- locking/rtmutex: Return success on deadlock for ww_mutex waiters (Waiman Long) [2007032]
- locking/rtmutex: Prevent spurious EDEADLK return caused by ww_mutexes (Waiman Long) [2007032]
- locking/rtmutex: Dequeue waiter on ww_mutex deadlock (Waiman Long) [2007032]
- locking/rtmutex: Dont dereference waiter lockless (Waiman Long) [2007032]
- locking/local_lock: Add PREEMPT_RT support (Waiman Long) [2007032]
- locking/spinlock/rt: Prepare for RT local_lock (Waiman Long) [2007032]
- locking/rtmutex: Add adaptive spinwait mechanism (Waiman Long) [2007032]
- locking/rtmutex: Implement equal priority lock stealing (Waiman Long) [2007032]
- preempt: Adjust PREEMPT_LOCK_OFFSET for RT (Waiman Long) [2007032]
- locking/rtmutex: Prevent lockdep false positive with PI futexes (Waiman Long) [2007032]
- futex: Prevent requeue_pi() lock nesting issue on RT (Waiman Long) [2007032]
- futex: Simplify handle_early_requeue_pi_wakeup() (Waiman Long) [2007032]
- futex: Reorder sanity checks in futex_requeue() (Waiman Long) [2007032]
- futex: Clarify comment in futex_requeue() (Waiman Long) [2007032]
- futex: Restructure futex_requeue() (Waiman Long) [2007032]
- futex: Correct the number of requeued waiters for PI (Waiman Long) [2007032]
- futex: Remove bogus condition for requeue PI (Waiman Long) [2007032]
- futex: Clarify futex_requeue() PI handling (Waiman Long) [2007032]
- futex: Clean up stale comments (Waiman Long) [2007032]
- futex: Validate waiter correctly in futex_proxy_trylock_atomic() (Waiman Long) [2007032]
- lib/test_lockup: Adapt to changed variables (Waiman Long) [2007032]
- locking/rtmutex: Add mutex variant for RT (Waiman Long) [2007032]
- locking/ww_mutex: Implement rtmutex based ww_mutex API functions (Waiman Long) [2007032]
- locking/rtmutex: Extend the rtmutex core to support ww_mutex (Waiman Long) [2007032]
- locking/ww_mutex: Add rt_mutex based lock type and accessors (Waiman Long) [2007032]
- locking/ww_mutex: Add RT priority to W/W order (Waiman Long) [2007032]
- locking/ww_mutex: Implement rt_mutex accessors (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out internal lock accesses (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out mutex types (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out mutex accessors (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out waiter enqueueing (Waiman Long) [2007032]
- locking/ww_mutex: Abstract out the waiter iteration (Waiman Long) [2007032]
- locking/ww_mutex: Remove the __sched annotation from ww_mutex APIs (Waiman Long) [2007032]
- locking/ww_mutex: Split out the W/W implementation logic into kernel/locking/ww_mutex.h (Waiman Long) [2007032]
- locking/ww_mutex: Split up ww_mutex_unlock() (Waiman Long) [2007032]
- locking/ww_mutex: Gather mutex_waiter initialization (Waiman Long) [2007032]
- locking/ww_mutex: Simplify lockdep annotations (Waiman Long) [2007032]
- locking/mutex: Make mutex::wait_lock raw (Waiman Long) [2007032]
- locking/ww_mutex: Move the ww_mutex definitions from <linux/mutex.h> into <linux/ww_mutex.h> (Waiman Long) [2007032]
- locking/mutex: Move the 'struct mutex_waiter' definition from <linux/mutex.h> to the internal header (Waiman Long) [2007032]
- locking/mutex: Consolidate core headers, remove kernel/locking/mutex-debug.h (Waiman Long) [2007032]
- locking/rtmutex: Squash !RT tasks to DEFAULT_PRIO (Waiman Long) [2007032]
- locking/rwlock: Provide RT variant (Waiman Long) [2007032]
- locking/spinlock: Provide RT variant (Waiman Long) [2007032]
- locking/rtmutex: Provide the spin/rwlock core lock function (Waiman Long) [2007032]
- locking/spinlock: Provide RT variant header: <linux/spinlock_rt.h> (Waiman Long) [2007032]
- locking/spinlock: Provide RT specific spinlock_t (Waiman Long) [2007032]
- locking/rtmutex: Reduce <linux/rtmutex.h> header dependencies, only include <linux/rbtree_types.h> (Waiman Long) [2007032]
- rbtree: Split out the rbtree type definitions into <linux/rbtree_types.h> (Waiman Long) [2007032]
- locking/lockdep: Reduce header dependencies in <linux/debug_locks.h> (Waiman Long) [2007032]
- locking/rtmutex: Prevent future include recursion hell (Waiman Long) [2007032]
- locking/spinlock: Split the lock types header, and move the raw types into <linux/spinlock_types_raw.h> (Waiman Long) [2007032]
- locking/rtmutex: Guard regular sleeping locks specific functions (Waiman Long) [2007032]
- locking/rtmutex: Prepare RT rt_mutex_wake_q for RT locks (Waiman Long) [2007032]
- locking/rtmutex: Use rt_mutex_wake_q_head (Waiman Long) [2007032]
- locking/rtmutex: Provide rt_wake_q_head and helpers (Waiman Long) [2007032]
- locking/rtmutex: Add wake_state to rt_mutex_waiter (Waiman Long) [2007032]
- locking/rwsem: Add rtmutex based R/W semaphore implementation (Waiman Long) [2007032]
- locking/rt: Add base code for RT rw_semaphore and rwlock (Waiman Long) [2007032]
- locking/rtmutex: Provide rt_mutex_base_is_locked() (Waiman Long) [2007032]
- locking/rtmutex: Provide rt_mutex_slowlock_locked() (Waiman Long) [2007032]
- locking/rtmutex: Split out the inner parts of 'struct rtmutex' (Waiman Long) [2007032]
- locking/rtmutex: Split API from implementation (Waiman Long) [2007032]
- locking/rtmutex: Switch to from cmpxchg_*() to try_cmpxchg_*() (Waiman Long) [2007032]
- locking/rtmutex: Convert macros to inlines (Waiman Long) [2007032]
- locking/rtmutex: Remove rt_mutex_is_locked() (Waiman Long) [2007032]
- sched/wake_q: Provide WAKE_Q_HEAD_INITIALIZER() (Waiman Long) [2007032]
- sched/core: Provide a scheduling point for RT locks (Waiman Long) [2007032]
- sched/core: Rework the __schedule() preempt argument (Waiman Long) [2007032]
- sched/wakeup: Prepare for RT sleeping spin/rwlocks (Waiman Long) [2007032]
- sched/wakeup: Reorganize the current::__state helpers (Waiman Long) [2007032]
- sched/wakeup: Introduce the TASK_RTLOCK_WAIT state bit (Waiman Long) [2007032]
- sched/wakeup: Split out the wakeup ->__state check (Waiman Long) [2007032]
- locking/rtmutex: Set proper wait context for lockdep (Waiman Long) [2007032]
- locking/local_lock: Add missing owner initialization (Waiman Long) [2007032]
- locking/mutex: Add MUTEX_WARN_ON (Waiman Long) [2007032]
- locking/mutex: Introduce __mutex_trylock_or_handoff() (Waiman Long) [2007032]
- locking/mutex: Fix HANDOFF condition (Waiman Long) [2007032]
- locking/mutex: Use try_cmpxchg() (Waiman Long) [2007032]

* Fri Nov 05 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-12.rt21.12.el9]
- redhat: make dist-srpm-gcov add to BUILDOPTS (Jan Stancek) [2017628]
- redhat: Fix dist-srpm-gcov (Jan Stancek) [2017628]
- s390: report more CPU capabilities (Robin Dapp) [2012095]
- s390/disassembler: add instructions (Robin Dapp) [2012095]
- audit: move put_tree() to avoid trim_trees refcount underflow and UAF (Richard Guy Briggs) [1985904]
- libbpf: Properly ignore STT_SECTION symbols in legacy map definitions (Jiri Olsa) [1998266]
- libbpf: Ignore STT_SECTION symbols in 'maps' section (Jiri Olsa) [1998266]
- selftests, bpf: test_lwt_ip_encap: Really disable rp_filter (Jiri Benc) [2006328]

* Fri Oct 29 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-11.rt21.11.el9]
- selinux: remove the SELinux lockdown implementation (Ondrej Mosnacek) [1940843 1945581]
- bpf: Fix integer overflow in prealloc_elems_and_freelist() (Yauheni Kaliuta) [2010494] {CVE-2021-41864}
- seltests: bpf: test_tunnel: Use ip neigh (Jiri Benc) [2006326]

* Wed Oct 27 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-10.rt21.10.el9]
- block: return ELEVATOR_DISCARD_MERGE if possible (Ming Lei) [1991958]
- blk-mq: avoid to iterate over stale request (Ming Lei) [2009110]
- redhat/configs: enable CONFIG_IMA_WRITE_POLICY (Bruno Meneguele) [2006320]
- CI: Update deprecated configs (Veronika Kabatova)

* Mon Oct 25 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-9.rt21.9.el9]
- powerpc/pseries: Prevent free CPU ids being reused on another node (Desnes A. Nunes do Rosario) [2004809]
- pseries/drmem: update LMBs after LPM (Desnes A. Nunes do Rosario) [2004809]
- powerpc/numa: Consider the max NUMA node for migratable LPAR (Desnes A. Nunes do Rosario) [2004809]
- selftests: bpf: disable test_lirc_mode2 (Jiri Benc) [2006359]
- selftests: bpf: disable test_doc_build.sh (Jiri Benc) [2006359]
- selftests: bpf: define SO_RCVTIMEO and SO_SNDTIMEO properly for ppc64le (Jiri Benc) [2006359]
- selftests: bpf: skip FOU tests in test_tc_tunnel (Jiri Benc) [2006359]
- selftests: bpf: disable test_seg6_loop test (Jiri Benc) [2006359]
- selftests: bpf: disable test_lwt_seg6local (Jiri Benc) [2006359]
- selftests: bpf: disable test_bpftool_build.sh (Jiri Benc) [2006359]
- selftests: add option to skip specific tests in RHEL (Jiri Benc) [2006359]

* Mon Oct 18 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-8.rt21.8.el9]
- selftests/powerpc: Add scv versions of the basic TM syscall tests (Desnes A. Nunes do Rosario) [1986651]
- powerpc/64s: system call scv tabort fix for corrupt irq soft-mask state (Desnes A. Nunes do Rosario) [1986651]
- mm/swap: consider max pages in iomap_swapfile_add_extent (Carlos Maiolino) [2005191]
- platform/x86/intel: pmc/core: Add GBE Package C10 fix for Alder Lake PCH (David Arcari) [2007707]
- platform/x86/intel: pmc/core: Add Alder Lake low power mode support for pmc core (David Arcari) [2007707]
- platform/x86/intel: pmc/core: Add Latency Tolerance Reporting (LTR) support to Alder Lake (David Arcari) [2007707]
- platform/x86/intel: pmc/core: Add Alderlake support to pmc core driver (David Arcari) [2007707]
- platform/x86: intel_pmc_core: Move to intel sub-directory (David Arcari) [2007707]
- platform/x86: intel_pmc_core: Prevent possibile overflow (David Arcari) [2007707]
- Clean-up CONFIG_X86_PLATFORM_DRIVERS_INTEL (David Arcari) [2007707]
- KVM: nVMX: Filter out all unsupported controls when eVMCS was activated (Vitaly Kuznetsov) [2001912]
- ipc: remove memcg accounting for sops objects in do_semtimedop() (Rafael Aquini) [1999707] {CVE-2021-3759}
- memcg: enable accounting of ipc resources (Rafael Aquini) [1999707] {CVE-2021-3759}
- redhat: BUILDID parameter must come last in genspec.sh (Herton R. Krzesinski)
- redhat/Makefile.variables: Set INCLUDE_FEDORA_FILES to 0 (Prarit Bhargava) [2009545]
- redhat: Remove fedora configs directories and files. (Prarit Bhargava) [2009545]
- redhat/kernel.spec.template: Cleanup source numbering (Prarit Bhargava) [2009545]
- redhat/kernel.spec.template: Reorganize RHEL and Fedora specific files (Prarit Bhargava) [2009545]
- redhat/kernel.spec.template: Add include_fedora and include_rhel variables (Prarit Bhargava) [2009545]
- redhat/Makefile: Make kernel-local global (Prarit Bhargava) [2009545]
- redhat/Makefile: Use flavors file (Prarit Bhargava) [2009545]

* Tue Oct 12 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-7.rt21.7.el9]
- locking/lockdep: Set sane defaults for lockdep entries on kernel-rt (Juri Lelli) [1990778]
- redhat: Enable Nitro Enclaves driver on x86 for real (Vitaly Kuznetsov) [2011739]
- redhat/.gitignore: Add rhel9 KABI files (Prarit Bhargava) [2009489]
- hwmon: (k10temp) Add support for yellow carp (David Arcari) [1987069]
- hwmon: (k10temp) Rework the temperature offset calculation (David Arcari) [1987069]
- hwmon: (k10temp) Don't show Tdie for all Zen/Zen2/Zen3 CPU/APU (David Arcari) [1987069]
- hwmon: (k10temp) Add additional missing Zen2 and Zen3 APUs (David Arcari) [1987069]
- hwmon: (k10temp) support Zen3 APUs (David Arcari) [1987069]
- selinux,smack: fix subjective/objective credential use mixups (Ondrej Mosnacek) [2008145]
- redhat: kernel.spec: selftests: abort on build failure (Jiri Benc) [2004012]
- Revert "bpf, selftests: Disable tests that need clang13" (Jiri Benc) [2004012]
- selftests, bpf: Fix makefile dependencies on libbpf (Jiri Benc) [2004012]

* Mon Oct 11 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-6.rt21.6.el9]
- pinctrl: Bulk conversion to generic_handle_domain_irq() (David Arcari) [2000232]
- pinctrl: amd: Handle wake-up interrupt (David Arcari) [2000232]
- pinctrl: amd: Add irq field data (David Arcari) [2000232]
- Revert "redhat: define _rhel variable because pesign macro now needs it" (Jan Stancek)
- redhat: switch secureboot kernel image signing to release keys (Jan Stancek)
- redhat/configs: Disable FIREWIRE (Prarit Bhargava) [1871862]
- Enable e1000 in rhel9 as unsupported (Ken Cox) [2002344]

* Fri Oct 01 2021 Juri Lelli <juri.lelli@redhat.com> [5.14.0-5.rt21.5.el9]
- redhat/configs: enable CONFIG_SQUASHFS_ZSTD which is already enabled in Fedora 34 (Tao Liu) [1998953]
- fs: dlm: fix return -EINTR on recovery stopped (Alexander Aring) [2004213]
- redhat: replace redhatsecureboot303 signing key with redhatsecureboot601 (Jan Stancek) [2002499]
- redhat: define _rhel variable because pesign macro now needs it (Jan Stancek) [2002499]
- redhat: drop certificates that were deprecated after GRUB's BootHole flaw (Jan Stancek) [1994849]
- redhat: correct file name of redhatsecurebootca1 (Jan Stancek) [2002499]
- redhat: align file names with names of signing keys for ppc and s390 (Jan Stancek) [2002499]
- redhat: restore sublevel in changelog (Jan Stancek)
- fs: dlm: avoid comms shutdown delay in release_lockspace (Alexander Aring) [1994749]
- redhat/configs: Enable CONFIG_BLK_CGROUP_IOLATENCY & CONFIG_BLK_CGROUP_FC_APPID (Waiman Long) [1996675]
- redhat/configs: remove conflicting SYSTEM_BLACKLIST_KEYRING (Bruno Meneguele) [2002350]
- Enable "inter server to server" NFSv4.2 COPY (Steve Dickson) [1487367]

* Thu Sep 23 2021 Juri Lelli <juri.lelli@redhat.com> [5.14-4.rt21.4.el9]
- Drivers: hv: vmbus: Fix kernel crash upon unbinding a device from uio_hv_generic driver (Vitaly Kuznetsov) [1999535]
- ipc: replace costly bailout check in sysvipc_find_ipc() (Rafael Aquini) [1987130 2003270] {CVE-2021-3669}
- redhat/configs: Disable CONFIG_DRM_VMWGFX on aarch64 (Michel Dänzer) [1996993]
- redhat: set USE_DIST_IN_SOURCE=1 for 9.0-beta (Jan Stancek)
- redhat: add option to use DIST tag in sources (Jan Stancek)
- CI: Enable notification messages for RHEL9 (Veronika Kabatova)
- CI: Enable private pipelines for RT branches (Veronika Kabatova)
- CI: Remove ARK leftovers (Veronika Kabatova)
- redhat: add *-matched meta packages to rpminspect emptyrpm config (Herton R. Krzesinski)
- gfs2: Don't call dlm after protocol is unmounted (Bob Peterson) [1988451]
- gfs2: don't stop reads while withdraw in progress (Bob Peterson) [1988451]
- gfs2: Mark journal inodes as "don't cache" (Bob Peterson) [1988451]
- cgroup/cpuset: Avoid memory migration when nodemasks match (Waiman Long) [1980430]
- cgroup/cpuset: Enable memory migration for cpuset v2 (Waiman Long) [1980430]
- iscsi_ibft: Fix isa_bus_to_virt not working under ARM (Maurizio Lombardi) [1963801]
- x86/setup: Explicitly include acpi.h (Maurizio Lombardi) [1963801]
- iscsi_ibft: fix warning in reserve_ibft_region() (Maurizio Lombardi) [1963801]
- iscsi_ibft: fix crash due to KASLR physical memory remapping (Maurizio Lombardi) [1963801]
- redhat: fix chronological order in the changelog file (Herton R. Krzesinski)

* Mon Sep 20 2021 Juri Lelli <juri.lelli@redhat.com> [5.14-3.rt21.3]
- redhat: Fix lasttag for kernel-rt (Juri Lelli)
- misc/pvpanic-pci: Allow automatic loading (Eric Auger) [1977192]
- md/raid10: Remove unnecessary rcu_dereference in raid10_handle_discard (Nigel Croxon) [1965294]
- rcu: Avoid unneeded function call in rcu_read_unlock() (Waiman Long) [1998549]
- Enable bridge jobs for scratch pipelines (Michael Hofmann)
- CI: use 9.0-beta-rt branch for -rt pipeline (Jan Stancek)
- crypto: ccp - Add support for new CCP/PSP device ID (Vladis Dronov) [1987099]
- crypto: ccp - shutdown SEV firmware on kexec (Vladis Dronov) [1987099]
- v5.14.2-rt21 (Clark Williams) [2002474]
- lockdep: Let lock_is_held_type() detect recursive read as read (Clark Williams) [2002474]
- drm/i915/gt: Use spin_lock_irq() instead of local_irq_disable() + spin_lock() (Clark Williams) [2002474]
- drm/i915/gt: Queue and wait for the irq_work item. (Clark Williams) [2002474]
- irq_work: Also rcuwait for !IRQ_WORK_HARD_IRQ on PREEMPT_RT (Clark Williams) [2002474]
- irq_work: Allow irq_work_sync() to sleep if irq_work() no IRQ support. (Clark Williams) [2002474]
- virt: acrn: Remove unsued acrn_irqfds_mutex. (Clark Williams) [2002474]
- smack: Guard smack_ipv6_lock definition within a SMACK_IPV6_PORT_LABELING block (Clark Williams) [2002474]
- ASoC: mediatek: mt8195: Remove unsued irqs_lock. (Clark Williams) [2002474]
- mm: Update Vlastimil Babka's SLUB series (Clark Williams) [2002474]
- locking: Remove rt_rwlock_is_contended() (Clark Williams) [2002474]
- locking/rtmutex: Fix ww_mutex deadlock check (Clark Williams) [2002474]
- sched: Make the idle timer expire always in hardirq context. (Clark Williams) [2002474]
- futex: Avoid redundant task lookup (Clark Williams) [2002474]
- futex: Clarify comment for requeue_pi_wake_futex() (Clark Williams) [2002474]
- futex: Prevent inconsistent state and exit race (Clark Williams) [2002474]
- futex: Return error code instead of assigning it without effect (Clark Williams) [2002474]
- lockdep: Let lock_is_held_type() detect recursive read as read (Clark Williams) [2002474]
- kcov: Replace local_irq_save() with a local_lock_t. (Clark Williams) [2002474]
- kcov: Avoid enable+disable interrupts if !in_task(). (Clark Williams) [2002474]
- kcov: Allocate per-CPU memory on the relevant node. (Clark Williams) [2002474]
- Documentation/kcov: Define `ip' in the example. (Clark Williams) [2002474]
- Documentation/kcov: Include types.h in the example. (Clark Williams) [2002474]
- sched: Prevent balance_push() on remote runqueues (Clark Williams) [2002474]

* Tue Sep 14 2021 Juri Lelli <juri.lelli@redhat.com> [5.14-2.rt15.2]
- redhat: Update RTBZ for 9.0 GA (Juri Lelli)
- redhat: Add machinery for official RT builds (Juri Lelli)
- redhat: update branches/targets after 9 Beta fork (Herton R. Krzesinski)
- hv_utils: Set the maximum packet size for VSS driver to the length of the receive buffer (Vitaly Kuznetsov) [1996628]
- Enable bridge jobs for scratch pipelines (Michael Hofmann)
- redhat: Fix legacy terminology (Juri Lelli)
- redhat: Use kernel changelog as starting base for kernel-rt (Juri Lelli)
- redhat: Change gating configuration for RT kernel (Juri Lelli)
- config: disable KASAN for kernel-rt-debug kernels (Luis Claudio R. Goncalves) [1977862]
- redhat: Add realtime-setup dependecy for kernel-rt metapackage (Juri Lelli) [1937013]
- spec: Generate separate kernel-rt-kvm packages (Juri Lelli)
- Add RT config options (Juri Lelli)
- specfile: Add with_realtime (Juri Lelli)
- RTize build scripts (Juri Lelli)
- Add localversion for -RT release (Thomas Gleixner)
- POWERPC: Allow to enable RT (Sebastian Andrzej Siewior)
- powerpc/stackprotector: work around stack-guard init from atomic (Sebastian Andrzej Siewior)
- powerpc/kvm: Disable in-kernel MPIC emulation for PREEMPT_RT (Bogdan Purcareata)
- powerpc/pseries/iommu: Use a locallock instead local_irq_save() (Sebastian Andrzej Siewior)
- powerpc: traps: Use PREEMPT_RT (Sebastian Andrzej Siewior)
- ARM64: Allow to enable RT (Sebastian Andrzej Siewior)
- ARM: Allow to enable RT (Sebastian Andrzej Siewior)
- arm64/sve: Make kernel FPU protection RT friendly (Sebastian Andrzej Siewior)
- arm64/sve: Delay freeing memory in fpsimd_flush_thread() (Sebastian Andrzej Siewior)
- KVM: arm/arm64: downgrade preempt_disable()d region to migrate_disable() (Josh Cartwright)
- ARM: enable irq in translation/section permission fault handlers (Yadi.hu)
- arch/arm64: Add lazy preempt support (Anders Roxell)
- powerpc: Add support for lazy preemption (Thomas Gleixner)
- arm: Add support for lazy preemption (Thomas Gleixner)
- entry: Fix the preempt lazy fallout (Thomas Gleixner)
- x86: Support for lazy preemption (Thomas Gleixner)
- x86/entry: Use should_resched() in idtentry_exit_cond_resched() (Sebastian Andrzej Siewior)
- sched: Add support for lazy preemption (Thomas Gleixner)
- x86: Enable RT also on 32bit (Sebastian Andrzej Siewior)
- x86: Allow to enable RT (Sebastian Andrzej Siewior)
- x86: kvm Require const tsc for RT (Thomas Gleixner)
- signal/x86: Delay calling signals in atomic (Oleg Nesterov)
- sysfs: Add /sys/kernel/realtime entry (Clark Williams)
- tpm_tis: fix stall after iowrite*()s (Haris Okanovic)
- tty/serial/pl011: Make the locking work on RT (Thomas Gleixner)
- tty/serial/omap: Make the locking RT aware (Thomas Gleixner)
- drm/i915/gt: Only disable interrupts for the timeline lock on !force-threaded (Sebastian Andrzej Siewior)
- drm/i915: skip DRM_I915_LOW_LEVEL_TRACEPOINTS with NOTRACE (Sebastian Andrzej Siewior)
- drm/i915: disable tracing on -RT (Sebastian Andrzej Siewior)
- drm/i915: Don't disable interrupts on PREEMPT_RT during atomic updates (Mike Galbraith)
- drm,radeon,i915: Use preempt_disable/enable_rt() where recommended (Mike Galbraith)
- random: Make it work on rt (Thomas Gleixner)
- x86: stackprotector: Avoid random pool on rt (Thomas Gleixner)
- panic: skip get_random_bytes for RT_FULL in init_oops_id (Thomas Gleixner)
- crypto: testmgr - Only disable migration in crypto_disable_simd_for_test() (Sebastian Andrzej Siewior)
- crypto: cryptd - add a lock instead preempt_disable/local_bh_disable (Sebastian Andrzej Siewior)
- crypto: limit more FPU-enabled sections (Sebastian Andrzej Siewior)
- scsi/fcoe: Make RT aware. (Thomas Gleixner)
- md: raid5: Make raid5_percpu handling RT aware (Thomas Gleixner)
- drivers/block/zram: Replace bit spinlocks with rtmutex for -rt (Mike Galbraith)
- block/mq: do not invoke preempt_disable() (Sebastian Andrzej Siewior)
- net: Remove preemption disabling in netif_rx() (Priyanka Jain)
- net: dev: always take qdisc's busylock in __dev_xmit_skb() (Sebastian Andrzej Siewior)
- net: Dequeue in dev_cpu_dead() without the lock (Sebastian Andrzej Siewior)
- net: Use skbufhead with raw lock (Thomas Gleixner)
- sunrpc: Make svc_xprt_do_enqueue() use get_cpu_light() (Mike Galbraith)
- net/core: use local_bh_disable() in netif_rx_ni() (Sebastian Andrzej Siewior)
- net: Properly annotate the try-lock for the seqlock (Sebastian Andrzej Siewior)
- net/Qdisc: use a seqlock instead seqcount (Sebastian Andrzej Siewior)
- rcutorture: Avoid problematic critical section nesting on PREEMPT_RT (From: Scott Wood)
- rcu: Delay RCU-selftests (Sebastian Andrzej Siewior)
- fs: namespace: Use cpu_chill() in trylock loops (Thomas Gleixner)
- rt: Introduce cpu_chill() (Thomas Gleixner)
- fs/dcache: disable preemption on i_dir_seq's write side (Sebastian Andrzej Siewior)
- fs/dcache: use swait_queue instead of waitqueue (Sebastian Andrzej Siewior)
- ptrace: fix ptrace vs tasklist_lock race (Sebastian Andrzej Siewior)
- signal: Revert ptrace preempt magic (Thomas Gleixner)
- mm/memcontrol: Disable on PREEMPT_RT (Thomas Gleixner)
- mm/scatterlist: Do not disable irqs on RT (Thomas Gleixner)
- mm/vmalloc: Another preempt disable region which sucks (Thomas Gleixner)
- mm/zsmalloc: copy with get_cpu_var() and locking (Mike Galbraith)
- u64_stats: Disable preemption on 32bit-UP/SMP with RT during updates (Sebastian Andrzej Siewior)
- mm/vmstat: Protect per cpu variables with preempt disable on RT (Ingo Molnar)
- mm: page_alloc: Use migrate_disable() in drain_local_pages_wq() (Sebastian Andrzej Siewior)
- irqwork: push most work into softirq context (Sebastian Andrzej Siewior)
- softirq: Disable softirq stacks for RT (Thomas Gleixner)
- softirq: Check preemption after reenabling interrupts (Thomas Gleixner)
- cpuset: Convert callback_lock to raw_spinlock_t (Mike Galbraith)
- sched: Disable TTWU_QUEUE on RT (Thomas Gleixner)
- sched: Do not account rcu_preempt_depth on RT in might_sleep() (Thomas Gleixner)
- kernel/sched: move stack + kprobe clean up to __put_task_struct() (Sebastian Andrzej Siewior)
- sched: Move mmdrop to RCU on RT (Thomas Gleixner)
- sched: Limit the number of task migrations per batch (Thomas Gleixner)
- kernel/sched: add {put|get}_cpu_light() (Sebastian Andrzej Siewior)
- preempt: Provide preempt_*_(no)rt variants (Thomas Gleixner)
- locking: Allow to include asm/spinlock_types.h from linux/spinlock_types_raw.h (Sebastian Andrzej Siewior)
- lockdep/selftests: Adapt ww-tests for PREEMPT_RT (Sebastian Andrzej Siewior)
- lockdep/selftests: Skip the softirq related tests on PREEMPT_RT (Sebastian Andrzej Siewior)
- lockdep/selftests: Unbalanced migrate_disable() & rcu_read_lock() (Sebastian Andrzej Siewior)
- lockdep/selftests: Add rtmutex to the last column (Sebastian Andrzej Siewior)
- lockdep: Make it RT aware (Thomas Gleixner)
- rtmutex: Add rt_mutex_lock_nest_lock() and rt_mutex_lock_killable(). (Sebastian Andrzej Siewior)
- rtmutex: Add a special case for ww-mutex handling. (Sebastian Andrzej Siewior)
- sched: Trigger warning if ->migration_disabled counter underflows. (Sebastian Andrzej Siewior)
- lockdep/selftests: Avoid using local_lock_{acquire|release}(). (Sebastian Andrzej Siewior)
- locking/rtmutex: Prevent spurious EDEADLK return caused by ww_mutexes (Peter Zijlstra)
- locking/rtmutex: Return success on deadlock for ww_mutex waiters (Peter Zijlstra)
- locking/rtmutex: Dequeue waiter on ww_mutex deadlock (Thomas Gleixner)
- locking/rtmutex: Dont dereference waiter lockless (Thomas Gleixner)
- locking/ww_mutex: Initialize waiter.ww_ctx properly (Sebastian Andrzej Siewior)
- locking/local_lock: Add PREEMPT_RT support (Thomas Gleixner)
- locking/spinlock/rt: Prepare for RT local_lock (Thomas Gleixner)
- locking/rtmutex: Add adaptive spinwait mechanism (Steven Rostedt)
- locking/rtmutex: Implement equal priority lock stealing (Gregory Haskins)
- preempt: Adjust PREEMPT_LOCK_OFFSET for RT (Thomas Gleixner)
- locking/rtmutex: Prevent lockdep false positive with PI futexes (Thomas Gleixner)
- futex: Prevent requeue_pi() lock nesting issue on RT (Thomas Gleixner)
- futex: Simplify handle_early_requeue_pi_wakeup() (Thomas Gleixner)
- futex: Reorder sanity checks in futex_requeue() (Thomas Gleixner)
- futex: Clarify comment in futex_requeue() (Thomas Gleixner)
- futex: Restructure futex_requeue() (Thomas Gleixner)
- futex: Correct the number of requeued waiters for PI (Thomas Gleixner)
- futex: Remove bogus condition for requeue PI (Thomas Gleixner)
- futex: Clarify futex_requeue() PI handling (Thomas Gleixner)
- futex: Clean up stale comments (Thomas Gleixner)
- futex: Validate waiter correctly in futex_proxy_trylock_atomic() (Thomas Gleixner)
- lib/test_lockup: Adapt to changed variables (Sebastian Andrzej Siewior)
- locking/rtmutex: Add mutex variant for RT (Thomas Gleixner)
- locking/ww_mutex: Implement rtmutex based ww_mutex API functions (Peter Zijlstra)
- locking/rtmutex: Extend the rtmutex core to support ww_mutex (Peter Zijlstra)
- locking/ww_mutex: Add rt_mutex based lock type and accessors (Peter Zijlstra)
- locking/ww_mutex: Add RT priority to W/W order (Peter Zijlstra)
- locking/ww_mutex: Implement rt_mutex accessors (Peter Zijlstra)
- locking/ww_mutex: Abstract out internal lock accesses (Thomas Gleixner)
- locking/ww_mutex: Abstract out mutex types (Peter Zijlstra)
- locking/ww_mutex: Abstract out mutex accessors (Peter Zijlstra)
- locking/ww_mutex: Abstract out waiter enqueueing (Peter Zijlstra)
- locking/ww_mutex: Abstract out the waiter iteration (Peter Zijlstra)
- locking/ww_mutex: Remove the __sched annotation from ww_mutex APIs (Peter Zijlstra)
- locking/ww_mutex: Split out the W/W implementation logic into kernel/locking/ww_mutex.h (Peter Zijlstra (Intel))
- locking/ww_mutex: Split up ww_mutex_unlock() (Peter Zijlstra (Intel))
- locking/ww_mutex: Gather mutex_waiter initialization (Peter Zijlstra)
- locking/ww_mutex: Simplify lockdep annotations (Peter Zijlstra)
- locking/mutex: Make mutex::wait_lock raw (Thomas Gleixner)
- locking/ww_mutex: Move the ww_mutex definitions from <linux/mutex.h> into <linux/ww_mutex.h> (Thomas Gleixner)
- locking/mutex: Move the 'struct mutex_waiter' definition from <linux/mutex.h> to the internal header (Thomas Gleixner)
- locking/mutex: Consolidate core headers, remove kernel/locking/mutex-debug.h (Thomas Gleixner)
- locking/rtmutex: Squash !RT tasks to DEFAULT_PRIO (Peter Zijlstra)
- locking/rwlock: Provide RT variant (Thomas Gleixner)
- locking/spinlock: Provide RT variant (Thomas Gleixner)
- locking/rtmutex: Provide the spin/rwlock core lock function (Thomas Gleixner)
- locking/spinlock: Provide RT variant header: <linux/spinlock_rt.h> (Thomas Gleixner)
- locking/spinlock: Provide RT specific spinlock_t (Thomas Gleixner)
- locking/rtmutex: Reduce <linux/rtmutex.h> header dependencies, only include <linux/rbtree_types.h> (Sebastian Andrzej Siewior)
- rbtree: Split out the rbtree type definitions into <linux/rbtree_types.h> (Sebastian Andrzej Siewior)
- locking/lockdep: Reduce header dependencies in <linux/debug_locks.h> (Sebastian Andrzej Siewior)
- locking/rtmutex: Prevent future include recursion hell (Sebastian Andrzej Siewior)
- locking/spinlock: Split the lock types header, and move the raw types into <linux/spinlock_types_raw.h> (Thomas Gleixner)
- locking/rtmutex: Guard regular sleeping locks specific functions (Thomas Gleixner)
- locking/rtmutex: Prepare RT rt_mutex_wake_q for RT locks (Thomas Gleixner)
- locking/rtmutex: Use rt_mutex_wake_q_head (Thomas Gleixner)
- locking/rtmutex: Provide rt_wake_q_head and helpers (Thomas Gleixner)
- locking/rtmutex: Add wake_state to rt_mutex_waiter (Thomas Gleixner)
- locking/rwsem: Add rtmutex based R/W semaphore implementation (Thomas Gleixner)
- locking/rt: Add base code for RT rw_semaphore and rwlock (Thomas Gleixner)
- locking/rtmutex: Provide rt_mutex_base_is_locked() (Thomas Gleixner)
- locking/rtmutex: Provide rt_mutex_slowlock_locked() (Thomas Gleixner)
- locking/rtmutex: Split out the inner parts of 'struct rtmutex' (Peter Zijlstra)
- locking/rtmutex: Split API from implementation (Thomas Gleixner)
- locking/rtmutex: Switch to from cmpxchg_*() to try_cmpxchg_*() (Thomas Gleixner)
- locking/rtmutex: Convert macros to inlines (Sebastian Andrzej Siewior)
- locking/rtmutex: Remove rt_mutex_is_locked() (Peter Zijlstra)
- media/atomisp: Use lockdep instead of *mutex_is_locked() (Peter Zijlstra)
- sched/wake_q: Provide WAKE_Q_HEAD_INITIALIZER() (Thomas Gleixner)
- sched/core: Provide a scheduling point for RT locks (Thomas Gleixner)
- sched/core: Rework the __schedule() preempt argument (Thomas Gleixner)
- sched/wakeup: Prepare for RT sleeping spin/rwlocks (Thomas Gleixner)
- sched/wakeup: Reorganize the current::__state helpers (Thomas Gleixner)
- sched/wakeup: Introduce the TASK_RTLOCK_WAIT state bit (Thomas Gleixner)
- sched/wakeup: Split out the wakeup ->__state check (Thomas Gleixner)
- locking/rtmutex: Set proper wait context for lockdep (Thomas Gleixner)
- locking/local_lock: Add missing owner initialization (Thomas Gleixner)
- debugobjects: Make RT aware (Thomas Gleixner)
- trace: Add migrate-disabled counter to tracing output (Thomas Gleixner)
- pid.h: include atomic.h (Grygorii Strashko)
- wait.h: include atomic.h (Sebastian Andrzej Siewior)
- efi: Allow efi=runtime (Sebastian Andrzej Siewior)
- efi: Disable runtime services on RT (Sebastian Andrzej Siewior)
- net/core: disable NET_RX_BUSY_POLL on RT (Sebastian Andrzej Siewior)
- sched: Disable CONFIG_RT_GROUP_SCHED on RT (Thomas Gleixner)
- mm: Allow only SLUB on RT (Ingo Molnar)
- kconfig: Disable config options which are not RT compatible (Thomas Gleixner)
- leds: trigger: disable CPU trigger on -RT (Sebastian Andrzej Siewior)
- jump-label: disable if stop_machine() is used (Thomas Gleixner)
- genirq: Disable irqpoll on -rt (Ingo Molnar)
- io-wq: Don't mix raw_spinlock_irq() & spin_lock_irq(). (Sebastian Andrzej Siewior)
- io-wq: remove GFP_ATOMIC allocation off schedule out path (Jens Axboe)
- genirq: update irq_set_irqchip_state documentation (Josh Cartwright)
- smp: Wake ksoftirqd on PREEMPT_RT instead do_softirq(). (Sebastian Andrzej Siewior)
- samples/kfifo: Rename read_lock/write_lock (Sebastian Andrzej Siewior)
- tcp: Remove superfluous BH-disable around listening_hash (Sebastian Andrzej Siewior)
- net: Move lockdep where it belongs (Thomas Gleixner)
- shmem: Use raw_spinlock_t for ->stat_lock (Sebastian Andrzej Siewior)
- mm: workingset: replace IRQ-off check with a lockdep assert. (Sebastian Andrzej Siewior)
- cgroup: use irqsave in cgroup_rstat_flush_locked() (Sebastian Andrzej Siewior)
- genirq: Move prio assignment into the newly created thread (Thomas Gleixner)
- kthread: Move prio/affinite change into the newly created thread (Sebastian Andrzej Siewior)
- sched: Prevent balance_push() on remote runqueues (Thomas Gleixner)
- sched: Switch wait_task_inactive to HRTIMER_MODE_REL_HARD (Sebastian Andrzej Siewior)
- highmem: Don't disable preemption on RT in kmap_atomic() (Sebastian Andrzej Siewior)
- mm, slub: convert kmem_cpu_slab protection to local_lock (Vlastimil Babka)
- mm, slub: use migrate_disable() on PREEMPT_RT (Vlastimil Babka)
- mm, slub: protect put_cpu_partial() with disabled irqs instead of cmpxchg (Vlastimil Babka)
- mm, slub: make slab_lock() disable irqs with PREEMPT_RT (Vlastimil Babka)
- mm, slub: optionally save/restore irqs in slab_[un]lock()/ (Vlastimil Babka)
- mm: slub: Make object_map_lock a raw_spinlock_t (Sebastian Andrzej Siewior)
- mm: slub: Move flush_cpu_slab() invocations __free_slab() invocations out of IRQ context (Sebastian Andrzej Siewior)
- mm, slab: make flush_slab() possible to call with irqs enabled (Vlastimil Babka)
- mm, slub: don't disable irqs in slub_cpu_dead() (Vlastimil Babka)
- mm, slub: only disable irq with spin_lock in __unfreeze_partials() (Vlastimil Babka)
- mm, slub: separate detaching of partial list in unfreeze_partials() from unfreezing (Vlastimil Babka)
- mm, slub: detach whole partial list at once in unfreeze_partials() (Vlastimil Babka)
- mm, slub: discard slabs in unfreeze_partials() without irqs disabled (Vlastimil Babka)
- mm, slub: move irq control into unfreeze_partials() (Vlastimil Babka)
- mm, slub: call deactivate_slab() without disabling irqs (Vlastimil Babka)
- mm, slub: make locking in deactivate_slab() irq-safe (Vlastimil Babka)
- mm, slub: move reset of c->page and freelist out of deactivate_slab() (Vlastimil Babka)
- mm, slub: stop disabling irqs around get_partial() (Vlastimil Babka)
- mm, slub: check new pages with restored irqs (Vlastimil Babka)
- mm, slub: validate slab from partial list or page allocator before making it cpu slab (Vlastimil Babka)
- mm, slub: restore irqs around calling new_slab() (Vlastimil Babka)
- mm, slub: move disabling irqs closer to get_partial() in ___slab_alloc() (Vlastimil Babka)
- mm, slub: do initial checks in ___slab_alloc() with irqs enabled (Vlastimil Babka)
- mm, slub: move disabling/enabling irqs to ___slab_alloc() (Vlastimil Babka)
- mm, slub: simplify kmem_cache_cpu and tid setup (Vlastimil Babka)
- mm, slub: restructure new page checks in ___slab_alloc() (Vlastimil Babka)
- mm, slub: return slab page from get_partial() and set c->page afterwards (Vlastimil Babka)
- mm, slub: dissolve new_slab_objects() into ___slab_alloc() (Vlastimil Babka)
- mm, slub: extract get_partial() from new_slab_objects() (Vlastimil Babka)
- mm, slub: unify cmpxchg_double_slab() and __cmpxchg_double_slab() (Vlastimil Babka)
- mm, slub: remove redundant unfreeze_partials() from put_cpu_partial() (Vlastimil Babka)
- mm, slub: don't disable irq for debug_check_no_locks_freed() (Vlastimil Babka)
- mm, slub: allocate private object map for validate_slab_cache() (Vlastimil Babka)
- mm, slub: allocate private object map for debugfs listings (Vlastimil Babka)
- mm, slub: don't call flush_all() from slab_debug_trace_open() (Vlastimil Babka)
- printk: Enhance the condition check of msleep in pr_flush() (Chao Qin)
- printk: add pr_flush() (John Ogness)
- printk: add console handover (John Ogness)
- printk: remove deferred printing (John Ogness)
- printk: move console printing to kthreads (John Ogness)
- printk: introduce kernel sync mode (John Ogness)
- printk: use seqcount_latch for console_seq (John Ogness)
- printk: call boot_delay_msec() in printk_delay() (John Ogness)
- printk: relocate printk_delay() (John Ogness)
- serial: 8250: implement write_atomic (John Ogness)
- kdb: only use atomic consoles for output mirroring (John Ogness)
- console: add write_atomic interface (John Ogness)
- printk: rename printk cpulock API and always disable interrupts (John Ogness)
- printk: syslog: close window between wait and read (John Ogness)
- printk: convert @syslog_lock to mutex (John Ogness)
- printk: remove NMI tracking (John Ogness)
- printk: remove safe buffers (John Ogness)
- printk: track/limit recursion (John Ogness)
- lib/nmi_backtrace: explicitly serialize banner and regs (John Ogness)
- printk/console: Check consistent sequence number when handling race in console_unlock() (Petr Mladek)
- arm64: mm: Make arch_faults_on_old_pte() check for migratability (Valentin Schneider)
- rcu/nocb: Protect NOCB state via local_lock() under PREEMPT_RT (Valentin Schneider)
- sched: Introduce migratable() (Valentin Schneider)
- eventfd: Make signal recursion protection a task bit (Thomas Gleixner)
- notifier: Remove atomic_notifier_call_chain_robust() (Valentin Schneider)
- cpu_pm: Make notifier chain use a raw_spinlock_t (Valentin Schneider)

* Tue Sep 14 2021 Juri Lelli <juri.lelli@redhat.com> [5.14-2.rt15.1]
- kernel-rt-5.14.0-1.rt15.1.el9 rebase
- redhat: Update RTBZ for 9.0 GA (Juri Lelli)
- redhat: Add machinery for official RT builds (Juri Lelli)
- redhat: Fix legacy terminology (Juri Lelli)
- redhat: Use kernel changelog as starting base for kernel-rt (Juri Lelli)
- redhat: Change gating configuration for RT kernel (Juri Lelli)
- config: disable KASAN for kernel-rt-debug kernels (Luis Claudio R. Goncalves) [1977862]
- redhat: Add realtime-setup dependecy for kernel-rt metapackage (Juri Lelli) [1937013]
- spec: Generate separate kernel-rt-kvm packages (Juri Lelli)
- Add RT config options (Juri Lelli)
- specfile: Add with_realtime (Juri Lelli)
- RTize build scripts (Juri Lelli)
- Add localversion for -RT release (Thomas Gleixner)
- POWERPC: Allow to enable RT (Sebastian Andrzej Siewior)
- powerpc/stackprotector: work around stack-guard init from atomic (Sebastian Andrzej Siewior)
- powerpc/kvm: Disable in-kernel MPIC emulation for PREEMPT_RT (Bogdan Purcareata)
- powerpc/pseries/iommu: Use a locallock instead local_irq_save() (Sebastian Andrzej Siewior)
- powerpc: traps: Use PREEMPT_RT (Sebastian Andrzej Siewior)
- ARM64: Allow to enable RT (Sebastian Andrzej Siewior)
- ARM: Allow to enable RT (Sebastian Andrzej Siewior)
- arm64/sve: Make kernel FPU protection RT friendly (Sebastian Andrzej Siewior)
- arm64/sve: Delay freeing memory in fpsimd_flush_thread() (Sebastian Andrzej Siewior)
- KVM: arm/arm64: downgrade preempt_disable()d region to migrate_disable() (Josh Cartwright)
- ARM: enable irq in translation/section permission fault handlers (Yadi.hu)
- arch/arm64: Add lazy preempt support (Anders Roxell)
- powerpc: Add support for lazy preemption (Thomas Gleixner)
- arm: Add support for lazy preemption (Thomas Gleixner)
- entry: Fix the preempt lazy fallout (Thomas Gleixner)
- x86: Support for lazy preemption (Thomas Gleixner)
- x86/entry: Use should_resched() in idtentry_exit_cond_resched() (Sebastian Andrzej Siewior)
- sched: Add support for lazy preemption (Thomas Gleixner)
- x86: Enable RT also on 32bit (Sebastian Andrzej Siewior)
- x86: Allow to enable RT (Sebastian Andrzej Siewior)
- x86: kvm Require const tsc for RT (Thomas Gleixner)
- signal/x86: Delay calling signals in atomic (Oleg Nesterov)
- sysfs: Add /sys/kernel/realtime entry (Clark Williams)
- tpm_tis: fix stall after iowrite*()s (Haris Okanovic)
- tty/serial/pl011: Make the locking work on RT (Thomas Gleixner)
- tty/serial/omap: Make the locking RT aware (Thomas Gleixner)
- drm/i915/gt: Only disable interrupts for the timeline lock on !force-threaded (Sebastian Andrzej Siewior)
- drm/i915: skip DRM_I915_LOW_LEVEL_TRACEPOINTS with NOTRACE (Sebastian Andrzej Siewior)
- drm/i915: disable tracing on -RT (Sebastian Andrzej Siewior)
- drm/i915: Don't disable interrupts on PREEMPT_RT during atomic updates (Mike Galbraith)
- drm,radeon,i915: Use preempt_disable/enable_rt() where recommended (Mike Galbraith)
- random: Make it work on rt (Thomas Gleixner)
- x86: stackprotector: Avoid random pool on rt (Thomas Gleixner)
- panic: skip get_random_bytes for RT_FULL in init_oops_id (Thomas Gleixner)
- crypto: testmgr - Only disable migration in crypto_disable_simd_for_test() (Sebastian Andrzej Siewior)
- crypto: cryptd - add a lock instead preempt_disable/local_bh_disable (Sebastian Andrzej Siewior)
- crypto: limit more FPU-enabled sections (Sebastian Andrzej Siewior)
- scsi/fcoe: Make RT aware. (Thomas Gleixner)
- md: raid5: Make raid5_percpu handling RT aware (Thomas Gleixner)
- drivers/block/zram: Replace bit spinlocks with rtmutex for -rt (Mike Galbraith)
- block/mq: do not invoke preempt_disable() (Sebastian Andrzej Siewior)
- net: Remove preemption disabling in netif_rx() (Priyanka Jain)
- net: dev: always take qdisc's busylock in __dev_xmit_skb() (Sebastian Andrzej Siewior)
- net: Dequeue in dev_cpu_dead() without the lock (Sebastian Andrzej Siewior)
- net: Use skbufhead with raw lock (Thomas Gleixner)
- sunrpc: Make svc_xprt_do_enqueue() use get_cpu_light() (Mike Galbraith)
- net/core: use local_bh_disable() in netif_rx_ni() (Sebastian Andrzej Siewior)
- net: Properly annotate the try-lock for the seqlock (Sebastian Andrzej Siewior)
- net/Qdisc: use a seqlock instead seqcount (Sebastian Andrzej Siewior)
- rcutorture: Avoid problematic critical section nesting on PREEMPT_RT (From: Scott Wood)
- rcu: Delay RCU-selftests (Sebastian Andrzej Siewior)
- fs: namespace: Use cpu_chill() in trylock loops (Thomas Gleixner)
- rt: Introduce cpu_chill() (Thomas Gleixner)
- fs/dcache: disable preemption on i_dir_seq's write side (Sebastian Andrzej Siewior)
- fs/dcache: use swait_queue instead of waitqueue (Sebastian Andrzej Siewior)
- ptrace: fix ptrace vs tasklist_lock race (Sebastian Andrzej Siewior)
- signal: Revert ptrace preempt magic (Thomas Gleixner)
- mm/memcontrol: Disable on PREEMPT_RT (Thomas Gleixner)
- mm/scatterlist: Do not disable irqs on RT (Thomas Gleixner)
- mm/vmalloc: Another preempt disable region which sucks (Thomas Gleixner)
- mm/zsmalloc: copy with get_cpu_var() and locking (Mike Galbraith)
- u64_stats: Disable preemption on 32bit-UP/SMP with RT during updates (Sebastian Andrzej Siewior)
- mm/vmstat: Protect per cpu variables with preempt disable on RT (Ingo Molnar)
- mm: page_alloc: Use migrate_disable() in drain_local_pages_wq() (Sebastian Andrzej Siewior)
- irqwork: push most work into softirq context (Sebastian Andrzej Siewior)
- softirq: Disable softirq stacks for RT (Thomas Gleixner)
- softirq: Check preemption after reenabling interrupts (Thomas Gleixner)
- cpuset: Convert callback_lock to raw_spinlock_t (Mike Galbraith)
- sched: Disable TTWU_QUEUE on RT (Thomas Gleixner)
- sched: Do not account rcu_preempt_depth on RT in might_sleep() (Thomas Gleixner)
- kernel/sched: move stack + kprobe clean up to __put_task_struct() (Sebastian Andrzej Siewior)
- sched: Move mmdrop to RCU on RT (Thomas Gleixner)
- sched: Limit the number of task migrations per batch (Thomas Gleixner)
- kernel/sched: add {put|get}_cpu_light() (Sebastian Andrzej Siewior)
- preempt: Provide preempt_*_(no)rt variants (Thomas Gleixner)
- locking: Allow to include asm/spinlock_types.h from linux/spinlock_types_raw.h (Sebastian Andrzej Siewior)
- lockdep/selftests: Adapt ww-tests for PREEMPT_RT (Sebastian Andrzej Siewior)
- lockdep/selftests: Skip the softirq related tests on PREEMPT_RT (Sebastian Andrzej Siewior)
- lockdep/selftests: Unbalanced migrate_disable() & rcu_read_lock() (Sebastian Andrzej Siewior)
- lockdep/selftests: Add rtmutex to the last column (Sebastian Andrzej Siewior)
- lockdep: Make it RT aware (Thomas Gleixner)
- rtmutex: Add rt_mutex_lock_nest_lock() and rt_mutex_lock_killable(). (Sebastian Andrzej Siewior)
- rtmutex: Add a special case for ww-mutex handling. (Sebastian Andrzej Siewior)
- sched: Trigger warning if ->migration_disabled counter underflows. (Sebastian Andrzej Siewior)
- lockdep/selftests: Avoid using local_lock_{acquire|release}(). (Sebastian Andrzej Siewior)
- locking/rtmutex: Prevent spurious EDEADLK return caused by ww_mutexes (Peter Zijlstra)
- locking/rtmutex: Return success on deadlock for ww_mutex waiters (Peter Zijlstra)
- locking/rtmutex: Dequeue waiter on ww_mutex deadlock (Thomas Gleixner)
- locking/rtmutex: Dont dereference waiter lockless (Thomas Gleixner)
- locking/ww_mutex: Initialize waiter.ww_ctx properly (Sebastian Andrzej Siewior)
- locking/local_lock: Add PREEMPT_RT support (Thomas Gleixner)
- locking/spinlock/rt: Prepare for RT local_lock (Thomas Gleixner)
- locking/rtmutex: Add adaptive spinwait mechanism (Steven Rostedt)
- locking/rtmutex: Implement equal priority lock stealing (Gregory Haskins)
- preempt: Adjust PREEMPT_LOCK_OFFSET for RT (Thomas Gleixner)
- locking/rtmutex: Prevent lockdep false positive with PI futexes (Thomas Gleixner)
- futex: Prevent requeue_pi() lock nesting issue on RT (Thomas Gleixner)
- futex: Simplify handle_early_requeue_pi_wakeup() (Thomas Gleixner)
- futex: Reorder sanity checks in futex_requeue() (Thomas Gleixner)
- futex: Clarify comment in futex_requeue() (Thomas Gleixner)
- futex: Restructure futex_requeue() (Thomas Gleixner)
- futex: Correct the number of requeued waiters for PI (Thomas Gleixner)
- futex: Remove bogus condition for requeue PI (Thomas Gleixner)
- futex: Clarify futex_requeue() PI handling (Thomas Gleixner)
- futex: Clean up stale comments (Thomas Gleixner)
- futex: Validate waiter correctly in futex_proxy_trylock_atomic() (Thomas Gleixner)
- lib/test_lockup: Adapt to changed variables (Sebastian Andrzej Siewior)
- locking/rtmutex: Add mutex variant for RT (Thomas Gleixner)
- locking/ww_mutex: Implement rtmutex based ww_mutex API functions (Peter Zijlstra)
- locking/rtmutex: Extend the rtmutex core to support ww_mutex (Peter Zijlstra)
- locking/ww_mutex: Add rt_mutex based lock type and accessors (Peter Zijlstra)
- locking/ww_mutex: Add RT priority to W/W order (Peter Zijlstra)
- locking/ww_mutex: Implement rt_mutex accessors (Peter Zijlstra)
- locking/ww_mutex: Abstract out internal lock accesses (Thomas Gleixner)
- locking/ww_mutex: Abstract out mutex types (Peter Zijlstra)
- locking/ww_mutex: Abstract out mutex accessors (Peter Zijlstra)
- locking/ww_mutex: Abstract out waiter enqueueing (Peter Zijlstra)
- locking/ww_mutex: Abstract out the waiter iteration (Peter Zijlstra)
- locking/ww_mutex: Remove the __sched annotation from ww_mutex APIs (Peter Zijlstra)
- locking/ww_mutex: Split out the W/W implementation logic into kernel/locking/ww_mutex.h (Peter Zijlstra (Intel))
- locking/ww_mutex: Split up ww_mutex_unlock() (Peter Zijlstra (Intel))
- locking/ww_mutex: Gather mutex_waiter initialization (Peter Zijlstra)
- locking/ww_mutex: Simplify lockdep annotations (Peter Zijlstra)
- locking/mutex: Make mutex::wait_lock raw (Thomas Gleixner)
- locking/ww_mutex: Move the ww_mutex definitions from <linux/mutex.h> into <linux/ww_mutex.h> (Thomas Gleixner)
- locking/mutex: Move the 'struct mutex_waiter' definition from <linux/mutex.h> to the internal header (Thomas Gleixner)
- locking/mutex: Consolidate core headers, remove kernel/locking/mutex-debug.h (Thomas Gleixner)
- locking/rtmutex: Squash !RT tasks to DEFAULT_PRIO (Peter Zijlstra)
- locking/rwlock: Provide RT variant (Thomas Gleixner)
- locking/spinlock: Provide RT variant (Thomas Gleixner)
- locking/rtmutex: Provide the spin/rwlock core lock function (Thomas Gleixner)
- locking/spinlock: Provide RT variant header: <linux/spinlock_rt.h> (Thomas Gleixner)
- locking/spinlock: Provide RT specific spinlock_t (Thomas Gleixner)
- locking/rtmutex: Reduce <linux/rtmutex.h> header dependencies, only include <linux/rbtree_types.h> (Sebastian Andrzej Siewior)
- rbtree: Split out the rbtree type definitions into <linux/rbtree_types.h> (Sebastian Andrzej Siewior)
- locking/lockdep: Reduce header dependencies in <linux/debug_locks.h> (Sebastian Andrzej Siewior)
- locking/rtmutex: Prevent future include recursion hell (Sebastian Andrzej Siewior)
- locking/spinlock: Split the lock types header, and move the raw types into <linux/spinlock_types_raw.h> (Thomas Gleixner)
- locking/rtmutex: Guard regular sleeping locks specific functions (Thomas Gleixner)
- locking/rtmutex: Prepare RT rt_mutex_wake_q for RT locks (Thomas Gleixner)
- locking/rtmutex: Use rt_mutex_wake_q_head (Thomas Gleixner)
- locking/rtmutex: Provide rt_wake_q_head and helpers (Thomas Gleixner)
- locking/rtmutex: Add wake_state to rt_mutex_waiter (Thomas Gleixner)
- locking/rwsem: Add rtmutex based R/W semaphore implementation (Thomas Gleixner)
- locking/rt: Add base code for RT rw_semaphore and rwlock (Thomas Gleixner)
- locking/rtmutex: Provide rt_mutex_base_is_locked() (Thomas Gleixner)
- locking/rtmutex: Provide rt_mutex_slowlock_locked() (Thomas Gleixner)
- locking/rtmutex: Split out the inner parts of 'struct rtmutex' (Peter Zijlstra)
- locking/rtmutex: Split API from implementation (Thomas Gleixner)
- locking/rtmutex: Switch to from cmpxchg_*() to try_cmpxchg_*() (Thomas Gleixner)
- locking/rtmutex: Convert macros to inlines (Sebastian Andrzej Siewior)
- locking/rtmutex: Remove rt_mutex_is_locked() (Peter Zijlstra)
- media/atomisp: Use lockdep instead of *mutex_is_locked() (Peter Zijlstra)
- sched/wake_q: Provide WAKE_Q_HEAD_INITIALIZER() (Thomas Gleixner)
- sched/core: Provide a scheduling point for RT locks (Thomas Gleixner)
- sched/core: Rework the __schedule() preempt argument (Thomas Gleixner)
- sched/wakeup: Prepare for RT sleeping spin/rwlocks (Thomas Gleixner)
- sched/wakeup: Reorganize the current::__state helpers (Thomas Gleixner)
- sched/wakeup: Introduce the TASK_RTLOCK_WAIT state bit (Thomas Gleixner)
- sched/wakeup: Split out the wakeup ->__state check (Thomas Gleixner)
- locking/rtmutex: Set proper wait context for lockdep (Thomas Gleixner)
- locking/local_lock: Add missing owner initialization (Thomas Gleixner)
- debugobjects: Make RT aware (Thomas Gleixner)
- trace: Add migrate-disabled counter to tracing output (Thomas Gleixner)
- pid.h: include atomic.h (Grygorii Strashko)
- wait.h: include atomic.h (Sebastian Andrzej Siewior)
- efi: Allow efi=runtime (Sebastian Andrzej Siewior)
- efi: Disable runtime services on RT (Sebastian Andrzej Siewior)
- net/core: disable NET_RX_BUSY_POLL on RT (Sebastian Andrzej Siewior)
- sched: Disable CONFIG_RT_GROUP_SCHED on RT (Thomas Gleixner)
- mm: Allow only SLUB on RT (Ingo Molnar)
- kconfig: Disable config options which are not RT compatible (Thomas Gleixner)
- leds: trigger: disable CPU trigger on -RT (Sebastian Andrzej Siewior)
- jump-label: disable if stop_machine() is used (Thomas Gleixner)
- genirq: Disable irqpoll on -rt (Ingo Molnar)
- io-wq: Don't mix raw_spinlock_irq() & spin_lock_irq(). (Sebastian Andrzej Siewior)
- io-wq: remove GFP_ATOMIC allocation off schedule out path (Jens Axboe)
- genirq: update irq_set_irqchip_state documentation (Josh Cartwright)
- smp: Wake ksoftirqd on PREEMPT_RT instead do_softirq(). (Sebastian Andrzej Siewior)
- samples/kfifo: Rename read_lock/write_lock (Sebastian Andrzej Siewior)
- tcp: Remove superfluous BH-disable around listening_hash (Sebastian Andrzej Siewior)
- net: Move lockdep where it belongs (Thomas Gleixner)
- shmem: Use raw_spinlock_t for ->stat_lock (Sebastian Andrzej Siewior)
- mm: workingset: replace IRQ-off check with a lockdep assert. (Sebastian Andrzej Siewior)
- cgroup: use irqsave in cgroup_rstat_flush_locked() (Sebastian Andrzej Siewior)
- genirq: Move prio assignment into the newly created thread (Thomas Gleixner)
- kthread: Move prio/affinite change into the newly created thread (Sebastian Andrzej Siewior)
- sched: Prevent balance_push() on remote runqueues (Thomas Gleixner)
- sched: Switch wait_task_inactive to HRTIMER_MODE_REL_HARD (Sebastian Andrzej Siewior)
- highmem: Don't disable preemption on RT in kmap_atomic() (Sebastian Andrzej Siewior)
- mm, slub: convert kmem_cpu_slab protection to local_lock (Vlastimil Babka)
- mm, slub: use migrate_disable() on PREEMPT_RT (Vlastimil Babka)
- mm, slub: protect put_cpu_partial() with disabled irqs instead of cmpxchg (Vlastimil Babka)
- mm, slub: make slab_lock() disable irqs with PREEMPT_RT (Vlastimil Babka)
- mm, slub: optionally save/restore irqs in slab_[un]lock()/ (Vlastimil Babka)
- mm: slub: Make object_map_lock a raw_spinlock_t (Sebastian Andrzej Siewior)
- mm: slub: Move flush_cpu_slab() invocations __free_slab() invocations out of IRQ context (Sebastian Andrzej Siewior)
- mm, slab: make flush_slab() possible to call with irqs enabled (Vlastimil Babka)
- mm, slub: don't disable irqs in slub_cpu_dead() (Vlastimil Babka)
- mm, slub: only disable irq with spin_lock in __unfreeze_partials() (Vlastimil Babka)
- mm, slub: separate detaching of partial list in unfreeze_partials() from unfreezing (Vlastimil Babka)
- mm, slub: detach whole partial list at once in unfreeze_partials() (Vlastimil Babka)
- mm, slub: discard slabs in unfreeze_partials() without irqs disabled (Vlastimil Babka)
- mm, slub: move irq control into unfreeze_partials() (Vlastimil Babka)
- mm, slub: call deactivate_slab() without disabling irqs (Vlastimil Babka)
- mm, slub: make locking in deactivate_slab() irq-safe (Vlastimil Babka)
- mm, slub: move reset of c->page and freelist out of deactivate_slab() (Vlastimil Babka)
- mm, slub: stop disabling irqs around get_partial() (Vlastimil Babka)
- mm, slub: check new pages with restored irqs (Vlastimil Babka)
- mm, slub: validate slab from partial list or page allocator before making it cpu slab (Vlastimil Babka)
- mm, slub: restore irqs around calling new_slab() (Vlastimil Babka)
- mm, slub: move disabling irqs closer to get_partial() in ___slab_alloc() (Vlastimil Babka)
- mm, slub: do initial checks in ___slab_alloc() with irqs enabled (Vlastimil Babka)
- mm, slub: move disabling/enabling irqs to ___slab_alloc() (Vlastimil Babka)
- mm, slub: simplify kmem_cache_cpu and tid setup (Vlastimil Babka)
- mm, slub: restructure new page checks in ___slab_alloc() (Vlastimil Babka)
- mm, slub: return slab page from get_partial() and set c->page afterwards (Vlastimil Babka)
- mm, slub: dissolve new_slab_objects() into ___slab_alloc() (Vlastimil Babka)
- mm, slub: extract get_partial() from new_slab_objects() (Vlastimil Babka)
- mm, slub: unify cmpxchg_double_slab() and __cmpxchg_double_slab() (Vlastimil Babka)
- mm, slub: remove redundant unfreeze_partials() from put_cpu_partial() (Vlastimil Babka)
- mm, slub: don't disable irq for debug_check_no_locks_freed() (Vlastimil Babka)
- mm, slub: allocate private object map for validate_slab_cache() (Vlastimil Babka)
- mm, slub: allocate private object map for debugfs listings (Vlastimil Babka)
- mm, slub: don't call flush_all() from slab_debug_trace_open() (Vlastimil Babka)
- printk: Enhance the condition check of msleep in pr_flush() (Chao Qin)
- printk: add pr_flush() (John Ogness)
- printk: add console handover (John Ogness)
- printk: remove deferred printing (John Ogness)
- printk: move console printing to kthreads (John Ogness)
- printk: introduce kernel sync mode (John Ogness)
- printk: use seqcount_latch for console_seq (John Ogness)
- printk: call boot_delay_msec() in printk_delay() (John Ogness)
- printk: relocate printk_delay() (John Ogness)
- serial: 8250: implement write_atomic (John Ogness)
- kdb: only use atomic consoles for output mirroring (John Ogness)
- console: add write_atomic interface (John Ogness)
- printk: rename printk cpulock API and always disable interrupts (John Ogness)
- printk: syslog: close window between wait and read (John Ogness)
- printk: convert @syslog_lock to mutex (John Ogness)
- printk: remove NMI tracking (John Ogness)
- printk: remove safe buffers (John Ogness)
- printk: track/limit recursion (John Ogness)
- lib/nmi_backtrace: explicitly serialize banner and regs (John Ogness)
- printk/console: Check consistent sequence number when handling race in console_unlock() (Petr Mladek)
- arm64: mm: Make arch_faults_on_old_pte() check for migratability (Valentin Schneider)
- rcu/nocb: Protect NOCB state via local_lock() under PREEMPT_RT (Valentin Schneider)
- sched: Introduce migratable() (Valentin Schneider)
- eventfd: Make signal recursion protection a task bit (Thomas Gleixner)
- notifier: Remove atomic_notifier_call_chain_robust() (Valentin Schneider)
- cpu_pm: Make notifier chain use a raw_spinlock_t (Valentin Schneider)

* Mon Sep 13 2021 Herton R. Krzesinski <herton@redhat.com> [5.14-2]
- redhat: update branches/targets after 9 Beta fork (Herton R. Krzesinski)
- hv_utils: Set the maximum packet size for VSS driver to the length of the receive buffer (Vitaly Kuznetsov) [1996628]
- Enable bridge jobs for scratch pipelines (Michael Hofmann)

* Mon Aug 30 2021 Herton R. Krzesinski <herton@redhat.com> [5.14-1]
- redhat: drop Patchlist.changelog for RHEL (Jan Stancek) [1997494]
- redhat: update Makefile.variables for centos/rhel9 fork (Herton R. Krzesinski)
- redhat: add support for stream profile in koji/brew (Herton R. Krzesinski)
- redhat: make DIST default to .el9 (Herton R. Krzesinski)
- redhat: set default values in Makefiles for RHEL 9 Beta (Jan Stancek) [1997494]
- arm64: use common CONFIG_MAX_ZONEORDER for arm kernel (Mark Salter)
- Create Makefile.variables for a single point of configuration change (Justin M. Forbes)
- rpmspec: drop traceevent files instead of just excluding them from files list (Herton R. Krzesinski) [1967640]
- redhat/config: Enablement of CONFIG_PAPR_SCM for PowerPC (Gustavo Walbon) [1962936]
- Attempt to fix Intel PMT code (David Arcari)
- CI: Enable realtime branch testing (Veronika Kabatova)
- CI: Enable realtime checks for c9s and RHEL9 (Veronika Kabatova)
- [fs] dax: mark tech preview (Bill O'Donnell)
- ark: wireless: enable all rtw88 pcie wirless variants (Peter Robinson)
- wireless: rtw88: move debug options to common/debug (Peter Robinson)
- fedora: minor PTP clock driver cleanups (Peter Robinson)
- common: x86: enable VMware PTP support on ark (Peter Robinson)
- arm64: dts: rockchip: Disable CDN DP on Pinebook Pro (Matthias Brugger)
- arm64: dts: rockchip: Setup USB typec port as datarole on (Dan Johansen)
- [scsi] megaraid_sas: re-add certain pci-ids (Tomas Henzl)
- xfs: drop experimental warnings for bigtime and inobtcount (Bill O'Donnell) [1995321]
- Disable liquidio driver on ark/rhel (Herton R. Krzesinski) [1993393]
- More Fedora config updates (Justin M. Forbes)
- Fedora config updates for 5.14 (Justin M. Forbes)
- CI: Rename ARK CI pipeline type (Veronika Kabatova)
- CI: Finish up c9s config (Veronika Kabatova)
- CI: Update ppc64le config (Veronika Kabatova)
- CI: use more templates (Veronika Kabatova)
- Filter updates for aarch64 (Justin M. Forbes)
- increase CONFIG_NODES_SHIFT for aarch64 (Chris von Recklinghausen) [1890304]
- redhat: configs: Enable CONFIG_WIRELESS_HOTKEY (Hans de Goede)
- redhat/configs: Update CONFIG_NVRAM (Desnes A. Nunes do Rosario) [1988254]
- common: serial: build in SERIAL_8250_LPSS for x86 (Peter Robinson)
- powerpc: enable CONFIG_FUNCTION_PROFILER (Diego Domingos) [1831065]
- crypto: rng - Override drivers/char/random in FIPS mode (Herbert Xu)
- random: Add hook to override device reads and getrandom(2) (Herbert Xu)
- redhat/configs: Disable Soft-RoCE driver (Kamal Heib)
- redhat/configs/evaluate_configs: Update help output (Prarit Bhargava)
- redhat/configs: Double MAX_LOCKDEP_CHAINS (Justin M. Forbes)
- fedora: configs: Fix WM5102 Kconfig (Hans de Goede)
- powerpc: enable CONFIG_POWER9_CPU (Diego Domingos) [1876436]
- redhat/configs: Fix CONFIG_VIRTIO_IOMMU to 'y' on aarch64 (Eric Auger) [1972795]
- filter-modules.sh: add more sound modules to filter (Jaroslav Kysela)
- redhat/configs: sound configuration cleanups and updates (Jaroslav Kysela)
- common: Update for CXL (Compute Express Link) configs (Peter Robinson)
- redhat: configs: disable CRYPTO_SM modules (Herton R. Krzesinski) [1990040]
- Remove fedora version of the LOCKDEP_BITS, we should use common (Justin M. Forbes)
- Re-enable sermouse for x86 (rhbz 1974002) (Justin M. Forbes)
- Fedora 5.14 configs round 1 (Justin M. Forbes)
- redhat: add gating configuration for centos stream/rhel9 (Herton R. Krzesinski)
- x86: configs: Enable CONFIG_TEST_FPU for debug kernels (Vitaly Kuznetsov) [1988384]
- redhat/configs: Move CHACHA and POLY1305 to core kernel to allow BIG_KEYS=y (root) [1983298]
- kernel.spec: fix build of samples/bpf (Jiri Benc)
- Enable OSNOISE_TRACER and TIMERLAT_TRACER (Jerome Marchand) [1979379]
- rpmspec: switch iio and gpio tools to use tools_make (Herton R. Krzesinski) [1956988]
- configs/process_configs.sh: Handle config items with no help text (Patrick Talbert)
- fedora: sound config updates for 5.14 (Peter Robinson)
- fedora: Only enable FSI drivers on POWER platform (Peter Robinson)
- The CONFIG_RAW_DRIVER has been removed from upstream (Peter Robinson)
- fedora: updates for 5.14 with a few disables for common from pending (Peter Robinson)
- fedora: migrate from MFD_TPS68470 -> INTEL_SKL_INT3472 (Peter Robinson)
- fedora: Remove STAGING_GASKET_FRAMEWORK (Peter Robinson)
- Fedora: move DRM_VMWGFX configs from ark -> common (Peter Robinson)
- fedora: arm: disabled unused FB drivers (Peter Robinson)
- fedora: don't enable FB_VIRTUAL (Peter Robinson)
- redhat/configs: Double MAX_LOCKDEP_ENTRIES (Waiman Long) [1940075]
- rpmspec: fix verbose output on kernel-devel installation (Herton R. Krzesinski) [1981406]
- Build Fedora x86s kernels with bytcr-wm5102 (Marius Hoch)
- Deleted redhat/configs/fedora/generic/x86/CONFIG_FB_HYPERV (Patrick Lang)
- rpmspec: correct the ghost initramfs attributes (Herton R. Krzesinski) [1977056]
- rpmspec: amend removal of depmod created files to include modules.builtin.alias.bin (Herton R. Krzesinski) [1977056]
- configs: remove duplicate CONFIG_DRM_HYPERV file (Patrick Talbert)
- CI: use common code for merge and release (Don Zickus)
- rpmspec: add release string to kernel doc directory name (Jan Stancek)
- redhat/configs: Add CONFIG_INTEL_PMT_CRASHLOG (Michael Petlan) [1880486]
- redhat/configs: Add CONFIG_INTEL_PMT_TELEMETRY (Michael Petlan) [1880486]
- redhat/configs: Add CONFIG_MFD_INTEL_PMT (Michael Petlan) [1880486]
- redhat/configs: enable CONFIG_BLK_DEV_ZONED (Ming Lei) [1638087]
- Add --with clang_lto option to build the kernel with Link Time Optimizations (Tom Stellard)
- common: disable DVB_AV7110 and associated pieces (Peter Robinson)
- Fix fedora-only config updates (Don Zickus)
- Fedor config update for new option (Justin M. Forbes)
- redhat/configs: Enable stmmac NIC for x86_64 (Mark Salter)
- all: hyperv: use the DRM driver rather than FB (Peter Robinson)
- all: hyperv: unify the Microsoft HyperV configs (Peter Robinson)
- all: VMWare: clean up VMWare configs (Peter Robinson)
- Update CONFIG_ARM_FFA_TRANSPORT (Patrick Talbert)
- CI: Handle all mirrors (Veronika Kabatova)
- Turn on CONFIG_STACKTRACE for s390x zfpcdump kernels (Justin M. Forbes)
- arm64: switch ark kernel to 4K pagesize (Mark Salter)
- Disable AMIGA_PARTITION and KARMA_PARTITION (Prarit Bhargava) [1802694]
- all: unify and cleanup i2c TPM2 modules (Peter Robinson)
- redhat/configs: Set CONFIG_VIRTIO_IOMMU on aarch64 (Eric Auger) [1972795]
- redhat/configs: Disable CONFIG_RT_GROUP_SCHED in rhel config (Phil Auld)
- redhat/configs: enable KEXEC_SIG which is already enabled in RHEL8 for s390x and x86_64 (Coiby Xu) [1976835]
- rpmspec: do not BuildRequires bpftool on noarch (Herton R. Krzesinski)
- redhat/configs: disable {IMA,EVM}_LOAD_X509 (Bruno Meneguele) [1977529]
- redhat: add secureboot CA certificate to trusted kernel keyring (Bruno Meneguele)
- redhat/configs: enable IMA_ARCH_POLICY for aarch64 and s390x (Bruno Meneguele)
- redhat/configs: Enable CONFIG_MLXBF_GIGE on aarch64 (Alaa Hleihel) [1858599]
- common: enable STRICT_MODULE_RWX everywhere (Peter Robinson)
- COMMON_CLK_STM32MP157_SCMI is bool and selects COMMON_CLK_SCMI (Justin M. Forbes)
- kernel.spec: Add kernel{,-debug}-devel-matched meta packages (Timothée Ravier)
- Turn off with_selftests for Fedora (Justin M. Forbes)
- Don't build bpftool on Fedora (Justin M. Forbes)
- Fix location of syscall scripts for kernel-devel (Justin M. Forbes)
- fedora: arm: Enable some i.MX8 options (Peter Robinson)
- Enable Landlock for Fedora (Justin M. Forbes)
- Filter update for Fedora aarch64 (Justin M. Forbes)
- rpmspec: only build debug meta packages where we build debug ones (Herton R. Krzesinski)
- rpmspec: do not BuildRequires bpftool on nobuildarches (Herton R. Krzesinski)
- redhat/configs: Consolidate CONFIG_HMC_DRV in the common s390x folder (Thomas Huth) [1976270]
- redhat/configs: Consolidate CONFIG_EXPOLINE_OFF in the common folder (Thomas Huth) [1976270]
- redhat/configs: Move CONFIG_HW_RANDOM_S390 into the s390x/ subfolder (Thomas Huth) [1976270]
- redhat/configs: Disable CONFIG_HOTPLUG_PCI_SHPC in the Fedora settings (Thomas Huth) [1976270]
- redhat/configs: Remove the non-existent CONFIG_NO_BOOTMEM switch (Thomas Huth) [1976270]
- redhat/configs: Compile the virtio-console as a module on s390x (Thomas Huth) [1976270]
- redhat/configs: Enable CONFIG_S390_CCW_IOMMU and CONFIG_VFIO_CCW for ARK, too (Thomas Huth) [1976270]
- Revert "Merge branch 'ec_fips' into 'os-build'" (Vladis Dronov) [1947240]
- Fix typos in fedora filters (Justin M. Forbes)
- More filtering for Fedora (Justin M. Forbes)
- Fix Fedora module filtering for spi-altera-dfl (Justin M. Forbes)
- Fedora 5.13 config updates (Justin M. Forbes)
- fedora: cleanup TCG_TIS_I2C_CR50 (Peter Robinson)
- fedora: drop duplicate configs (Peter Robinson)
- More Fedora config updates for 5.13 (Justin M. Forbes)
- redhat/configs: Enable needed drivers for BlueField SoC on aarch64 (Alaa Hleihel) [1858592 1858594 1858596]
- redhat: Rename mod-blacklist.sh to mod-denylist.sh (Prarit Bhargava)
- redhat/configs: enable CONFIG_NET_ACT_MPLS (Marcelo Ricardo Leitner)
- configs: Enable CONFIG_DEBUG_KERNEL for zfcpdump (Jiri Olsa)
- kernel.spec: Add support to use vmlinux.h (Don Zickus)
- spec: Add vmlinux.h to kernel-devel package (Jiri Olsa)
- Turn off DRM_XEN_FRONTEND for Fedora as we had DRM_XEN off already (Justin M. Forbes)
- Fedora 5.13 config updates pt 3 (Justin M. Forbes)
- all: enable ath11k wireless modules (Peter Robinson)
- all: Enable WWAN and associated MHI bus pieces (Peter Robinson)
- spec: Enable sefltests rpm build (Jiri Olsa)
- spec: Allow bpf selftest/samples to fail (Jiri Olsa)
- bpf, selftests: Disable tests that need clang13 (Toke Høiland-Jørgensen)
- kvm: Add kvm_stat.service file and kvm_stat logrotate config to the tools (Jiri Benc)
- kernel.spec: Add missing source files to kernel-selftests-internal (Jiri Benc)
- kernel.spec: selftests: add net/forwarding to TARGETS list (Jiri Benc)
- kernel.spec: selftests: add build requirement on libmnl-devel (Jiri Benc)
- kernel.spec: add action.o to kernel-selftests-internal (Jiri Benc)
- kernel.spec: avoid building bpftool repeatedly (Jiri Benc)
- kernel.spec: selftests require python3 (Jiri Benc)
- kernel.spec: skip selftests that failed to build (Jiri Benc)
- kernel.spec: fix installation of bpf selftests (Jiri Benc)
- redhat: fix samples and selftests make options (Jiri Benc)
- kernel.spec: enable mptcp selftests for kernel-selftests-internal (Jiri Benc)
- kernel.spec: Do not export shared objects from libexecdir to RPM Provides (Jiri Benc)
- kernel.spec: add missing dependency for the which package (Jiri Benc)
- kernel.spec: add netfilter selftests to kernel-selftests-internal (Jiri Benc)
- kernel.spec: move slabinfo and page_owner_sort debuginfo to tools-debuginfo (Jiri Benc)
- kernel.spec: package and ship VM tools (Jiri Benc)
- configs: enable CONFIG_PAGE_OWNER (Jiri Benc)
- kernel.spec: add coreutils (Jiri Benc)
- kernel.spec: add netdevsim driver selftests to kernel-selftests-internal (Jiri Benc)
- redhat/Makefile: Clean out the --without flags from the baseonly rule (Jiri Benc)
- kernel.spec: Stop building unnecessary rpms for baseonly builds (Jiri Benc)
- kernel.spec: disable more kabi switches for gcov build (Jiri Benc)
- kernel.spec: Rename kabi-dw base (Jiri Benc)
- kernel.spec: Fix error messages during build of zfcpdump kernel (Jiri Benc)
- kernel.spec: perf: remove bpf examples (Jiri Benc)
- kernel.spec: selftests should not depend on modules-internal (Jiri Benc)
- kernel.spec: build samples (Jiri Benc)
- kernel.spec: tools: sync missing options with RHEL 8 (Jiri Benc)
- redhat/configs: nftables: Enable extra flowtable symbols (Phil Sutter)
- redhat/configs: Sync netfilter options with RHEL8 (Phil Sutter)
- Fedora 5.13 config updates pt 2 (Justin M. Forbes)
- Move CONFIG_ARCH_INTEL_SOCFPGA up a level for Fedora (Justin M. Forbes)
- fedora: enable the Rockchip rk3399 pcie drivers (Peter Robinson)
- Fedora 5.13 config updates pt 1 (Justin M. Forbes)
- Fix version requirement from opencsd-devel buildreq (Justin M. Forbes)
- configs/ark/s390: set CONFIG_MARCH_Z14 and CONFIG_TUNE_Z15 (Philipp Rudo) [1876435]
- configs/common/s390: Clean up CONFIG_{MARCH,TUNE}_Z* (Philipp Rudo)
- configs/process_configs.sh: make use of dummy-tools (Philipp Rudo)
- configs/common: disable CONFIG_INIT_STACK_ALL_{PATTERN,ZERO} (Philipp Rudo)
- configs/common/aarch64: disable CONFIG_RELR (Philipp Rudo)
- redhat/config: enable STMICRO nic for RHEL (Mark Salter)
- redhat/configs: Enable ARCH_TEGRA on RHEL (Mark Salter)
- redhat/configs: enable IMA_KEXEC for supported arches (Bruno Meneguele)
- redhat/configs: enable INTEGRITY_SIGNATURE to all arches (Bruno Meneguele)
- configs: enable CONFIG_LEDS_BRIGHTNESS_HW_CHANGED (Benjamin Tissoires)
- RHEL: disable io_uring support (Jeff Moyer)
- all: Changing CONFIG_UV_SYSFS to build uv_sysfs.ko as a loadable module. (Frank Ramsay)
- Enable NITRO_ENCLAVES on RHEL (Vitaly Kuznetsov)
- Update the Quick Start documentation (David Ward)
- redhat/configs: Set PVPANIC_MMIO for x86 and PVPANIC_PCI for aarch64 (Eric Auger) [1961178]
- bpf: Fix unprivileged_bpf_disabled setup (Jiri Olsa)
- Enable CONFIG_BPF_UNPRIV_DEFAULT_OFF (Jiri Olsa)
- configs/common/s390: disable CONFIG_QETH_{OSN,OSX} (Philipp Rudo) [1903201]
- nvme: nvme_mpath_init remove multipath check (Mike Snitzer)
- team: mark team driver as deprecated (Hangbin Liu) [1945477]
- Make CRYPTO_EC also builtin (Simo Sorce) [1947240]
- Do not hard-code a default value for DIST (David Ward)
- Override %%{debugbuildsenabled} if the --with-release option is used (David Ward)
- Improve comments in SPEC file, and move some option tests and macros (David Ward)
- configs: enable CONFIG_EXFAT_FS (Pavel Reichl) [1943423]
- Revert s390x/zfcpdump part of a9d179c40281 and ecbfddd98621 (Vladis Dronov)
- Embed crypto algos, modes and templates needed in the FIPS mode (Vladis Dronov) [1947240]
- configs: Add and enable CONFIG_HYPERV_TESTING for debug kernels (Mohammed Gamal)
- mm/cma: mark CMA on x86_64 tech preview and print RHEL-specific infos (David Hildenbrand) [1945002]
- configs: enable CONFIG_CMA on x86_64 in ARK (David Hildenbrand) [1945002]
- rpmspec: build debug-* meta-packages if debug builds are disabled (Herton R. Krzesinski)
- UIO: disable unused config options (Aristeu Rozanski) [1957819]
- ARK-config: Make amd_pinctrl module builtin (Hans de Goede)
- rpmspec: revert/drop content hash for kernel-headers (Herton R. Krzesinski)
- rpmspec: fix check that calls InitBuildVars (Herton R. Krzesinski)
- fedora: enable zonefs (Damien Le Moal)
- redhat: load specific ARCH keys to INTEGRITY_PLATFORM_KEYRING (Bruno Meneguele)
- redhat: enable INTEGRITY_TRUSTED_KEYRING across all variants (Bruno Meneguele)
- redhat: enable SYSTEM_BLACKLIST_KEYRING across all variants (Bruno Meneguele)
- redhat: enable INTEGRITY_ASYMMETRIC_KEYS across all variants (Bruno Meneguele)
- Remove unused boot loader specification files (David Ward)
- redhat/configs: Enable mlx5 IPsec and TLS offloads (Alaa Hleihel) [1869674 1957636]
- Force DWARF4 because crash does not support DWARF5 yet (Justin M. Forbes)
- common: disable Apple Silicon generally (Peter Robinson)
- cleanup Intel's FPGA configs (Peter Robinson)
- common: move PTP KVM support from ark to common (Peter Robinson)
- Enable CONFIG_DRM_AMDGPU_USERPTR for everyone (Justin M. Forbes)
- redhat: add initial rpminspect configuration (Herton R. Krzesinski)
- fedora: arm updates for 5.13 (Peter Robinson)
- fedora: Enable WWAN and associated MHI bits (Peter Robinson)
- Update CONFIG_MODPROBE_PATH to /usr/sbin (Justin Forbes)
- Fedora set modprobe path (Justin M. Forbes)
- Keep sctp and l2tp modules in modules-extra (Don Zickus)
- Fix ppc64le cross build packaging (Don Zickus)
- Fedora: Make amd_pinctrl module builtin (Hans de Goede)
- Keep CONFIG_KASAN_HW_TAGS off for aarch64 debug configs (Justin M. Forbes)
- New configs in drivers/bus (Fedora Kernel Team)
- RHEL: Don't build KVM PR module on ppc64 (David Gibson) [1930649]
- Flip CONFIG_USB_ROLE_SWITCH from m to y (Justin M. Forbes)
- Set valid options for CONFIG_FW_LOADER_USER_HELPER (Justin M. Forbes)
- Clean up CONFIG_FB_MODE_HELPERS (Justin M. Forbes)
- Turn off CONFIG_VFIO for the s390x zfcpdump kernel (Justin M. Forbes)
- Delete unused CONFIG_SND_SOC_MAX98390 pending-common (Justin M. Forbes)
- Update pending-common configs, preparing to set correctly (Justin M. Forbes)
- Update fedora filters for surface (Justin M. Forbes)
- Build CONFIG_CRYPTO_ECDSA inline for s390x zfcpdump (Justin M. Forbes)
- Replace "flavour" where "variant" is meant instead (David Ward)
- Drop the %%{variant} macro and fix --with-vanilla (David Ward)
- Fix syntax of %%kernel_variant_files (David Ward)
- Change description of --without-vdso-install to fix typo (David Ward)
- Config updates to work around mismatches (Justin M. Forbes)
- CONFIG_SND_SOC_FSL_ASOC_CARD selects CONFIG_MFD_WM8994 now (Justin M. Forbes)
- wireguard: disable in FIPS mode (Hangbin Liu) [1940794]
- Enable mtdram for fedora (rhbz 1955916) (Justin M. Forbes)
- Remove reference to bpf-helpers man page (Justin M. Forbes)
- Fedora: enable more modules for surface devices (Dave Olsthoorn)
- Fix Fedora config mismatch for CONFIG_FSL_ENETC_IERB (Justin M. Forbes)
- hardlink is in /usr/bin/ now (Justin M. Forbes)
- Ensure CONFIG_KVM_BOOK3S_64_PR stays on in Fedora, even if it is turned off in RHEL (Justin M. Forbes)
- Set date in package release from repository commit, not system clock (David Ward)
- Use a better upstream tarball filename for snapshots (David Ward)
- Don't create empty pending-common files on pending-fedora commits (Don Zickus)
- nvme: decouple basic ANA log page re-read support from native multipathing (Mike Snitzer)
- nvme: allow local retry and proper failover for REQ_FAILFAST_TRANSPORT (Mike Snitzer)
- nvme: Return BLK_STS_TARGET if the DNR bit is set (Mike Snitzer)
- Add redhat/configs/pending-common/generic/s390x/zfcpdump/CONFIG_NETFS_SUPPORT (Justin M. Forbes)
- Create ark-latest branch last for CI scripts (Don Zickus)
- Replace /usr/libexec/platform-python with /usr/bin/python3 (David Ward)
- Turn off ADI_AXI_ADC and AD9467 which now require CONFIG_OF (Justin M. Forbes)
- Export ark infrastructure files (Don Zickus)
- docs: Update docs to reflect newer workflow. (Don Zickus)
- Use upstream/master for merge-base with fallback to master (Don Zickus)
- Fedora: Turn off the SND_INTEL_BYT_PREFER_SOF option (Hans de Goede)
- filter-modules.sh.fedora: clean up "netprots" (Paul Bolle)
- filter-modules.sh.fedora: clean up "scsidrvs" (Paul Bolle)
- filter-*.sh.fedora: clean up "ethdrvs" (Paul Bolle)
- filter-*.sh.fedora: clean up "driverdirs" (Paul Bolle)
- filter-*.sh.fedora: remove incorrect entries (Paul Bolle)
- filter-*.sh.fedora: clean up "singlemods" (Paul Bolle)
- filter-modules.sh.fedora: drop unused list "iiodrvs" (Paul Bolle)
- Update mod-internal to fix depmod issue (Nico Pache)
- Turn on CONFIG_VDPA_SIM_NET (rhbz 1942343) (Justin M. Forbes)
- New configs in drivers/power (Fedora Kernel Team)
- Turn on CONFIG_NOUVEAU_DEBUG_PUSH for debug configs (Justin M. Forbes)
- Turn off KFENCE sampling by default for Fedora (Justin M. Forbes)
- Fedora config updates round 2 (Justin M. Forbes)
- New configs in drivers/soc (Jeremy Cline)
- filter-modules.sh: Fix copy/paste error 'input' (Paul Bolle)
- Update module filtering for 5.12 kernels (Justin M. Forbes)
- Fix genlog.py to ensure that comments retain "%%" characters. (Mark Mielke)
- New configs in drivers/leds (Fedora Kernel Team)
- Limit CONFIG_USB_CDNS_SUPPORT to x86_64 and arm in Fedora (David Ward)
- Fedora: Enable CHARGER_GPIO on aarch64 too (Peter Robinson)
- Fedora config updates (Justin M. Forbes)
- wireguard: mark as Tech Preview (Hangbin Liu) [1613522]
- configs: enable CONFIG_WIREGUARD in ARK (Hangbin Liu) [1613522]
- Remove duplicate configs acroos fedora, ark and common (Don Zickus)
- Combine duplicate configs across ark and fedora into common (Don Zickus)
- common/ark: cleanup and unify the parport configs (Peter Robinson)
- iommu/vt-d: enable INTEL_IDXD_SVM for both fedora and rhel (Jerry Snitselaar)
- REDHAT: coresight: etm4x: Disable coresight on HPE Apollo 70 (Jeremy Linton)
- configs/common/generic: disable CONFIG_SLAB_MERGE_DEFAULT (Rafael Aquini)
- Remove _legacy_common_support (Justin M. Forbes)
- redhat/mod-blacklist.sh: Fix floppy blacklisting (Hans de Goede)
- New configs in fs/pstore (CKI@GitLab)
- New configs in arch/powerpc (Fedora Kernel Team)
- configs: enable BPF LSM on Fedora and ARK (Ondrej Mosnacek)
- configs: clean up LSM configs (Ondrej Mosnacek)
- New configs in drivers/platform (CKI@GitLab)
- New configs in drivers/firmware (CKI@GitLab)
- New configs in drivers/mailbox (Fedora Kernel Team)
- New configs in drivers/net/phy (Justin M. Forbes)
- Update CONFIG_DM_MULTIPATH_IOA (Augusto Caringi)
- New configs in mm/Kconfig (CKI@GitLab)
- New configs in arch/powerpc (Jeremy Cline)
- New configs in arch/powerpc (Jeremy Cline)
- New configs in drivers/input (Fedora Kernel Team)
- New configs in net/bluetooth (Justin M. Forbes)
- New configs in drivers/clk (Fedora Kernel Team)
- New configs in init/Kconfig (Jeremy Cline)
- redhat: allow running fedora-configs and rh-configs targets outside of redhat/ (Herton R. Krzesinski)
- all: unify the disable of goldfish (android emulation platform) (Peter Robinson)
- common: minor cleanup/de-dupe of dma/dmabuf debug configs (Peter Robinson)
- common/ark: these drivers/arches were removed in 5.12 (Peter Robinson)
- Correct kernel-devel make prepare build for 5.12. (Paulo E. Castro)
- redhat: add initial support for centos stream dist-git sync on Makefiles (Herton R. Krzesinski)
- redhat/configs: Enable CONFIG_SCHED_STACK_END_CHECK for Fedora and ARK (Josh Poimboeuf) [1856174]
- CONFIG_VFIO now selects IOMMU_API instead of depending on it, causing several config mismatches for the zfcpdump kernel (Justin M. Forbes)
- Turn off weak-modules for Fedora (Justin M. Forbes)
- redhat: enable CONFIG_FW_LOADER_COMPRESS for ARK (Herton R. Krzesinski) [1939095]
- Fedora: filters: update to move dfl-emif to modules (Peter Robinson)
- drop duplicate DEVFREQ_GOV_SIMPLE_ONDEMAND config (Peter Robinson)
- efi: The EFI_VARS is legacy and now x86 only (Peter Robinson)
- common: enable RTC_SYSTOHC to supplement update_persistent_clock64 (Peter Robinson)
- generic: arm: enable SCMI for all options (Peter Robinson)
- fedora: the PCH_CAN driver is x86-32 only (Peter Robinson)
- common: disable legacy CAN device support (Peter Robinson)
- common: Enable Microchip MCP251x/MCP251xFD CAN controllers (Peter Robinson)
- common: Bosch MCAN support for Intel Elkhart Lake (Peter Robinson)
- common: enable CAN_PEAK_PCIEFD PCI-E driver (Peter Robinson)
- common: disable CAN_PEAK_PCIEC PCAN-ExpressCard (Peter Robinson)
- common: enable common CAN layer 2 protocols (Peter Robinson)
- ark: disable CAN_LEDS option (Peter Robinson)
- Fedora: Turn on SND_SOC_INTEL_SKYLAKE_HDAUDIO_CODEC option (Hans de Goede)
- Fedora: enable modules for surface devices (Dave Olsthoorn)
- Turn on SND_SOC_INTEL_SOUNDWIRE_SOF_MACH for Fedora again (Justin M. Forbes)
- common: fix WM8804 codec dependencies (Peter Robinson)
- Build SERIO_SERPORT as a module (Peter Robinson)
- input: touchscreen: move ELO and Wacom serial touchscreens to x86 (Peter Robinson)
- Sync serio touchscreens for non x86 architectures to the same as ARK (Peter Robinson)
- Only enable SERIO_LIBPS2 on x86 (Peter Robinson)
- Only enable PC keyboard controller and associated keyboard on x86 (Peter Robinson)
- Generic: Mouse: Tweak generic serial mouse options (Peter Robinson)
- Only enable PS2 Mouse options on x86 (Peter Robinson)
- Disable bluetooth highspeed by default (Peter Robinson)
- Fedora: A few more general updates for 5.12 window (Peter Robinson)
- Fedora: Updates for 5.12 merge window (Peter Robinson)
- Fedora: remove dead options that were removed upstream (Peter Robinson)
- redhat: remove CONFIG_DRM_PANEL_XINGBANGDA_XBD599 (Herton R. Krzesinski)
- New configs in arch/powerpc (Fedora Kernel Team)
- Turn on CONFIG_PPC_QUEUED_SPINLOCKS as it is default upstream now (Justin M. Forbes)
- Update pending-common configs to address new upstream config deps (Justin M. Forbes)
- rpmspec: ship gpio-watch.debug in the proper debuginfo package (Herton R. Krzesinski)
- Removed description text as a comment confuses the config generation (Justin M. Forbes)
- New configs in drivers/dma-buf (Jeremy Cline)
- Fedora: ARMv7: build for 16 CPUs. (Peter Robinson)
- Fedora: only enable DEBUG_HIGHMEM on debug kernels (Peter Robinson)
- process_configs.sh: fix find/xargs data flow (Ondrej Mosnacek)
- Fedora config update (Justin M. Forbes)
- fedora: minor arm sound config updates (Peter Robinson)
- Fix trailing white space in redhat/configs/fedora/generic/CONFIG_SND_INTEL_BYT_PREFER_SOF (Justin M. Forbes)
- Add a redhat/rebase-notes.txt file (Hans de Goede)
- Turn on SND_INTEL_BYT_PREFER_SOF for Fedora (Hans de Goede)
- CI: Drop MR ID from the name variable (Veronika Kabatova)
- redhat: add DUP and kpatch certificates to system trusted keys for RHEL build (Herton R. Krzesinski)
- The comments in CONFIG_USB_RTL8153_ECM actually turn off CONFIG_USB_RTL8152 (Justin M. Forbes)
- Update CKI pipeline project (Veronika Kabatova)
- Turn off additional KASAN options for Fedora (Justin M. Forbes)
- Rename the master branch to rawhide for Fedora (Justin M. Forbes)
- Makefile targets for packit integration (Ben Crocker)
- Turn off KASAN for rawhide debug builds (Justin M. Forbes)
- New configs in arch/arm64 (Justin Forbes)
- Remove deprecated Intel MIC config options (Peter Robinson)
- redhat: replace inline awk script with genlog.py call (Herton R. Krzesinski)
- redhat: add genlog.py script (Herton R. Krzesinski)
- kernel.spec.template - fix use_vdso usage (Ben Crocker)
- redhat: remove remaining references of CONFIG_RH_DISABLE_DEPRECATED (Herton R. Krzesinski)
- Turn off vdso_install for ppc (Justin M. Forbes)
- Remove bpf-helpers.7 from bpftool package (Jiri Olsa)
- New configs in lib/Kconfig.debug (Fedora Kernel Team)
- Turn off CONFIG_VIRTIO_CONSOLE for s390x zfcpdump (Justin M. Forbes)
- New configs in drivers/clk (Justin M. Forbes)
- Keep VIRTIO_CONSOLE on s390x available. (Jakub Čajka)
- New configs in lib/Kconfig.debug (Jeremy Cline)
- Fedora 5.11 config updates part 4 (Justin M. Forbes)
- Fedora 5.11 config updates part 3 (Justin M. Forbes)
- Fedora 5.11 config updates part 2 (Justin M. Forbes)
- Update internal (test) module list from RHEL-8 (Joe Lawrence) [1915073]
- Fix USB_XHCI_PCI regression (Justin M. Forbes)
- fedora: fixes for ARMv7 build issue by disabling HIGHPTE (Peter Robinson)
- all: s390x: Increase CONFIG_PCI_NR_FUNCTIONS to 512 (#1888735) (Dan Horák)
- Fedora 5.11 configs pt 1 (Justin M. Forbes)
- redhat: avoid conflict with mod-blacklist.sh and released_kernel defined (Herton R. Krzesinski)
- redhat: handle certificate files conditionally as done for src.rpm (Herton R. Krzesinski)
- specfile: add %%{?_smp_mflags} to "make headers_install" in tools/testing/selftests (Denys Vlasenko)
- specfile: add %%{?_smp_mflags} to "make samples/bpf/" (Denys Vlasenko)
- Run MR testing in CKI pipeline (Veronika Kabatova)
- Reword comment (Nicolas Chauvet)
- Add with_cross_arm conditional (Nicolas Chauvet)
- Redefines __strip if with_cross (Nicolas Chauvet)
- fedora: only enable ACPI_CONFIGFS, ACPI_CUSTOM_METHOD in debug kernels (Peter Robinson)
- fedora: User the same EFI_CUSTOM_SSDT_OVERLAYS as ARK (Peter Robinson)
- all: all arches/kernels enable the same DMI options (Peter Robinson)
- all: move SENSORS_ACPI_POWER to common/generic (Peter Robinson)
- fedora: PCIE_HISI_ERR is already in common (Peter Robinson)
- all: all ACPI platforms enable ATA_ACPI so move it to common (Peter Robinson)
- all: x86: move shared x86 acpi config options to generic (Peter Robinson)
- All: x86: Move ACPI_VIDEO to common/x86 (Peter Robinson)
- All: x86: Enable ACPI_DPTF (Intel DPTF) (Peter Robinson)
- All: enable ACPI_BGRT for all ACPI platforms. (Peter Robinson)
- All: Only build ACPI_EC_DEBUGFS for debug kernels (Peter Robinson)
- All: Disable Intel Classmate PC ACPI_CMPC option (Peter Robinson)
- cleanup: ACPI_PROCFS_POWER was removed upstream (Peter Robinson)
- All: ACPI: De-dupe the ACPI options that are the same across ark/fedora on x86/arm (Peter Robinson)
- Enable the vkms module in Fedora (Jeremy Cline)
- Fedora: arm updates for 5.11 and general cross Fedora cleanups (Peter Robinson)
- Add gcc-c++ to BuildRequires (Justin M. Forbes)
- Update CONFIG_KASAN_HW_TAGS (Justin M. Forbes)
- fedora: arm: move generic power off/reset to all arm (Peter Robinson)
- fedora: ARMv7: build in DEVFREQ_GOV_SIMPLE_ONDEMAND until I work out why it's changed (Peter Robinson)
- fedora: cleanup joystick_adc (Peter Robinson)
- fedora: update some display options (Peter Robinson)
- fedora: arm: enable TI PRU options (Peter Robinson)
- fedora: arm: minor exynos plaform updates (Peter Robinson)
- arm: SoC: disable Toshiba Visconti SoC (Peter Robinson)
- common: disable ARCH_BCM4908 (NFC) (Peter Robinson)
- fedora: minor arm config updates (Peter Robinson)
- fedora: enable Tegra 234 SoC (Peter Robinson)
- fedora: arm: enable new Hikey 3xx options (Peter Robinson)
- Fedora: USB updates (Peter Robinson)
- fedora: enable the GNSS receiver subsystem (Peter Robinson)
- Remove POWER_AVS as no longer upstream (Peter Robinson)
- Cleanup RESET_RASPBERRYPI (Peter Robinson)
- Cleanup GPIO_CDEV_V1 options. (Peter Robinson)
- fedora: arm crypto updates (Peter Robinson)
- CONFIG_KASAN_HW_TAGS for aarch64 (Justin M. Forbes)
- Fedora: cleanup PCMCIA configs, move to x86 (Peter Robinson)
- New configs in drivers/rtc (Fedora Kernel Team)
- redhat/configs: Enable CONFIG_GCC_PLUGIN_STRUCTLEAK_BYREF_ALL (Josh Poimboeuf) [1856176]
- redhat/configs: Enable CONFIG_GCC_PLUGIN_STRUCTLEAK (Josh Poimboeuf) [1856176]
- redhat/configs: Enable CONFIG_GCC_PLUGINS on ARK (Josh Poimboeuf) [1856176]
- redhat/configs: Enable CONFIG_KASAN on Fedora (Josh Poimboeuf) [1856176]
- New configs in init/Kconfig (Fedora Kernel Team)
- build_configs.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- genspec.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- mod-blacklist.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- Enable Speakup accessibility driver (Justin M. Forbes)
- New configs in init/Kconfig (Fedora Kernel Team)
- Fix fedora config mismatch due to dep changes (Justin M. Forbes)
- New configs in drivers/crypto (Jeremy Cline)
- Remove duplicate ENERGY_MODEL configs (Peter Robinson)
- This is selected by PCIE_QCOM so must match (Justin M. Forbes)
- drop unused BACKLIGHT_GENERIC (Peter Robinson)
- Remove cp instruction already handled in instruction below. (Paulo E. Castro)
- Add all the dependencies gleaned from running `make prepare` on a bloated devel kernel. (Paulo E. Castro)
- Add tools to path mangling script. (Paulo E. Castro)
- Remove duplicate cp statement which is also not specific to x86. (Paulo E. Castro)
- Correct orc_types failure whilst running `make prepare` https://bugzilla.redhat.com/show_bug.cgi?id=1882854 (Paulo E. Castro)
- redhat: ark: enable CONFIG_IKHEADERS (Jiri Olsa)
- Add missing '$' sign to (GIT) in redhat/Makefile (Augusto Caringi)
- Remove filterdiff and use native git instead (Don Zickus)
- New configs in net/sched (Justin M. Forbes)
- New configs in drivers/mfd (CKI@GitLab)
- New configs in drivers/mfd (Fedora Kernel Team)
- New configs in drivers/firmware (Fedora Kernel Team)
- Temporarily backout parallel xz script (Justin M. Forbes)
- redhat: explicitly disable CONFIG_IMA_APPRAISE_SIGNED_INIT (Bruno Meneguele)
- redhat: enable CONFIG_EVM_LOAD_X509 on ARK (Bruno Meneguele)
- redhat: enable CONFIG_EVM_ATTR_FSUUID on ARK (Bruno Meneguele)
- redhat: enable CONFIG_EVM in all arches and flavors (Bruno Meneguele)
- redhat: enable CONFIG_IMA_LOAD_X509 on ARK (Bruno Meneguele)
- redhat: set CONFIG_IMA_DEFAULT_HASH to SHA256 (Bruno Meneguele)
- redhat: enable CONFIG_IMA_SECURE_AND_OR_TRUSTED_BOOT (Bruno Meneguele)
- redhat: enable CONFIG_IMA_READ_POLICY on ARK (Bruno Meneguele)
- redhat: set default IMA template for all ARK arches (Bruno Meneguele)
- redhat: enable CONFIG_IMA_DEFAULT_HASH_SHA256 for all flavors (Bruno Meneguele)
- redhat: disable CONFIG_IMA_DEFAULT_HASH_SHA1 (Bruno Meneguele)
- redhat: enable CONFIG_IMA_ARCH_POLICY for ppc and x86 (Bruno Meneguele)
- redhat: enable CONFIG_IMA_APPRAISE_MODSIG (Bruno Meneguele)
- redhat: enable CONFIG_IMA_APPRAISE_BOOTPARAM (Bruno Meneguele)
- redhat: enable CONFIG_IMA_APPRAISE (Bruno Meneguele)
- redhat: enable CONFIG_INTEGRITY for aarch64 (Bruno Meneguele)
- kernel: Update some missing KASAN/KCSAN options (Jeremy Linton)
- kernel: Enable coresight on aarch64 (Jeremy Linton)
- Update CONFIG_INET6_ESPINTCP (Justin Forbes)
- New configs in net/ipv6 (Justin M. Forbes)
- fedora: move CONFIG_RTC_NVMEM options from ark to common (Peter Robinson)
- configs: Enable CONFIG_DEBUG_INFO_BTF (Don Zickus)
- fedora: some minor arm audio config tweaks (Peter Robinson)
- Ship xpad with default modules on Fedora and RHEL (Bastien Nocera)
- Fedora: Only enable legacy serial/game port joysticks on x86 (Peter Robinson)
- Fedora: Enable the options required for the Librem 5 Phone (Peter Robinson)
- Fedora config update (Justin M. Forbes)
- Fedora config change because CONFIG_FSL_DPAA2_ETH now selects CONFIG_FSL_XGMAC_MDIO (Justin M. Forbes)
- redhat: generic  enable CONFIG_INET_MPTCP_DIAG (Davide Caratti)
- Fedora config update (Justin M. Forbes)
- Enable NANDSIM for Fedora (Justin M. Forbes)
- Re-enable CONFIG_ACPI_TABLE_UPGRADE for Fedora since upstream disables this if secureboot is active (Justin M. Forbes)
- Ath11k related config updates (Justin M. Forbes)
- Fedora config updates for ath11k (Justin M. Forbes)
- Turn on ATH11K for Fedora (Justin M. Forbes)
- redhat: enable CONFIG_INTEL_IOMMU_SVM (Jerry Snitselaar)
- More Fedora config fixes (Justin M. Forbes)
- Fedora 5.10 config updates (Justin M. Forbes)
- Fedora 5.10 configs round 1 (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Allow kernel-tools to build without selftests (Don Zickus)
- Allow building of kernel-tools standalone (Don Zickus)
- redhat: ark: disable CONFIG_NET_ACT_CTINFO (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_TEQL (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_SFB (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_QFQ (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_PLUG (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_PIE (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_HHF (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_DSMARK (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_DRR (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_CODEL (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_CHOKE (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_CBQ (Davide Caratti)
- redhat: ark: disable CONFIG_NET_SCH_ATM (Davide Caratti)
- redhat: ark: disable CONFIG_NET_EMATCH and sub-targets (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_TCINDEX (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_RSVP6 (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_RSVP (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_ROUTE4 (Davide Caratti)
- redhat: ark: disable CONFIG_NET_CLS_BASIC (Davide Caratti)
- redhat: ark: disable CONFIG_NET_ACT_SKBMOD (Davide Caratti)
- redhat: ark: disable CONFIG_NET_ACT_SIMP (Davide Caratti)
- redhat: ark: disable CONFIG_NET_ACT_NAT (Davide Caratti)
- arm64/defconfig: Enable CONFIG_KEXEC_FILE (Bhupesh Sharma) [1821565]
- redhat/configs: Cleanup CONFIG_CRYPTO_SHA512 (Prarit Bhargava)
- New configs in drivers/mfd (Fedora Kernel Team)
- Fix LTO issues with kernel-tools (Don Zickus)
- Point pathfix to the new location for gen_compile_commands.py (Justin M. Forbes)
- configs: Disable CONFIG_SECURITY_SELINUX_DISABLE (Ondrej Mosnacek)
- [Automatic] Handle config dependency changes (Don Zickus)
- configs/iommu: Add config comment to empty CONFIG_SUN50I_IOMMU file (Jerry Snitselaar)
- New configs in kernel/trace (Fedora Kernel Team)
- Fix Fedora config locations (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- configs: enable CONFIG_CRYPTO_CTS=y so cts(cbc(aes)) is available in FIPS mode (Vladis Dronov) [1855161]
- Partial revert: Add master merge check (Don Zickus)
- Update Maintainers doc to reflect workflow changes (Don Zickus)
- WIP: redhat/docs: Update documentation for single branch workflow (Prarit Bhargava)
- Add CONFIG_ARM64_MTE which is not picked up by the config scripts for some reason (Justin M. Forbes)
- Disable Speakup synth DECEXT (Justin M. Forbes)
- Enable Speakup for Fedora since it is out of staging (Justin M. Forbes)
- Modify patchlist changelog output (Don Zickus)
- process_configs.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- generate_all_configs.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- redhat/self-test: Initial commit (Ben Crocker)
- Fixes "acpi: prefer booting with ACPI over DTS" to be RHEL only (Peter Robinson)
- arch/x86: Remove vendor specific CPU ID checks (Prarit Bhargava)
- redhat: Replace hardware.redhat.com link in Unsupported message (Prarit Bhargava) [1810301]
- x86: Fix compile issues with rh_check_supported() (Don Zickus)
- KEYS: Make use of platform keyring for module signature verify (Robert Holmes)
- Input: rmi4 - remove the need for artificial IRQ in case of HID (Benjamin Tissoires)
- ARM: tegra: usb no reset (Peter Robinson)
- arm: make CONFIG_HIGHPTE optional without CONFIG_EXPERT (Jon Masters)
- redhat: rh_kabi: deduplication friendly structs (Jiri Benc)
- redhat: rh_kabi add a comment with warning about RH_KABI_EXCLUDE usage (Jiri Benc)
- redhat: rh_kabi: introduce RH_KABI_EXTEND_WITH_SIZE (Jiri Benc)
- redhat: rh_kabi: Indirect EXTEND macros so nesting of other macros will resolve. (Don Dutile)
- redhat: rh_kabi: Fix RH_KABI_SET_SIZE to use dereference operator (Tony Camuso)
- redhat: rh_kabi: Add macros to size and extend structs (Prarit Bhargava)
- Removing Obsolete hba pci-ids from rhel8 (Dick Kennedy)
- mptsas: pci-id table changes (Laura Abbott)
- mptsas: Taint kernel if mptsas is loaded (Laura Abbott)
- mptspi: pci-id table changes (Laura Abbott)
- qla2xxx: Remove PCI IDs of deprecated adapter (Jeremy Cline)
- be2iscsi: remove unsupported device IDs (Chris Leech)
- mptspi: Taint kernel if mptspi is loaded (Laura Abbott)
- hpsa: remove old cciss-based smartarray pci ids (Joseph Szczypek)
- qla4xxx: Remove deprecated PCI IDs from RHEL 8 (Chad Dupuis)
- aacraid: Remove depreciated device and vendor PCI id's (Raghava Aditya Renukunta)
- megaraid_sas: remove deprecated pci-ids (Tomas Henzl)
- mpt*: remove certain deprecated pci-ids (Jeremy Cline)
- kernel: add SUPPORT_REMOVED kernel taint (Tomas Henzl)
- Rename RH_DISABLE_DEPRECATED to RHEL_DIFFERENCES (Don Zickus)
- Add option of 13 for FORCE_MAX_ZONEORDER (Peter Robinson)
- s390: Lock down the kernel when the IPL secure flag is set (Jeremy Cline)
- efi: Lock down the kernel if booted in secure boot mode (David Howells)
- efi: Add an EFI_SECURE_BOOT flag to indicate secure boot mode (David Howells)
- security: lockdown: expose a hook to lock the kernel down (Jeremy Cline)
- Make get_cert_list() use efi_status_to_str() to print error messages. (Peter Jones)
- Add efi_status_to_str() and rework efi_status_to_err(). (Peter Jones)
- Add support for deprecating processors (Laura Abbott) [1565717 1595918 1609604 1610493]
- arm: aarch64: Drop the EXPERT setting from ARM64_FORCE_52BIT (Jeremy Cline)
- iommu/arm-smmu: workaround DMA mode issues (Laura Abbott)
- rh_kabi: introduce RH_KABI_EXCLUDE (Jakub Racek)
- ipmi: do not configure ipmi for HPE m400 (Laura Abbott) [1670017]
- kABI: Add generic kABI macros to use for kABI workarounds (Myron Stowe) [1546831]
- add pci_hw_vendor_status() (Maurizio Lombardi)
- ahci: thunderx2: Fix for errata that affects stop engine (Robert Richter)
- Vulcan: AHCI PCI bar fix for Broadcom Vulcan early silicon (Robert Richter)
- bpf: set unprivileged_bpf_disabled to 1 by default, add a boot parameter (Eugene Syromiatnikov) [1561171]
- add Red Hat-specific taint flags (Eugene Syromiatnikov) [1559877]
- tags.sh: Ignore redhat/rpm (Jeremy Cline)
- put RHEL info into generated headers (Laura Abbott) [1663728]
- acpi: prefer booting with ACPI over DTS (Mark Salter) [1576869]
- aarch64: acpi scan: Fix regression related to X-Gene UARTs (Mark Salter) [1519554]
- ACPI / irq: Workaround firmware issue on X-Gene based m400 (Mark Salter) [1519554]
- modules: add rhelversion MODULE_INFO tag (Laura Abbott)
- ACPI: APEI: arm64: Ignore broken HPE moonshot APEI support (Al Stone) [1518076]
- Add Red Hat tainting (Laura Abbott) [1565704]
- Introduce CONFIG_RH_DISABLE_DEPRECATED (Laura Abbott)
- Stop merging ark-patches for release (Don Zickus)
- Fix path location for ark-update-configs.sh (Don Zickus)
- Combine Red Hat patches into single patch (Don Zickus)
- New configs in drivers/misc (Jeremy Cline)
- New configs in drivers/net/wireless (Justin M. Forbes)
- New configs in drivers/phy (Fedora Kernel Team)
- New configs in drivers/tty (Fedora Kernel Team)
- Set SquashFS decompression options for all flavors to match RHEL (Bohdan Khomutskyi)
- configs: Enable CONFIG_ENERGY_MODEL (Phil Auld)
- New configs in drivers/pinctrl (Fedora Kernel Team)
- Update CONFIG_THERMAL_NETLINK (Justin Forbes)
- Separate merge-upstream and release stages (Don Zickus)
- Re-enable CONFIG_IR_SERIAL on Fedora (Prarit Bhargava)
- Create Patchlist.changelog file (Don Zickus)
- Filter out upstream commits from changelog (Don Zickus)
- Merge Upstream script fixes (Don Zickus)
- kernel.spec: Remove kernel-keys directory on rpm erase (Prarit Bhargava)
- Add mlx5_vdpa to module filter for Fedora (Justin M. Forbes)
- Add python3-sphinx_rtd_theme buildreq for docs (Justin M. Forbes)
- redhat/configs/process_configs.sh: Remove *.config.orig files (Prarit Bhargava)
- redhat/configs/process_configs.sh: Add process_configs_known_broken flag (Prarit Bhargava)
- redhat/Makefile: Fix '*-configs' targets (Prarit Bhargava)
- dist-merge-upstream: Checkout known branch for ci scripts (Don Zickus)
- kernel.spec: don't override upstream compiler flags for ppc64le (Dan Horák)
- Fedora config updates (Justin M. Forbes)
- Fedora confi gupdate (Justin M. Forbes)
- mod-sign.sh: Fix syntax flagged by shellcheck (Ben Crocker)
- Swap how ark-latest is built (Don Zickus)
- Add extra version bump to os-build branch (Don Zickus)
- dist-release: Avoid needless version bump. (Don Zickus)
- Add dist-fedora-release target (Don Zickus)
- Remove redundant code in dist-release (Don Zickus)
- Makefile.common rename TAG to _TAG (Don Zickus)
- Fedora config change (Justin M. Forbes)
- Fedora filter update (Justin M. Forbes)
- Config update for Fedora (Justin M. Forbes)
- enable PROTECTED_VIRTUALIZATION_GUEST for all s390x kernels (Dan Horák)
- redhat: ark: enable CONFIG_NET_SCH_TAPRIO (Davide Caratti)
- redhat: ark: enable CONFIG_NET_SCH_ETF (Davide Caratti)
- More Fedora config updates (Justin M. Forbes)
- New config deps (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- First half of config updates for Fedora (Justin M. Forbes)
- Updates for Fedora arm architectures for the 5.9 window (Peter Robinson)
- Merge 5.9 config changes from Peter Robinson (Justin M. Forbes)
- Add config options that only show up when we prep on arm (Justin M. Forbes)
- Config updates for Fedora (Justin M. Forbes)
- fedora: enable enery model (Peter Robinson)
- Use the configs/generic config for SND_HDA_INTEL everywhere (Peter Robinson)
- Enable ZSTD compression algorithm on all kernels (Peter Robinson)
- Enable ARM_SMCCC_SOC_ID on all aarch64 kernels (Peter Robinson)
- iio: enable LTR-559 light and proximity sensor (Peter Robinson)
- iio: chemical: enable some popular chemical and partical sensors (Peter Robinson)
- More mismatches (Justin M. Forbes)
- Fedora config change due to deps (Justin M. Forbes)
- CONFIG_SND_SOC_MAX98390 is now selected by SND_SOC_INTEL_DA7219_MAX98357A_GENERIC (Justin M. Forbes)
- Config change required for build part 2 (Justin M. Forbes)
- Config change required for build (Justin M. Forbes)
- Fedora config update (Justin M. Forbes)
- Add ability to sync upstream through Makefile (Don Zickus)
- Add master merge check (Don Zickus)
- Replace hardcoded values 'os-build' and project id with variables (Don Zickus)
- redhat/Makefile.common: Fix MARKER (Prarit Bhargava)
- gitattributes: Remove unnecesary export restrictions (Prarit Bhargava)
- Add new certs for dual signing with boothole (Justin M. Forbes)
- Update secureboot signing for dual keys (Justin M. Forbes)
- fedora: enable LEDS_SGM3140 for arm configs (Peter Robinson)
- Enable CONFIG_DM_VERITY_VERIFY_ROOTHASH_SIG (Justin M. Forbes)
- redhat/configs: Fix common CONFIGs (Prarit Bhargava)
- redhat/configs: General CONFIG cleanups (Prarit Bhargava)
- redhat/configs: Update & generalize evaluate_configs (Prarit Bhargava)
- fedora: arm: Update some meson config options (Peter Robinson)
- redhat/docs: Add Fedora RPM tagging date (Prarit Bhargava)
- Update config for renamed panel driver. (Peter Robinson)
- Enable SERIAL_SC16IS7XX for SPI interfaces (Peter Robinson)
- s390x-zfcpdump: Handle missing Module.symvers file (Don Zickus)
- Fedora config updates (Justin M. Forbes)
- redhat/configs: Add .tmp files to .gitignore (Prarit Bhargava)
- disable uncommon TCP congestion control algorithms (Davide Caratti)
- Add new bpf man pages (Justin M. Forbes)
- Add default option for CONFIG_ARM64_BTI_KERNEL to pending-common so that eln kernels build (Justin M. Forbes)
- redhat/Makefile: Add fedora-configs and rh-configs make targets (Prarit Bhargava)
- redhat/configs: Use SHA512 for module signing (Prarit Bhargava)
- genspec.sh: 'touch' empty Patchlist file for single tarball (Don Zickus)
- Fedora config update for rc1 (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- redhat/Makefile.common: fix RPMKSUBLEVEL condition (Ondrej Mosnacek)
- redhat/Makefile: silence KABI tar output (Ondrej Mosnacek)
- One more Fedora config update (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fix PATCHLEVEL for merge window (Justin M. Forbes)
- Change ark CONFIG_COMMON_CLK to yes, it is selected already by other options (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- More module filtering for Fedora (Justin M. Forbes)
- Update filters for rnbd in Fedora (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fix up module filtering for 5.8 (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- More Fedora config work (Justin M. Forbes)
- RTW88BE and CE have been extracted to their own modules (Justin M. Forbes)
- Set CONFIG_BLK_INLINE_ENCRYPTION_FALLBACK for Fedora (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Arm64 Use Branch Target Identification for kernel (Justin M. Forbes)
- Change value of CONFIG_SECURITY_SELINUX_CHECKREQPROT_VALUE (Justin M. Forbes)
- Fedora config updates (Justin M. Forbes)
- Fix configs for Fedora (Justin M. Forbes)
- Add zero-commit to format-patch options (Justin M. Forbes)
- Copy Makefile.rhelver as a source file rather than a patch (Jeremy Cline)
- Move the sed to clear the patch templating outside of conditionals (Justin M. Forbes)
- Match template format in kernel.spec.template (Justin M. Forbes)
- Break out the Patches into individual files for dist-git (Justin M. Forbes)
- Break the Red Hat patch into individual commits (Jeremy Cline)
- Fix update_scripts.sh unselective pattern sub (David Howells)
- Add cec to the filter overrides (Justin M. Forbes)
- Add overrides to filter-modules.sh (Justin M. Forbes)
- redhat/configs: Enable CONFIG_SMC91X and disable CONFIG_SMC911X (Prarit Bhargava) [1722136]
- Include bpftool-struct_ops man page in the bpftool package (Jeremy Cline)
- Add sharedbuffer_configuration.py to the pathfix.py script (Jeremy Cline)
- Use __make macro instead of make (Tom Stellard)
- Sign off generated configuration patches (Jeremy Cline)
- Drop the static path configuration for the Sphinx docs (Jeremy Cline)
- redhat: Add dummy-module kernel module (Prarit Bhargava)
- redhat: enable CONFIG_LWTUNNEL_BPF (Jiri Benc)
- Remove typoed config file aarch64CONFIG_SM_GCC_8150 (Justin M. Forbes)
- Add Documentation back to kernel-devel as it has Kconfig now (Justin M. Forbes)
- Copy distro files rather than moving them (Jeremy Cline)
- kernel.spec: fix 'make scripts' for kernel-devel package (Brian Masney)
- Makefile: correct help text for dist-cross-<arch>-rpms (Brian Masney)
- redhat/Makefile: Fix RHEL8 python warning (Prarit Bhargava)
- redhat: Change Makefile target names to dist- (Prarit Bhargava)
- configs: Disable Serial IR driver (Prarit Bhargava)
- Fix "multiple %%files for package kernel-tools" (Pablo Greco)
- Introduce a Sphinx documentation project (Jeremy Cline)
- Build ARK against ELN (Don Zickus)
- Drop the requirement to have a remote called linus (Jeremy Cline)
- Rename 'internal' branch to 'os-build' (Don Zickus)
- Only include open merge requests with "Include in Releases" label (Jeremy Cline)
- Package gpio-watch in kernel-tools (Jeremy Cline)
- Exit non-zero if the tag already exists for a release (Jeremy Cline)
- Adjust the changelog update script to not push anything (Jeremy Cline)
- Drop --target noarch from the rh-rpms make target (Jeremy Cline)
- Add a script to generate release tags and branches (Jeremy Cline)
- Set CONFIG_VDPA for fedora (Justin M. Forbes)
- Add a README to the dist-git repository (Jeremy Cline)
- Provide defaults in ark-rebase-patches.sh (Jeremy Cline)
- Default ark-rebase-patches.sh to not report issues (Jeremy Cline)
- Drop DIST from release commits and tags (Jeremy Cline)
- Place the buildid before the dist in the release (Jeremy Cline)
- Sync up with Fedora arm configuration prior to merging (Jeremy Cline)
- Disable CONFIG_PROTECTED_VIRTUALIZATION_GUEST for zfcpdump (Jeremy Cline)
- Add RHMAINTAINERS file and supporting conf (Don Zickus)
- Add a script to test if all commits are signed off (Jeremy Cline)
- Fix make rh-configs-arch (Don Zickus)
- Drop RH_FEDORA in favor of the now-merged RHEL_DIFFERENCES (Jeremy Cline)
- Sync up Fedora configs from the first week of the merge window (Jeremy Cline)
- Migrate blacklisting floppy.ko to mod-blacklist.sh (Don Zickus)
- kernel packaging: Combine mod-blacklist.sh and mod-extra-blacklist.sh (Don Zickus)
- kernel packaging: Fix extra namespace collision (Don Zickus)
- mod-extra.sh: Rename to mod-blacklist.sh (Don Zickus)
- mod-extra.sh: Make file generic (Don Zickus)
- Fix a painfully obvious YAML syntax error in .gitlab-ci.yml (Jeremy Cline)
- Add in armv7hl kernel header support (Don Zickus)
- Disable all BuildKernel commands when only building headers (Don Zickus)
- Drop any gitlab-ci patches from ark-patches (Jeremy Cline)
- Build the srpm for internal branch CI using the vanilla tree (Jeremy Cline)
- Pull in the latest ARM configurations for Fedora (Jeremy Cline)
- Fix xz memory usage issue (Neil Horman)
- Use ark-latest instead of master for update script (Jeremy Cline)
- Move the CI jobs back into the ARK repository (Jeremy Cline)
- Sync up ARK's Fedora config with the dist-git repository (Jeremy Cline)
- Pull in the latest configuration changes from Fedora (Jeremy Cline)
- configs: enable CONFIG_NET_SCH_CBS (Marcelo Ricardo Leitner)
- Drop configuration options in fedora/ that no longer exist (Jeremy Cline)
- Set RH_FEDORA for ARK and Fedora (Jeremy Cline)
- redhat/kernel.spec: Include the release in the kernel COPYING file (Jeremy Cline)
- redhat/kernel.spec: add scripts/jobserver-exec to py3_shbang_opts list (Jeremy Cline)
- redhat/kernel.spec: package bpftool-gen man page (Jeremy Cline)
- distgit-changelog: handle multiple y-stream BZ numbers (Bruno Meneguele)
- redhat/kernel.spec: remove all inline comments (Bruno Meneguele)
- redhat/genspec: awk unknown whitespace regex pattern (Bruno Meneguele)
- Improve the readability of gen_config_patches.sh (Jeremy Cline)
- Fix some awkward edge cases in gen_config_patches.sh (Jeremy Cline)
- Update the CI environment to use Fedora 31 (Jeremy Cline)
- redhat: drop whitespace from with_gcov macro (Jan Stancek)
- configs: Enable CONFIG_KEY_DH_OPERATIONS on ARK (Ondrej Mosnacek)
- configs: Adjust CONFIG_MPLS_ROUTING and CONFIG_MPLS_IPTUNNEL (Laura Abbott)
- New configs in lib/crypto (Jeremy Cline)
- New configs in drivers/char (Jeremy Cline)
- Turn on BLAKE2B for Fedora (Jeremy Cline)
- kernel.spec.template: Clean up stray *.h.s files (Laura Abbott)
- Build the SRPM in the CI job (Jeremy Cline)
- New configs in net/tls (Jeremy Cline)
- New configs in net/tipc (Jeremy Cline)
- New configs in lib/kunit (Jeremy Cline)
- Fix up released_kernel case (Laura Abbott)
- New configs in lib/Kconfig.debug (Jeremy Cline)
- New configs in drivers/ptp (Jeremy Cline)
- New configs in drivers/nvme (Jeremy Cline)
- New configs in drivers/net/phy (Jeremy Cline)
- New configs in arch/arm64 (Jeremy Cline)
- New configs in drivers/crypto (Jeremy Cline)
- New configs in crypto/Kconfig (Jeremy Cline)
- Add label so the Gitlab to email bridge ignores the changelog (Jeremy Cline)
- Temporarily switch TUNE_DEFAULT to y (Jeremy Cline)
- Run config test for merge requests and internal (Jeremy Cline)
- Add missing licensedir line (Laura Abbott)
- redhat/scripts: Remove redhat/scripts/rh_get_maintainer.pl (Prarit Bhargava)
- configs: Take CONFIG_DEFAULT_MMAP_MIN_ADDR from Fedra (Laura Abbott)
- configs: Turn off ISDN (Laura Abbott)
- Add a script to generate configuration patches (Laura Abbott)
- Introduce rh-configs-commit (Laura Abbott)
- kernel-packaging: Remove kernel files from kernel-modules-extra package (Prarit Bhargava)
- configs: Enable CONFIG_DEBUG_WX (Laura Abbott)
- configs: Disable wireless USB (Laura Abbott)
- Clean up some temporary config files (Laura Abbott)
- configs: New config in drivers/gpu for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/powerpc for v5.4-rc1 (Jeremy Cline)
- configs: New config in crypto for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/usb for v5.4-rc1 (Jeremy Cline)
- AUTOMATIC: New configs (Jeremy Cline)
- Skip ksamples for bpf, they are broken (Jeremy Cline)
- configs: New config in fs/erofs for v5.4-rc1 (Jeremy Cline)
- configs: New config in mm for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/md for v5.4-rc1 (Jeremy Cline)
- configs: New config in init for v5.4-rc1 (Jeremy Cline)
- configs: New config in fs/fuse for v5.4-rc1 (Jeremy Cline)
- merge.pl: Avoid comments but do not skip them (Don Zickus)
- configs: New config in drivers/net/ethernet/pensando for v5.4-rc1 (Jeremy Cline)
- Update a comment about what released kernel means (Laura Abbott)
- Provide both Fedora and RHEL files in the SRPM (Laura Abbott)
- kernel.spec.template: Trim EXTRAVERSION in the Makefile (Laura Abbott)
- kernel.spec.template: Add macros for building with nopatches (Laura Abbott)
- kernel.spec.template: Add some macros for Fedora differences (Laura Abbott)
- kernel.spec.template: Consolodate the options (Laura Abbott)
- configs: Add pending direcory to Fedora (Laura Abbott)
- kernel.spec.template: Don't run hardlink if rpm-ostree is in use (Laura Abbott)
- configs: New config in net/can for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/phy for v5.4-rc1 (Jeremy Cline)
- configs: Increase x86_64 NR_UARTS to 64 (Prarit Bhargava) [1730649]
- configs: turn on ARM64_FORCE_52BIT for debug builds (Jeremy Cline)
- kernel.spec.template: Tweak the python3 mangling (Laura Abbott)
- kernel.spec.template: Add --with verbose option (Laura Abbott)
- kernel.spec.template: Switch to using %%install instead of %%__install (Laura Abbott)
- kernel.spec.template: Make the kernel.org URL https (Laura Abbott)
- kernel.spec.template: Update message about secure boot signing (Laura Abbott)
- kernel.spec.template: Move some with flags definitions up (Laura Abbott)
- kernel.spec.template: Update some BuildRequires (Laura Abbott)
- kernel.spec.template: Get rid of %%clean (Laura Abbott)
- configs: New config in drivers/char for v5.4-rc1 (Jeremy Cline)
- configs: New config in net/sched for v5.4-rc1 (Jeremy Cline)
- configs: New config in lib for v5.4-rc1 (Jeremy Cline)
- configs: New config in fs/verity for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/aarch64 for v5.4-rc4 (Jeremy Cline)
- configs: New config in arch/arm64 for v5.4-rc1 (Jeremy Cline)
- Flip off CONFIG_ARM64_VA_BITS_52 so the bundle that turns it on applies (Jeremy Cline)
- New configuration options for v5.4-rc4 (Jeremy Cline)
- Correctly name tarball for single tarball builds (Laura Abbott)
- configs: New config in drivers/pci for v5.4-rc1 (Jeremy Cline)
- Allow overriding the dist tag on the command line (Laura Abbott)
- Allow scratch branch target to be overridden (Laura Abbott)
- Remove long dead BUILD_DEFAULT_TARGET (Laura Abbott)
- Amend the changelog when rebasing (Laura Abbott)
- configs: New config in drivers/platform for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/pinctrl for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/wireless for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/ethernet/mellanox for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/net/can for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/hid for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/dma-buf for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/crypto for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/s390 for v5.4-rc1 (Jeremy Cline)
- configs: New config in block for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/cpuidle for v5.4-rc1 (Jeremy Cline)
- redhat: configs: Split CONFIG_CRYPTO_SHA512 (Laura Abbott)
- redhat: Set Fedora options (Laura Abbott)
- Set CRYPTO_SHA3_*_S390 to builtin on zfcpdump (Jeremy Cline)
- configs: New config in drivers/edac for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/firmware for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/hwmon for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/iio for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/mmc for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/tty for v5.4-rc1 (Jeremy Cline)
- configs: New config in arch/s390 for v5.4-rc1 (Jeremy Cline)
- configs: New config in drivers/bus for v5.4-rc1 (Jeremy Cline)
- Add option to allow mismatched configs on the command line (Laura Abbott)
- configs: New config in drivers/crypto for v5.4-rc1 (Jeremy Cline)
- configs: New config in sound/pci for v5.4-rc1 (Jeremy Cline)
- configs: New config in sound/soc for v5.4-rc1 (Jeremy Cline)
- gitlab: Add CI job for packaging scripts (Major Hayden)
- Speed up CI with CKI image (Major Hayden)
- Disable e1000 driver in ARK (Neil Horman)
- configs: Fix the pending default for CONFIG_ARM64_VA_BITS_52 (Jeremy Cline)
- configs: Turn on OPTIMIZE_INLINING for everything (Jeremy Cline)
- configs: Set valid pending defaults for CRYPTO_ESSIV (Jeremy Cline)
- Add an initial CI configuration for the internal branch (Jeremy Cline)
- New drop of configuration options for v5.4-rc1 (Jeremy Cline)
- New drop of configuration options for v5.4-rc1 (Jeremy Cline)
- Pull the RHEL version defines out of the Makefile (Jeremy Cline)
- Sync up the ARK build scripts (Jeremy Cline)
- Sync up the Fedora Rawhide configs (Jeremy Cline)
- Sync up the ARK config files (Jeremy Cline)
- configs: Adjust CONFIG_FORCE_MAX_ZONEORDER for Fedora (Laura Abbott)
- configs: Add README for some other arches (Laura Abbott)
- configs: Sync up Fedora configs (Laura Abbott)
- [initial commit] Add structure for building with git (Laura Abbott)
- [initial commit] Add Red Hat variables in the top level makefile (Laura Abbott)
- [initial commit] Red Hat gitignore and attributes (Laura Abbott)
- [initial commit] Add changelog (Laura Abbott)
- [initial commit] Add makefile (Laura Abbott)
- [initial commit] Add files for generating the kernel.spec (Laura Abbott)
- [initial commit] Add rpm directory (Laura Abbott)
- [initial commit] Add files for packaging (Laura Abbott)
- [initial commit] Add kabi files (Laura Abbott)
- [initial commit] Add scripts (Laura Abbott)
- [initial commit] Add configs (Laura Abbott)
- [initial commit] Add Makefiles (Laura Abbott)

# The following bit is important for automation so please do not remove
# END OF CHANGELOG

###
# The following Emacs magic makes C-c C-e use UTC dates.
# Local Variables:
# rpm-change-log-uses-utc: t
# End:
###
